<?php
/***************************************************************************
 *  					Theme Functions
 * 	----------------------------------------------------------------------
 * 						DO NOT EDIT THIS FILE
 *	----------------------------------------------------------------------
 *
 *  					Copyright (C) Themify
 * 						https://themify.me
 *
 *  To add custom PHP functions to the theme, create a child theme (https://themify.me/docs/child-theme) and add it to the child theme functions.php file.
 *  They will be added to the theme automatically.
 *
 ***************************************************************************/

/////// Actions ////////
// Enqueue scripts and styles required by theme
add_action( 'wp_enqueue_scripts', 'themify_theme_enqueue_scripts', 11 );

// Browser compatibility
add_action( 'wp_head', 'themify_viewport_tag' );

// Register custom menu
add_action( 'init', 'themify_register_custom_nav');

// Set post format according to custom field value
add_action( 'save_post', 'themify_theme_set_post_format', 20 );

// Register theme support, setup meta boxes
add_action( 'after_setup_theme', 'themify_theme_after_setup_theme' );

// Register sidebars
add_action( 'widgets_init', 'themify_theme_register_sidebars' );

// Exclude CPT for sidebar
add_filter( 'themify_exclude_CPT_for_sidebar', 'themify_CPT_exclude_sidebar' );

// Theme Action
add_action('themify_builder_override_loop_themify_vars', 'themify_theme_portfolio_builder_vars', 10, 2 );

// Output CSS styling for entry based on user setting
add_action( 'themify_post_end', 'themify_theme_custom_post_css' );

// Set class on body tag according to layout width
add_filter( 'body_class', 'themify_theme_body_class', 99 );

// Add format to RSS entries
add_filter( 'the_content', 'themify_theme_post_format_custom_fields' );

/**
 * Enqueue Stylesheets and Scripts
 * @since 1.0.0
 */
function themify_theme_enqueue_scripts() {
	global $wp_query;

	// Get theme version for Themify theme scripts and styles
	$theme_version = wp_get_theme()->display( 'Version' );

	///////////////////
	//Enqueue styles
	///////////////////

	// Themify base styling
	wp_enqueue_style( 'theme-style', themify_enque( THEME_URI . '/style.css' ), array(), $theme_version );

	// Themify Media Queries CSS
	wp_enqueue_style( 'themify-media-queries', themify_enque(THEME_URI . '/media-queries.css'), array(), $theme_version);

	// Themify child base styling
	if( is_child_theme() ) {
		wp_enqueue_style( 'theme-style-child', themify_enque( get_stylesheet_uri() ), array(), $theme_version );
	}

	///////////////////
	//Enqueue scripts
	///////////////////

	// Masonry layout
	wp_enqueue_script( 'themify-isotope', THEME_URI . '/js/jquery.isotope.min.js', array('jquery'), $theme_version, true );

	if ( is_home() || is_archive() || themify_is_query_page() || is_search() ) {
		// Infinite scroll
		wp_enqueue_script( 'infinitescroll', THEME_URI . '/js/jquery.infinitescroll.min.js', array('jquery'), false, true );
	}

	// Backstretch
	wp_register_script( 'themify-backstretch', themify_enque(THEMIFY_URI . '/js/backstretch.themify-version.js'), array( 'jquery' ), $theme_version, true );

	// Smart Resize for events debouncedresize and throttledresize
	wp_enqueue_script( 'themify-smartresize', THEME_URI.'/js/jquery.smartresize.min.js', array('jquery'), $theme_version, true );

	// Gallery plugin
	wp_register_script( 'themify-widegallery', themify_enque(THEME_URI . '/js/themify.widegallery.js'), array('jquery', 'themify-smartresize'), $theme_version, true );

	// Slide mobile navigation menu
	wp_enqueue_script( 'slide-nav', themify_enque(THEMIFY_URI . '/js/themify.sidemenu.js'), array( 'jquery' ), $theme_version, true );

	// Smooth scroll and scrollbar
	wp_enqueue_script( 'themify-nicescroll', THEME_URI . '/js/jquery.nicescroll.min.js', array( 'jquery' ), $theme_version, true );

	// Web fonts loader
	wp_enqueue_script( 'webfontsloader', '//ajax.googleapis.com/ajax/libs/webfont/1.4.7/webfont.js', null, '1.4.7' );

	// Themify internal scripts
	wp_enqueue_script( 'theme-script', themify_enque(THEME_URI . '/js/themify.script.js'), array('jquery'), $theme_version, true );

	// Prepare JS variables
	$themify_script_vars = array(
		'lightbox' => themify_lightbox_vars_init(),
		'lightboxContext' => apply_filters('themify_lightbox_context', '#pagewrap'),
		'expand' => '<i class="ti-angle-down" title="' . __( 'Expand', 'themify' ) . '"></i>',
		'collapse' => '<i class="ti-close" title="' . __( 'Collapse', 'themify' ) . '"></i>',
		'galleryFadeSpeed' => '300',
		'galleryEvent' => 'click',
		'loadingImg'   	=> THEME_URI . '/images/loading.gif',
		'maxPages'	   	=> $wp_query->max_num_pages,
		'autoInfinite' 	=> themify_check( 'setting-autoinfinite' ) ? 'no': 'auto',
		'infiniteURL' => themify_check( 'setting-infinite-url' ) ? 1 : 0,
		'scrollToNewOnLoad' => 'scroll',
		'resetFilterOnLoad' => 'reset',
	);

	// Inject variable values in gallery script
	wp_localize_script( 'theme-script', 'themifyScript', apply_filters('themify_script_vars', $themify_script_vars ) );

	// WordPress internal script to move the comment box to the right place when replying to a user
	if ( is_single() || is_page() ) wp_enqueue_script( 'comment-reply' );
}

/**
 * Load Google fonts used by the theme
 *
 * @return array
 */
function themify_theme_google_fonts( $fonts ) {
	/* translators: If there are characters in your language that are not supported by Roboto Condensed, translate this to 'off'. Do not translate into your own language. */
	if ( 'off' !== _x( 'on', 'Roboto Condensed font: on or off', 'themify' ) ) {
		$fonts['roboto-condensed'] = 'Roboto+Condensed:400,700';
	}
	/* translators: If there are characters in your language that are not supported by Roboto Slab, translate this to 'off'. Do not translate into your own language. */
	if ( 'off' !== _x( 'on', 'Roboto Slab font: on or off', 'themify' ) ) {
		$fonts['roboto-slab'] = 'Roboto+Slab:300';
	}
	/* translators: If there are characters in your language that are not supported by Roboto, translate this to 'off'. Do not translate into your own language. */
	if ( 'off' !== _x( 'on', 'Roboto font: on or off', 'themify' ) ) {
		$fonts['roboto'] = 'Roboto:400,300,500,700';
	}

	return $fonts;
}
add_filter( 'themify_google_fonts', 'themify_theme_google_fonts' );

/**
 * Add viewport tag for responsive layouts
 * @since 1.0.0
 */
function themify_viewport_tag(){
	echo "\n".'<meta name="viewport" content="width=device-width, initial-scale=1">'."\n";
}

if ( ! function_exists( 'themify_theme_after_setup_theme' ) ) {
	/**
	 * Register theme support.
	 *
	 * Initialize custom panel with its definitions.
	 * Custom panel definitions are located in admin/post-type-TYPE.php
	 *
	 * @since 1.0.7
	 */
	function themify_theme_after_setup_theme() {
		///////////////////////////////////////
		// Enable WordPress feature image
		///////////////////////////////////////
		add_theme_support( 'post-thumbnails' );

		///////////////////////////////////////
		// Post Formats
		///////////////////////////////////////
		add_theme_support( 'post-formats', array( 'quote', 'link', 'gallery', 'video', 'aside', 'audio', 'image' ) );
		if ( is_admin() ) {
			add_action( 'admin_menu', 'themify_theme_remove_formatdiv' );
		}

		///////////////////////////////////////
		// Build Write Panels
		///////////////////////////////////////

		// Load required files for post, page and custom post types where it applies
		foreach ( array( 'post', 'page', 'portfolio', 'product' ) as $type ) {
			require_once "admin/post-type-$type.php";
		}
		/**
		 * Navigation menus used in page custom panel to specify a custom menu for the page.
		 * @var array
		 * @since 1.2.7
		 */
		$nav_menus = array(	array( 'name' => '', 'value' => '', 'selected' => true ) );
		foreach ( get_terms( 'nav_menu' ) as $menu ) {
			$nav_menus[] = array( 'name' => $menu->name, 'value' => $menu->slug );
		}

		themify_build_write_panels( apply_filters('themify_theme_meta_boxes',
			array(
				array(
					'name'		=> __('Post Options', 'themify'),
					'id' 		=> 'post-options',
					'options'	=> themify_theme_post_meta_box(),
					'pages'		=> 'post'
				),
				array(
					'name'		=> __('Page Options', 'themify'),
					'id' 		=> 'page-options',
					'options'	=> themify_theme_page_meta_box( array( 'nav_menus' => $nav_menus ) ),
					'pages'		=> 'page'
				),
				array(
					'name'		=> __('Query Posts', 'themify'),
					'id'		=> 'query-posts',
					'options'	=> themify_theme_query_post_meta_box(),
					'pages'		=> 'page'
				),
				array(
					'name'		=> __('Query Portfolios', 'themify'),
					'id' 		=> 'query-portfolio',
					'options'	=> themify_theme_query_portfolio_meta_box(),
					'pages'		=> 'page'
				),
				array(
					'name'		=> __('Portfolio Options', 'themify'),
					'id' 		=> 'portfolio-options',
					'options' 	=> themify_theme_portfolio_meta_box(),
					'pages'		=> 'portfolio'
				),
			)
		));
	}
}

/**
 * Set post format according to custom field.
 *
 * @since 1.0.0
 *
 * @param $post_id
 */
function themify_theme_set_post_format( $post_id ) {
	if ( ! wp_is_post_revision( $post_id ) ) {
		set_post_format( $post_id, get_post_meta( $post_id, 'post_format', true ) );
	}
}

/**
 * Remove standard post format meta box.
 *
 * @since 1.0.0
 */
function themify_theme_remove_formatdiv() {
	remove_meta_box( 'formatdiv', 'post', 'normal' );
}

if ( ! function_exists( 'themify_theme_post_format_custom_fields' ) ) {
	/**
	 * Filter RSS Feed to include Custom Fields
	 *
	 * @param string $content Post content to filter.
	 *
	 * @return string $content Filtered content with custom fields included.
	 */
	function themify_theme_post_format_custom_fields( $content ) {
		global $themify_check;
		if ( ! is_feed() || $themify_check == true ) {
			return $content;
		}
		if ( has_post_format( 'image' ) && themify_check( 'post_image' ) ) {
			$content = "<img src='" . esc_url( themify_get( 'post_image' ) ) . "'><br>" . $content;
		} elseif ( has_post_format( 'quote' ) && themify_check( 'quote_author' ) ) {
			$content = '"' . $content . '" ' . esc_html( themify_get( 'quote_author' ) ) . sprintf( __( ' &mdash; %s', 'themify' ), "<a href='" . esc_url( themify_get( 'quote_author_link' ) ) . "'>" ) . esc_url( themify_get( 'quote_author_link' ) ) . "</a>";
		} elseif ( has_post_format( 'link' ) && themify_check( 'external_link' ) ) {
			$content .= "<a href='" . esc_url( themify_get( 'external_link' ) ) . "'>" . esc_url( themify_get( 'external_link' ) ) . "</a>";
		} elseif ( has_post_format( 'audio' ) && themify_check( 'audio_url' ) ) {
			$content = "<p><img src='" . esc_url( themify_get( 'post_image' ) ) . "'></p><br>" . $content;
			$content .= themify_get( 'audio_url' );
		} elseif ( has_post_format( 'video' ) && themify_check( 'video_url' ) ) {
			$themify_check = true;
			$content = apply_filters( 'the_content', themify_get( 'video_url' ) ) . $content;
		}
		$themify_check = false;

		return $content;
	}
}

/**
 * Register Custom Menu Function
 * @since 1.0.0
 */
function themify_register_custom_nav() {
	register_nav_menus( array(
		'main-nav' => __( 'Main Navigation', 'themify' ),
	));
}

/**
 * Default Main Nav Function
 * @since 1.0.0
 */
function themify_default_main_nav() {
	echo '<ul id="main-nav" class="main-nav clearfix">';
		wp_list_pages('title_li=');
	echo '</ul>';
}

/**
 * Sets custom menu selected in page custom panel as navigation, otherwise sets the default.
 *
 * @since 1.0.0
 */
function themify_theme_menu_nav() {
	$custom_menu = themify_get( 'custom_menu' );
	if ( isset( $custom_menu ) && '' != $custom_menu ) {
		wp_nav_menu( array( 'menu' => $custom_menu, 'fallback_cb' => 'themify_default_main_nav' , 'container'  => '' , 'menu_id' => 'main-nav' , 'menu_class' => 'main-nav clearfix' ) );
	} else {
		wp_nav_menu( array( 'theme_location' => 'main-nav' , 'fallback_cb' => 'themify_default_main_nav' , 'container'  => '' , 'menu_id' => 'main-nav' , 'menu_class' => 'main-nav clearfix' ) );
	}
}

/**
 * Checks if the browser is a mobile device
 * @return boolean
 */
function themify_is_mobile(){
	return preg_match("/(android|avantgo|blackberry|bolt|boost|cricket|docomo|fone|hiptop|mini|mobi|palm|phone|pie|tablet|up\.browser|up\.link|webos|wos)/i", $_SERVER["HTTP_USER_AGENT"]);
}

/**
 * Register sidebars
 * @since 1.0.0
 */
function themify_theme_register_sidebars() {
	$sidebars = array(
		array(
			'name' => __('Sidebar', 'themify'),
			'id' => 'sidebar-main',
			'before_widget' => '<div id="%1$s" class="widget %2$s">',
			'after_widget' => '</div>',
			'before_title' => '<h4 class="widgettitle">',
			'after_title' => '</h4>',
		),
		array(
			'name' => __('Social Widget', 'themify'),
			'id' => 'social-widget',
			'before_widget' => '<div id="%1$s" class="widget %2$s">',
			'after_widget' => '</div>',
			'before_title' => '<strong class="widgettitle">',
			'after_title' => '</strong>',
		),
		array(
			'name' => __('Header Widget', 'themify'),
			'id' => 'header-widget',
			'before_widget' => '<div id="%1$s" class="widget %2$s">',
			'after_widget' => '</div>',
			'before_title' => '<strong class="widgettitle">',
			'after_title' => '</strong>',
		),
	);
	foreach( $sidebars as $sidebar ) {
		register_sidebar( $sidebar );
	}

	// Footer Sidebars
	themify_register_grouped_widgets();
}

if ( ! function_exists( 'themify_theme_custom_post_css' ) ) {
	/**
	 * Outputs custom post CSS at the end of a post
	 * @since 1.0.0
	 */
	function themify_theme_custom_post_css() {
		global $themify;
		$post_id = get_the_ID();
		if ( in_array( get_post_type( $post_id ), array( 'post', 'portfolio' ) ) ) {
			$css = array();
			$style = '';
			$rules = array();

			if ( ! is_single() ) {
				$entry_id = '.post-' . $post_id;
				$entry = $entry_id . '.post';
				$rules = array(
					$entry => array(
						array(
							'prop' => 'background-color',
							'key'  => 'background_color'
						),
						array(
							'prop' => 'background-image',
							'key'  => 'background_image'
						),
						array(
							'prop' => 'background-repeat',
							'key'  => 'background_repeat',
							'dependson' => array(
								'prop' => 'background-image',
								'key'  => 'background_image'
							),
						),
						array(
							'prop' => 'color',
							'key'  => 'text_color'
						),
					),
					"$entry a" => array(
						array(
							'prop' => 'color',
							'key'  => 'link_color'
						),
					),
				);
			}

			foreach ( $rules as $selector => $property ) {
				foreach ( $property as $val ) {
					$prop = $val['prop'];
					$key = $val['key'];
					if ( is_array( $key ) ) {
						if ( $prop == 'font-size' && themify_check( $key[0] ) ) {
							$css[$selector][$prop] = $prop . ': ' . themify_get( $key[0] ) . themify_get( $key[1] );
						}
					} elseif ( themify_check( $key ) && 'default' != themify_get( $key ) ) {
						if ( $prop == 'color' || stripos( $prop, 'color' ) ) {
							$css[$selector][$prop] = $prop . ': ' . themify_get_color( $key );
						}
						elseif ( $prop == 'background-image' && 'default' != themify_get( $key ) ) {
							$css[$selector][$prop] = $prop .': url(' . themify_get( $key ) . ')';
						}
						elseif ( $prop == 'background-repeat' && 'fullcover' == themify_get( $key ) ) {
							if ( isset( $val['dependson'] ) ) {
								if ( $val['dependson']['prop'] == 'background-image' && ( themify_check( $val['dependson']['key'] ) && 'default' != themify_get( $val['dependson']['key'] ) ) ) {
									$css[$selector]['background-size'] = 'background-size: cover';
								}
							} else {
								$css[$selector]['background-size'] = 'background-size: cover';
							}
						}
						elseif ( $prop == 'font-family' ) {
							$font = themify_get( $key );
							$css[$selector][$prop] = $prop .': '. $font;
							if ( ! in_array( $font, themify_get_web_safe_font_list( true ) ) ) {
								$themify->google_fonts .= str_replace( ' ', '+', $font.'|' );
							}
						}
						else {
							$css[$selector][$prop] = $prop .': '. themify_get( $key );
						}
					}
				}
				if ( ! empty( $css[$selector] ) ) {
					$style .= "$selector {\n\t" . implode( ";\n\t", $css[$selector] ) . "\n}\n";
				}
			}

			if ( '' != $style ) {
				echo "\n<!-- Entry Style -->\n<style>\n$style</style>\n<!-- End Entry Style -->\n";
			}
		}
	}
}

if ( ! function_exists( 'themify_theme_enqueue_google_fonts' ) ) {
	/**
	 * Enqueue Google Fonts
	 * @since 1.0.0
	 */
	function themify_theme_enqueue_google_fonts() {
		global $themify;
		if ( ! isset( $themify->google_fonts ) || '' == $themify->google_fonts ) return;
		$themify->google_fonts = substr( $themify->google_fonts, 0, -1 );
		wp_enqueue_style( 'section-styling-google-fonts', themify_https_esc( 'http://fonts.googleapis.com/css' ). '?family='.$themify->google_fonts );
	}
	add_action( 'wp_footer', 'themify_theme_enqueue_google_fonts' );
}

if( ! function_exists('themify_CPT_exclude_sidebar') ) {
	/**
	 * Exclude Custom Post Types
	 */
	function themify_CPT_exclude_sidebar($CPT = array()) {
		
		$stack = array('portfolio');
		
		if(empty($CPT)){
			$CPT = array('post', 'page', 'attachment', 'tbuilder_layout', 'tbuilder_layout_part', 'section');
		}

		$CPT = array_merge($CPT, $stack);

		return $CPT;
	}
}

if ( ! function_exists('themify_theme_comment') ) {
	/**
	 * Custom Theme Comment
	 * @param object $comment Current comment.
	 * @param array $args Parameters for comment reply link.
	 * @param int $depth Maximum comment nesting depth.
	 * @since 1.0.0
	 */
	function themify_theme_comment( $comment, $args, $depth ) {
	   $GLOBALS['comment'] = $comment; ?>

		<li id="comment-<?php comment_ID() ?>">
			<p class="comment-author">
				<?php printf( '%s <cite>%s</cite>', get_avatar( $comment, $size='48' ), get_comment_author_link() ); ?>
				<br />
				<small class="comment-time">
					<?php comment_date( apply_filters('themify_comment_date', '') ); ?>
					 @
					<?php comment_time( apply_filters('themify_comment_time', '') ); ?>
					<?php edit_comment_link( __('Edit', 'themify' ),' [',']' ); ?>
				</small>
			</p>
			<div class="commententry">
				<?php if ( '0' == $comment->comment_approved ) : ?>
					<p><em><?php _e( 'Your comment is awaiting moderation.', 'themify' ); ?></em></p>
				<?php endif; ?>
				<?php comment_text(); ?>
			</div>
			<p class="reply">
				<?php comment_reply_link( array_merge( $args, array( 'add_below' => 'comment', 'depth' => $depth, 'reply_text' => __( 'Reply', 'themify' ), 'max_depth' => $args['max_depth'] ) ) ) ?>
			</p>
		<?php
	}
}

if ( ! function_exists( 'themify_theme_featured_area_style' ) ) {
	/**
	 * Returns the background repeat style as a class.
	 *
	 * @return mixed|string
	 */
	function themify_theme_featured_area_style() {
		return themify_check( 'background_repeat' ) ? themify_get( 'background_repeat' ) : '';
	}
}

/**
 * Adds body classes for special theme features.
 *
 * @param $args
 *
 * @return array
 */
function themify_theme_body_class( $classes ) {
	// Checks if the single post or page has default or full width.
	$classes[] = themify_check( 'content_width' ) ? themify_get( 'content_width' ) : 'default_width';

	// Add transparent-header class to body if user selected it in custom panel
	if ( ( is_single() || is_page() ) && 'transparent' == themify_get( 'header_wrap' ) ) {
		$classes[] = 'transparent-header';
	}
	// Check if masonry is enabled
	$classes[] = themify_theme_is_masonry_enabled();

	return $classes;
}

/**
 * Checks if masonry is enabled in this query page or in the default index layout settings.
 *
 * @since 1.0.0
 *
 * @return string
 */
function themify_theme_is_masonry_enabled() {
	$do_masonry = '';
	$post_type = '';
	if ( themify_is_query_page() ) {
		global $themify;
		if ( isset($themify->query_post_type) && !in_array( $themify->query_post_type, array( 'post', 'page' ) ) ) {
			$post_type = $themify->query_post_type . '_';
		}
		$enable_masonry = themify_get( $post_type . 'enable_masonry' );
		if ( 'yes' == $enable_masonry ) {
			$do_masonry = 'masonry-enabled';
		} elseif ( 'default' == $enable_masonry || '' == $enable_masonry ) {
			if ( 'no' != themify_get( 'setting-' . $post_type . 'disable_masonry' ) ) {
				$do_masonry = 'masonry-enabled';
			}
		}
	} else {
		if ( ! is_search() ) {
			$post_type = 'post' == get_post_type() ? '' : get_post_type() . '_';
		}
		if ( 'no' != themify_get( 'setting-' . $post_type . 'disable_masonry' ) ) {
			$do_masonry = 'masonry-enabled';
		}
	}
	return $do_masonry;
}

/**
 * Check if portfolio in builder_loop
 * Passed parameter to $themify object
 * @param object $themify
 * @param string $module_name
 */
function themify_theme_portfolio_builder_vars( $themify, $module_name ) {
	if ( 'portfolio' == $module_name ) {
		$themify->is_builder_portfolio_loop = true;
	}
}

/**
 * Load Tiles add-on for Builder.
 */
if( ! class_exists( 'Builder_Tiles' ) ) :
	define( 'BUILDER_TILES_URL', THEME_URI . '/builder-tiles/' );
	define( 'BUILDER_TILES_DIR', THEME_DIR . '/builder-tiles/' );

	add_filter( 'override_load_textdomain', 'themify_override_builder_tiles_textdomain', 5, 2 );

	locate_template( 'builder-tiles/init.php', true );
endif;

/**
 * Use theme's text domain for Builder Tiles strings.
 *
 * @param $plugin_override
 * @param $domain
 *
 * @return bool
 */
function themify_override_builder_tiles_textdomain( $plugin_override, $domain ) {
	if ( 'builder-tiles' === $domain ) {
		global $l10n;
		if ( isset( $l10n['themify'] ) ) {
			$l10n[$domain] = $l10n['themify'];
			return true;
		}
	}
	return $plugin_override;
}

if ( ! function_exists( '_wp_render_title_tag' ) ) {
	/**
	 * Fallback to render title before WP 4.1
	 *
	 * @since 1.0.4
	 */
	function themify_theme_render_title() { ?>
		<title><?php wp_title(); ?></title>
	<?php
	}
	// Fallback WP Title
	add_action( 'wp_head', 'themify_theme_render_title' );
} else {
	// Add Title Tag support
	add_theme_support( 'title-tag' );
	/**
	 * Remove last part of title to keep the traditional Themify theme title.
	 *
	 * @since 1.0.4
	 *
	 * @param string $title
	 *
	 * @return string
	 */
	function themify_theme_title_tag( $title ) {
		if ( ! is_front_page() ) {
			$title = str_replace( get_bloginfo( 'name' ), '', $title );
		}
		return $title;
	}
	// Generate title
	add_filter( 'wp_title', 'themify_theme_title_tag', 10 );
}

/** Compatibility with portfolio posts plugin */
define( 'THEMIFY_PORTFOLIO_POSTS_COMPAT_MODE', true );

/**
 * Register plugins required for the theme
 *
 * @since 1.0.0
 */
function themify_theme_register_required_plugins( $plugins ) {
	$plugins[] = array(
		'name'               => __( 'Themify Portfolio Posts', 'themify' ),
		'slug'               => 'themify-portfolio-post',
		'source'             => 'https://themify.me/files/themify-portfolio-post/themify-portfolio-post.zip',
		'required'           => true,
		'version'            => '1.0.0',
		'force_activation'   => false,
		'force_deactivation' => false,
	);
	return $plugins;
}
add_filter( 'themify_theme_required_plugins', 'themify_theme_register_required_plugins' );

/**
 * Set portfolio post type slug
 *
 * @since 1.1.0
 * @return string
 */
function themify_theme_portfolio_post_rewrite( $id ) {
	$slug = themify_get( 'themify_portfolio_slug' );
	return empty( $slug ) ? apply_filters( 'themify_portfolio_rewrite', 'project' ) : $slug;
}
add_filter( 'themify_portfolio_post_rewrite', 'themify_theme_portfolio_post_rewrite' );

// Portfolio comments filter
function portfolio_comments_open( $open, $post_id ) {
	$post = get_post( $post_id );
	! empty( $post ) && 'portfolio' == $post->post_type
		&& themify_check( 'setting-portfolio_comments' ) && ( $open = true );
	return $open;
}
add_filter( 'comments_open', 'portfolio_comments_open', 10, 2 );