<?php

defined( 'ABSPATH' ) or die;

$GLOBALS['processed_terms'] = array();
$GLOBALS['processed_posts'] = array();

require_once ABSPATH . 'wp-admin/includes/post.php';
require_once ABSPATH . 'wp-admin/includes/taxonomy.php';
require_once ABSPATH . 'wp-admin/includes/image.php';

/**
 * Add an Import Action, this data is stored for processing after import is done.
 *
 * Each action is sent as an Ajax request and is handled by themify-ajax.php file
 */ 
function themify_add_import_action( $action = '', $data = array() ) {
	global $import_actions;

	if ( ! isset( $import_actions[ $action ] ) ) {
		$import_actions[ $action ] = array();
	}

	$import_actions[ $action ][] = $data;
}

function themify_import_post( $post ) {
	global $processed_posts, $processed_terms;

	if ( ! post_type_exists( $post['post_type'] ) ) {
		return;
	}

	/* Menu items don't have reliable post_title, skip the post_exists check */
	if( $post['post_type'] !== 'nav_menu_item' ) {
		$post_exists = post_exists( $post['post_title'], '', $post['post_date'] );
		if ( $post_exists && get_post_type( $post_exists ) == $post['post_type'] ) {
			$processed_posts[ intval( $post['ID'] ) ] = intval( $post_exists );
			return;
		}
	}

	if( $post['post_type'] == 'nav_menu_item' ) {
		if( ! isset( $post['tax_input']['nav_menu'] ) || ! term_exists( $post['tax_input']['nav_menu'], 'nav_menu' ) ) {
			return;
		}
		$_menu_item_type = $post['meta_input']['_menu_item_type'];
		$_menu_item_object_id = $post['meta_input']['_menu_item_object_id'];

		if ( 'taxonomy' == $_menu_item_type && isset( $processed_terms[ intval( $_menu_item_object_id ) ] ) ) {
			$post['meta_input']['_menu_item_object_id'] = $processed_terms[ intval( $_menu_item_object_id ) ];
		} else if ( 'post_type' == $_menu_item_type && isset( $processed_posts[ intval( $_menu_item_object_id ) ] ) ) {
			$post['meta_input']['_menu_item_object_id'] = $processed_posts[ intval( $_menu_item_object_id ) ];
		} else if ( 'custom' != $_menu_item_type ) {
			// associated object is missing or not imported yet, we'll retry later
			// $missing_menu_items[] = $item;
			return;
		}
	}

	$post_parent = ( $post['post_type'] == 'nav_menu_item' ) ? $post['meta_input']['_menu_item_menu_item_parent'] : (int) $post['post_parent'];
	$post['post_parent'] = 0;
	if ( $post_parent ) {
		// if we already know the parent, map it to the new local ID
		if ( isset( $processed_posts[ $post_parent ] ) ) {
			if( $post['post_type'] == 'nav_menu_item' ) {
				$post['meta_input']['_menu_item_menu_item_parent'] = $processed_posts[ $post_parent ];
			} else {
				$post['post_parent'] = $processed_posts[ $post_parent ];
			}
		}
	}

	/**
	 * for hierarchical taxonomies, IDs must be used so wp_set_post_terms can function properly
	 * convert term slugs to IDs for hierarchical taxonomies
	 */
	if( ! empty( $post['tax_input'] ) ) {
		foreach( $post['tax_input'] as $tax => $terms ) {
			if( is_taxonomy_hierarchical( $tax ) ) {
				$terms = explode( ', ', $terms );
				$post['tax_input'][ $tax ] = array_map( 'themify_get_term_id_by_slug', $terms, array_fill( 0, count( $terms ), $tax ) );
			}
		}
	}

	$post['post_author'] = (int) get_current_user_id();
	$post['post_status'] = 'publish';

	$old_id = $post['ID'];

	unset( $post['ID'] );
	$post_id = wp_insert_post( $post, true );
	if( is_wp_error( $post_id ) ) {
		return false;
	} else {
		$processed_posts[ $old_id ] = $post_id;

		return $post_id;
	}
}

function themify_get_placeholder_image() {
	static $placeholder_image = null;

	if( $placeholder_image == null ) {
		if ( ! function_exists( 'WP_Filesystem' ) ) {
			require_once ABSPATH . 'wp-admin/includes/file.php';
		}
		WP_Filesystem();
		global $wp_filesystem;
		$upload = wp_upload_bits( $post['post_name'] . '.jpg', null, $wp_filesystem->get_contents( THEMIFY_DIR . '/img/image-placeholder.jpg' ) );

		if ( $info = wp_check_filetype( $upload['file'] ) )
			$post['post_mime_type'] = $info['type'];
		else
			return new WP_Error( 'attachment_processing_error', __( 'Invalid file type', 'themify' ) );

		$post['guid'] = $upload['url'];
		$post_id = wp_insert_attachment( $post, $upload['file'] );
		wp_update_attachment_metadata( $post_id, wp_generate_attachment_metadata( $post_id, $upload['file'] ) );

		$placeholder_image = $post_id;
	}

	return $placeholder_image;
}

function themify_import_term( $term ) {
	global $processed_terms;

	if( $term_id = term_exists( $term['slug'], $term['taxonomy'] ) ) {
		if ( is_array( $term_id ) ) $term_id = $term_id['term_id'];
		if ( isset( $term['term_id'] ) )
			$processed_terms[ intval( $term['term_id'] ) ] = (int) $term_id;
		return (int) $term_id;
	}

	if ( empty( $term['parent'] ) ) {
		$parent = 0;
	} else {
		$parent = term_exists( $processed_terms[ intval( $term['parent'] ) ], $term['taxonomy'] );
		if ( is_array( $parent ) ) $parent = $parent['term_id'];
	}

	$id = wp_insert_term( $term['name'], $term['taxonomy'], array(
		'parent' => $parent,
		'slug' => $term['slug'],
		'description' => $term['description'],
	) );
	if ( ! is_wp_error( $id ) ) {
		if ( isset( $term['term_id'] ) ) {
			// success!
			$processed_terms[ intval($term['term_id']) ] = $id['term_id'];
			if ( isset( $term['thumbnail'] ) ) {
				themify_add_import_action( 'term_thumb', array(
					'id' => $id['term_id'],
					'thumb' => $term['thumbnail'],
				) );
			}
			return $term['term_id'];
		}
	}

	return false;
}

function themify_get_term_id_by_slug( $slug, $tax ) {
	$term = get_term_by( 'slug', $slug, $tax );
	if( $term ) {
		return $term->term_id;
	}

	return false;
}

function themify_undo_import_term( $term ) {
	$term_id = term_exists( $term['slug'], $term['taxonomy'] );
	if ( $term_id ) {
		if ( is_array( $term_id ) ) $term_id = $term_id['term_id'];

		if ( $term_thumbnail = get_term_meta( $term['term_id'], 'thumbnail_id', true ) ) {
			wp_delete_attachment( $term_thumbnail, true );
		}

		if ( isset( $term_id ) ) {
			wp_delete_term( $term_id, $term['taxonomy'] );
		}
	}
}

/**
 * Determine if a post exists based on title, content, and date
 *
 * @global wpdb $wpdb WordPress database abstraction object.
 *
 * @param array $args array of database parameters to check
 * @return int Post ID if post exists, 0 otherwise.
 */
function themify_post_exists( $args = array() ) {
	global $wpdb;

	$query = "SELECT ID FROM $wpdb->posts WHERE 1=1";
	$db_args = array();

	foreach ( $args as $key => $value ) {
		$value = wp_unslash( sanitize_post_field( $key, $value, 0, 'db' ) );
		if( ! empty( $value ) ) {
			$query .= ' AND ' . $key . ' = %s';
			$db_args[] = $value;
		}
	}

	if ( !empty ( $args ) )
		return (int) $wpdb->get_var( $wpdb->prepare($query, $args) );

	return 0;
}

function themify_undo_import_post( $post ) {
	if( $post['post_type'] == 'nav_menu_item' ) {
		$post_exists = themify_post_exists( array(
			'post_name' => $post['post_name'],
			'post_modified' => $post['post_date'],
			'post_type' => 'nav_menu_item',
		) );
	} else {
		$post_exists = post_exists( $post['post_title'], '', $post['post_date'] );
	}
	if( $post_exists && get_post_type( $post_exists ) == $post['post_type'] ) {
		/**
		 * check if the post has been modified, if so leave it be
		 *
		 * NOTE: posts are imported using wp_insert_post() which modifies post_modified field
		 * to be the same as post_date, hence to check if the post has been modified,
		 * the post_modified field is compared against post_date in the original post.
		 */
		if( $post['post_date'] == get_post_field( 'post_modified', $post_exists ) ) {
			// find and remove all post attachments
			$attachments = get_posts( array(
				'post_type' => 'attachment',
				'posts_per_page' => -1,
				'post_parent' => $post_exists,
			) );
			if ( $attachments ) {
				foreach ( $attachments as $attachment ) {
					wp_delete_attachment( $attachment->ID, true );
				}
			}
			wp_delete_post( $post_exists, true ); // true: bypass trash
		}
	}
}

function themify_process_post_import( $post ) {
	if( ERASEDEMO ) {
		themify_undo_import_post( $post );
	} else {
		if ( $id = themify_import_post( $post ) ) {
			if ( defined( 'IMPORT_IMAGES' ) && ! IMPORT_IMAGES ) {
				/* if importing images is disabled and post is supposed to have a thumbnail, create a placeholder image instead */
				if ( isset( $post['thumb'] ) ) { // the post is supposed to have featured image
					$placeholder = themify_get_placeholder_image();
					if( ! is_wp_error( $placeholder ) ) {
						set_post_thumbnail( $id, $placeholder );
					}
				}
			} else {
				if ( isset( $post["thumb"] ) ) {
					themify_add_import_action( 'post_thumb', array(
						'id' => $id,
						'thumb' => $post["thumb"],
					) );
				}
				if ( isset( $post["gallery_shortcode"] ) ) {
					themify_add_import_action( 'gallery_field', array(
						'id' => $id,
						'fields' => $post["gallery_shortcode"],
					) );
				}
			}
		}
	}
}
$thumbs = array();
function themify_do_demo_import() {
global $import_actions;

	if ( isset( $GLOBALS["ThemifyBuilder_Data_Manager"] ) ) {
		remove_action( "save_post", array( $GLOBALS["ThemifyBuilder_Data_Manager"], "save_builder_text_only"), 10, 3 );
	}
$term = array (
  'term_id' => 4,
  'name' => 'Video',
  'slug' => 'video',
  'term_group' => 0,
  'taxonomy' => 'category',
  'description' => '',
  'parent' => 0,
);

if( ERASEDEMO ) {
	themify_undo_import_term( $term );
} else {
	themify_import_term( $term );
}

$term = array (
  'term_id' => 5,
  'name' => 'Image',
  'slug' => 'image',
  'term_group' => 0,
  'taxonomy' => 'category',
  'description' => '',
  'parent' => 0,
);

if( ERASEDEMO ) {
	themify_undo_import_term( $term );
} else {
	themify_import_term( $term );
}

$term = array (
  'term_id' => 7,
  'name' => 'Gallery',
  'slug' => 'gallery',
  'term_group' => 0,
  'taxonomy' => 'category',
  'description' => '',
  'parent' => 0,
);

if( ERASEDEMO ) {
	themify_undo_import_term( $term );
} else {
	themify_import_term( $term );
}

$term = array (
  'term_id' => 9,
  'name' => 'Quote',
  'slug' => 'quote',
  'term_group' => 0,
  'taxonomy' => 'category',
  'description' => '',
  'parent' => 0,
);

if( ERASEDEMO ) {
	themify_undo_import_term( $term );
} else {
	themify_import_term( $term );
}

$term = array (
  'term_id' => 10,
  'name' => 'Audio',
  'slug' => 'audio',
  'term_group' => 0,
  'taxonomy' => 'category',
  'description' => '',
  'parent' => 0,
);

if( ERASEDEMO ) {
	themify_undo_import_term( $term );
} else {
	themify_import_term( $term );
}

$term = array (
  'term_id' => 13,
  'name' => 'Link',
  'slug' => 'link',
  'term_group' => 0,
  'taxonomy' => 'category',
  'description' => '',
  'parent' => 0,
);

if( ERASEDEMO ) {
	themify_undo_import_term( $term );
} else {
	themify_import_term( $term );
}

$term = array (
  'term_id' => 15,
  'name' => 'Aside',
  'slug' => 'aside',
  'term_group' => 0,
  'taxonomy' => 'category',
  'description' => '',
  'parent' => 0,
);

if( ERASEDEMO ) {
	themify_undo_import_term( $term );
} else {
	themify_import_term( $term );
}

$term = array (
  'term_id' => 21,
  'name' => 'Blog',
  'slug' => 'blog',
  'term_group' => 0,
  'taxonomy' => 'category',
  'description' => '',
  'parent' => 0,
);

if( ERASEDEMO ) {
	themify_undo_import_term( $term );
} else {
	themify_import_term( $term );
}

$term = array (
  'term_id' => 27,
  'name' => 'Games',
  'slug' => 'games',
  'term_group' => 0,
  'taxonomy' => 'product_cat',
  'description' => '',
  'parent' => 0,
);

if( ERASEDEMO ) {
	themify_undo_import_term( $term );
} else {
	themify_import_term( $term );
}

$term = array (
  'term_id' => 36,
  'name' => 'Tshirts',
  'slug' => 'tshirts',
  'term_group' => 0,
  'taxonomy' => 'product_cat',
  'description' => '',
  'parent' => 0,
);

if( ERASEDEMO ) {
	themify_undo_import_term( $term );
} else {
	themify_import_term( $term );
}

$term = array (
  'term_id' => 37,
  'name' => 'Shoes',
  'slug' => 'shoes',
  'term_group' => 0,
  'taxonomy' => 'product_cat',
  'description' => '',
  'parent' => 0,
);

if( ERASEDEMO ) {
	themify_undo_import_term( $term );
} else {
	themify_import_term( $term );
}

$term = array (
  'term_id' => 38,
  'name' => 'Jacket',
  'slug' => 'jacket',
  'term_group' => 0,
  'taxonomy' => 'product_cat',
  'description' => '',
  'parent' => 0,
);

if( ERASEDEMO ) {
	themify_undo_import_term( $term );
} else {
	themify_import_term( $term );
}

$term = array (
  'term_id' => 41,
  'name' => 'Men',
  'slug' => 'men',
  'term_group' => 0,
  'taxonomy' => 'product_cat',
  'description' => '',
  'parent' => 0,
);

if( ERASEDEMO ) {
	themify_undo_import_term( $term );
} else {
	themify_import_term( $term );
}

$term = array (
  'term_id' => 42,
  'name' => 'Women',
  'slug' => 'women',
  'term_group' => 0,
  'taxonomy' => 'product_cat',
  'description' => '',
  'parent' => 0,
);

if( ERASEDEMO ) {
	themify_undo_import_term( $term );
} else {
	themify_import_term( $term );
}

$term = array (
  'term_id' => 28,
  'name' => 'Blue',
  'slug' => 'blue',
  'term_group' => 0,
  'taxonomy' => 'pa_color',
  'description' => '',
  'parent' => 0,
);

if( ERASEDEMO ) {
	themify_undo_import_term( $term );
} else {
	themify_import_term( $term );
}

$term = array (
  'term_id' => 29,
  'name' => 'Gray',
  'slug' => 'gray',
  'term_group' => 0,
  'taxonomy' => 'pa_color',
  'description' => '',
  'parent' => 0,
);

if( ERASEDEMO ) {
	themify_undo_import_term( $term );
} else {
	themify_import_term( $term );
}

$term = array (
  'term_id' => 30,
  'name' => 'Green',
  'slug' => 'green',
  'term_group' => 0,
  'taxonomy' => 'pa_color',
  'description' => '',
  'parent' => 0,
);

if( ERASEDEMO ) {
	themify_undo_import_term( $term );
} else {
	themify_import_term( $term );
}

$term = array (
  'term_id' => 35,
  'name' => 'Yellow',
  'slug' => 'yellow',
  'term_group' => 0,
  'taxonomy' => 'pa_color',
  'description' => '',
  'parent' => 0,
);

if( ERASEDEMO ) {
	themify_undo_import_term( $term );
} else {
	themify_import_term( $term );
}

$term = array (
  'term_id' => 32,
  'name' => 'Large',
  'slug' => 'large',
  'term_group' => 0,
  'taxonomy' => 'pa_size',
  'description' => '',
  'parent' => 0,
);

if( ERASEDEMO ) {
	themify_undo_import_term( $term );
} else {
	themify_import_term( $term );
}

$term = array (
  'term_id' => 33,
  'name' => 'Medium',
  'slug' => 'medium',
  'term_group' => 0,
  'taxonomy' => 'pa_size',
  'description' => '',
  'parent' => 0,
);

if( ERASEDEMO ) {
	themify_undo_import_term( $term );
} else {
	themify_import_term( $term );
}

$term = array (
  'term_id' => 34,
  'name' => 'Small',
  'slug' => 'small',
  'term_group' => 0,
  'taxonomy' => 'pa_size',
  'description' => '',
  'parent' => 0,
);

if( ERASEDEMO ) {
	themify_undo_import_term( $term );
} else {
	themify_import_term( $term );
}

$term = array (
  'term_id' => 16,
  'name' => 'Design',
  'slug' => 'design',
  'term_group' => 0,
  'taxonomy' => 'portfolio-category',
  'description' => '',
  'parent' => 0,
);

if( ERASEDEMO ) {
	themify_undo_import_term( $term );
} else {
	themify_import_term( $term );
}

$term = array (
  'term_id' => 18,
  'name' => 'Photography',
  'slug' => 'photography',
  'term_group' => 0,
  'taxonomy' => 'portfolio-category',
  'description' => '',
  'parent' => 0,
);

if( ERASEDEMO ) {
	themify_undo_import_term( $term );
} else {
	themify_import_term( $term );
}

$term = array (
  'term_id' => 19,
  'name' => 'Fashion',
  'slug' => 'fashion',
  'term_group' => 0,
  'taxonomy' => 'portfolio-category',
  'description' => '',
  'parent' => 0,
);

if( ERASEDEMO ) {
	themify_undo_import_term( $term );
} else {
	themify_import_term( $term );
}

$term = array (
  'term_id' => 22,
  'name' => 'Main Nav',
  'slug' => 'main-nav',
  'term_group' => 0,
  'taxonomy' => 'nav_menu',
  'description' => '',
  'parent' => 0,
);

if( ERASEDEMO ) {
	themify_undo_import_term( $term );
} else {
	themify_import_term( $term );
}

$term = array (
  'term_id' => 40,
  'name' => 'Main Navigation',
  'slug' => 'main-navigation',
  'term_group' => 0,
  'taxonomy' => 'nav_menu',
  'description' => '',
  'parent' => 0,
);

if( ERASEDEMO ) {
	themify_undo_import_term( $term );
} else {
	themify_import_term( $term );
}

$post = array (
  'ID' => 2353,
  'post_date' => '2014-08-23 19:45:07',
  'post_date_gmt' => '2014-08-23 19:45:07',
  'post_content' => 'Aenean sagittis lorem purus, in fringilla quam bibendum quis. <!--more-->

Fusce maximus est eu nisl commodo, quis luctus neque condimentum. Proin non orci rhoncus, eleifend turpis id, auctor orci. Praesent ut augue in augue efficitur cursus vel eu diam. Sed ornare diam in luctus pretium. Donec volutpat tellus ac odio posuere dignissim. Sed et libero malesuada, varius lectus nec, sodales felis. Proin fermentum massa nec lacinia sollicitudin. Etiam varius nec metus vel mollis. Praesent at urna purus. Sed tempor ligula a enim feugiat, id lobortis massa volutpat. Integer fringilla at ante eget vehicula. Etiam elit velit, facilisis ac enim a, ultrices faucibus mi.

&nbsp;',
  'post_title' => 'Breakfast of Champions',
  'post_excerpt' => '',
  'post_name' => 'breakfast-champions',
  'post_modified' => '2017-08-21 07:27:00',
  'post_modified_gmt' => '2017-08-21 07:27:00',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/stack/?p=2353',
  'menu_order' => 0,
  'post_type' => 'post',
  'meta_input' => 
  array (
    'content_width' => 'default_width',
    'layout' => 'default',
    'post_format' => 'image',
    'gallery_autoplay' => '4000',
    'gallery_transition' => '1000',
    'hide_post_title' => 'default',
    'unlink_post_title' => 'default',
    'hide_post_date' => 'default',
    'hide_post_image' => 'default',
    'unlink_post_image' => 'default',
    'builder_switch_frontend' => '0',
  ),
  'tax_input' => 
  array (
    'category' => 'image',
    'post_format' => 'post-format-image',
  ),
  'thumb' => 'https://themify.me/demo/themes/stack/files/2014/12/188434373.jpg',
);
themify_process_post_import( $post );


$post = array (
  'ID' => 2358,
  'post_date' => '2014-01-11 19:47:12',
  'post_date_gmt' => '2014-01-11 19:47:12',
  'post_content' => 'Duis at felis ut risus egestas mattis vel non elit. Maecenas dapibus urna eu eros malesuada auctor. Mauris ligula ante, consequat sit amet pretium et, dapibus non nunc.<!--more-->

Fusce maximus est eu nisl commodo, quis luctus neque condimentum. Proin non orci rhoncus, eleifend turpis id, auctor orci. Praesent ut augue in augue efficitur cursus vel eu diam. Sed ornare diam in luctus pretium. Donec volutpat tellus ac odio posuere dignissim. Sed et libero malesuada, varius lectus nec, sodales felis. Proin fermentum massa nec lacinia sollicitudin. Etiam varius nec metus vel mollis. Praesent at urna purus. Sed tempor ligula a enim feugiat, id lobortis massa volutpat. Integer fringilla at ante eget vehicula. Etiam elit velit, facilisis ac enim a, ultrices faucibus mi.

&nbsp;',
  'post_title' => 'Image Post Type',
  'post_excerpt' => '',
  'post_name' => 'image-post-type',
  'post_modified' => '2017-08-21 07:27:22',
  'post_modified_gmt' => '2017-08-21 07:27:22',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/stack/?p=2358',
  'menu_order' => 0,
  'post_type' => 'post',
  'meta_input' => 
  array (
    'content_width' => 'default_width',
    'layout' => 'default',
    'post_format' => 'image',
    'gallery_autoplay' => '4000',
    'gallery_transition' => '1000',
    'hide_post_title' => 'default',
    'unlink_post_title' => 'default',
    'hide_post_date' => 'default',
    'hide_post_image' => 'default',
    'unlink_post_image' => 'default',
    'builder_switch_frontend' => '0',
  ),
  'tax_input' => 
  array (
    'category' => 'image',
    'post_format' => 'post-format-image',
  ),
  'thumb' => 'https://themify.me/demo/themes/stack/files/2014/12/208621960.jpg',
);
themify_process_post_import( $post );


$post = array (
  'ID' => 2361,
  'post_date' => '2014-02-11 19:53:11',
  'post_date_gmt' => '2014-02-11 19:53:11',
  'post_content' => '',
  'post_title' => 'Video Post Type',
  'post_excerpt' => '',
  'post_name' => 'video-post-type',
  'post_modified' => '2017-08-21 07:27:20',
  'post_modified_gmt' => '2017-08-21 07:27:20',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/stack/?p=2361',
  'menu_order' => 0,
  'post_type' => 'post',
  'meta_input' => 
  array (
    'content_width' => 'default_width',
    'layout' => 'default',
    'post_format' => 'video',
    'gallery_autoplay' => '4000',
    'gallery_transition' => '1000',
    'video_url' => 'http://vimeo.com/channels/staffpicks/111721083',
    'hide_post_title' => 'default',
    'unlink_post_title' => 'default',
    'hide_post_date' => 'default',
    'hide_post_image' => 'default',
    'unlink_post_image' => 'default',
    'builder_switch_frontend' => '0',
  ),
  'tax_input' => 
  array (
    'category' => 'video',
    'post_format' => 'post-format-video',
  ),
  'thumb' => 'https://themify.me/demo/themes/stack/files/2014/12/208621960.jpg',
);
themify_process_post_import( $post );


$post = array (
  'ID' => 2363,
  'post_date' => '2014-07-23 19:54:49',
  'post_date_gmt' => '2014-07-23 19:54:49',
  'post_content' => 'Donec volutpat tellus ac odio posuere dignissim.',
  'post_title' => 'Let\'s Hug It Out',
  'post_excerpt' => '',
  'post_name' => 'lets-hug',
  'post_modified' => '2017-08-21 07:27:01',
  'post_modified_gmt' => '2017-08-21 07:27:01',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/stack/?p=2363',
  'menu_order' => 0,
  'post_type' => 'post',
  'meta_input' => 
  array (
    'content_width' => 'default_width',
    'layout' => 'default',
    'post_format' => 'video',
    'gallery_autoplay' => '4000',
    'gallery_transition' => '1000',
    'video_url' => 'http://vimeo.com/channels/staffpicks/113336111',
    'hide_post_title' => 'default',
    'unlink_post_title' => 'default',
    'hide_post_date' => 'default',
    'hide_post_image' => 'default',
    'unlink_post_image' => 'default',
    'builder_switch_frontend' => '0',
  ),
  'tax_input' => 
  array (
    'category' => 'video',
    'post_format' => 'post-format-video',
  ),
  'thumb' => 'https://themify.me/demo/themes/stack/files/2014/12/208621960.jpg',
);
themify_process_post_import( $post );


$post = array (
  'ID' => 2365,
  'post_date' => '2014-12-22 23:03:48',
  'post_date_gmt' => '2014-12-22 23:03:48',
  'post_content' => '',
  'post_title' => 'Gallery Post Type',
  'post_excerpt' => '',
  'post_name' => 'gallery-post-type',
  'post_modified' => '2018-12-06 21:44:35',
  'post_modified_gmt' => '2018-12-06 21:44:35',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/stack/?p=2365',
  'menu_order' => 0,
  'post_type' => 'post',
  'meta_input' => 
  array (
    'content_width' => 'default_width',
    'layout' => 'default',
    'post_format' => 'gallery',
    'gallery_shortcode' => '[gallery size="large" ids="2372,2374,2375,2376,2727"]',
    'gallery_autoplay' => '3000',
    'gallery_transition' => '1000',
    'video_url' => 'http://vimeo.com/channels/staffpicks/113336111',
    'hide_post_title' => 'default',
    'unlink_post_title' => 'default',
    'hide_post_date' => 'default',
    'hide_post_image' => 'default',
    'unlink_post_image' => 'default',
    '_themify_builder_settings_json' => '[{\\"element_id\\":\\"44c274d\\",\\"row_order\\":\\"0\\",\\"cols\\":[{\\"element_id\\":\\"1460fab\\",\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\"}]}]',
  ),
  'tax_input' => 
  array (
    'category' => 'video',
    'post_format' => 'post-format-gallery',
  ),
  'gallery_shortcode' => 
  array (
    'gallery_shortcode' => 
    array (
      0 => 'https://themify.me/demo/themes/stack/files/2014/12/122177932.jpg',
      1 => 'https://themify.me/demo/themes/stack/files/2014/12/155080403.jpg',
      2 => 'https://themify.me/demo/themes/stack/files/2014/12/197705528.jpg',
      3 => 'https://themify.me/demo/themes/stack/files/2014/12/206166310.jpg',
      4 => 'https://themify.me/demo/themes/stack/files/2014/12/122701141.jpg',
    ),
  ),
);
themify_process_post_import( $post );


$post = array (
  'ID' => 2379,
  'post_date' => '2014-10-23 21:16:25',
  'post_date_gmt' => '2014-10-23 21:16:25',
  'post_content' => 'This is a sample gallery.',
  'post_title' => 'Gallery Images',
  'post_excerpt' => '',
  'post_name' => 'gallery-images',
  'post_modified' => '2017-08-21 07:26:58',
  'post_modified_gmt' => '2017-08-21 07:26:58',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/stack/?p=2379',
  'menu_order' => 0,
  'post_type' => 'post',
  'meta_input' => 
  array (
    'content_width' => 'default_width',
    'layout' => 'default',
    'post_format' => 'gallery',
    'gallery_shortcode' => '[gallery size="large" _orderByField="menu_order ID" ids="2386,2387,2388,2557"]',
    'gallery_autoplay' => '4000',
    'gallery_transition' => '1000',
    'video_url' => 'http://vimeo.com/channels/staffpicks/113336111',
    'hide_post_title' => 'default',
    'unlink_post_title' => 'default',
    'hide_post_date' => 'default',
    'hide_post_image' => 'default',
    'unlink_post_image' => 'default',
    'builder_switch_frontend' => '0',
  ),
  'tax_input' => 
  array (
    'category' => 'gallery',
    'post_format' => 'post-format-gallery',
  ),
  'gallery_shortcode' => 
  array (
    'gallery_shortcode' => 
    array (
      0 => 'https://themify.me/demo/themes/stack/files/2014/12/67088788.jpg',
      1 => 'https://themify.me/demo/themes/stack/files/2014/12/67588990.jpg',
      2 => 'https://themify.me/demo/themes/stack/files/2014/12/67777039.jpg',
      3 => 'https://themify.me/demo/themes/stack/files/2014/12/192449156.jpg',
    ),
  ),
);
themify_process_post_import( $post );


$post = array (
  'ID' => 2394,
  'post_date' => '2014-06-24 17:11:48',
  'post_date_gmt' => '2014-06-24 17:11:48',
  'post_content' => 'Perfection is not attainable, but if we chase perfection we can catch excellence',
  'post_title' => 'Quote of the Day',
  'post_excerpt' => '',
  'post_name' => 'quote-day',
  'post_modified' => '2017-08-21 07:27:05',
  'post_modified_gmt' => '2017-08-21 07:27:05',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/stack/?p=2394',
  'menu_order' => 0,
  'post_type' => 'post',
  'meta_input' => 
  array (
    'content_width' => 'default_width',
    'layout' => 'default',
    'post_format' => 'quote',
    'gallery_autoplay' => '4000',
    'gallery_transition' => '1000',
    'quote_author' => 'Vince Lombardi',
    'quote_author_link' => 'http://www.brainyquote.com/quotes/quotes/v/vincelomba385070.html?src=t_inspirational',
    'hide_post_title' => 'default',
    'unlink_post_title' => 'default',
    'hide_post_date' => 'default',
    'hide_post_image' => 'default',
    'unlink_post_image' => 'default',
    'background_color' => '#56d1cd',
    'text_color' => '#ffffff',
    'link_color' => '#ffffff',
    'builder_switch_frontend' => '0',
  ),
  'tax_input' => 
  array (
    'category' => 'quote',
    'post_format' => 'post-format-quote',
  ),
);
themify_process_post_import( $post );


$post = array (
  'ID' => 2397,
  'post_date' => '2014-12-22 10:17:07',
  'post_date_gmt' => '2014-12-22 10:17:07',
  'post_content' => 'Faith is the strength by which a shattered world shall emerge into the light.',
  'post_title' => 'Food for thought',
  'post_excerpt' => '',
  'post_name' => 'food-thought',
  'post_modified' => '2017-08-21 07:26:52',
  'post_modified_gmt' => '2017-08-21 07:26:52',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/stack/?p=2397',
  'menu_order' => 0,
  'post_type' => 'post',
  'meta_input' => 
  array (
    'content_width' => 'default_width',
    'layout' => 'default',
    'post_format' => 'quote',
    'gallery_autoplay' => '4000',
    'gallery_transition' => '1000',
    'quote_author' => 'Helen Keller',
    'quote_author_link' => 'http://www.brainyquote.com/quotes/quotes/h/helenkelle121382.html',
    'hide_post_title' => 'default',
    'unlink_post_title' => 'default',
    'hide_post_date' => 'default',
    'hide_post_image' => 'default',
    'unlink_post_image' => 'default',
    'builder_switch_frontend' => '0',
  ),
  'tax_input' => 
  array (
    'category' => 'quote',
    'post_format' => 'post-format-quote',
  ),
);
themify_process_post_import( $post );


$post = array (
  'ID' => 2399,
  'post_date' => '2014-12-22 21:22:05',
  'post_date_gmt' => '2014-12-22 21:22:05',
  'post_content' => 'Contrary to popular belief, Lorem Ipsum is not simply random text. It has roots in a piece of classical Latin literature from 45 BC, making it over 2000 years old.',
  'post_title' => 'Jam to this new beat!',
  'post_excerpt' => '',
  'post_name' => 'jam-new-beat',
  'post_modified' => '2017-08-21 07:26:48',
  'post_modified_gmt' => '2017-08-21 07:26:48',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/stack/?p=2399',
  'menu_order' => 0,
  'post_type' => 'post',
  'meta_input' => 
  array (
    'content_width' => 'default_width',
    'layout' => 'default',
    'post_format' => 'audio',
    'gallery_autoplay' => '4000',
    'gallery_transition' => '1000',
    'audio_url' => 'https://themify.me/demo/themes/music/files/2014/06/rock-5CentsBack.mp3',
    'quote_author' => 'Helen Keller',
    'quote_author_link' => 'http://www.brainyquote.com/quotes/quotes/h/helenkelle121382.html',
    'hide_post_title' => 'default',
    'unlink_post_title' => 'default',
    'hide_post_date' => 'default',
    'hide_post_image' => 'default',
    'unlink_post_image' => 'default',
    'builder_switch_frontend' => '0',
  ),
  'tax_input' => 
  array (
    'category' => 'audio',
    'post_format' => 'post-format-audio',
  ),
  'thumb' => 'https://themify.me/demo/themes/stack/files/2014/12/205462138.jpg',
);
themify_process_post_import( $post );


$post = array (
  'ID' => 2404,
  'post_date' => '2014-05-23 17:25:37',
  'post_date_gmt' => '2014-05-23 17:25:37',
  'post_content' => '',
  'post_title' => 'Audio Post Type',
  'post_excerpt' => '',
  'post_name' => 'audio-post-type',
  'post_modified' => '2017-08-21 07:27:10',
  'post_modified_gmt' => '2017-08-21 07:27:10',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/stack/?p=2404',
  'menu_order' => 0,
  'post_type' => 'post',
  'meta_input' => 
  array (
    'content_width' => 'default_width',
    'layout' => 'default',
    'post_format' => 'audio',
    'gallery_autoplay' => '4000',
    'gallery_transition' => '1000',
    'audio_url' => 'https://themify.me/demo/themes/music/files/2014/06/trip-hop-Derealization.mp3',
    'quote_author' => 'Helen Keller',
    'quote_author_link' => 'http://www.brainyquote.com/quotes/quotes/h/helenkelle121382.html',
    'hide_post_title' => 'default',
    'unlink_post_title' => 'default',
    'hide_post_date' => 'default',
    'hide_post_image' => 'default',
    'unlink_post_image' => 'default',
    'builder_switch_frontend' => '0',
  ),
  'tax_input' => 
  array (
    'category' => 'audio',
    'post_format' => 'post-format-audio',
  ),
  'thumb' => 'https://themify.me/demo/themes/stack/files/2014/07/182685461.jpg',
);
themify_process_post_import( $post );


$post = array (
  'ID' => 2409,
  'post_date' => '2014-12-22 22:29:49',
  'post_date_gmt' => '2014-12-22 22:29:49',
  'post_content' => 'External Link Post Type allows you to redirect users after seeing this post to another page on your site.',
  'post_title' => 'Holiday Xmas Sale!',
  'post_excerpt' => '',
  'post_name' => 'holiday-xmas-sale',
  'post_modified' => '2017-08-21 07:26:42',
  'post_modified_gmt' => '2017-08-21 07:26:42',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/stack/?p=2409',
  'menu_order' => 0,
  'post_type' => 'post',
  'meta_input' => 
  array (
    'content_width' => 'default_width',
    'layout' => 'default',
    'post_format' => 'link',
    'gallery_autoplay' => '4000',
    'gallery_transition' => '1000',
    'audio_url' => 'https://themify.me/demo/themes/music/files/2014/06/trip-hop-Derealization.mp3',
    'quote_author' => 'Helen Keller',
    'quote_author_link' => 'http://www.brainyquote.com/quotes/quotes/h/helenkelle121382.html',
    'hide_post_title' => 'default',
    'unlink_post_title' => 'default',
    'hide_post_date' => 'default',
    'hide_post_image' => 'default',
    'unlink_post_image' => 'default',
    'external_link' => 'https://themify.me/',
    'builder_switch_frontend' => '0',
  ),
  'tax_input' => 
  array (
    'category' => 'link',
    'post_format' => 'post-format-link',
  ),
);
themify_process_post_import( $post );


$post = array (
  'ID' => 2413,
  'post_date' => '2014-04-24 17:36:03',
  'post_date_gmt' => '2014-04-24 17:36:03',
  'post_content' => 'Lightbox link post type allows you to create a lightbox that\'ll pop up when they click on the link. This eliminates the need for your users to navigate away from your page.',
  'post_title' => 'Amazing documentary!',
  'post_excerpt' => '',
  'post_name' => 'amazing-documentary',
  'post_modified' => '2017-08-21 07:27:12',
  'post_modified_gmt' => '2017-08-21 07:27:12',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/stack/?p=2413',
  'menu_order' => 0,
  'post_type' => 'post',
  'meta_input' => 
  array (
    'content_width' => 'default_width',
    'layout' => 'default',
    'post_format' => 'link',
    'gallery_autoplay' => '4000',
    'gallery_transition' => '1000',
    'audio_url' => 'https://themify.me/demo/themes/music/files/2014/06/trip-hop-Derealization.mp3',
    'quote_author' => 'Helen Keller',
    'quote_author_link' => 'http://www.brainyquote.com/quotes/quotes/h/helenkelle121382.html',
    'hide_post_title' => 'default',
    'unlink_post_title' => 'default',
    'hide_post_date' => 'default',
    'hide_post_image' => 'default',
    'unlink_post_image' => 'default',
    'lightbox_link' => 'http://vimeo.com/channels/staffpicks/115068830',
    'lightbox_icon' => 'on',
    'builder_switch_frontend' => '0',
  ),
  'tax_input' => 
  array (
    'category' => 'link',
    'post_format' => 'post-format-link',
  ),
);
themify_process_post_import( $post );


$post = array (
  'ID' => 2415,
  'post_date' => '2014-12-22 07:38:19',
  'post_date_gmt' => '2014-12-22 07:38:19',
  'post_content' => 'Phasellus malesuada consequat metus, a accumsan libero dapibus ut. Nunc venenatis ut libero vitae porta.',
  'post_title' => 'Aside Post Type',
  'post_excerpt' => '',
  'post_name' => 'aside-post-type',
  'post_modified' => '2017-08-21 07:26:53',
  'post_modified_gmt' => '2017-08-21 07:26:53',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/stack/?p=2415',
  'menu_order' => 0,
  'post_type' => 'post',
  'meta_input' => 
  array (
    'content_width' => 'default_width',
    'layout' => 'default',
    'post_format' => 'aside',
    'gallery_autoplay' => '4000',
    'gallery_transition' => '1000',
    'audio_url' => 'https://themify.me/demo/themes/music/files/2014/06/trip-hop-Derealization.mp3',
    'quote_author' => 'Helen Keller',
    'quote_author_link' => 'http://www.brainyquote.com/quotes/quotes/h/helenkelle121382.html',
    'hide_post_title' => 'default',
    'unlink_post_title' => 'default',
    'hide_post_date' => 'default',
    'hide_post_image' => 'default',
    'unlink_post_image' => 'default',
    'builder_switch_frontend' => '0',
  ),
  'tax_input' => 
  array (
    'category' => 'aside',
    'post_format' => 'post-format-aside',
  ),
);
themify_process_post_import( $post );


$post = array (
  'ID' => 2417,
  'post_date' => '2014-03-24 17:41:44',
  'post_date_gmt' => '2014-03-24 17:41:44',
  'post_content' => 'Suspendisse elementum augue vel dolor sodales, dignissim venenatis quam sollicitudin. Duis vel volutpat eros. Pellentesque nec euismod ante.',
  'post_title' => 'Random Post',
  'post_excerpt' => '',
  'post_name' => 'random-post',
  'post_modified' => '2017-08-21 07:27:13',
  'post_modified_gmt' => '2017-08-21 07:27:13',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/stack/?p=2417',
  'menu_order' => 0,
  'post_type' => 'post',
  'meta_input' => 
  array (
    'content_width' => 'default_width',
    'layout' => 'default',
    'post_format' => 'aside',
    'gallery_autoplay' => '4000',
    'gallery_transition' => '1000',
    'audio_url' => 'https://themify.me/demo/themes/music/files/2014/06/trip-hop-Derealization.mp3',
    'quote_author' => 'Helen Keller',
    'quote_author_link' => 'http://www.brainyquote.com/quotes/quotes/h/helenkelle121382.html',
    'hide_post_title' => 'default',
    'unlink_post_title' => 'default',
    'hide_post_date' => 'default',
    'hide_post_image' => 'default',
    'unlink_post_image' => 'default',
    'builder_switch_frontend' => '0',
  ),
  'tax_input' => 
  array (
    'category' => 'aside',
    'post_format' => 'post-format-aside',
  ),
);
themify_process_post_import( $post );


$post = array (
  'ID' => 2423,
  'post_date' => '2014-11-22 17:48:51',
  'post_date_gmt' => '2014-11-22 17:48:51',
  'post_content' => 'Maecenas faucibus, est sed pretium convallis, urna turpis malesuada leo, eu venenatis neque magna eget urna.',
  'post_title' => 'Standard Post Type',
  'post_excerpt' => '',
  'post_name' => 'standard-post-type',
  'post_modified' => '2017-08-21 07:26:55',
  'post_modified_gmt' => '2017-08-21 07:26:55',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/stack/?p=2423',
  'menu_order' => 0,
  'post_type' => 'post',
  'meta_input' => 
  array (
    'content_width' => 'default_width',
    'layout' => 'default',
    'post_format' => '0',
    'gallery_autoplay' => '4000',
    'gallery_transition' => '1000',
    'hide_post_title' => 'default',
    'unlink_post_title' => 'default',
    'hide_post_date' => 'default',
    'hide_post_image' => 'default',
    'unlink_post_image' => 'default',
    'builder_switch_frontend' => '0',
  ),
  'tax_input' => 
  array (
    'category' => 'blog',
  ),
  'thumb' => 'https://themify.me/demo/themes/stack/files/2014/12/128256290.jpg',
);
themify_process_post_import( $post );


$post = array (
  'ID' => 2427,
  'post_date' => '2014-12-22 19:54:18',
  'post_date_gmt' => '2014-12-22 19:54:18',
  'post_content' => 'Fusce maximus est eu nisl commodo, quis luctus neque condimentum.
<!--more-->

roin non orci rhoncus, eleifend turpis id, auctor orci. Praesent ut augue in augue efficitur cursus vel eu diam. Sed ornare diam in luctus pretium. Donec volutpat tellus ac odio posuere dignissim. Sed et libero malesuada, varius lectus nec, sodales felis. Proin fermentum massa nec lacinia sollicitudin. Etiam varius nec metus vel mollis. Praesent at urna purus. Sed tempor ligula a enim feugiat, id lobortis massa volutpat. Integer fringilla at ante eget vehicula. Etiam elit velit, facilisis ac enim a, ultrices faucibus mi.

&nbsp;',
  'post_title' => 'Fashion Trends',
  'post_excerpt' => '',
  'post_name' => 'fashion-trends',
  'post_modified' => '2017-08-21 07:26:50',
  'post_modified_gmt' => '2017-08-21 07:26:50',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/stack/?p=2427',
  'menu_order' => 0,
  'post_type' => 'post',
  'meta_input' => 
  array (
    'content_width' => 'default_width',
    'layout' => 'default',
    'post_format' => 'image',
    'gallery_autoplay' => '4000',
    'gallery_transition' => '1000',
    'hide_post_title' => 'default',
    'unlink_post_title' => 'default',
    'hide_post_date' => 'default',
    'hide_post_image' => 'default',
    'unlink_post_image' => 'default',
    'builder_switch_frontend' => '0',
  ),
  'tax_input' => 
  array (
    'category' => 'image',
    'post_format' => 'post-format-image',
  ),
  'thumb' => 'https://themify.me/demo/themes/stack/files/2014/12/98761157.jpg',
);
themify_process_post_import( $post );


$post = array (
  'ID' => 2430,
  'post_date' => '2013-12-24 18:00:02',
  'post_date_gmt' => '2013-12-24 18:00:02',
  'post_content' => 'Another gallery post here.',
  'post_title' => 'Photogaphy',
  'post_excerpt' => '',
  'post_name' => 'photogaphy',
  'post_modified' => '2017-08-21 07:27:26',
  'post_modified_gmt' => '2017-08-21 07:27:26',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/stack/?p=2430',
  'menu_order' => 0,
  'post_type' => 'post',
  'meta_input' => 
  array (
    'content_width' => 'default_width',
    'layout' => 'default',
    'post_format' => 'gallery',
    'gallery_shortcode' => '[gallery ids="2433,2437,2438,2439"]',
    'gallery_autoplay' => '3000',
    'gallery_transition' => '1000',
    'video_url' => 'http://vimeo.com/channels/staffpicks/113336111',
    'hide_post_title' => 'default',
    'unlink_post_title' => 'default',
    'hide_post_date' => 'default',
    'hide_post_image' => 'default',
    'unlink_post_image' => 'default',
    'builder_switch_frontend' => '0',
  ),
  'tax_input' => 
  array (
    'category' => 'gallery',
    'post_format' => 'post-format-gallery',
  ),
  'gallery_shortcode' => 
  array (
    'gallery_shortcode' => 
    array (
      0 => 'https://themify.me/demo/themes/stack/files/2014/12/63826084.jpg',
      1 => 'https://themify.me/demo/themes/stack/files/2014/12/71936986.jpg',
      2 => 'https://themify.me/demo/themes/stack/files/2014/12/73337353.jpg',
      3 => 'https://themify.me/demo/themes/stack/files/2014/12/73524040.jpg',
    ),
  ),
);
themify_process_post_import( $post );


$post = array (
  'ID' => 2431,
  'post_date' => '2013-12-24 18:05:36',
  'post_date_gmt' => '2013-12-24 18:05:36',
  'post_content' => 'Contrary to popular belief, Lorem Ipsum is not simply random text. It has roots in a piece of classical Latin literature from 45 BC, making it over 2000 years old.',
  'post_title' => 'My First Original',
  'post_excerpt' => '',
  'post_name' => 'first-original',
  'post_modified' => '2017-08-21 07:27:23',
  'post_modified_gmt' => '2017-08-21 07:27:23',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/stack/?p=2431',
  'menu_order' => 0,
  'post_type' => 'post',
  'meta_input' => 
  array (
    'content_width' => 'default_width',
    'layout' => 'default',
    'post_format' => 'audio',
    'gallery_autoplay' => '4000',
    'gallery_transition' => '1000',
    'audio_url' => 'https://themify.me/demo/themes/music/files/2014/06/jazz-BeBop25.mp3',
    'quote_author' => 'Helen Keller',
    'quote_author_link' => 'http://www.brainyquote.com/quotes/quotes/h/helenkelle121382.html',
    'hide_post_title' => 'default',
    'unlink_post_title' => 'default',
    'hide_post_date' => 'default',
    'hide_post_image' => 'default',
    'unlink_post_image' => 'default',
    'builder_switch_frontend' => '0',
  ),
  'tax_input' => 
  array (
    'category' => 'audio',
    'post_format' => 'post-format-audio',
  ),
  'thumb' => 'https://themify.me/demo/themes/stack/files/2014/12/205462138.jpg',
);
themify_process_post_import( $post );


$post = array (
  'ID' => 2432,
  'post_date' => '2013-12-24 18:01:34',
  'post_date_gmt' => '2013-12-24 18:01:34',
  'post_content' => 'Put your heart, mind, and soul into even your smallest acts. This is the secret of success.',
  'post_title' => 'Inspirational Quote',
  'post_excerpt' => '',
  'post_name' => 'inspirational-quote',
  'post_modified' => '2017-08-21 07:27:24',
  'post_modified_gmt' => '2017-08-21 07:27:24',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/stack/?p=2432',
  'menu_order' => 0,
  'post_type' => 'post',
  'meta_input' => 
  array (
    'content_width' => 'default_width',
    'layout' => 'default',
    'post_format' => 'quote',
    'gallery_autoplay' => '4000',
    'gallery_transition' => '1000',
    'quote_author' => 'Swami Sivananda',
    'quote_author_link' => 'http://www.brainyquote.com/quotes/quotes/s/swamisivan390760.html?src=t_inspirational',
    'hide_post_title' => 'default',
    'unlink_post_title' => 'default',
    'hide_post_date' => 'default',
    'hide_post_image' => 'default',
    'unlink_post_image' => 'default',
    'background_color' => '#000000',
    'background_repeat' => 'fullcover',
    'text_color' => '#e0e0e0',
    'link_color' => '#ffffff',
    'builder_switch_frontend' => '0',
  ),
  'tax_input' => 
  array (
    'category' => 'quote',
    'post_format' => 'post-format-quote',
  ),
);
themify_process_post_import( $post );


$post = array (
  'ID' => 2502,
  'post_date' => '2014-12-24 19:40:45',
  'post_date_gmt' => '2014-12-24 19:40:45',
  'post_content' => 'Phasellus malesuada consequat metus, a accumsan libero dapibus ut. Nunc venenatis ut libero vitae porta. Sed est turpis, pharetra nec lorem non, porttitor ullamcorper nisi.

<!--more-->

Suspendisse et ex non leo mattis eleifend. Duis aliquet erat purus, ut lacinia nulla placerat vitae. Integer non sem mi. Nam ac volutpat augue, in sollicitudin nulla. Maecenas in sapien eget arcu vestibulum tincidunt.',
  'post_title' => 'Trip Notes',
  'post_excerpt' => '',
  'post_name' => 'trip-notes',
  'post_modified' => '2017-08-21 07:26:11',
  'post_modified_gmt' => '2017-08-21 07:26:11',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/stack/?p=2502',
  'menu_order' => 0,
  'post_type' => 'post',
  'meta_input' => 
  array (
    'content_width' => 'default_width',
    'layout' => 'default',
    'post_format' => '0',
    'gallery_autoplay' => '4000',
    'gallery_transition' => '1000',
    'hide_post_title' => 'default',
    'unlink_post_title' => 'default',
    'hide_post_date' => 'default',
    'hide_post_image' => 'default',
    'unlink_post_image' => 'default',
    'builder_switch_frontend' => '0',
  ),
  'tax_input' => 
  array (
    'category' => 'blog',
  ),
  'thumb' => 'https://themify.me/demo/themes/stack/files/2014/12/129985073.jpg',
);
themify_process_post_import( $post );


$post = array (
  'ID' => 2503,
  'post_date' => '2014-12-24 15:24:43',
  'post_date_gmt' => '2014-12-24 15:24:43',
  'post_content' => 'To succeed in life, you need two things: ignorance and confidence',
  'post_title' => 'Inspirational',
  'post_excerpt' => '',
  'post_name' => 'life-quote',
  'post_modified' => '2017-08-21 07:26:11',
  'post_modified_gmt' => '2017-08-21 07:26:11',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/stack/?p=2503',
  'menu_order' => 0,
  'post_type' => 'post',
  'meta_input' => 
  array (
    'content_width' => 'default_width',
    'layout' => 'default',
    'post_format' => 'quote',
    'gallery_autoplay' => '4000',
    'gallery_transition' => '1000',
    'quote_author' => 'Mark Twain',
    'quote_author_link' => 'http://www.brainyquote.com/quotes/quotes/m/marktwain125616.html',
    'hide_post_title' => 'default',
    'unlink_post_title' => 'default',
    'hide_post_date' => 'default',
    'hide_post_image' => 'default',
    'unlink_post_image' => 'default',
    'background_color' => '#fff700',
    'background_image' => 'https://themify.me/demo/themes/stack/files/2014/02/201242249.jpg',
    'background_repeat' => 'fullcover',
    'text_color' => '#000000',
    'link_color' => '#000000',
    'builder_switch_frontend' => '0',
  ),
  'tax_input' => 
  array (
    'category' => 'quote',
    'post_format' => 'post-format-quote',
  ),
);
themify_process_post_import( $post );


$post = array (
  'ID' => 2504,
  'post_date' => '2014-12-24 14:22:48',
  'post_date_gmt' => '2014-12-24 14:22:48',
  'post_content' => '',
  'post_title' => 'Single Post with MP3 Audio',
  'post_excerpt' => '',
  'post_name' => 'single-post-mp3-audio',
  'post_modified' => '2017-08-21 07:26:30',
  'post_modified_gmt' => '2017-08-21 07:26:30',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/stack/?p=2504',
  'menu_order' => 0,
  'post_type' => 'post',
  'meta_input' => 
  array (
    'content_width' => 'default_width',
    'layout' => 'default',
    'post_format' => 'audio',
    'gallery_autoplay' => '4000',
    'gallery_transition' => '1000',
    'audio_url' => 'https://themify.me/demo/themes/music/files/2014/07/funk-oniongrass.mp3',
    'quote_author' => 'Helen Keller',
    'quote_author_link' => 'http://www.brainyquote.com/quotes/quotes/h/helenkelle121382.html',
    'hide_post_title' => 'default',
    'unlink_post_title' => 'default',
    'hide_post_date' => 'default',
    'hide_post_image' => 'default',
    'unlink_post_image' => 'default',
    'builder_switch_frontend' => '0',
  ),
  'tax_input' => 
  array (
    'category' => 'audio',
    'post_format' => 'post-format-audio',
  ),
  'thumb' => 'https://themify.me/demo/themes/stack/files/2014/07/148328327.jpg',
);
themify_process_post_import( $post );


$post = array (
  'ID' => 2505,
  'post_date' => '2014-12-24 13:21:31',
  'post_date_gmt' => '2014-12-24 13:21:31',
  'post_content' => '',
  'post_title' => 'Themify WordPress Themes',
  'post_excerpt' => '',
  'post_name' => 'themify-wordpress-themes',
  'post_modified' => '2017-08-21 07:26:33',
  'post_modified_gmt' => '2017-08-21 07:26:33',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/stack/?p=2505',
  'menu_order' => 0,
  'post_type' => 'post',
  'meta_input' => 
  array (
    'content_width' => 'default_width',
    'layout' => 'default',
    'post_format' => 'link',
    'gallery_autoplay' => '4000',
    'gallery_transition' => '1000',
    'audio_url' => 'https://themify.me/demo/themes/music/files/2014/06/trip-hop-Derealization.mp3',
    'quote_author' => 'Helen Keller',
    'quote_author_link' => 'http://www.brainyquote.com/quotes/quotes/h/helenkelle121382.html',
    'hide_post_title' => 'default',
    'unlink_post_title' => 'default',
    'hide_post_date' => 'default',
    'hide_post_image' => 'default',
    'unlink_post_image' => 'default',
    'external_link' => 'https://themify.me/themes',
    'builder_switch_frontend' => '0',
  ),
  'tax_input' => 
  array (
    'category' => 'link',
    'post_format' => 'post-format-link',
  ),
);
themify_process_post_import( $post );


$post = array (
  'ID' => 2506,
  'post_date' => '2014-12-24 12:19:02',
  'post_date_gmt' => '2014-12-24 12:19:02',
  'post_content' => 'Maecenas faucibus, est sed pretium convallis, urna turpis malesuada leo, eu venenatis neque magna eget urna.',
  'post_title' => 'A Few Photos From My Trip',
  'post_excerpt' => '',
  'post_name' => 'photos-trip',
  'post_modified' => '2017-08-21 07:26:34',
  'post_modified_gmt' => '2017-08-21 07:26:34',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/stack/?p=2506',
  'menu_order' => 0,
  'post_type' => 'post',
  'meta_input' => 
  array (
    'content_width' => 'default_width',
    'layout' => 'default',
    'post_format' => 'gallery',
    'gallery_shortcode' => '[gallery size="large" ids="2517,2518,2519"]',
    'gallery_autoplay' => '3000',
    'gallery_transition' => '1000',
    'video_url' => 'http://vimeo.com/channels/staffpicks/113336111',
    'hide_post_title' => 'default',
    'unlink_post_title' => 'default',
    'hide_post_date' => 'default',
    'hide_post_image' => 'default',
    'unlink_post_image' => 'default',
    'builder_switch_frontend' => '0',
  ),
  'tax_input' => 
  array (
    'category' => 'video',
    'post_format' => 'post-format-gallery',
  ),
  'gallery_shortcode' => 
  array (
    'gallery_shortcode' => 
    array (
      0 => 'https://themify.me/demo/themes/stack/files/2014/12/57443208.jpg',
      1 => 'https://themify.me/demo/themes/stack/files/2014/12/76753619.jpg',
      2 => 'https://themify.me/demo/themes/stack/files/2014/12/sb10068474v-001.jpg',
    ),
  ),
);
themify_process_post_import( $post );


$post = array (
  'ID' => 2507,
  'post_date' => '2014-12-24 11:18:17',
  'post_date_gmt' => '2014-12-24 11:18:17',
  'post_content' => 'Donec volutpat tellus ac odio posuere dignissim. Maecenas faucibus, est sed pretium convallis, urna turpis malesuada leo, eu venenatis neque magna eget urna.',
  'post_title' => 'Concert',
  'post_excerpt' => '',
  'post_name' => 'concert',
  'post_modified' => '2017-08-21 07:26:36',
  'post_modified_gmt' => '2017-08-21 07:26:36',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/stack/?p=2507',
  'menu_order' => 0,
  'post_type' => 'post',
  'meta_input' => 
  array (
    'content_width' => 'default_width',
    'layout' => 'default',
    'post_format' => 'video',
    'gallery_autoplay' => '4000',
    'gallery_transition' => '1000',
    'video_url' => 'https://www.youtube.com/watch?v=8UMeSUb-pEw',
    'hide_post_title' => 'default',
    'unlink_post_title' => 'default',
    'hide_post_date' => 'default',
    'hide_post_image' => 'default',
    'unlink_post_image' => 'default',
    'builder_switch_frontend' => '0',
  ),
  'tax_input' => 
  array (
    'category' => 'video',
    'post_format' => 'post-format-video',
  ),
  'thumb' => 'https://themify.me/demo/themes/stack/files/2014/12/208621960.jpg',
);
themify_process_post_import( $post );


$post = array (
  'ID' => 2508,
  'post_date' => '2014-12-24 10:04:49',
  'post_date_gmt' => '2014-12-24 10:04:49',
  'post_content' => 'Phasellus malesuada consequat metus, a accumsan libero dapibus ut. Nunc venenatis ut libero vitae porta.',
  'post_title' => 'Maecenas faucibus, est sed pretium convallis, urna turpis malesuada leo, eu venenatis neque magna eget urna.',
  'post_excerpt' => '',
  'post_name' => 'maecenas-faucibus-est-sed-pretium-convallis-urna-turpis-malesuada-leo-eu-venenatis-neque-magna-eget-urna',
  'post_modified' => '2017-08-21 07:26:38',
  'post_modified_gmt' => '2017-08-21 07:26:38',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/stack/?p=2508',
  'menu_order' => 0,
  'post_type' => 'post',
  'meta_input' => 
  array (
    'content_width' => 'default_width',
    'layout' => 'default',
    'post_format' => 'aside',
    'gallery_autoplay' => '4000',
    'gallery_transition' => '1000',
    'audio_url' => 'https://themify.me/demo/themes/music/files/2014/06/trip-hop-Derealization.mp3',
    'quote_author' => 'Helen Keller',
    'quote_author_link' => 'http://www.brainyquote.com/quotes/quotes/h/helenkelle121382.html',
    'hide_post_title' => 'default',
    'unlink_post_title' => 'default',
    'hide_post_date' => 'default',
    'hide_post_image' => 'default',
    'unlink_post_image' => 'default',
    'background_image' => 'https://themify.me/demo/themes/stack/files/2014/12/595532622.jpg',
    'background_repeat' => 'fullcover',
    'text_color' => '#ffffff',
    'link_color' => '#ffffff',
    'builder_switch_frontend' => '0',
  ),
  'tax_input' => 
  array (
    'category' => 'aside',
    'post_format' => 'post-format-aside',
  ),
);
themify_process_post_import( $post );


$post = array (
  'ID' => 2648,
  'post_date' => '2014-12-27 11:48:09',
  'post_date_gmt' => '2014-12-27 11:48:09',
  'post_content' => '',
  'post_title' => 'Blog - 2 Column',
  'post_excerpt' => '',
  'post_name' => 'blog-2-column',
  'post_modified' => '2017-08-21 07:29:20',
  'post_modified_gmt' => '2017-08-21 07:29:20',
  'post_content_filtered' => '',
  'post_parent' => 2500,
  'guid' => 'https://themify.me/demo/themes/stack/?page_id=2648',
  'menu_order' => 0,
  'post_type' => 'page',
  'meta_input' => 
  array (
    'page_layout' => 'sidebar-none',
    'content_width' => 'default_width',
    'hide_page_title' => 'yes',
    'query_category' => '0',
    'order' => 'desc',
    'orderby' => 'date',
    'layout' => 'grid2',
    'enable_masonry' => 'yes',
    'hide_title' => 'default',
    'unlink_title' => 'default',
    'hide_date' => 'default',
    'hide_image' => 'default',
    'unlink_image' => 'default',
    'hide_navigation' => 'default',
    'portfolio_order' => 'desc',
    'portfolio_orderby' => 'date',
    'portfolio_layout' => 'grid4',
    'portfolio_enable_masonry' => 'default',
    'portfolio_display_content' => 'content',
    'portfolio_hide_title' => 'default',
    'portfolio_unlink_title' => 'default',
    'portfolio_hide_meta_all' => 'default',
    'portfolio_hide_image' => 'default',
    'portfolio_unlink_image' => 'default',
    'portfolio_hide_navigation' => 'default',
    'builder_tiles_fluid_tiles_base_size' => '16',
    'builder_switch_frontend' => '0',
  ),
  'tax_input' => 
  array (
  ),
);
themify_process_post_import( $post );


$post = array (
  'ID' => 2646,
  'post_date' => '2014-12-27 11:47:12',
  'post_date_gmt' => '2014-12-27 11:47:12',
  'post_content' => '',
  'post_title' => 'Blog - 4 Column',
  'post_excerpt' => '',
  'post_name' => 'blog-4-column',
  'post_modified' => '2017-08-21 07:29:21',
  'post_modified_gmt' => '2017-08-21 07:29:21',
  'post_content_filtered' => '',
  'post_parent' => 2500,
  'guid' => 'https://themify.me/demo/themes/stack/?page_id=2646',
  'menu_order' => 0,
  'post_type' => 'page',
  'meta_input' => 
  array (
    'page_layout' => 'sidebar-none',
    'content_width' => 'default_width',
    'hide_page_title' => 'yes',
    'query_category' => '0',
    'order' => 'desc',
    'orderby' => 'date',
    'layout' => 'grid4',
    'enable_masonry' => 'yes',
    'hide_title' => 'default',
    'unlink_title' => 'default',
    'hide_date' => 'default',
    'hide_image' => 'default',
    'unlink_image' => 'default',
    'hide_navigation' => 'default',
    'portfolio_order' => 'desc',
    'portfolio_orderby' => 'date',
    'portfolio_layout' => 'grid4',
    'portfolio_enable_masonry' => 'default',
    'portfolio_display_content' => 'content',
    'portfolio_hide_title' => 'default',
    'portfolio_unlink_title' => 'default',
    'portfolio_hide_meta_all' => 'default',
    'portfolio_hide_image' => 'default',
    'portfolio_unlink_image' => 'default',
    'portfolio_hide_navigation' => 'default',
    'builder_tiles_fluid_tiles_base_size' => '16',
    'builder_switch_frontend' => '0',
  ),
  'tax_input' => 
  array (
  ),
);
themify_process_post_import( $post );


$post = array (
  'ID' => 2380,
  'post_date' => '2014-12-23 21:12:14',
  'post_date_gmt' => '2014-12-23 21:12:14',
  'post_content' => '',
  'post_title' => 'All-In-One',
  'post_excerpt' => '',
  'post_name' => 'one',
  'post_modified' => '2017-08-21 07:28:56',
  'post_modified_gmt' => '2017-08-21 07:28:56',
  'post_content_filtered' => '',
  'post_parent' => 2981,
  'guid' => 'https://themify.me/demo/themes/stack/?page_id=2380',
  'menu_order' => 1,
  'post_type' => 'page',
  'meta_input' => 
  array (
    'page_layout' => 'sidebar-none',
    'content_width' => 'full_width',
    'hide_page_title' => 'yes',
    'order' => 'desc',
    'orderby' => 'date',
    'layout' => 'grid3',
    'enable_masonry' => 'yes',
    'posts_per_page' => '9',
    'hide_title' => 'default',
    'unlink_title' => 'default',
    'hide_date' => 'default',
    'hide_image' => 'default',
    'unlink_image' => 'default',
    'hide_navigation' => 'yes',
    'portfolio_order' => 'desc',
    'portfolio_orderby' => 'date',
    'portfolio_layout' => 'grid4',
    'portfolio_enable_masonry' => 'default',
    'portfolio_display_content' => 'content',
    'portfolio_hide_title' => 'default',
    'portfolio_unlink_title' => 'default',
    'portfolio_hide_meta_all' => 'default',
    'portfolio_hide_image' => 'default',
    'portfolio_unlink_image' => 'default',
    'portfolio_hide_navigation' => 'default',
    'builder_tiles_fluid_tiles_base_size' => '16',
    'builder_switch_frontend' => '0',
    '_themify_builder_settings_json' => '[{\\"row_order\\":\\"0\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col3-2 first\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h1 style=\\\\\\\\\\\\\\"text-align: left;\\\\\\\\\\\\\\">Welcome to Stack</h1><h4 style=\\\\\\\\\\\\\\"text-align: left;\\\\\\\\\\\\\\">Stack is a responsive and fluid WordPress theme that works on all resolutions, and on any device (desktop, tablet, and mobile). It comes with masonry &amp; infinite scroll features for WordPress Post Formats, Portfolio, and WooCommerce shop.<br /><br /></h4><p>[themify_button style=\\\\\\\\\\\\\\"rect outline white\\\\\\\\\\\\\\" link=\\\\\\\\\\\\\\"https://themify.me/demo/themes/stack/demo-1/\\\\\\\\\\\\\\" ]Demo 1[/themify_button] [themify_button style=\\\\\\\\\\\\\\"rect outline white\\\\\\\\\\\\\\" link=\\\\\\\\\\\\\\"https://themify.me/demo/themes/stack/demo-2/\\\\\\\\\\\\\\" ]Demo 2[/themify_button] [themify_button style=\\\\\\\\\\\\\\"rect outline white\\\\\\\\\\\\\\" link=\\\\\\\\\\\\\\"https://themify.me/demo/themes/stack/demo-3/\\\\\\\\\\\\\\" ]Demo 3[/themify_button] [themify_button style=\\\\\\\\\\\\\\"rect outline white\\\\\\\\\\\\\\" link=\\\\\\\\\\\\\\"https://themify.me/demo/themes/stack/demo-4/\\\\\\\\\\\\\\" ]Demo 4[/themify_button]</p>\\",\\"text_user_role\\":\\"|\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"text_align_justify\\":\\"justify\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\"}}],\\"styling\\":[]},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col3-1 last\\",\\"modules\\":[],\\"styling\\":[]}],\\"column_alignment\\":\\"\\",\\"styling\\":{\\"row_width\\":\\"\\",\\"row_height\\":\\"\\",\\"animation_effect\\":\\"\\",\\"background_type\\":\\"video\\",\\"background_slider\\":\\"\\",\\"background_slider_mode\\":\\"\\",\\"background_video\\":\\"https://themify.me/demo/themes/stack/files/2015/01/clips_of_the_aurora.mp4\\",\\"background_image\\":\\"https://themify.me/demo/themes/stack/files/2015/01/clips_of_the_aurora.jpg\\",\\"background_repeat\\":\\"builder-parallax-scrolling\\",\\"background_color\\":\\"\\",\\"font_family\\":\\"default\\",\\"font_color\\":\\"\\",\\"font_size\\":\\"\\",\\"font_size_unit\\":\\"\\",\\"line_height\\":\\"\\",\\"line_height_unit\\":\\"\\",\\"text_align\\":\\"\\",\\"link_color\\":\\"\\",\\"text_decoration\\":\\"\\",\\"padding_top\\":\\"9\\",\\"padding_top_unit\\":\\"%\\",\\"padding_right\\":\\"\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom\\":\\"9\\",\\"padding_bottom_unit\\":\\"%\\",\\"padding_left\\":\\"\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top\\":\\"\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right\\":\\"\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom\\":\\"\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left\\":\\"\\",\\"margin_left_unit\\":\\"px\\",\\"border_top_color\\":\\"\\",\\"border_top_width\\":\\"\\",\\"border_top_style\\":\\"\\",\\"border_right_color\\":\\"\\",\\"border_right_width\\":\\"\\",\\"border_right_style\\":\\"\\",\\"border_bottom_color\\":\\"\\",\\"border_bottom_width\\":\\"\\",\\"border_bottom_style\\":\\"\\",\\"border_left_color\\":\\"\\",\\"border_left_width\\":\\"\\",\\"border_left_style\\":\\"\\",\\"custom_css_row\\":\\"\\",\\"row_anchor\\":\\"\\"}},{\\"row_order\\":\\"1\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full first\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h2 style=\\\\\\\\\\\\\\"text-align: left;\\\\\\\\\\\\\\">Theme Features</h2><p style=\\\\\\\\\\\\\\"text-align: left;\\\\\\\\\\\\\\">Below are some theme feature highlights contructed with the Tiles and Counter module.<br /><br /></p>\\",\\"font_family\\":\\"default\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\"}},{\\"row_order\\":\\"1\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col6-1 first\\",\\"modules\\":[{\\"mod_name\\":\\"counter\\",\\"mod_settings\\":{\\"number_counter\\":\\"4\\",\\"label_counter\\":\\"Tile Sizes\\",\\"size_counter\\":\\"medium\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom\\":\\"60\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\"}}],\\"styling\\":[]},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col6-1\\",\\"modules\\":[{\\"mod_name\\":\\"counter\\",\\"mod_settings\\":{\\"number_counter\\":\\"5\\",\\"label_counter\\":\\"Tile Types\\",\\"size_counter\\":\\"medium\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\"}}],\\"styling\\":[]},{\\"column_order\\":\\"2\\",\\"grid_class\\":\\"col6-1\\",\\"modules\\":[{\\"mod_name\\":\\"counter\\",\\"mod_settings\\":{\\"number_counter\\":\\"14\\",\\"label_counter\\":\\"Preset Colors\\",\\"size_counter\\":\\"medium\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\"}}],\\"styling\\":[]},{\\"column_order\\":\\"3\\",\\"grid_class\\":\\"col6-1\\",\\"modules\\":[{\\"mod_name\\":\\"counter\\",\\"mod_settings\\":{\\"number_counter\\":\\"11\\",\\"label_counter\\":\\"Flip Animation\\",\\"size_counter\\":\\"medium\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\"}}],\\"styling\\":[]},{\\"column_order\\":\\"4\\",\\"grid_class\\":\\"col6-1\\",\\"modules\\":[],\\"styling\\":[]},{\\"column_order\\":\\"5\\",\\"grid_class\\":\\"col6-1 last\\",\\"modules\\":[],\\"styling\\":[]}],\\"column_alignment\\":\\"\\",\\"styling\\":[]},{\\"mod_name\\":\\"tile\\",\\"mod_settings\\":{\\"size\\":\\"square-small\\",\\"type_front\\":\\"text\\",\\"color_front\\":\\"light-blue\\",\\"title_front\\":\\"Post Formats\\",\\"text_front\\":\\"<p>Create Tumblr-like micro blogs</p>\\",\\"button_link_params_front\\":\\"|\\",\\"icon_type_front\\":\\"icon\\",\\"gallery_autoplay_front\\":\\"off\\",\\"gallery_hide_timer_front\\":\\"no\\",\\"type_map_front\\":\\"ROADMAP\\",\\"scrollwheel_map_front\\":\\"enable\\",\\"draggable_map_front\\":\\"enable\\",\\"action_text_front\\":\\"Learn More\\",\\"action_link_front\\":\\"https://themify.me/themes/stack\\",\\"action_param_front\\":\\"|\\",\\"background_color_front\\":\\"ab49c9_1.00\\",\\"text_color_front\\":\\"ffffff_1.00\\",\\"link_color_front\\":\\"ffffff_1.00\\",\\"type_back\\":\\"text\\",\\"color_back\\":\\"default\\",\\"button_link_params_back\\":\\"|\\",\\"icon_type_back\\":\\"icon\\",\\"gallery_autoplay_back\\":\\"off\\",\\"gallery_hide_timer_back\\":\\"no\\",\\"type_map_back\\":\\"ROADMAP\\",\\"scrollwheel_map_back\\":\\"enable\\",\\"draggable_map_back\\":\\"enable\\",\\"action_param_back\\":\\"|\\",\\"tile_autoflip\\":\\"0\\",\\"flip_effect\\":\\"flip-horizontal\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\"}},{\\"mod_name\\":\\"tile\\",\\"mod_settings\\":{\\"size\\":\\"square-small\\",\\"type_front\\":\\"text\\",\\"color_front\\":\\"light-blue\\",\\"title_front\\":\\"Infinite Scroll\\",\\"button_link_params_front\\":\\"|\\",\\"icon_type_front\\":\\"icon\\",\\"icon_front\\":\\"fa-comment-o\\",\\"icon_color_front\\":\\"ffffff_1.00\\",\\"gallery_autoplay_front\\":\\"off\\",\\"gallery_hide_timer_front\\":\\"no\\",\\"type_map_front\\":\\"ROADMAP\\",\\"scrollwheel_map_front\\":\\"enable\\",\\"draggable_map_front\\":\\"enable\\",\\"action_text_front\\":\\"Learn More\\",\\"action_link_front\\":\\"https://themify.me/themes/stack\\",\\"action_param_front\\":\\"|\\",\\"background_color_front\\":\\"ed395d_1.00\\",\\"text_color_front\\":\\"ffffff_1.00\\",\\"link_color_front\\":\\"ffffff_1.00\\",\\"type_back\\":\\"text\\",\\"color_back\\":\\"default\\",\\"text_back\\":\\"<p>With option to disable Infinite Scroll (then the numbered pagination will be used).</p>\\",\\"button_link_params_back\\":\\"|\\",\\"icon_type_back\\":\\"icon\\",\\"gallery_autoplay_back\\":\\"off\\",\\"gallery_hide_timer_back\\":\\"no\\",\\"type_map_back\\":\\"ROADMAP\\",\\"scrollwheel_map_back\\":\\"enable\\",\\"draggable_map_back\\":\\"enable\\",\\"action_param_back\\":\\"|\\",\\"tile_autoflip\\":\\"0\\",\\"flip_effect\\":\\"flip-vertical\\",\\"background_color_back\\":\\"7fcceb_1.00\\",\\"text_color_back\\":\\"000000_1.00\\",\\"link_color_back\\":\\"000000_1.00\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\"}},{\\"mod_name\\":\\"tile\\",\\"mod_settings\\":{\\"size\\":\\"portrait\\",\\"type_front\\":\\"button\\",\\"color_front\\":\\"light-blue\\",\\"title_front\\":\\"Image\\",\\"text_front\\":\\"<p>Create Tumblr-like micro blogs</p>\\",\\"button_link_params_front\\":\\"|\\",\\"icon_type_front\\":\\"icon\\",\\"gallery_autoplay_front\\":\\"off\\",\\"gallery_hide_timer_front\\":\\"no\\",\\"type_map_front\\":\\"ROADMAP\\",\\"scrollwheel_map_front\\":\\"enable\\",\\"draggable_map_front\\":\\"enable\\",\\"action_text_front\\":\\"Learn More\\",\\"action_link_front\\":\\"https://themify.me/themes/stack\\",\\"action_param_front\\":\\"|\\",\\"text_color_front\\":\\"ffffff_1.00\\",\\"link_color_front\\":\\"ffffff_1.00\\",\\"background_image_front\\":\\"https://themify.me/demo/themes/stack/files/2014/12/135815177.jpg\\",\\"type_back\\":\\"text\\",\\"color_back\\":\\"blue\\",\\"title_back\\":\\"Solid Background\\",\\"text_back\\":\\"<p>Or solid background</p>\\",\\"button_link_params_back\\":\\"|\\",\\"icon_type_back\\":\\"icon\\",\\"gallery_autoplay_back\\":\\"off\\",\\"gallery_hide_timer_back\\":\\"no\\",\\"type_map_back\\":\\"ROADMAP\\",\\"scrollwheel_map_back\\":\\"enable\\",\\"draggable_map_back\\":\\"enable\\",\\"action_param_back\\":\\"|\\",\\"tile_autoflip\\":\\"0\\",\\"flip_effect\\":\\"fadeInRight\\",\\"background_color_back\\":\\"3c46d6_1.00\\",\\"text_color_back\\":\\"ffffff_1.00\\",\\"link_color_back\\":\\"ffffff_1.00\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\"}},{\\"mod_name\\":\\"tile\\",\\"mod_settings\\":{\\"size\\":\\"landscape\\",\\"type_front\\":\\"text\\",\\"color_front\\":\\"purple\\",\\"title_front\\":\\"11 Flip Animation\\",\\"text_front\\":\\"<p>With timed controlled auto flip option</p>\\",\\"button_link_params_front\\":\\"|\\",\\"icon_type_front\\":\\"icon\\",\\"gallery_autoplay_front\\":\\"off\\",\\"gallery_hide_timer_front\\":\\"no\\",\\"type_map_front\\":\\"ROADMAP\\",\\"zoom_map_front\\":\\"7\\",\\"scrollwheel_map_front\\":\\"enable\\",\\"draggable_map_front\\":\\"enable\\",\\"action_param_front\\":\\"|\\",\\"type_back\\":\\"text\\",\\"color_back\\":\\"red\\",\\"title_back\\":\\"Back\\",\\"text_back\\":\\"<p>Auto flip back and forth</p>\\",\\"button_link_params_back\\":\\"|\\",\\"icon_type_back\\":\\"icon\\",\\"gallery_autoplay_back\\":\\"off\\",\\"gallery_hide_timer_back\\":\\"no\\",\\"type_map_back\\":\\"ROADMAP\\",\\"zoom_map_back\\":\\"7\\",\\"scrollwheel_map_back\\":\\"enable\\",\\"draggable_map_back\\":\\"enable\\",\\"action_param_back\\":\\"|\\",\\"tile_autoflip\\":\\"2\\",\\"flip_effect\\":\\"flip-horizontal\\",\\"background_color_back\\":\\"6e2e99_1.00\\",\\"text_color_back\\":\\"ffffff_1.00\\",\\"link_color_back\\":\\"ffffff_1.00\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\",\\"visibility_desktop\\":\\"show\\",\\"visibility_desktop_show\\":\\"show\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet\\":\\"show\\",\\"visibility_tablet_show\\":\\"show\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile\\":\\"show\\",\\"visibility_mobile_show\\":\\"show\\",\\"visibility_mobile_hide\\":\\"hide\\"}},{\\"mod_name\\":\\"tile\\",\\"mod_settings\\":{\\"size\\":\\"square-small\\",\\"type_front\\":\\"blank\\",\\"color_front\\":\\"purple\\",\\"button_link_params_front\\":\\"|\\",\\"icon_type_front\\":\\"icon\\",\\"gallery_autoplay_front\\":\\"off\\",\\"gallery_hide_timer_front\\":\\"no\\",\\"type_map_front\\":\\"ROADMAP\\",\\"scrollwheel_map_front\\":\\"enable\\",\\"draggable_map_front\\":\\"enable\\",\\"action_param_front\\":\\"|\\",\\"type_back\\":\\"text\\",\\"color_back\\":\\"black\\",\\"title_back\\":\\"Hidden Tile\\",\\"text_back\\":\\"<p>Cool?</p>\\",\\"button_link_params_back\\":\\"|\\",\\"icon_type_back\\":\\"icon\\",\\"gallery_autoplay_back\\":\\"off\\",\\"gallery_hide_timer_back\\":\\"no\\",\\"type_map_back\\":\\"ROADMAP\\",\\"scrollwheel_map_back\\":\\"enable\\",\\"draggable_map_back\\":\\"enable\\",\\"action_param_back\\":\\"|\\",\\"tile_autoflip\\":\\"0\\",\\"flip_effect\\":\\"flip-horizontal\\",\\"background_color_back\\":\\"000000_1.00\\",\\"text_color_back\\":\\"ffffff_1.00\\",\\"link_color_back\\":\\"ffffff_1.00\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\"}},{\\"mod_name\\":\\"tile\\",\\"mod_settings\\":{\\"size\\":\\"square-large\\",\\"type_front\\":\\"gallery\\",\\"color_front\\":\\"light-blue\\",\\"button_link_params_front\\":\\"|\\",\\"icon_type_front\\":\\"icon\\",\\"gallery_front\\":\\"[gallery ids=\\\\\\\\\\\\\\"2750,2640,2629,2614\\\\\\\\\\\\\\"]\\",\\"gallery_autoplay_front\\":\\"3000\\",\\"gallery_hide_timer_front\\":\\"no\\",\\"type_map_front\\":\\"ROADMAP\\",\\"scrollwheel_map_front\\":\\"enable\\",\\"draggable_map_front\\":\\"enable\\",\\"action_param_front\\":\\"|\\",\\"type_back\\":\\"text\\",\\"color_back\\":\\"default\\",\\"title_back\\":\\"Gallery Slider\\",\\"text_back\\":\\"<p>Gallery slider with timer control.</p>\\",\\"button_link_params_back\\":\\"|\\",\\"icon_type_back\\":\\"icon\\",\\"gallery_autoplay_back\\":\\"off\\",\\"gallery_hide_timer_back\\":\\"no\\",\\"type_map_back\\":\\"ROADMAP\\",\\"scrollwheel_map_back\\":\\"enable\\",\\"draggable_map_back\\":\\"enable\\",\\"action_param_back\\":\\"|\\",\\"tile_autoflip\\":\\"0\\",\\"flip_effect\\":\\"zoomInUp\\",\\"background_color_back\\":\\"f542a5_1.00\\",\\"text_color_back\\":\\"ffffff_1.00\\",\\"link_color_back\\":\\"ffffff_1.00\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\"}},{\\"mod_name\\":\\"tile\\",\\"mod_settings\\":{\\"size\\":\\"square-small\\",\\"type_front\\":\\"map\\",\\"color_front\\":\\"light-blue\\",\\"button_link_params_front\\":\\"|\\",\\"icon_type_front\\":\\"icon\\",\\"gallery_autoplay_front\\":\\"off\\",\\"gallery_hide_timer_front\\":\\"no\\",\\"address_map_front\\":\\"30 Adelaide St E, Toronto, ON, Canada\\",\\"type_map_front\\":\\"ROADMAP\\",\\"zoom_map_front\\":\\"13\\",\\"scrollwheel_map_front\\":\\"disable\\",\\"draggable_map_front\\":\\"enable\\",\\"action_param_front\\":\\"|\\",\\"type_back\\":\\"text\\",\\"color_back\\":\\"default\\",\\"button_link_params_back\\":\\"|\\",\\"icon_type_back\\":\\"icon\\",\\"gallery_autoplay_back\\":\\"off\\",\\"gallery_hide_timer_back\\":\\"no\\",\\"type_map_back\\":\\"ROADMAP\\",\\"zoom_map_back\\":\\"7\\",\\"scrollwheel_map_back\\":\\"enable\\",\\"draggable_map_back\\":\\"enable\\",\\"action_param_back\\":\\"|\\",\\"tile_autoflip\\":\\"0\\",\\"flip_effect\\":\\"flip-horizontal\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\",\\"visibility_desktop\\":\\"show\\",\\"visibility_desktop_show\\":\\"show\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet\\":\\"show\\",\\"visibility_tablet_show\\":\\"show\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile\\":\\"show\\",\\"visibility_mobile_show\\":\\"show\\",\\"visibility_mobile_hide\\":\\"hide\\"}},{\\"mod_name\\":\\"tile\\",\\"mod_settings\\":{\\"size\\":\\"square-small\\",\\"type_front\\":\\"button\\",\\"color_front\\":\\"light-blue\\",\\"title_front\\":\\"300+ Icons\\",\\"text_front\\":\\"<p>Over 300+ icons available</p>\\",\\"button_link_params_front\\":\\"|\\",\\"icon_type_front\\":\\"icon\\",\\"icon_front\\":\\"fa-comment-o\\",\\"icon_color_front\\":\\"ffffff_1.00\\",\\"gallery_autoplay_front\\":\\"off\\",\\"gallery_hide_timer_front\\":\\"no\\",\\"type_map_front\\":\\"ROADMAP\\",\\"scrollwheel_map_front\\":\\"enable\\",\\"draggable_map_front\\":\\"enable\\",\\"action_text_front\\":\\"Learn More\\",\\"action_link_front\\":\\"https://themify.me/themes/stack\\",\\"action_param_front\\":\\"|\\",\\"background_color_front\\":\\"36c9d6_1.00\\",\\"text_color_front\\":\\"ffffff_1.00\\",\\"link_color_front\\":\\"ffffff_1.00\\",\\"type_back\\":\\"text\\",\\"color_back\\":\\"default\\",\\"button_link_params_back\\":\\"|\\",\\"icon_type_back\\":\\"icon\\",\\"gallery_autoplay_back\\":\\"off\\",\\"gallery_hide_timer_back\\":\\"no\\",\\"type_map_back\\":\\"ROADMAP\\",\\"scrollwheel_map_back\\":\\"enable\\",\\"draggable_map_back\\":\\"enable\\",\\"action_param_back\\":\\"|\\",\\"tile_autoflip\\":\\"0\\",\\"flip_effect\\":\\"flip-horizontal\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\"}},{\\"mod_name\\":\\"tile\\",\\"mod_settings\\":{\\"size\\":\\"square-small\\",\\"type_front\\":\\"text\\",\\"color_front\\":\\"light-blue\\",\\"title_front\\":\\"Masonry\\",\\"text_front\\":\\"<p>Masonry layouts in shop, blog, portfolio and tiles.</p>\\",\\"button_link_params_front\\":\\"|\\",\\"icon_type_front\\":\\"icon\\",\\"icon_front\\":\\"fa-comment-o\\",\\"icon_color_front\\":\\"ffffff_1.00\\",\\"gallery_autoplay_front\\":\\"off\\",\\"gallery_hide_timer_front\\":\\"no\\",\\"type_map_front\\":\\"ROADMAP\\",\\"scrollwheel_map_front\\":\\"enable\\",\\"draggable_map_front\\":\\"enable\\",\\"action_param_front\\":\\"|\\",\\"background_color_front\\":\\"3cba60_1.00\\",\\"text_color_front\\":\\"ffffff_1.00\\",\\"link_color_front\\":\\"ffffff_1.00\\",\\"type_back\\":\\"text\\",\\"color_back\\":\\"default\\",\\"button_link_params_back\\":\\"|\\",\\"icon_type_back\\":\\"icon\\",\\"gallery_autoplay_back\\":\\"off\\",\\"gallery_hide_timer_back\\":\\"no\\",\\"type_map_back\\":\\"ROADMAP\\",\\"scrollwheel_map_back\\":\\"enable\\",\\"draggable_map_back\\":\\"enable\\",\\"action_param_back\\":\\"|\\",\\"tile_autoflip\\":\\"0\\",\\"flip_effect\\":\\"flip-horizontal\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\"}},{\\"mod_name\\":\\"tile\\",\\"mod_settings\\":{\\"size\\":\\"square-small\\",\\"type_front\\":\\"text\\",\\"color_front\\":\\"light-blue\\",\\"title_front\\":\\"Customizable\\",\\"text_front\\":\\"<p>Both front and back tile can be customized</p>\\",\\"button_link_params_front\\":\\"|\\",\\"icon_type_front\\":\\"icon\\",\\"gallery_autoplay_front\\":\\"off\\",\\"gallery_hide_timer_front\\":\\"no\\",\\"address_map_front\\":\\"Toronto, Ontario\\",\\"type_map_front\\":\\"ROADMAP\\",\\"scrollwheel_map_front\\":\\"disable\\",\\"draggable_map_front\\":\\"enable\\",\\"action_text_front\\":\\"Learn More\\",\\"action_link_front\\":\\"https://themify.me/themes/stack\\",\\"action_param_front\\":\\"|\\",\\"background_color_front\\":\\"199473_1.00\\",\\"text_color_front\\":\\"ffffff_1.00\\",\\"link_color_front\\":\\"ffffff_1.00\\",\\"type_back\\":\\"text\\",\\"color_back\\":\\"default\\",\\"button_link_params_back\\":\\"|\\",\\"icon_type_back\\":\\"icon\\",\\"gallery_autoplay_back\\":\\"off\\",\\"gallery_hide_timer_back\\":\\"no\\",\\"type_map_back\\":\\"ROADMAP\\",\\"scrollwheel_map_back\\":\\"enable\\",\\"draggable_map_back\\":\\"enable\\",\\"action_param_back\\":\\"|\\",\\"tile_autoflip\\":\\"0\\",\\"flip_effect\\":\\"flip-horizontal\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\"}}],\\"styling\\":[]}],\\"styling\\":{\\"row_width\\":\\"\\",\\"row_height\\":\\"\\",\\"animation_effect\\":\\"\\",\\"background_type\\":\\"image\\",\\"background_slider\\":\\"\\",\\"background_slider_mode\\":\\"\\",\\"background_video\\":\\"\\",\\"background_image\\":\\"\\",\\"background_repeat\\":\\"\\",\\"background_color\\":\\"240675_1.00\\",\\"font_family\\":\\"default\\",\\"font_color\\":\\"\\",\\"font_size\\":\\"\\",\\"font_size_unit\\":\\"\\",\\"line_height\\":\\"\\",\\"line_height_unit\\":\\"\\",\\"text_align\\":\\"\\",\\"link_color\\":\\"\\",\\"text_decoration\\":\\"\\",\\"padding_top\\":\\"6\\",\\"padding_top_unit\\":\\"%\\",\\"padding_right\\":\\"\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom\\":\\"6\\",\\"padding_bottom_unit\\":\\"%\\",\\"padding_left\\":\\"\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top\\":\\"\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right\\":\\"\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom\\":\\"\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left\\":\\"\\",\\"margin_left_unit\\":\\"px\\",\\"border_top_color\\":\\"\\",\\"border_top_width\\":\\"\\",\\"border_top_style\\":\\"\\",\\"border_right_color\\":\\"\\",\\"border_right_width\\":\\"\\",\\"border_right_style\\":\\"\\",\\"border_bottom_color\\":\\"\\",\\"border_bottom_width\\":\\"\\",\\"border_bottom_style\\":\\"\\",\\"border_left_color\\":\\"\\",\\"border_left_width\\":\\"\\",\\"border_left_style\\":\\"\\",\\"custom_css_row\\":\\"\\",\\"row_anchor\\":\\"\\"}},{\\"row_order\\":\\"2\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full first\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h2 style=\\\\\\\\\\\\\\"text-align: left;\\\\\\\\\\\\\\">Portfolio</h2><p>Custom Portfolio post type with post filter.</p><p>[themify_portfolio_posts limit=\\\\\\\\\\\\\\"3\\\\\\\\\\\\\\" style=\\\\\\\\\\\\\\"masonry-layout\\\\\\\\\\\\\\" title=\\\\\\\\\\\\\\"yes\\\\\\\\\\\\\\" display=\\\\\\\\\\\\\\"excerpt\\\\\\\\\\\\\\" post_meta=\\\\\\\\\\\\\\"no\\\\\\\\\\\\\\" post_date=\\\\\\\\\\\\\\"no\\\\\\\\\\\\\\"]</p>\\",\\"font_family\\":\\"default\\",\\"text_align\\":\\"left\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"text_align_justify\\":\\"justify\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\"}}],\\"styling\\":[]}],\\"styling\\":{\\"row_width\\":\\"\\",\\"row_height\\":\\"\\",\\"animation_effect\\":\\"\\",\\"background_type\\":\\"image\\",\\"background_slider\\":\\"\\",\\"background_slider_mode\\":\\"\\",\\"background_video\\":\\"\\",\\"background_image\\":\\"\\",\\"background_repeat\\":\\"\\",\\"background_color\\":\\"000000_1.00\\",\\"font_family\\":\\"default\\",\\"font_color\\":\\"\\",\\"font_size\\":\\"\\",\\"font_size_unit\\":\\"\\",\\"line_height\\":\\"\\",\\"line_height_unit\\":\\"\\",\\"text_align\\":\\"\\",\\"link_color\\":\\"\\",\\"text_decoration\\":\\"\\",\\"padding_top\\":\\"6\\",\\"padding_top_unit\\":\\"%\\",\\"padding_right\\":\\"\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom\\":\\"6\\",\\"padding_bottom_unit\\":\\"%\\",\\"padding_left\\":\\"\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top\\":\\"\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right\\":\\"\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom\\":\\"\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left\\":\\"\\",\\"margin_left_unit\\":\\"px\\",\\"border_top_color\\":\\"\\",\\"border_top_width\\":\\"\\",\\"border_top_style\\":\\"\\",\\"border_right_color\\":\\"\\",\\"border_right_width\\":\\"\\",\\"border_right_style\\":\\"\\",\\"border_bottom_color\\":\\"\\",\\"border_bottom_width\\":\\"\\",\\"border_bottom_style\\":\\"\\",\\"border_left_color\\":\\"\\",\\"border_left_width\\":\\"\\",\\"border_left_style\\":\\"\\",\\"custom_css_row\\":\\"\\",\\"row_anchor\\":\\"\\"}},{\\"row_order\\":\\"3\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full first\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h2 style=\\\\\\\\\\\\\\"text-align: left;\\\\\\\\\\\\\\">Blog</h2><p>Customizable posts with WP Post Format support.</p>\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"text_align_justify\\":\\"justify\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\"}},{\\"mod_name\\":\\"post\\",\\"mod_settings\\":{\\"layout_post\\":\\"grid3\\",\\"category_post\\":\\"0|multiple\\",\\"post_per_page_post\\":\\"7\\",\\"order_post\\":\\"desc\\",\\"orderby_post\\":\\"date\\",\\"display_post\\":\\"content\\",\\"hide_page_nav_post\\":\\"yes\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"text_align_justify\\":\\"justify\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\"}}],\\"styling\\":[]}],\\"styling\\":{\\"row_width\\":\\"\\",\\"row_height\\":\\"\\",\\"animation_effect\\":\\"\\",\\"background_type\\":\\"image\\",\\"background_slider\\":\\"\\",\\"background_slider_mode\\":\\"\\",\\"background_video\\":\\"\\",\\"background_image\\":\\"\\",\\"background_repeat\\":\\"\\",\\"background_color\\":\\"\\",\\"font_family\\":\\"default\\",\\"font_color\\":\\"\\",\\"font_size\\":\\"\\",\\"font_size_unit\\":\\"\\",\\"line_height\\":\\"\\",\\"line_height_unit\\":\\"\\",\\"text_align\\":\\"\\",\\"link_color\\":\\"\\",\\"text_decoration\\":\\"\\",\\"padding_top\\":\\"6\\",\\"padding_top_unit\\":\\"%\\",\\"padding_right\\":\\"\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom\\":\\"6\\",\\"padding_bottom_unit\\":\\"%\\",\\"padding_left\\":\\"\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top\\":\\"\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right\\":\\"\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom\\":\\"\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left\\":\\"\\",\\"margin_left_unit\\":\\"px\\",\\"border_top_color\\":\\"\\",\\"border_top_width\\":\\"\\",\\"border_top_style\\":\\"\\",\\"border_right_color\\":\\"\\",\\"border_right_width\\":\\"\\",\\"border_right_style\\":\\"\\",\\"border_bottom_color\\":\\"\\",\\"border_bottom_width\\":\\"\\",\\"border_bottom_style\\":\\"\\",\\"border_left_color\\":\\"\\",\\"border_left_width\\":\\"\\",\\"border_left_style\\":\\"\\",\\"custom_css_row\\":\\"\\",\\"row_anchor\\":\\"\\"}},{\\"row_order\\":\\"4\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full first\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h2>Shop</h2><p>Use the <a href=\\\\\\\\\\\\\\"http://https://themify.me/addons/woocommerce\\\\\\\\\\\\\\">WooCommerce Addon</a> to display products anywhere on your site. </p>\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"text_align_justify\\":\\"justify\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\"}},{\\"mod_name\\":\\"products\\",\\"mod_settings\\":{\\"query_products\\":\\"all\\",\\"category_products\\":\\"0|multiple\\",\\"hide_free_products\\":\\"no\\",\\"post_per_page_products\\":\\"8\\",\\"orderby_products\\":\\"date\\",\\"order_products\\":\\"desc\\",\\"template_products\\":\\"list\\",\\"layout_products\\":\\"grid4\\",\\"layout_slider\\":\\"slider-default\\",\\"visible_opt_slider\\":\\"1\\",\\"auto_scroll_opt_slider\\":\\"4\\",\\"scroll_opt_slider\\":\\"1\\",\\"speed_opt_slider\\":\\"normal\\",\\"effect_slider\\":\\"scroll\\",\\"pause_on_hover_slider\\":\\"resume\\",\\"wrap_slider\\":\\"yes\\",\\"show_nav_slider\\":\\"yes\\",\\"show_arrow_slider\\":\\"yes\\",\\"description_products\\":\\"none\\",\\"hide_feat_img_products\\":\\"no\\",\\"unlink_feat_img_products\\":\\"no\\",\\"hide_post_title_products\\":\\"no\\",\\"unlink_post_title_products\\":\\"no\\",\\"hide_price_products\\":\\"no\\",\\"hide_add_to_cart_products\\":\\"no\\",\\"hide_rating_products\\":\\"no\\",\\"hide_sales_badge\\":\\"no\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"text_align_justify\\":\\"justify\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\"}}],\\"styling\\":[]}],\\"styling\\":{\\"row_width\\":\\"\\",\\"row_height\\":\\"\\",\\"animation_effect\\":\\"\\",\\"background_type\\":\\"image\\",\\"background_slider\\":\\"\\",\\"background_slider_mode\\":\\"\\",\\"background_video\\":\\"\\",\\"background_image\\":\\"\\",\\"background_repeat\\":\\"\\",\\"background_color\\":\\"3093ba_1.00\\",\\"font_family\\":\\"default\\",\\"font_color\\":\\"\\",\\"font_size\\":\\"\\",\\"font_size_unit\\":\\"\\",\\"line_height\\":\\"\\",\\"line_height_unit\\":\\"\\",\\"text_align\\":\\"\\",\\"link_color\\":\\"\\",\\"text_decoration\\":\\"\\",\\"padding_top\\":\\"6\\",\\"padding_top_unit\\":\\"%\\",\\"padding_right\\":\\"\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom\\":\\"6\\",\\"padding_bottom_unit\\":\\"%\\",\\"padding_left\\":\\"\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top\\":\\"\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right\\":\\"\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom\\":\\"\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left\\":\\"\\",\\"margin_left_unit\\":\\"px\\",\\"border_top_color\\":\\"\\",\\"border_top_width\\":\\"\\",\\"border_top_style\\":\\"\\",\\"border_right_color\\":\\"\\",\\"border_right_width\\":\\"\\",\\"border_right_style\\":\\"\\",\\"border_bottom_color\\":\\"\\",\\"border_bottom_width\\":\\"\\",\\"border_bottom_style\\":\\"\\",\\"border_left_color\\":\\"\\",\\"border_left_width\\":\\"\\",\\"border_left_style\\":\\"\\",\\"custom_css_row\\":\\"\\",\\"row_anchor\\":\\"\\"}},{\\"row_order\\":\\"5\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full first\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h2>Contact Us</h2><p>Create a custom contact form and display it anywhere on your site using our <a href=\\\\\\\\\\\\\\"http://https://themify.me/addons/contact\\\\\\\\\\\\\\">Contact Addon</a>.</p>\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"text_align_justify\\":\\"justify\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\"}},{\\"row_order\\":\\"1\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col4-2 first\\",\\"modules\\":[{\\"mod_name\\":\\"contact\\",\\"mod_settings\\":{\\"field_name_label\\":\\"Tell us who you are\\",\\"field_email_label\\":\\"Contact Email\\",\\"field_subject_label\\":\\"Problem Summary\\",\\"field_captcha_label\\":\\"You Human? Prove it!\\",\\"field_captcha_active\\":\\"|\\",\\"field_message_label\\":\\"Problem Details\\",\\"field_sendcopy_label\\":\\"Would you like a copy\\",\\"field_sendcopy_active\\":\\"|\\",\\"field_send_label\\":\\"Confirm\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"text_align_justify\\":\\"justify\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\"}}],\\"styling\\":[]},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col4-2 last\\",\\"modules\\":[{\\"mod_name\\":\\"map\\",\\"mod_settings\\":{\\"address_map\\":\\"Toronto Ontario\\",\\"zoom_map\\":\\"8\\",\\"w_map\\":\\"100\\",\\"unit_w\\":\\"%\\",\\"h_map\\":\\"300\\",\\"unit_h\\":\\"px\\",\\"b_style_map\\":\\"solid\\",\\"type_map\\":\\"ROADMAP\\",\\"scrollwheel_map\\":\\"disable\\",\\"draggable_map\\":\\"enable\\",\\"draggable_disable_mobile_map\\":\\"yes\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\"}},{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h4>Address</h4><p>123 Street Ave<br />Toronto, Ontario<br />Canada</p>\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"text_align_justify\\":\\"justify\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\"}}],\\"styling\\":[]}],\\"column_alignment\\":\\"\\",\\"styling\\":[]}],\\"styling\\":[]}],\\"styling\\":{\\"row_width\\":\\"\\",\\"row_height\\":\\"\\",\\"animation_effect\\":\\"\\",\\"background_type\\":\\"image\\",\\"background_slider\\":\\"\\",\\"background_slider_mode\\":\\"\\",\\"background_video\\":\\"\\",\\"background_image\\":\\"\\",\\"background_repeat\\":\\"\\",\\"background_color\\":\\"56e3ab_1.00\\",\\"font_family\\":\\"default\\",\\"font_color\\":\\"000000_1.00\\",\\"font_size\\":\\"\\",\\"font_size_unit\\":\\"\\",\\"line_height\\":\\"\\",\\"line_height_unit\\":\\"\\",\\"text_align\\":\\"\\",\\"link_color\\":\\"000000_1.00\\",\\"text_decoration\\":\\"\\",\\"padding_top\\":\\"6\\",\\"padding_top_unit\\":\\"%\\",\\"padding_right\\":\\"\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom\\":\\"6\\",\\"padding_bottom_unit\\":\\"%\\",\\"padding_left\\":\\"\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top\\":\\"\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right\\":\\"\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom\\":\\"\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left\\":\\"\\",\\"margin_left_unit\\":\\"px\\",\\"border_top_color\\":\\"\\",\\"border_top_width\\":\\"\\",\\"border_top_style\\":\\"\\",\\"border_right_color\\":\\"\\",\\"border_right_width\\":\\"\\",\\"border_right_style\\":\\"\\",\\"border_bottom_color\\":\\"\\",\\"border_bottom_width\\":\\"\\",\\"border_bottom_style\\":\\"\\",\\"border_left_color\\":\\"\\",\\"border_left_width\\":\\"\\",\\"border_left_style\\":\\"\\",\\"custom_css_row\\":\\"\\",\\"row_anchor\\":\\"\\"}},{\\"row_order\\":\\"6\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full first\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h2>Social Links</h2><p>Easily showcase all your social links with the Feature module.</p>\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"text_align_justify\\":\\"justify\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\"}},{\\"row_order\\":\\"1\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col5-1 first\\",\\"modules\\":[{\\"mod_name\\":\\"feature\\",\\"mod_settings\\":{\\"layout_feature\\":\\"icon-top\\",\\"circle_size_feature\\":\\"large\\",\\"icon_type_feature\\":\\"icon\\",\\"icon_feature\\":\\"fa-youtube\\",\\"icon_color_feature\\":\\"ffffff_1.00\\",\\"link_feature\\":\\"https://plus.google.com/u/0/b/109280316400365629341/109280316400365629341/posts\\",\\"param_feature\\":\\"newtab\\",\\"background_color\\":\\"DD2826\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"text_align_justify\\":\\"justify\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\"}}],\\"styling\\":[]},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col5-1\\",\\"modules\\":[{\\"mod_name\\":\\"feature\\",\\"mod_settings\\":{\\"layout_feature\\":\\"icon-top\\",\\"circle_size_feature\\":\\"large\\",\\"icon_type_feature\\":\\"icon\\",\\"icon_feature\\":\\"fa-twitter\\",\\"icon_color_feature\\":\\"ffffff_1.00\\",\\"link_feature\\":\\"https://twitter.com/themify\\",\\"param_feature\\":\\"newtab\\",\\"background_color\\":\\"0084B4\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"text_align_justify\\":\\"justify\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\"}}],\\"styling\\":[]},{\\"column_order\\":\\"2\\",\\"grid_class\\":\\"col5-1\\",\\"modules\\":[{\\"mod_name\\":\\"feature\\",\\"mod_settings\\":{\\"layout_feature\\":\\"icon-top\\",\\"circle_size_feature\\":\\"large\\",\\"icon_type_feature\\":\\"icon\\",\\"icon_feature\\":\\"fa-facebook\\",\\"icon_color_feature\\":\\"ffffff_1.00\\",\\"link_feature\\":\\"https://www.facebook.com/themify\\",\\"param_feature\\":\\"newtab\\",\\"background_color\\":\\"43609C\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"text_align_justify\\":\\"justify\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\"}}],\\"styling\\":[]},{\\"column_order\\":\\"3\\",\\"grid_class\\":\\"col5-1\\",\\"modules\\":[{\\"mod_name\\":\\"feature\\",\\"mod_settings\\":{\\"layout_feature\\":\\"icon-top\\",\\"circle_size_feature\\":\\"large\\",\\"icon_type_feature\\":\\"icon\\",\\"icon_feature\\":\\"fa-google-plus\\",\\"icon_color_feature\\":\\"ffffff_1.00\\",\\"link_feature\\":\\"https://plus.google.com/u/0/b/109280316400365629341/109280316400365629341/posts\\",\\"param_feature\\":\\"newtab\\",\\"background_color\\":\\"DE5C4B\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"text_align_justify\\":\\"justify\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\"}}],\\"styling\\":[]},{\\"column_order\\":\\"4\\",\\"grid_class\\":\\"col5-1 last\\",\\"modules\\":[{\\"mod_name\\":\\"feature\\",\\"mod_settings\\":{\\"layout_feature\\":\\"icon-top\\",\\"circle_size_feature\\":\\"large\\",\\"icon_type_feature\\":\\"icon\\",\\"icon_feature\\":\\"fa-desktop\\",\\"icon_color_feature\\":\\"ffffff_1.00\\",\\"link_feature\\":\\"https://themify.me/contact\\",\\"param_feature\\":\\"newtab\\",\\"background_color\\":\\"FEBD0F\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"text_align_justify\\":\\"justify\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\"}}],\\"styling\\":[]}],\\"gutter\\":\\"gutter-none\\",\\"column_alignment\\":\\"\\",\\"styling\\":[]}],\\"styling\\":[]}],\\"styling\\":{\\"row_width\\":\\"\\",\\"row_height\\":\\"\\",\\"animation_effect\\":\\"\\",\\"background_type\\":\\"image\\",\\"background_slider\\":\\"\\",\\"background_slider_mode\\":\\"\\",\\"background_video\\":\\"\\",\\"background_image\\":\\"\\",\\"background_repeat\\":\\"\\",\\"background_color\\":\\"4cb7ed_1.00\\",\\"font_family\\":\\"default\\",\\"font_color\\":\\"000000_1.00\\",\\"font_size\\":\\"\\",\\"font_size_unit\\":\\"\\",\\"line_height\\":\\"\\",\\"line_height_unit\\":\\"\\",\\"text_align\\":\\"\\",\\"link_color\\":\\"\\",\\"text_decoration\\":\\"\\",\\"padding_top\\":\\"6\\",\\"padding_top_unit\\":\\"%\\",\\"padding_right\\":\\"\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom\\":\\"6\\",\\"padding_bottom_unit\\":\\"%\\",\\"padding_left\\":\\"\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top\\":\\"\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right\\":\\"\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom\\":\\"\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left\\":\\"\\",\\"margin_left_unit\\":\\"px\\",\\"border_top_color\\":\\"\\",\\"border_top_width\\":\\"\\",\\"border_top_style\\":\\"\\",\\"border_right_color\\":\\"\\",\\"border_right_width\\":\\"\\",\\"border_right_style\\":\\"\\",\\"border_bottom_color\\":\\"\\",\\"border_bottom_width\\":\\"\\",\\"border_bottom_style\\":\\"\\",\\"border_left_color\\":\\"\\",\\"border_left_width\\":\\"\\",\\"border_left_style\\":\\"\\",\\"custom_css_row\\":\\"\\",\\"row_anchor\\":\\"\\"}},{\\"row_order\\":\\"7\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full first last\\",\\"modules\\":[],\\"styling\\":[]}],\\"styling\\":[]}]',
  ),
  'tax_input' => 
  array (
  ),
);
themify_process_post_import( $post );


$post = array (
  'ID' => 2664,
  'post_date' => '2014-12-29 17:32:43',
  'post_date_gmt' => '2014-12-29 17:32:43',
  'post_content' => '[woocommerce_cart]',
  'post_title' => 'Cart',
  'post_excerpt' => '',
  'post_name' => 'cart',
  'post_modified' => '2017-08-21 07:28:41',
  'post_modified_gmt' => '2017-08-21 07:28:41',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/stack/cart/',
  'menu_order' => 1,
  'post_type' => 'page',
  'meta_input' => 
  array (
    'page_layout' => 'default',
    'content_width' => 'default_width',
    'hide_page_title' => 'default',
    'order' => 'desc',
    'orderby' => 'date',
    'layout' => 'list-post',
    'enable_masonry' => 'default',
    'hide_title' => 'default',
    'unlink_title' => 'default',
    'hide_date' => 'default',
    'hide_image' => 'default',
    'unlink_image' => 'default',
    'hide_navigation' => 'default',
    'portfolio_order' => 'desc',
    'portfolio_orderby' => 'date',
    'portfolio_layout' => 'grid4',
    'portfolio_enable_masonry' => 'default',
    'portfolio_hide_title' => 'default',
    'portfolio_unlink_title' => 'default',
    'portfolio_hide_meta_all' => 'default',
    'portfolio_hide_image' => 'default',
    'portfolio_unlink_image' => 'default',
    'portfolio_hide_navigation' => 'default',
    'builder_tiles_fluid_tiles_base_size' => '16',
  ),
  'tax_input' => 
  array (
  ),
);
themify_process_post_import( $post );


$post = array (
  'ID' => 2797,
  'post_date' => '2014-12-30 20:38:42',
  'post_date_gmt' => '2014-12-30 20:38:42',
  'post_content' => '',
  'post_title' => 'Portfolio - List Post',
  'post_excerpt' => '',
  'post_name' => 'portfolio-list-post',
  'post_modified' => '2017-08-21 07:29:19',
  'post_modified_gmt' => '2017-08-21 07:29:19',
  'post_content_filtered' => '',
  'post_parent' => 2455,
  'guid' => 'https://themify.me/demo/themes/stack/?page_id=2797',
  'menu_order' => 2,
  'post_type' => 'page',
  'meta_input' => 
  array (
    'page_layout' => 'sidebar-none',
    'content_width' => 'full_width',
    'hide_page_title' => 'default',
    'order' => 'desc',
    'orderby' => 'date',
    'layout' => 'list-post',
    'enable_masonry' => 'default',
    'display_content' => 'content',
    'hide_title' => 'default',
    'unlink_title' => 'default',
    'hide_date' => 'default',
    'hide_image' => 'default',
    'unlink_image' => 'default',
    'hide_navigation' => 'default',
    'portfolio_query_category' => '0',
    'portfolio_order' => 'desc',
    'portfolio_orderby' => 'date',
    'portfolio_layout' => 'list-post',
    'portfolio_enable_masonry' => 'no',
    'portfolio_posts_per_page' => '8',
    'portfolio_hide_title' => 'default',
    'portfolio_unlink_title' => 'default',
    'portfolio_hide_meta_all' => 'default',
    'portfolio_hide_image' => 'default',
    'portfolio_unlink_image' => 'default',
    'portfolio_hide_navigation' => 'default',
    'builder_tiles_fluid_tiles_base_size' => '16',
    'builder_switch_frontend' => '0',
  ),
  'tax_input' => 
  array (
  ),
);
themify_process_post_import( $post );


$post = array (
  'ID' => 2665,
  'post_date' => '2014-12-29 17:32:43',
  'post_date_gmt' => '2014-12-29 17:32:43',
  'post_content' => '[woocommerce_checkout]',
  'post_title' => 'Checkout',
  'post_excerpt' => '',
  'post_name' => 'checkout',
  'post_modified' => '2017-08-21 07:28:43',
  'post_modified_gmt' => '2017-08-21 07:28:43',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/stack/checkout/',
  'menu_order' => 2,
  'post_type' => 'page',
  'meta_input' => 
  array (
    'page_layout' => 'default',
    'content_width' => 'default_width',
    'hide_page_title' => 'default',
    'order' => 'desc',
    'orderby' => 'date',
    'layout' => 'list-post',
    'enable_masonry' => 'default',
    'hide_title' => 'default',
    'unlink_title' => 'default',
    'hide_date' => 'default',
    'hide_image' => 'default',
    'unlink_image' => 'default',
    'hide_navigation' => 'default',
    'portfolio_order' => 'desc',
    'portfolio_orderby' => 'date',
    'portfolio_layout' => 'grid4',
    'portfolio_enable_masonry' => 'default',
    'portfolio_hide_title' => 'default',
    'portfolio_unlink_title' => 'default',
    'portfolio_hide_meta_all' => 'default',
    'portfolio_hide_image' => 'default',
    'portfolio_unlink_image' => 'default',
    'portfolio_hide_navigation' => 'default',
    'builder_tiles_fluid_tiles_base_size' => '16',
  ),
  'tax_input' => 
  array (
  ),
);
themify_process_post_import( $post );


$post = array (
  'ID' => 2779,
  'post_date' => '2014-12-29 21:10:59',
  'post_date_gmt' => '2014-12-29 21:10:59',
  'post_content' => '<!--themify_builder_static--><h4>Images Transformed</h4> <p>It amet ornare ante nibh quis ex. Aenean porta suscipit massa id iaculis. Quisque convallis, nisl a placerat rhoncus.....</p> <a href="https://themify.me/themes/stack" class="action-button " target="_blank" Buy Now </a>
 
 
 
 
 <p>Quisque convallis, nisl a placerat rhoncus, eros nulla accumsan augue, sit amet ornare ante nibh quis ex. Aenean porta suscipit massa id iaculis.</p> <a href="https://themify.me/themes/stack" class="action-button " Read More </a>
 
 
 
 <h4>Gray Design</h4> <p>Suscipit! Nis a placerat rhoncus, eros nulla accumsan augue, sit amet ornare ante nibh quis ex. Aenean porta  massa id iaculis.</p> 
 
 
 
 
 
 
 
 <h4>WordPress </h4> 
 <p>Quisque convallis, nisl a placera...</p> <a href="https://themify.me/themes" class="action-button " target="_blank" See more themes </a>
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 <ul data-id="gallery-shortcode-slider-tile-0-" data-autoplay="4000" data-effect="scroll" data-speed="1000" data-visible="2" data-width="33" data-wrap="yes" data-slidernav="yes" data-pager="no"> <li> <a href="#" data-image="https://themify.me/demo/themes/stack/files/2014/12/168015233-1024x682.jpg" data-caption="" data-description=""> <img src="https://themify.me/demo/themes/stack/files/2014/12/168015233-40x33.jpg" width="40" height="33" alt="168015233" /> </a> </li> <li> <a href="#" data-image="https://themify.me/demo/themes/stack/files/2014/05/95259592-1024x698.jpg" data-caption="" data-description=""> <img src="https://themify.me/demo/themes/stack/files/2014/05/95259592-40x33.jpg" width="40" height="33" alt="95259592" /> </a> </li> <li> <a href="#" data-image="https://themify.me/demo/themes/stack/files/2014/12/74685121-1024x682.jpg" data-caption="" data-description=""> <img src="https://themify.me/demo/themes/stack/files/2014/12/74685121-40x33.jpg" width="40" height="33" alt="74685121" /> </a> </li> </ul> 
 
 
 
 <h4>About us</h4> <p>Convallis, nisl a placerat rhoncus, eros nulla. Ila accumsan augue, sit amet ornare.</p> 
 <a href="https://twitter.com/themify" > </a><!--/themify_builder_static-->',
  'post_title' => 'Demo 1',
  'post_excerpt' => '',
  'post_name' => 'demo-1-2',
  'post_modified' => '2018-11-09 21:02:19',
  'post_modified_gmt' => '2018-11-09 21:02:19',
  'post_content_filtered' => '',
  'post_parent' => 2981,
  'guid' => 'https://themify.me/demo/themes/stack/?page_id=2779',
  'menu_order' => 2,
  'post_type' => 'page',
  'meta_input' => 
  array (
    'page_layout' => 'sidebar-none',
    'content_width' => 'full_width',
    'hide_page_title' => 'yes',
    'order' => 'desc',
    'orderby' => 'date',
    'layout' => 'list-post',
    'enable_masonry' => 'default',
    'display_content' => 'content',
    'hide_title' => 'default',
    'unlink_title' => 'default',
    'hide_date' => 'default',
    'hide_image' => 'default',
    'unlink_image' => 'default',
    'hide_navigation' => 'default',
    'portfolio_order' => 'desc',
    'portfolio_orderby' => 'date',
    'portfolio_layout' => 'grid4',
    'portfolio_enable_masonry' => 'default',
    'portfolio_display_content' => 'content',
    'portfolio_hide_title' => 'default',
    'portfolio_unlink_title' => 'default',
    'portfolio_hide_meta_all' => 'default',
    'portfolio_hide_image' => 'default',
    'portfolio_unlink_image' => 'default',
    'portfolio_hide_navigation' => 'default',
    'builder_tiles_fluid_tiles' => 'yes',
    'builder_tiles_fluid_tiles_base_size' => '25',
    'builder_switch_frontend' => '0',
    '_themify_builder_settings_json' => '[{\\"element_id\\":\\"b0e734d\\",\\"row_order\\":\\"0\\",\\"cols\\":[{\\"element_id\\":\\"a5a20ff\\",\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\"}],\\"styling\\":{\\"row_width\\":\\"fullwidth\\",\\"row_height\\":\\"fullheight\\",\\"background_type\\":\\"slider\\",\\"background_slider\\":\\"[gallery ids=\\\\\\\\\\\\\\"2749,2763,2726\\\\\\\\\\\\\\"]\\"}},{\\"element_id\\":\\"0c18394\\",\\"row_order\\":\\"1\\",\\"cols\\":[{\\"element_id\\":\\"225e2ac\\",\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"mod_name\\":\\"tile\\",\\"element_id\\":\\"af401c2\\",\\"mod_settings\\":{\\"size\\":\\"square-large\\",\\"type_front\\":\\"text\\",\\"icon_type_front\\":\\"icon\\",\\"gallery_autoplay_front\\":\\"4000\\",\\"gallery_hide_timer_front\\":\\"no\\",\\"type_map_front\\":\\"ROADMAP\\",\\"scrollwheel_map_front\\":\\"enable\\",\\"draggable_map_front\\":\\"enable\\",\\"background_image_front\\":\\"https://themify.me/demo/themes/stack\\\\/files\\\\/2014\\\\/12\\\\/192995783.jpg\\",\\"type_back\\":\\"text\\",\\"title_back\\":\\"Images Transformed\\",\\"text_back\\":\\"<p>It amet ornare ante nibh quis ex. Aenean porta suscipit massa id iaculis. Quisque convallis, nisl a placerat rhoncus.....<\\\\/p>\\",\\"icon_type_back\\":\\"icon\\",\\"gallery_autoplay_back\\":\\"off\\",\\"gallery_hide_timer_back\\":\\"no\\",\\"type_map_back\\":\\"ROADMAP\\",\\"scrollwheel_map_back\\":\\"enable\\",\\"draggable_map_back\\":\\"enable\\",\\"action_text_back\\":\\"Buy Now\\",\\"action_link_back\\":\\"https:\\\\/\\\\/themify.me\\\\/themes\\\\/stack\\",\\"action_param_back\\":\\"newtab\\",\\"tile_autoflip\\":\\"5\\",\\"flip_effect\\":\\"fadeInUp\\",\\"background_color_back\\":\\"787878_0.69\\",\\"text_color_back\\":\\"ffffff_1.00\\",\\"link_color_back\\":\\"ffffff_1.00\\",\\"padding_top\\":\\"4\\",\\"padding_right\\":\\"4\\",\\"padding_bottom\\":\\"4\\",\\"padding_left\\":\\"4\\"}},{\\"mod_name\\":\\"tile\\",\\"element_id\\":\\"ba000a7\\",\\"mod_settings\\":{\\"size\\":\\"landscape\\",\\"type_front\\":\\"button\\",\\"color_front\\":\\"black\\",\\"icon_type_front\\":\\"icon\\",\\"icon_front\\":\\"fa-bicycle\\",\\"icon_color_front\\":\\"ffffff_1.00\\",\\"gallery_front\\":\\"[gallery ids=\\\\\\\\\\\\\\"2621,2611,2604,2608\\\\\\\\\\\\\\"]\\",\\"gallery_autoplay_front\\":\\"4000\\",\\"gallery_hide_timer_front\\":\\"no\\",\\"type_map_front\\":\\"ROADMAP\\",\\"scrollwheel_map_front\\":\\"enable\\",\\"draggable_map_front\\":\\"enable\\",\\"type_back\\":\\"text\\",\\"text_back\\":\\"<p>Quisque convallis, nisl a placerat rhoncus, eros nulla accumsan augue, sit amet ornare ante nibh quis ex. Aenean porta suscipit massa id iaculis.<\\\\/p>\\",\\"icon_type_back\\":\\"icon\\",\\"gallery_autoplay_back\\":\\"off\\",\\"gallery_hide_timer_back\\":\\"no\\",\\"type_map_back\\":\\"ROADMAP\\",\\"scrollwheel_map_back\\":\\"enable\\",\\"draggable_map_back\\":\\"enable\\",\\"action_text_back\\":\\"Read More\\",\\"action_link_back\\":\\"https:\\\\/\\\\/themify.me\\\\/themes\\\\/stack\\",\\"tile_autoflip\\":\\"0\\",\\"flip_effect\\":\\"flip-horizontal\\",\\"background_color_back\\":\\"ffffff_1.00\\",\\"text_color_back\\":\\"3d3d3d_1.00\\",\\"padding_top\\":\\"4\\",\\"padding_right\\":\\"4\\",\\"padding_bottom\\":\\"4\\",\\"padding_left\\":\\"4\\"}},{\\"mod_name\\":\\"tile\\",\\"element_id\\":\\"8023953\\",\\"mod_settings\\":{\\"size\\":\\"portrait\\",\\"type_front\\":\\"text\\",\\"color_front\\":\\"gray\\",\\"title_front\\":\\"Gray Design\\",\\"text_front\\":\\"<p>Suscipit! Nis a placerat rhoncus, eros nulla accumsan augue, sit amet ornare ante nibh quis ex. Aenean porta  massa id iaculis.<\\\\/p>\\",\\"icon_type_front\\":\\"icon\\",\\"icon_front\\":\\"fa-bicycle\\",\\"icon_color_front\\":\\"ffffff_1.00\\",\\"gallery_front\\":\\"[gallery ids=\\\\\\\\\\\\\\"2621,2611,2604,2608\\\\\\\\\\\\\\"]\\",\\"gallery_autoplay_front\\":\\"4000\\",\\"gallery_hide_timer_front\\":\\"no\\",\\"type_map_front\\":\\"ROADMAP\\",\\"scrollwheel_map_front\\":\\"enable\\",\\"draggable_map_front\\":\\"enable\\",\\"background_color_front\\":\\"4a4a4a_1.00\\",\\"text_color_front\\":\\"f2f2f2_1.00\\",\\"type_back\\":\\"text\\",\\"icon_type_back\\":\\"icon\\",\\"gallery_autoplay_back\\":\\"off\\",\\"gallery_hide_timer_back\\":\\"no\\",\\"type_map_back\\":\\"ROADMAP\\",\\"scrollwheel_map_back\\":\\"enable\\",\\"draggable_map_back\\":\\"enable\\",\\"tile_autoflip\\":\\"0\\",\\"flip_effect\\":\\"flip-horizontal\\",\\"text_color_back\\":\\"4f4f4f_1.00\\",\\"padding_top\\":\\"4\\",\\"padding_right\\":\\"4\\",\\"padding_bottom\\":\\"4\\",\\"padding_left\\":\\"4\\"}},{\\"mod_name\\":\\"tile\\",\\"element_id\\":\\"0c7d7d6\\",\\"mod_settings\\":{\\"size\\":\\"square-small\\",\\"type_front\\":\\"blank\\",\\"color_front\\":\\"gray\\",\\"text_front\\":\\"<p>Suscipit! Nis a placerat rhoncus, eros nulla accumsan augue, sit amet ornare ante nibh quis ex. Aenean porta  massa id iaculis.<\\\\/p>\\",\\"icon_type_front\\":\\"icon\\",\\"gallery_front\\":\\"[gallery ids=\\\\\\\\\\\\\\"2621,2611,2604,2608\\\\\\\\\\\\\\"]\\",\\"gallery_autoplay_front\\":\\"4000\\",\\"gallery_hide_timer_front\\":\\"no\\",\\"type_map_front\\":\\"ROADMAP\\",\\"scrollwheel_map_front\\":\\"enable\\",\\"draggable_map_front\\":\\"enable\\",\\"type_back\\":\\"text\\",\\"icon_type_back\\":\\"icon\\",\\"gallery_autoplay_back\\":\\"off\\",\\"gallery_hide_timer_back\\":\\"no\\",\\"type_map_back\\":\\"ROADMAP\\",\\"scrollwheel_map_back\\":\\"enable\\",\\"draggable_map_back\\":\\"enable\\",\\"action_param_back\\":\\"newtab\\",\\"tile_autoflip\\":\\"3\\",\\"flip_effect\\":\\"flip-vertical\\",\\"background_color_back\\":\\"ffffff_1.00\\",\\"padding_top\\":\\"4\\",\\"padding_right\\":\\"4\\",\\"padding_bottom\\":\\"4\\",\\"padding_left\\":\\"4\\"}},{\\"mod_name\\":\\"tile\\",\\"element_id\\":\\"99e62da\\",\\"mod_settings\\":{\\"size\\":\\"square-small\\",\\"type_front\\":\\"button\\",\\"color_front\\":\\"gray\\",\\"title_front\\":\\"WordPress \\",\\"text_front\\":\\"<p>Suscipit! Nis a placerat rhoncus, eros nulla accumsan augue, sit amet ornare ante nibh quis ex. Aenean porta  massa id iaculis.<\\\\/p>\\",\\"icon_type_front\\":\\"icon\\",\\"icon_front\\":\\"fa-phone-square\\",\\"icon_color_front\\":\\"808080\\",\\"gallery_front\\":\\"[gallery ids=\\\\\\\\\\\\\\"2621,2611,2604,2608\\\\\\\\\\\\\\"]\\",\\"gallery_autoplay_front\\":\\"4000\\",\\"gallery_hide_timer_front\\":\\"no\\",\\"type_map_front\\":\\"ROADMAP\\",\\"scrollwheel_map_front\\":\\"enable\\",\\"draggable_map_front\\":\\"enable\\",\\"background_color_front\\":\\"ffffff_1.00\\",\\"text_color_front\\":\\"808080\\",\\"type_back\\":\\"text\\",\\"text_back\\":\\"<p>Quisque convallis, nisl a placera...<\\\\/p>\\",\\"icon_type_back\\":\\"icon\\",\\"gallery_autoplay_back\\":\\"off\\",\\"gallery_hide_timer_back\\":\\"no\\",\\"type_map_back\\":\\"ROADMAP\\",\\"scrollwheel_map_back\\":\\"enable\\",\\"draggable_map_back\\":\\"enable\\",\\"action_text_back\\":\\"See more themes\\",\\"action_link_back\\":\\"https:\\\\/\\\\/themify.me\\\\/themes\\",\\"action_param_back\\":\\"newtab\\",\\"tile_autoflip\\":\\"3\\",\\"flip_effect\\":\\"flip-vertical\\",\\"background_color_back\\":\\"4f4f4f\\",\\"text_color_back\\":\\"ffffff_1.00\\",\\"link_color_back\\":\\"ffffff_1.00\\",\\"padding_top\\":\\"4\\",\\"padding_right\\":\\"4\\",\\"padding_bottom\\":\\"4\\",\\"padding_left\\":\\"4\\"}},{\\"mod_name\\":\\"tile\\",\\"element_id\\":\\"76bb45d\\",\\"mod_settings\\":{\\"size\\":\\"square-small\\",\\"type_front\\":\\"blank\\",\\"color_front\\":\\"gray\\",\\"text_front\\":\\"<p>Suscipit! Nis a placerat rhoncus, eros nulla accumsan augue, sit amet ornare ante nibh quis ex. Aenean porta  massa id iaculis.<\\\\/p>\\",\\"icon_type_front\\":\\"icon\\",\\"gallery_front\\":\\"[gallery ids=\\\\\\\\\\\\\\"2621,2611,2604,2608\\\\\\\\\\\\\\"]\\",\\"gallery_autoplay_front\\":\\"4000\\",\\"gallery_hide_timer_front\\":\\"no\\",\\"type_map_front\\":\\"ROADMAP\\",\\"scrollwheel_map_front\\":\\"enable\\",\\"draggable_map_front\\":\\"enable\\",\\"type_back\\":\\"text\\",\\"icon_type_back\\":\\"icon\\",\\"gallery_autoplay_back\\":\\"off\\",\\"gallery_hide_timer_back\\":\\"no\\",\\"type_map_back\\":\\"ROADMAP\\",\\"scrollwheel_map_back\\":\\"enable\\",\\"draggable_map_back\\":\\"enable\\",\\"action_param_back\\":\\"newtab\\",\\"tile_autoflip\\":\\"3\\",\\"flip_effect\\":\\"flip-vertical\\",\\"background_color_back\\":\\"ffffff_1.00\\",\\"padding_top\\":\\"4\\",\\"padding_right\\":\\"4\\",\\"padding_bottom\\":\\"4\\",\\"padding_left\\":\\"4\\"}},{\\"mod_name\\":\\"tile\\",\\"element_id\\":\\"749c5ec\\",\\"mod_settings\\":{\\"size\\":\\"square-small\\",\\"type_front\\":\\"button\\",\\"color_front\\":\\"gray\\",\\"text_front\\":\\"<p>Suscipit! Nis a placerat rhoncus, eros nulla accumsan augue, sit amet ornare ante nibh quis ex. Aenean porta  massa id iaculis.<\\\\/p>\\",\\"icon_type_front\\":\\"icon\\",\\"icon_front\\":\\"fa-bullhorn\\",\\"icon_color_front\\":\\"ffffff_1.00\\",\\"gallery_front\\":\\"[gallery ids=\\\\\\\\\\\\\\"2621,2611,2604,2608\\\\\\\\\\\\\\"]\\",\\"gallery_autoplay_front\\":\\"4000\\",\\"gallery_hide_timer_front\\":\\"no\\",\\"type_map_front\\":\\"ROADMAP\\",\\"scrollwheel_map_front\\":\\"enable\\",\\"draggable_map_front\\":\\"enable\\",\\"background_color_front\\":\\"a8a8a8_1.00\\",\\"text_color_front\\":\\"ffffff_1.00\\",\\"link_color_front\\":\\"ffffff_1.00\\",\\"type_back\\":\\"blank\\",\\"text_back\\":\\"<p>Quisque convallis, nisl a placera...<\\\\/p>\\",\\"icon_type_back\\":\\"icon\\",\\"gallery_autoplay_back\\":\\"off\\",\\"gallery_hide_timer_back\\":\\"no\\",\\"type_map_back\\":\\"ROADMAP\\",\\"scrollwheel_map_back\\":\\"enable\\",\\"draggable_map_back\\":\\"enable\\",\\"action_text_back\\":\\"See more themes\\",\\"action_link_back\\":\\"https:\\\\/\\\\/themify.me\\\\/themes\\",\\"action_param_back\\":\\"newtab\\",\\"tile_autoflip\\":\\"3\\",\\"flip_effect\\":\\"flip-vertical\\",\\"background_color_back\\":\\"4f4f4f\\",\\"text_color_back\\":\\"ffffff_1.00\\",\\"link_color_back\\":\\"ffffff_1.00\\",\\"padding_top\\":\\"4\\",\\"padding_right\\":\\"4\\",\\"padding_bottom\\":\\"4\\",\\"padding_left\\":\\"4\\"}},{\\"mod_name\\":\\"tile\\",\\"element_id\\":\\"36c7ab8\\",\\"mod_settings\\":{\\"padding_top\\":\\"4\\",\\"padding_right\\":\\"4\\",\\"padding_bottom\\":\\"4\\",\\"padding_left\\":\\"4\\",\\"size\\":\\"landscape\\",\\"type_front\\":\\"map\\",\\"icon_type_front\\":\\"icon\\",\\"gallery_front\\":\\"[gallery _orderByField=\\\\\\\\\\\\\\"menu_order ID\\\\\\\\\\\\\\" ids=\\\\\\\\\\\\\\"2637,2696,2577\\\\\\\\\\\\\\"]\\",\\"gallery_autoplay_front\\":\\"4000\\",\\"gallery_hide_timer_front\\":\\"no\\",\\"address_map_front\\":\\"30 Adelaide St E, Toronto, ON, Canada\\",\\"type_map_front\\":\\"TERRAIN\\",\\"zoom_map_front\\":\\"17\\",\\"scrollwheel_map_front\\":\\"enable\\",\\"draggable_map_front\\":\\"enable\\",\\"type_back\\":\\"text\\",\\"icon_type_back\\":\\"icon\\",\\"gallery_autoplay_back\\":\\"off\\",\\"gallery_hide_timer_back\\":\\"no\\",\\"type_map_back\\":\\"ROADMAP\\",\\"zoom_map_back\\":\\"7\\",\\"scrollwheel_map_back\\":\\"enable\\",\\"draggable_map_back\\":\\"enable\\",\\"tile_autoflip\\":\\"0\\",\\"flip_effect\\":\\"flip-horizontal\\",\\"stick_at_position\\":\\"top\\",\\"unstick_when_element\\":\\"builder_end\\",\\"unstick_when_el_row_id\\":\\"b0e734d\\",\\"unstick_when_el_mod_id\\":\\"af401c2\\",\\"unstick_when_condition\\":\\"hits\\",\\"unstick_when_pos\\":\\"this\\"}},{\\"mod_name\\":\\"tile\\",\\"element_id\\":\\"4d87cd0\\",\\"mod_settings\\":{\\"size\\":\\"landscape\\",\\"type_front\\":\\"gallery\\",\\"icon_type_front\\":\\"icon\\",\\"gallery_front\\":\\"[gallery _orderByField=\\\\\\\\\\\\\\"menu_order ID\\\\\\\\\\\\\\" ids=\\\\\\\\\\\\\\"2637,2696,2577\\\\\\\\\\\\\\"]\\",\\"gallery_autoplay_front\\":\\"4000\\",\\"gallery_hide_timer_front\\":\\"no\\",\\"type_map_front\\":\\"ROADMAP\\",\\"scrollwheel_map_front\\":\\"enable\\",\\"draggable_map_front\\":\\"enable\\",\\"type_back\\":\\"text\\",\\"icon_type_back\\":\\"icon\\",\\"gallery_autoplay_back\\":\\"off\\",\\"gallery_hide_timer_back\\":\\"no\\",\\"type_map_back\\":\\"ROADMAP\\",\\"scrollwheel_map_back\\":\\"enable\\",\\"draggable_map_back\\":\\"enable\\",\\"tile_autoflip\\":\\"0\\",\\"flip_effect\\":\\"flip-horizontal\\",\\"padding_top\\":\\"4\\",\\"padding_right\\":\\"4\\",\\"padding_bottom\\":\\"4\\",\\"padding_left\\":\\"4\\"}},{\\"mod_name\\":\\"tile\\",\\"element_id\\":\\"ed9edd4\\",\\"mod_settings\\":{\\"size\\":\\"square-small\\",\\"type_front\\":\\"text\\",\\"title_front\\":\\"About us\\",\\"text_front\\":\\"<p>Convallis, nisl a placerat rhoncus, eros nulla. Ila accumsan augue, sit amet ornare.<\\\\/p>\\",\\"icon_type_front\\":\\"icon\\",\\"gallery_front\\":\\"[gallery _orderByField=\\\\\\\\\\\\\\"menu_order ID\\\\\\\\\\\\\\" ids=\\\\\\\\\\\\\\"2637,2696,2577\\\\\\\\\\\\\\"]\\",\\"gallery_autoplay_front\\":\\"4000\\",\\"gallery_hide_timer_front\\":\\"no\\",\\"type_map_front\\":\\"ROADMAP\\",\\"scrollwheel_map_front\\":\\"enable\\",\\"draggable_map_front\\":\\"enable\\",\\"background_color_front\\":\\"242424_1.00\\",\\"text_color_front\\":\\"ffffff_1.00\\",\\"type_back\\":\\"button\\",\\"button_link_back\\":\\"https:\\\\/\\\\/twitter.com\\\\/themify\\",\\"icon_type_back\\":\\"icon\\",\\"icon_back\\":\\"fa-twitter\\",\\"icon_color_back\\":\\"ffffff_1.00\\",\\"gallery_autoplay_back\\":\\"off\\",\\"gallery_hide_timer_back\\":\\"no\\",\\"type_map_back\\":\\"ROADMAP\\",\\"scrollwheel_map_back\\":\\"enable\\",\\"draggable_map_back\\":\\"enable\\",\\"tile_autoflip\\":\\"0\\",\\"flip_effect\\":\\"flip-vertical\\",\\"background_color_back\\":\\"333333_1.00\\",\\"text_color_back\\":\\"ffffff_1.00\\",\\"link_color_back\\":\\"ffffff_1.00\\",\\"padding_top\\":\\"4\\",\\"padding_right\\":\\"4\\",\\"padding_bottom\\":\\"4\\",\\"padding_left\\":\\"4\\"}}]}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"background_color\\":\\"d1d1d1_1.00\\",\\"padding_top\\":\\"5\\",\\"padding_top_unit\\":\\"%\\"}},{\\"element_id\\":\\"e496991\\",\\"row_order\\":\\"2\\",\\"cols\\":[{\\"element_id\\":\\"f8f334c\\",\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\"}]}]',
  ),
  'tax_input' => 
  array (
  ),
);
themify_process_post_import( $post );


$post = array (
  'ID' => 2782,
  'post_date' => '2014-12-29 23:51:14',
  'post_date_gmt' => '2014-12-29 23:51:14',
  'post_content' => '',
  'post_title' => 'Portfolio - 3 Columns',
  'post_excerpt' => '',
  'post_name' => 'portfolio-3-columns',
  'post_modified' => '2017-08-21 07:29:06',
  'post_modified_gmt' => '2017-08-21 07:29:06',
  'post_content_filtered' => '',
  'post_parent' => 2455,
  'guid' => 'https://themify.me/demo/themes/stack/?page_id=2782',
  'menu_order' => 2,
  'post_type' => 'page',
  'meta_input' => 
  array (
    'page_layout' => 'sidebar-none',
    'content_width' => 'full_width',
    'hide_page_title' => 'default',
    'order' => 'desc',
    'orderby' => 'date',
    'layout' => 'list-post',
    'enable_masonry' => 'default',
    'display_content' => 'content',
    'hide_title' => 'default',
    'unlink_title' => 'default',
    'hide_date' => 'default',
    'hide_image' => 'default',
    'unlink_image' => 'default',
    'hide_navigation' => 'default',
    'portfolio_query_category' => '0',
    'portfolio_order' => 'desc',
    'portfolio_orderby' => 'date',
    'portfolio_layout' => 'grid3',
    'portfolio_enable_masonry' => 'yes',
    'portfolio_posts_per_page' => '9',
    'portfolio_image_width' => '500',
    'portfolio_image_height' => '0',
    'portfolio_hide_title' => 'default',
    'portfolio_unlink_title' => 'default',
    'portfolio_hide_meta_all' => 'default',
    'portfolio_hide_image' => 'default',
    'portfolio_unlink_image' => 'default',
    'portfolio_hide_navigation' => 'default',
    'builder_tiles_fluid_tiles_base_size' => '16',
    'builder_switch_frontend' => '0',
  ),
  'tax_input' => 
  array (
  ),
);
themify_process_post_import( $post );


$post = array (
  'ID' => 2785,
  'post_date' => '2014-12-30 00:59:05',
  'post_date_gmt' => '2014-12-30 00:59:05',
  'post_content' => '',
  'post_title' => 'Portfolio - 4 Columns',
  'post_excerpt' => '',
  'post_name' => 'portfolio-4-columns',
  'post_modified' => '2017-08-21 07:29:06',
  'post_modified_gmt' => '2017-08-21 07:29:06',
  'post_content_filtered' => '',
  'post_parent' => 2455,
  'guid' => 'https://themify.me/demo/themes/stack/?page_id=2785',
  'menu_order' => 2,
  'post_type' => 'page',
  'meta_input' => 
  array (
    'page_layout' => 'sidebar-none',
    'content_width' => 'full_width',
    'hide_page_title' => 'default',
    'order' => 'desc',
    'orderby' => 'date',
    'layout' => 'list-post',
    'enable_masonry' => 'default',
    'display_content' => 'content',
    'hide_title' => 'default',
    'unlink_title' => 'default',
    'hide_date' => 'default',
    'hide_image' => 'default',
    'unlink_image' => 'default',
    'hide_navigation' => 'default',
    'portfolio_query_category' => '0',
    'portfolio_order' => 'desc',
    'portfolio_orderby' => 'date',
    'portfolio_layout' => 'grid4',
    'portfolio_enable_masonry' => 'yes',
    'portfolio_posts_per_page' => '8',
    'portfolio_image_width' => '400',
    'portfolio_image_height' => '0',
    'portfolio_hide_title' => 'default',
    'portfolio_unlink_title' => 'default',
    'portfolio_hide_meta_all' => 'default',
    'portfolio_hide_image' => 'no',
    'portfolio_unlink_image' => 'default',
    'portfolio_hide_navigation' => 'default',
    'builder_tiles_fluid_tiles_base_size' => '16',
    'builder_switch_frontend' => '0',
  ),
  'tax_input' => 
  array (
  ),
);
themify_process_post_import( $post );


$post = array (
  'ID' => 2787,
  'post_date' => '2014-12-30 00:59:24',
  'post_date_gmt' => '2014-12-30 00:59:24',
  'post_content' => '',
  'post_title' => 'Portfolio - 2 Columns',
  'post_excerpt' => '',
  'post_name' => 'portfolio-2-columns',
  'post_modified' => '2017-08-21 07:29:05',
  'post_modified_gmt' => '2017-08-21 07:29:05',
  'post_content_filtered' => '',
  'post_parent' => 2455,
  'guid' => 'https://themify.me/demo/themes/stack/?page_id=2787',
  'menu_order' => 2,
  'post_type' => 'page',
  'meta_input' => 
  array (
    'page_layout' => 'sidebar-none',
    'content_width' => 'full_width',
    'hide_page_title' => 'default',
    'order' => 'desc',
    'orderby' => 'date',
    'layout' => 'list-post',
    'enable_masonry' => 'default',
    'display_content' => 'content',
    'hide_title' => 'default',
    'unlink_title' => 'default',
    'hide_date' => 'default',
    'hide_image' => 'default',
    'unlink_image' => 'default',
    'hide_navigation' => 'default',
    'portfolio_query_category' => '0',
    'portfolio_order' => 'desc',
    'portfolio_orderby' => 'date',
    'portfolio_layout' => 'grid2',
    'portfolio_enable_masonry' => 'yes',
    'portfolio_posts_per_page' => '8',
    'portfolio_image_width' => '700',
    'portfolio_image_height' => '0',
    'portfolio_hide_title' => 'default',
    'portfolio_unlink_title' => 'default',
    'portfolio_hide_meta_all' => 'default',
    'portfolio_hide_image' => 'default',
    'portfolio_unlink_image' => 'default',
    'portfolio_hide_navigation' => 'default',
    'builder_tiles_fluid_tiles_base_size' => '16',
    'builder_switch_frontend' => '0',
  ),
  'tax_input' => 
  array (
  ),
);
themify_process_post_import( $post );


$post = array (
  'ID' => 2653,
  'post_date' => '2014-12-28 09:55:21',
  'post_date_gmt' => '2014-12-28 09:55:21',
  'post_content' => '<!--themify_builder_static--><p>Use the <a href="https://themify.me/addons/contact">Contact Addon</a> to drop a simple contact form anywhere in the Builder.</p> 
 <form action="https://themify.me/demo/themes/stack/wp-admin/admin-ajax.php" id="contact-0--form" method="post"> 
 <label for="contact-0--contact-name">Name *</label> <input type="text" name="contact-name" placeholder="" id="contact-0--contact-name" value="" required /> 
 <label for="contact-0--contact-email">Email *</label> <input type="text" name="contact-email" placeholder="" id="contact-0--contact-email" value="" required /> 
 <label for="contact-0--contact-message">Message *</label> <textarea name="contact-message" placeholder="" id="contact-0--contact-message" rows="8" cols="45" required></textarea> <button type="submit"> Send </button> </form>
 
<h3></h3><iframe frameborder="0" scrolling="no" marginheight="0" marginwidth="0" src="https://maps.google.com/maps?q=124+Street%2C+Toronto%2C+ON%2C+Canada&amp;t=m&amp;z=12&amp;output=embed&amp;iwloc=near"></iframe>
 <h4>Address</h4><p>124 Street<br />Toronto, ON<br />Canada</p> 
 <h4>Phone</h4><p>433-344-6788</p><!--/themify_builder_static-->',
  'post_title' => 'Contact',
  'post_excerpt' => '',
  'post_name' => 'contact',
  'post_modified' => '2018-11-13 00:34:02',
  'post_modified_gmt' => '2018-11-13 00:34:02',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/stack/?page_id=2653',
  'menu_order' => 3,
  'post_type' => 'page',
  'meta_input' => 
  array (
    'page_layout' => 'sidebar-none',
    'content_width' => 'default_width',
    'hide_page_title' => 'default',
    'order' => 'desc',
    'orderby' => 'date',
    'layout' => 'list-post',
    'enable_masonry' => 'default',
    'display_content' => 'content',
    'hide_title' => 'default',
    'unlink_title' => 'default',
    'hide_date' => 'default',
    'hide_image' => 'default',
    'unlink_image' => 'default',
    'hide_navigation' => 'default',
    'portfolio_order' => 'desc',
    'portfolio_orderby' => 'date',
    'portfolio_layout' => 'grid4',
    'portfolio_enable_masonry' => 'default',
    'portfolio_display_content' => 'content',
    'portfolio_hide_title' => 'default',
    'portfolio_unlink_title' => 'default',
    'portfolio_hide_meta_all' => 'default',
    'portfolio_hide_image' => 'default',
    'portfolio_unlink_image' => 'default',
    'portfolio_hide_navigation' => 'default',
    'builder_tiles_fluid_tiles_base_size' => '16',
    'builder_switch_frontend' => '0',
    '_themify_builder_settings_json' => '[{\\"element_id\\":\\"38786f9\\",\\"row_order\\":\\"0\\",\\"cols\\":[{\\"element_id\\":\\"92c180c\\",\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col4-2\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"element_id\\":\\"75d0624\\",\\"mod_settings\\":{\\"content_text\\":\\"<p>Use the <a href=\\\\\\\\\\\\\\"https:\\\\/\\\\/themify.me\\\\/addons\\\\/contact\\\\\\\\\\\\\\">Contact Addon<\\\\/a> to drop a simple contact form anywhere in the Builder.<\\\\/p>\\"}},{\\"mod_name\\":\\"contact\\",\\"element_id\\":\\"6b9048c\\",\\"mod_settings\\":{\\"mail_contact\\":\\"info@themify.me\\"}}]},{\\"element_id\\":\\"7531ccf\\",\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col4-2\\",\\"modules\\":[{\\"mod_name\\":\\"map\\",\\"element_id\\":\\"3c6e545\\",\\"mod_settings\\":{\\"address_map\\":\\"124 Street, Toronto, ON, Canada\\",\\"zoom_map\\":\\"12\\",\\"w_map\\":\\"100\\",\\"unit_w\\":\\"%\\",\\"h_map\\":\\"350\\",\\"type_map\\":\\"ROADMAP\\",\\"scrollwheel_map\\":\\"disable\\",\\"draggable_map\\":\\"enable\\",\\"draggable_disable_mobile_map\\":\\"yes\\",\\"info_window_map\\":\\"124 Street, Toronto, ON, Canada\\\\nPhone: 433-344-6788\\",\\"margin_bottom\\":\\"40\\",\\"w_map_static\\":\\"500\\",\\"w_map_unit\\":\\"%\\",\\"map_display_type\\":\\"dynamic\\"}},{\\"element_id\\":\\"5812ef1\\",\\"row_order\\":\\"1\\",\\"cols\\":[{\\"element_id\\":\\"e0e9777\\",\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col4-2\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"element_id\\":\\"c68cb41\\",\\"mod_settings\\":{\\"content_text\\":\\"<h4>Address<\\\\/h4><p>124 Street<br \\\\/>Toronto, ON<br \\\\/>Canada<\\\\/p>\\"}}]},{\\"element_id\\":\\"ab18496\\",\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col4-2\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"element_id\\":\\"4b2b6ab\\",\\"mod_settings\\":{\\"content_text\\":\\"<h4>Phone<\\\\/h4><p>433-344-6788<\\\\/p>\\"}}]}]}]}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"padding_top\\":\\"3\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"3\\",\\"padding_bottom_unit\\":\\"%\\"}},{\\"element_id\\":\\"64e4fe1\\",\\"row_order\\":\\"1\\",\\"cols\\":[{\\"element_id\\":\\"eb217c9\\",\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"mod_name\\":\\"tile\\",\\"element_id\\":\\"b92fb88\\",\\"mod_settings\\":{\\"size\\":\\"square-large\\",\\"type_front\\":\\"map\\",\\"title_front\\":\\"Tile Title\\",\\"text_front\\":\\"<p>Tile content<\\\\/p>\\",\\"icon_type_front\\":\\"icon\\",\\"gallery_autoplay_front\\":\\"off\\",\\"gallery_hide_timer_front\\":\\"no\\",\\"type_map_front\\":\\"ROADMAP\\",\\"zoom_map_front\\":\\"7\\",\\"scrollwheel_map_front\\":\\"enable\\",\\"draggable_map_front\\":\\"enable\\",\\"type_back\\":\\"text\\",\\"icon_type_back\\":\\"icon\\",\\"gallery_autoplay_back\\":\\"off\\",\\"gallery_hide_timer_back\\":\\"no\\",\\"type_map_back\\":\\"ROADMAP\\",\\"zoom_map_back\\":\\"7\\",\\"scrollwheel_map_back\\":\\"enable\\",\\"draggable_map_back\\":\\"enable\\",\\"tile_autoflip\\":\\"0\\",\\"flip_effect\\":\\"flip-horizontal\\",\\"stick_at_position\\":\\"top\\",\\"unstick_when_element\\":\\"builder_end\\",\\"unstick_when_el_row_id\\":\\"38786f9\\",\\"unstick_when_el_mod_id\\":\\"75d0624\\",\\"unstick_when_condition\\":\\"hits\\",\\"unstick_when_pos\\":\\"this\\"}}]}]},{\\"element_id\\":\\"7595869\\",\\"row_order\\":\\"2\\",\\"cols\\":[{\\"element_id\\":\\"c980627\\",\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\"}]}]',
  ),
  'tax_input' => 
  array (
  ),
);
themify_process_post_import( $post );


$post = array (
  'ID' => 2808,
  'post_date' => '2014-12-30 22:40:47',
  'post_date_gmt' => '2014-12-30 22:40:47',
  'post_content' => '',
  'post_title' => 'Demo 2',
  'post_excerpt' => '',
  'post_name' => 'demo-2-2',
  'post_modified' => '2017-08-21 07:28:59',
  'post_modified_gmt' => '2017-08-21 07:28:59',
  'post_content_filtered' => '',
  'post_parent' => 2981,
  'guid' => 'https://themify.me/demo/themes/stack/?page_id=2808',
  'menu_order' => 3,
  'post_type' => 'page',
  'meta_input' => 
  array (
    'page_layout' => 'sidebar-none',
    'content_width' => 'full_width',
    'hide_page_title' => 'yes',
    'order' => 'desc',
    'orderby' => 'date',
    'layout' => 'list-post',
    'enable_masonry' => 'default',
    'display_content' => 'content',
    'hide_title' => 'default',
    'unlink_title' => 'default',
    'hide_date' => 'default',
    'hide_image' => 'default',
    'unlink_image' => 'default',
    'hide_navigation' => 'default',
    'portfolio_order' => 'desc',
    'portfolio_orderby' => 'date',
    'portfolio_layout' => 'grid4',
    'portfolio_enable_masonry' => 'default',
    'portfolio_display_content' => 'content',
    'portfolio_hide_title' => 'default',
    'portfolio_unlink_title' => 'default',
    'portfolio_hide_meta_all' => 'default',
    'portfolio_hide_image' => 'default',
    'portfolio_unlink_image' => 'default',
    'portfolio_hide_navigation' => 'default',
    'builder_tiles_fluid_tiles_base_size' => '16',
    'builder_switch_frontend' => '0',
    '_themify_builder_settings_json' => '[{\\"row_order\\":\\"0\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full first\\",\\"modules\\":[{\\"mod_name\\":\\"tile\\",\\"mod_settings\\":{\\"size\\":\\"square-large\\",\\"type_front\\":\\"text\\",\\"color_front\\":\\"default\\",\\"title_front\\":\\"About\\",\\"text_front\\":\\"<p>The Stack is designed with the Tiles module built-in to it, allowing you to create custom designed sites using tiles with the Metro layout. The Tiles module is an extendable addon that can be purchase for $10. Purchasing it as a stand-alone plugin allows you to use it on any WordPress site.</p>\\",\\"button_link_params_front\\":\\"|\\",\\"icon_type_front\\":\\"icon\\",\\"gallery_autoplay_front\\":\\"off\\",\\"gallery_hide_timer_front\\":\\"no\\",\\"type_map_front\\":\\"ROADMAP\\",\\"scrollwheel_map_front\\":\\"enable\\",\\"draggable_map_front\\":\\"enable\\",\\"action_text_front\\":\\"Buy Now\\",\\"action_link_front\\":\\"https://themify.me/themes/stack\\",\\"action_param_front\\":\\"newtab\\",\\"background_color_front\\":\\"4e3e7d_1.00\\",\\"text_color_front\\":\\"ffffff_1.00\\",\\"link_color_front\\":\\"ffffff_1.00\\",\\"type_back\\":\\"text\\",\\"color_back\\":\\"default\\",\\"button_link_params_back\\":\\"|\\",\\"icon_type_back\\":\\"icon\\",\\"gallery_autoplay_back\\":\\"off\\",\\"gallery_hide_timer_back\\":\\"no\\",\\"type_map_back\\":\\"ROADMAP\\",\\"scrollwheel_map_back\\":\\"enable\\",\\"draggable_map_back\\":\\"enable\\",\\"action_param_back\\":\\"|\\",\\"tile_autoflip\\":\\"0\\",\\"flip_effect\\":\\"flip-horizontal\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"padding_top\\":\\"4\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right\\":\\"4\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom\\":\\"4\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left\\":\\"4\\",\\"padding_left_unit\\":\\"px\\"}},{\\"mod_name\\":\\"tile\\",\\"mod_settings\\":{\\"size\\":\\"square-small\\",\\"type_front\\":\\"button\\",\\"color_front\\":\\"default\\",\\"title_front\\":\\"Shop\\",\\"button_link_front\\":\\"https://themify.me/demo/themes/stack/shop/\\",\\"button_link_params_front\\":\\"|\\",\\"icon_type_front\\":\\"icon\\",\\"icon_front\\":\\"fa-shopping-cart\\",\\"icon_color_front\\":\\"ffffff_1.00\\",\\"gallery_autoplay_front\\":\\"off\\",\\"gallery_hide_timer_front\\":\\"no\\",\\"type_map_front\\":\\"ROADMAP\\",\\"scrollwheel_map_front\\":\\"enable\\",\\"draggable_map_front\\":\\"enable\\",\\"action_param_front\\":\\"|\\",\\"background_color_front\\":\\"9e4fa8_1.00\\",\\"text_color_front\\":\\"ffffff_1.00\\",\\"link_color_front\\":\\"ffffff_1.00\\",\\"type_back\\":\\"text\\",\\"color_back\\":\\"default\\",\\"button_link_params_back\\":\\"|\\",\\"icon_type_back\\":\\"icon\\",\\"gallery_autoplay_back\\":\\"off\\",\\"gallery_hide_timer_back\\":\\"no\\",\\"type_map_back\\":\\"ROADMAP\\",\\"scrollwheel_map_back\\":\\"enable\\",\\"draggable_map_back\\":\\"enable\\",\\"action_param_back\\":\\"|\\",\\"tile_autoflip\\":\\"0\\",\\"flip_effect\\":\\"flip-horizontal\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"padding_top\\":\\"4\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right\\":\\"4\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom\\":\\"4\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left\\":\\"4\\",\\"padding_left_unit\\":\\"px\\"}},{\\"mod_name\\":\\"tile\\",\\"mod_settings\\":{\\"size\\":\\"square-small\\",\\"type_front\\":\\"button\\",\\"color_front\\":\\"default\\",\\"title_front\\":\\"Portfolio\\",\\"button_link_front\\":\\"https://themify.me/demo/themes/stack/portfolio/\\",\\"button_link_params_front\\":\\"newtab\\",\\"icon_type_front\\":\\"icon\\",\\"gallery_autoplay_front\\":\\"off\\",\\"gallery_hide_timer_front\\":\\"no\\",\\"type_map_front\\":\\"ROADMAP\\",\\"scrollwheel_map_front\\":\\"enable\\",\\"draggable_map_front\\":\\"enable\\",\\"action_param_front\\":\\"|\\",\\"text_color_front\\":\\"ffffff_1.00\\",\\"link_color_front\\":\\"ffffff_1.00\\",\\"background_image_front\\":\\"https://themify.me/demo/themes/stack/files/2014/12/91078382.jpg\\",\\"type_back\\":\\"text\\",\\"color_back\\":\\"default\\",\\"button_link_params_back\\":\\"|\\",\\"icon_type_back\\":\\"icon\\",\\"gallery_autoplay_back\\":\\"off\\",\\"gallery_hide_timer_back\\":\\"no\\",\\"type_map_back\\":\\"ROADMAP\\",\\"scrollwheel_map_back\\":\\"enable\\",\\"draggable_map_back\\":\\"enable\\",\\"action_param_back\\":\\"|\\",\\"tile_autoflip\\":\\"0\\",\\"flip_effect\\":\\"flip-horizontal\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"padding_top\\":\\"4\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right\\":\\"4\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom\\":\\"4\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left\\":\\"4\\",\\"padding_left_unit\\":\\"px\\"}},{\\"mod_name\\":\\"tile\\",\\"mod_settings\\":{\\"size\\":\\"square-large\\",\\"type_front\\":\\"gallery\\",\\"color_front\\":\\"default\\",\\"button_link_params_front\\":\\"|\\",\\"icon_type_front\\":\\"icon\\",\\"gallery_front\\":\\"[gallery ids=\\\\\\\\\\\\\\"2641,2689,2640,2629,2687\\\\\\\\\\\\\\"]\\",\\"gallery_autoplay_front\\":\\"off\\",\\"gallery_hide_timer_front\\":\\"no\\",\\"type_map_front\\":\\"ROADMAP\\",\\"scrollwheel_map_front\\":\\"enable\\",\\"draggable_map_front\\":\\"enable\\",\\"action_param_front\\":\\"|\\",\\"text_color_front\\":\\"ffffff_1.00\\",\\"link_color_front\\":\\"ffffff_1.00\\",\\"type_back\\":\\"text\\",\\"color_back\\":\\"default\\",\\"button_link_params_back\\":\\"|\\",\\"icon_type_back\\":\\"icon\\",\\"gallery_autoplay_back\\":\\"off\\",\\"gallery_hide_timer_back\\":\\"no\\",\\"type_map_back\\":\\"ROADMAP\\",\\"scrollwheel_map_back\\":\\"enable\\",\\"draggable_map_back\\":\\"enable\\",\\"action_param_back\\":\\"|\\",\\"tile_autoflip\\":\\"0\\",\\"flip_effect\\":\\"flip-horizontal\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"padding_top\\":\\"4\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right\\":\\"4\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom\\":\\"4\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left\\":\\"4\\",\\"padding_left_unit\\":\\"px\\"}},{\\"mod_name\\":\\"tile\\",\\"mod_settings\\":{\\"size\\":\\"square-small\\",\\"type_front\\":\\"button\\",\\"color_front\\":\\"default\\",\\"title_front\\":\\"Blog\\",\\"button_link_front\\":\\"https://themify.me/demo/themes/stack/blog/\\",\\"button_link_params_front\\":\\"newtab\\",\\"icon_type_front\\":\\"icon\\",\\"gallery_autoplay_front\\":\\"off\\",\\"gallery_hide_timer_front\\":\\"no\\",\\"type_map_front\\":\\"ROADMAP\\",\\"scrollwheel_map_front\\":\\"enable\\",\\"draggable_map_front\\":\\"enable\\",\\"action_param_front\\":\\"|\\",\\"text_color_front\\":\\"ffffff_1.00\\",\\"link_color_front\\":\\"ffffff_1.00\\",\\"background_image_front\\":\\"https://themify.me/demo/themes/stack/files/2014/12/136757601.jpg\\",\\"type_back\\":\\"text\\",\\"color_back\\":\\"default\\",\\"button_link_params_back\\":\\"|\\",\\"icon_type_back\\":\\"icon\\",\\"gallery_autoplay_back\\":\\"off\\",\\"gallery_hide_timer_back\\":\\"no\\",\\"type_map_back\\":\\"ROADMAP\\",\\"scrollwheel_map_back\\":\\"enable\\",\\"draggable_map_back\\":\\"enable\\",\\"action_param_back\\":\\"|\\",\\"tile_autoflip\\":\\"0\\",\\"flip_effect\\":\\"flip-horizontal\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"padding_top\\":\\"4\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right\\":\\"4\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom\\":\\"4\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left\\":\\"4\\",\\"padding_left_unit\\":\\"px\\"}},{\\"mod_name\\":\\"tile\\",\\"mod_settings\\":{\\"size\\":\\"square-small\\",\\"type_front\\":\\"button\\",\\"color_front\\":\\"default\\",\\"title_front\\":\\"Contact\\",\\"button_link_front\\":\\"https://themify.me/contact\\",\\"button_link_params_front\\":\\"newtab\\",\\"icon_type_front\\":\\"icon\\",\\"icon_front\\":\\"fa-envelope-o\\",\\"icon_color_front\\":\\"ffffff_1.00\\",\\"gallery_autoplay_front\\":\\"off\\",\\"gallery_hide_timer_front\\":\\"no\\",\\"type_map_front\\":\\"ROADMAP\\",\\"scrollwheel_map_front\\":\\"enable\\",\\"draggable_map_front\\":\\"enable\\",\\"action_param_front\\":\\"|\\",\\"background_color_front\\":\\"4fbdb9_1.00\\",\\"text_color_front\\":\\"ffffff_1.00\\",\\"link_color_front\\":\\"ffffff_1.00\\",\\"type_back\\":\\"text\\",\\"color_back\\":\\"default\\",\\"button_link_params_back\\":\\"|\\",\\"icon_type_back\\":\\"icon\\",\\"gallery_autoplay_back\\":\\"off\\",\\"gallery_hide_timer_back\\":\\"no\\",\\"type_map_back\\":\\"ROADMAP\\",\\"scrollwheel_map_back\\":\\"enable\\",\\"draggable_map_back\\":\\"enable\\",\\"action_param_back\\":\\"|\\",\\"tile_autoflip\\":\\"0\\",\\"flip_effect\\":\\"flip-horizontal\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"padding_top\\":\\"4\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right\\":\\"4\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom\\":\\"4\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left\\":\\"4\\",\\"padding_left_unit\\":\\"px\\"}},{\\"mod_name\\":\\"tile\\",\\"mod_settings\\":{\\"size\\":\\"square-large\\",\\"type_front\\":\\"text\\",\\"color_front\\":\\"default\\",\\"title_front\\":\\"Tweets\\",\\"text_front\\":\\"<p>[themify_twitter username=\\\\\\\\\\\\\\"themify\\\\\\\\\\\\\\" show_count=\\\\\\\\\\\\\\"3\\\\\\\\\\\\\\" show_follow=\\\\\\\\\\\\\\"true\\\\\\\\\\\\\\" follow_text=\\\\\\\\\\\\\\"Follow Themify\\\\\\\\\\\\\\"]</p>\\",\\"button_link_params_front\\":\\"|\\",\\"icon_type_front\\":\\"icon\\",\\"gallery_autoplay_front\\":\\"off\\",\\"gallery_hide_timer_front\\":\\"no\\",\\"type_map_front\\":\\"ROADMAP\\",\\"scrollwheel_map_front\\":\\"enable\\",\\"draggable_map_front\\":\\"enable\\",\\"action_param_front\\":\\"|\\",\\"background_color_front\\":\\"cc6c2b_1.00\\",\\"text_color_front\\":\\"ffffff_1.00\\",\\"link_color_front\\":\\"ffffff_1.00\\",\\"type_back\\":\\"text\\",\\"color_back\\":\\"default\\",\\"button_link_params_back\\":\\"|\\",\\"icon_type_back\\":\\"icon\\",\\"gallery_autoplay_back\\":\\"off\\",\\"gallery_hide_timer_back\\":\\"no\\",\\"type_map_back\\":\\"ROADMAP\\",\\"scrollwheel_map_back\\":\\"enable\\",\\"draggable_map_back\\":\\"enable\\",\\"action_param_back\\":\\"|\\",\\"tile_autoflip\\":\\"0\\",\\"flip_effect\\":\\"flip-horizontal\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"padding_top\\":\\"4\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right\\":\\"4\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom\\":\\"4\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left\\":\\"4\\",\\"padding_left_unit\\":\\"px\\"}},{\\"mod_name\\":\\"tile\\",\\"mod_settings\\":{\\"size\\":\\"square-small\\",\\"type_front\\":\\"button\\",\\"color_front\\":\\"default\\",\\"title_front\\":\\"Facebook\\",\\"button_link_front\\":\\"https://www.facebook.com/themify\\",\\"button_link_params_front\\":\\"newtab\\",\\"icon_type_front\\":\\"icon\\",\\"icon_front\\":\\"fa-facebook\\",\\"icon_color_front\\":\\"ffffff_1.00\\",\\"gallery_autoplay_front\\":\\"off\\",\\"gallery_hide_timer_front\\":\\"no\\",\\"type_map_front\\":\\"ROADMAP\\",\\"scrollwheel_map_front\\":\\"enable\\",\\"draggable_map_front\\":\\"enable\\",\\"action_param_front\\":\\"|\\",\\"background_color_front\\":\\"3D5B99\\",\\"text_color_front\\":\\"ffffff_1.00\\",\\"link_color_front\\":\\"ffffff_1.00\\",\\"type_back\\":\\"text\\",\\"color_back\\":\\"default\\",\\"button_link_params_back\\":\\"|\\",\\"icon_type_back\\":\\"icon\\",\\"gallery_autoplay_back\\":\\"off\\",\\"gallery_hide_timer_back\\":\\"no\\",\\"type_map_back\\":\\"ROADMAP\\",\\"scrollwheel_map_back\\":\\"enable\\",\\"draggable_map_back\\":\\"enable\\",\\"action_param_back\\":\\"|\\",\\"tile_autoflip\\":\\"0\\",\\"flip_effect\\":\\"flip-horizontal\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"padding_top\\":\\"4\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right\\":\\"4\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom\\":\\"4\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left\\":\\"4\\",\\"padding_left_unit\\":\\"px\\"}},{\\"mod_name\\":\\"tile\\",\\"mod_settings\\":{\\"size\\":\\"square-small\\",\\"type_front\\":\\"button\\",\\"color_front\\":\\"default\\",\\"title_front\\":\\"Google+\\",\\"button_link_front\\":\\"https://plus.google.com/u/0/b/109280316400365629341/109280316400365629341/posts\\",\\"button_link_params_front\\":\\"newtab\\",\\"icon_type_front\\":\\"icon\\",\\"icon_front\\":\\"fa-google-plus\\",\\"icon_color_front\\":\\"ffffff_1.00\\",\\"gallery_autoplay_front\\":\\"off\\",\\"gallery_hide_timer_front\\":\\"no\\",\\"type_map_front\\":\\"ROADMAP\\",\\"scrollwheel_map_front\\":\\"enable\\",\\"draggable_map_front\\":\\"enable\\",\\"action_param_front\\":\\"|\\",\\"background_color_front\\":\\"DD4B39\\",\\"text_color_front\\":\\"ffffff_1.00\\",\\"link_color_front\\":\\"ffffff_1.00\\",\\"type_back\\":\\"text\\",\\"color_back\\":\\"default\\",\\"button_link_params_back\\":\\"|\\",\\"icon_type_back\\":\\"icon\\",\\"gallery_autoplay_back\\":\\"off\\",\\"gallery_hide_timer_back\\":\\"no\\",\\"type_map_back\\":\\"ROADMAP\\",\\"scrollwheel_map_back\\":\\"enable\\",\\"draggable_map_back\\":\\"enable\\",\\"action_param_back\\":\\"|\\",\\"tile_autoflip\\":\\"0\\",\\"flip_effect\\":\\"flip-horizontal\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"padding_top\\":\\"4\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right\\":\\"4\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom\\":\\"4\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left\\":\\"4\\",\\"padding_left_unit\\":\\"px\\"}},{\\"mod_name\\":\\"tile\\",\\"mod_settings\\":{\\"size\\":\\"square-small\\",\\"type_front\\":\\"button\\",\\"color_front\\":\\"default\\",\\"title_front\\":\\"Youtube\\",\\"button_link_front\\":\\"https://www.youtube.com/user/themifyme\\",\\"button_link_params_front\\":\\"newtab\\",\\"icon_type_front\\":\\"icon\\",\\"icon_front\\":\\"fa-youtube-play\\",\\"icon_color_front\\":\\"ffffff_1.00\\",\\"gallery_autoplay_front\\":\\"off\\",\\"gallery_hide_timer_front\\":\\"no\\",\\"type_map_front\\":\\"ROADMAP\\",\\"scrollwheel_map_front\\":\\"enable\\",\\"draggable_map_front\\":\\"enable\\",\\"action_param_front\\":\\"|\\",\\"background_color_front\\":\\"E02927\\",\\"text_color_front\\":\\"ffffff_1.00\\",\\"link_color_front\\":\\"ffffff_1.00\\",\\"type_back\\":\\"text\\",\\"color_back\\":\\"default\\",\\"button_link_params_back\\":\\"|\\",\\"icon_type_back\\":\\"icon\\",\\"gallery_autoplay_back\\":\\"off\\",\\"gallery_hide_timer_back\\":\\"no\\",\\"type_map_back\\":\\"ROADMAP\\",\\"scrollwheel_map_back\\":\\"enable\\",\\"draggable_map_back\\":\\"enable\\",\\"action_param_back\\":\\"|\\",\\"tile_autoflip\\":\\"0\\",\\"flip_effect\\":\\"flip-horizontal\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"padding_top\\":\\"4\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right\\":\\"4\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom\\":\\"4\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left\\":\\"4\\",\\"padding_left_unit\\":\\"px\\"}},{\\"mod_name\\":\\"tile\\",\\"mod_settings\\":{\\"size\\":\\"square-small\\",\\"type_front\\":\\"button\\",\\"color_front\\":\\"default\\",\\"title_front\\":\\"Linkedin\\",\\"button_link_front\\":\\"https://www.linkedin.com/\\",\\"button_link_params_front\\":\\"newtab\\",\\"icon_type_front\\":\\"icon\\",\\"icon_front\\":\\"fa-linkedin\\",\\"icon_color_front\\":\\"ffffff_1.00\\",\\"gallery_autoplay_front\\":\\"off\\",\\"gallery_hide_timer_front\\":\\"no\\",\\"type_map_front\\":\\"ROADMAP\\",\\"scrollwheel_map_front\\":\\"enable\\",\\"draggable_map_front\\":\\"enable\\",\\"action_param_front\\":\\"|\\",\\"background_color_front\\":\\"0077B5\\",\\"text_color_front\\":\\"ffffff_1.00\\",\\"link_color_front\\":\\"ffffff_1.00\\",\\"type_back\\":\\"text\\",\\"color_back\\":\\"default\\",\\"button_link_params_back\\":\\"|\\",\\"icon_type_back\\":\\"icon\\",\\"gallery_autoplay_back\\":\\"off\\",\\"gallery_hide_timer_back\\":\\"no\\",\\"type_map_back\\":\\"ROADMAP\\",\\"scrollwheel_map_back\\":\\"enable\\",\\"draggable_map_back\\":\\"enable\\",\\"action_param_back\\":\\"|\\",\\"tile_autoflip\\":\\"0\\",\\"flip_effect\\":\\"flip-horizontal\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"padding_top\\":\\"4\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right\\":\\"4\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom\\":\\"4\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left\\":\\"4\\",\\"padding_left_unit\\":\\"px\\"}}],\\"styling\\":[]}],\\"styling\\":[]},{\\"row_order\\":\\"1\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[],\\"styling\\":[]}],\\"styling\\":[]}]',
  ),
  'tax_input' => 
  array (
  ),
);
themify_process_post_import( $post );


$post = array (
  'ID' => 2666,
  'post_date' => '2014-12-29 17:32:43',
  'post_date_gmt' => '2014-12-29 17:32:43',
  'post_content' => '[woocommerce_my_account]',
  'post_title' => 'My Account',
  'post_excerpt' => '',
  'post_name' => 'my-account',
  'post_modified' => '2017-08-21 07:28:43',
  'post_modified_gmt' => '2017-08-21 07:28:43',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/stack/my-account/',
  'menu_order' => 4,
  'post_type' => 'page',
  'meta_input' => 
  array (
    'page_layout' => 'default',
    'content_width' => 'default_width',
    'hide_page_title' => 'default',
    'order' => 'desc',
    'orderby' => 'date',
    'layout' => 'list-post',
    'enable_masonry' => 'default',
    'hide_title' => 'default',
    'unlink_title' => 'default',
    'hide_date' => 'default',
    'hide_image' => 'default',
    'unlink_image' => 'default',
    'hide_navigation' => 'default',
    'portfolio_order' => 'desc',
    'portfolio_orderby' => 'date',
    'portfolio_layout' => 'grid4',
    'portfolio_enable_masonry' => 'default',
    'portfolio_hide_title' => 'default',
    'portfolio_unlink_title' => 'default',
    'portfolio_hide_meta_all' => 'default',
    'portfolio_hide_image' => 'default',
    'portfolio_unlink_image' => 'default',
    'portfolio_hide_navigation' => 'default',
    'builder_tiles_fluid_tiles_base_size' => '16',
  ),
  'tax_input' => 
  array (
  ),
);
themify_process_post_import( $post );


$post = array (
  'ID' => 2810,
  'post_date' => '2014-12-30 23:11:09',
  'post_date_gmt' => '2014-12-30 23:11:09',
  'post_content' => '',
  'post_title' => 'Demo 3',
  'post_excerpt' => '',
  'post_name' => 'demo-3-2',
  'post_modified' => '2017-08-21 07:28:59',
  'post_modified_gmt' => '2017-08-21 07:28:59',
  'post_content_filtered' => '',
  'post_parent' => 2981,
  'guid' => 'https://themify.me/demo/themes/stack/?page_id=2810',
  'menu_order' => 4,
  'post_type' => 'page',
  'meta_input' => 
  array (
    'page_layout' => 'sidebar-none',
    'content_width' => 'full_width',
    'hide_page_title' => 'yes',
    'order' => 'desc',
    'orderby' => 'date',
    'layout' => 'list-post',
    'enable_masonry' => 'default',
    'display_content' => 'content',
    'hide_title' => 'default',
    'unlink_title' => 'default',
    'hide_date' => 'default',
    'hide_image' => 'default',
    'unlink_image' => 'default',
    'hide_navigation' => 'default',
    'portfolio_order' => 'desc',
    'portfolio_orderby' => 'date',
    'portfolio_layout' => 'grid4',
    'portfolio_enable_masonry' => 'default',
    'portfolio_display_content' => 'content',
    'portfolio_hide_title' => 'default',
    'portfolio_unlink_title' => 'default',
    'portfolio_hide_meta_all' => 'default',
    'portfolio_hide_image' => 'default',
    'portfolio_unlink_image' => 'default',
    'portfolio_hide_navigation' => 'default',
    'builder_tiles_fluid_tiles' => 'yes',
    'builder_tiles_fluid_tiles_base_size' => '25',
    'builder_switch_frontend' => '0',
    '_themify_builder_settings_json' => '[{\\"row_order\\":\\"0\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full first\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h1 style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">We\\\\\\\\\\\'re Getting Married...</h1>\\",\\"font_family\\":\\"default\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\"}},{\\"mod_name\\":\\"countdown\\",\\"mod_settings\\":{\\"mod_date_countdown\\":\\"2016-08-31 11:40:09\\",\\"color_countdown\\":\\"transparent\\",\\"done_action_countdown\\":\\"nothing\\",\\"font_family\\":\\"default\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom\\":\\"30\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\"}},{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<p style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">(Display a countdown timer on any row on your site using the <a href=\\\\\\\\\\\\\\"https://themify.me/addons/countdown\\\\\\\\\\\\\\">Countdown Addon</a>)</p>\\",\\"font_family\\":\\"default\\"}}],\\"styling\\":[]}],\\"styling\\":{\\"row_width\\":\\"fullwidth\\",\\"row_height\\":\\"fullheight\\",\\"animation_effect\\":\\"\\",\\"background_type\\":\\"slider\\",\\"background_slider\\":\\"[gallery _orderByField=\\\\\\\\\\\\\\"menu_order ID\\\\\\\\\\\\\\" ids=\\\\\\\\\\\\\\"2564,2557,2718\\\\\\\\\\\\\\"]\\",\\"background_slider_mode\\":\\"\\",\\"background_video\\":\\"\\",\\"background_image\\":\\"\\",\\"background_repeat\\":\\"\\",\\"background_color\\":\\"000000_1.00\\",\\"font_family\\":\\"default\\",\\"font_color\\":\\"ffffff_1.00\\",\\"font_size\\":\\"\\",\\"font_size_unit\\":\\"\\",\\"line_height\\":\\"\\",\\"line_height_unit\\":\\"\\",\\"text_align\\":\\"center\\",\\"link_color\\":\\"ffffff_1.00\\",\\"text_decoration\\":\\"\\",\\"padding_top\\":\\"\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right\\":\\"\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom\\":\\"\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left\\":\\"\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top\\":\\"\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right\\":\\"\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom\\":\\"\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left\\":\\"\\",\\"margin_left_unit\\":\\"px\\",\\"border_top_color\\":\\"\\",\\"border_top_width\\":\\"\\",\\"border_top_style\\":\\"\\",\\"border_right_color\\":\\"\\",\\"border_right_width\\":\\"\\",\\"border_right_style\\":\\"\\",\\"border_bottom_color\\":\\"\\",\\"border_bottom_width\\":\\"\\",\\"border_bottom_style\\":\\"\\",\\"border_left_color\\":\\"\\",\\"border_left_width\\":\\"\\",\\"border_left_style\\":\\"\\",\\"custom_css_row\\":\\"\\",\\"row_anchor\\":\\"\\"}},{\\"row_order\\":\\"1\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full first\\",\\"modules\\":[{\\"mod_name\\":\\"tile\\",\\"mod_settings\\":{\\"size\\":\\"square-large\\",\\"type_front\\":\\"gallery\\",\\"color_front\\":\\"default\\",\\"title_front\\":\\"About\\",\\"button_link_params_front\\":\\"|\\",\\"icon_type_front\\":\\"icon\\",\\"gallery_front\\":\\"[gallery _orderByField=\\\\\\\\\\\\\\"menu_order ID\\\\\\\\\\\\\\" ids=\\\\\\\\\\\\\\"2611,2750,2626,2625,2552\\\\\\\\\\\\\\"]\\",\\"gallery_autoplay_front\\":\\"off\\",\\"gallery_hide_timer_front\\":\\"no\\",\\"type_map_front\\":\\"ROADMAP\\",\\"scrollwheel_map_front\\":\\"enable\\",\\"draggable_map_front\\":\\"enable\\",\\"action_param_front\\":\\"|\\",\\"type_back\\":\\"text\\",\\"color_back\\":\\"default\\",\\"button_link_params_back\\":\\"|\\",\\"icon_type_back\\":\\"icon\\",\\"gallery_autoplay_back\\":\\"off\\",\\"gallery_hide_timer_back\\":\\"no\\",\\"type_map_back\\":\\"ROADMAP\\",\\"scrollwheel_map_back\\":\\"enable\\",\\"draggable_map_back\\":\\"enable\\",\\"action_param_back\\":\\"|\\",\\"tile_autoflip\\":\\"0\\",\\"flip_effect\\":\\"flip-horizontal\\",\\"font_family\\":\\"default\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\"}},{\\"mod_name\\":\\"tile\\",\\"mod_settings\\":{\\"size\\":\\"square-small\\",\\"type_front\\":\\"text\\",\\"color_front\\":\\"default\\",\\"title_front\\":\\"About him\\",\\"button_link_params_front\\":\\"|\\",\\"icon_type_front\\":\\"icon\\",\\"gallery_autoplay_front\\":\\"off\\",\\"gallery_hide_timer_front\\":\\"no\\",\\"type_map_front\\":\\"ROADMAP\\",\\"scrollwheel_map_front\\":\\"enable\\",\\"draggable_map_front\\":\\"enable\\",\\"action_text_front\\":\\"Peter\\",\\"action_link_front\\":\\"https://themify.me\\",\\"action_param_front\\":\\"|\\",\\"text_color_front\\":\\"ffffff_1.00\\",\\"link_color_front\\":\\"ffffff_1.00\\",\\"background_image_front\\":\\"https://themify.me/demo/themes/stack/files/2014/12/192230474.jpg\\",\\"type_back\\":\\"text\\",\\"color_back\\":\\"default\\",\\"button_link_params_back\\":\\"|\\",\\"icon_type_back\\":\\"icon\\",\\"gallery_autoplay_back\\":\\"off\\",\\"gallery_hide_timer_back\\":\\"no\\",\\"type_map_back\\":\\"ROADMAP\\",\\"scrollwheel_map_back\\":\\"enable\\",\\"draggable_map_back\\":\\"enable\\",\\"action_param_back\\":\\"|\\",\\"tile_autoflip\\":\\"0\\",\\"flip_effect\\":\\"flip-horizontal\\",\\"font_family\\":\\"default\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\"}},{\\"mod_name\\":\\"tile\\",\\"mod_settings\\":{\\"size\\":\\"portrait\\",\\"type_front\\":\\"text\\",\\"color_front\\":\\"default\\",\\"title_front\\":\\"About her\\",\\"button_link_front\\":\\"https://themify.me\\",\\"button_link_params_front\\":\\"|\\",\\"icon_type_front\\":\\"icon\\",\\"gallery_autoplay_front\\":\\"off\\",\\"gallery_hide_timer_front\\":\\"no\\",\\"type_map_front\\":\\"ROADMAP\\",\\"scrollwheel_map_front\\":\\"enable\\",\\"draggable_map_front\\":\\"enable\\",\\"action_text_front\\":\\"Sandy\\",\\"action_link_front\\":\\"https://themify.me\\",\\"action_param_front\\":\\"|\\",\\"text_color_front\\":\\"ffffff_1.00\\",\\"link_color_front\\":\\"ffffff_1.00\\",\\"background_image_front\\":\\"https://themify.me/demo/themes/stack/files/2014/12/120947872.jpg\\",\\"type_back\\":\\"text\\",\\"color_back\\":\\"default\\",\\"button_link_params_back\\":\\"|\\",\\"icon_type_back\\":\\"icon\\",\\"gallery_autoplay_back\\":\\"off\\",\\"gallery_hide_timer_back\\":\\"no\\",\\"type_map_back\\":\\"ROADMAP\\",\\"scrollwheel_map_back\\":\\"enable\\",\\"draggable_map_back\\":\\"enable\\",\\"action_param_back\\":\\"|\\",\\"tile_autoflip\\":\\"0\\",\\"flip_effect\\":\\"flip-horizontal\\",\\"font_family\\":\\"default\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\"}},{\\"mod_name\\":\\"tile\\",\\"mod_settings\\":{\\"size\\":\\"square-small\\",\\"type_front\\":\\"button\\",\\"color_front\\":\\"default\\",\\"title_front\\":\\"Her Friend\\",\\"button_link_params_front\\":\\"|\\",\\"icon_type_front\\":\\"icon\\",\\"gallery_autoplay_front\\":\\"off\\",\\"gallery_hide_timer_front\\":\\"no\\",\\"type_map_front\\":\\"ROADMAP\\",\\"scrollwheel_map_front\\":\\"enable\\",\\"draggable_map_front\\":\\"enable\\",\\"action_param_front\\":\\"|\\",\\"text_color_front\\":\\"000000_1.00\\",\\"link_color_front\\":\\"000000_1.00\\",\\"background_image_front\\":\\"https://themify.me/demo/themes/stack/files/2014/12/209647441.jpg\\",\\"type_back\\":\\"text\\",\\"color_back\\":\\"purple\\",\\"title_back\\":\\"Jennifer\\",\\"button_link_params_back\\":\\"|\\",\\"icon_type_back\\":\\"icon\\",\\"gallery_autoplay_back\\":\\"off\\",\\"gallery_hide_timer_back\\":\\"no\\",\\"type_map_back\\":\\"ROADMAP\\",\\"scrollwheel_map_back\\":\\"enable\\",\\"draggable_map_back\\":\\"enable\\",\\"action_param_back\\":\\"|\\",\\"tile_autoflip\\":\\"2\\",\\"flip_effect\\":\\"flip-horizontal\\",\\"font_family\\":\\"default\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\"}},{\\"mod_name\\":\\"tile\\",\\"mod_settings\\":{\\"size\\":\\"square-small\\",\\"type_front\\":\\"button\\",\\"color_front\\":\\"default\\",\\"title_front\\":\\"His Friend\\",\\"button_link_params_front\\":\\"newtab\\",\\"icon_type_front\\":\\"icon\\",\\"gallery_autoplay_front\\":\\"off\\",\\"gallery_hide_timer_front\\":\\"no\\",\\"type_map_front\\":\\"ROADMAP\\",\\"scrollwheel_map_front\\":\\"enable\\",\\"draggable_map_front\\":\\"enable\\",\\"action_param_front\\":\\"|\\",\\"text_color_front\\":\\"ffffff\\",\\"link_color_front\\":\\"ffffff_1.00\\",\\"background_image_front\\":\\"https://themify.me/demo/themes/stack/files/2014/12/111005441.jpg\\",\\"type_back\\":\\"text\\",\\"color_back\\":\\"green\\",\\"title_back\\":\\"Gary\\",\\"button_link_params_back\\":\\"|\\",\\"icon_type_back\\":\\"icon\\",\\"gallery_autoplay_back\\":\\"off\\",\\"gallery_hide_timer_back\\":\\"no\\",\\"type_map_back\\":\\"ROADMAP\\",\\"scrollwheel_map_back\\":\\"enable\\",\\"draggable_map_back\\":\\"enable\\",\\"action_param_back\\":\\"|\\",\\"tile_autoflip\\":\\"2\\",\\"flip_effect\\":\\"flip-horizontal\\",\\"text_color_back\\":\\"ffffff_1.00\\",\\"link_color_back\\":\\"ffffff_1.00\\",\\"font_family\\":\\"default\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\"}},{\\"mod_name\\":\\"tile\\",\\"mod_settings\\":{\\"size\\":\\"square-small\\",\\"type_front\\":\\"button\\",\\"color_front\\":\\"default\\",\\"title_front\\":\\"Wedding Planner\\",\\"button_link_params_front\\":\\"newtab\\",\\"icon_type_front\\":\\"icon\\",\\"icon_color_front\\":\\"ffffff_1.00\\",\\"gallery_autoplay_front\\":\\"off\\",\\"gallery_hide_timer_front\\":\\"no\\",\\"type_map_front\\":\\"ROADMAP\\",\\"scrollwheel_map_front\\":\\"enable\\",\\"draggable_map_front\\":\\"enable\\",\\"action_param_front\\":\\"|\\",\\"text_color_front\\":\\"ffffff_1.00\\",\\"link_color_front\\":\\"ffffff_1.00\\",\\"background_image_front\\":\\"https://themify.me/demo/themes/stack/files/2014/12/147917882.jpg\\",\\"type_back\\":\\"text\\",\\"color_back\\":\\"pink\\",\\"title_back\\":\\"Thanks\\",\\"text_back\\":\\"<p>to Lisa and the team!</p>\\",\\"button_link_params_back\\":\\"|\\",\\"icon_type_back\\":\\"icon\\",\\"gallery_autoplay_back\\":\\"off\\",\\"gallery_hide_timer_back\\":\\"no\\",\\"type_map_back\\":\\"ROADMAP\\",\\"scrollwheel_map_back\\":\\"enable\\",\\"draggable_map_back\\":\\"enable\\",\\"action_param_back\\":\\"|\\",\\"tile_autoflip\\":\\"2\\",\\"flip_effect\\":\\"zoomInUp\\",\\"font_family\\":\\"default\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\"}},{\\"mod_name\\":\\"tile\\",\\"mod_settings\\":{\\"size\\":\\"square-large\\",\\"type_front\\":\\"map\\",\\"color_front\\":\\"default\\",\\"button_link_params_front\\":\\"|\\",\\"icon_type_front\\":\\"icon\\",\\"gallery_autoplay_front\\":\\"off\\",\\"gallery_hide_timer_front\\":\\"no\\",\\"address_map_front\\":\\" 318 Wellington St W, Toronto, ON M5V 3T4, Canada\\",\\"type_map_front\\":\\"ROADMAP\\",\\"zoom_map_front\\":\\"17\\",\\"scrollwheel_map_front\\":\\"enable\\",\\"draggable_map_front\\":\\"enable\\",\\"action_param_front\\":\\"|\\",\\"text_color_front\\":\\"ffffff_1.00\\",\\"link_color_front\\":\\"ffffff_1.00\\",\\"type_back\\":\\"text\\",\\"color_back\\":\\"red\\",\\"title_back\\":\\"Venue\\",\\"text_back\\":\\"<h3>A-Hotel</h3><p>123 Street Ave.<br />Toronto, Ontario</p>\\",\\"button_link_params_back\\":\\"|\\",\\"icon_type_back\\":\\"icon\\",\\"gallery_autoplay_back\\":\\"off\\",\\"gallery_hide_timer_back\\":\\"no\\",\\"type_map_back\\":\\"ROADMAP\\",\\"zoom_map_back\\":\\"7\\",\\"scrollwheel_map_back\\":\\"enable\\",\\"draggable_map_back\\":\\"enable\\",\\"action_param_back\\":\\"|\\",\\"tile_autoflip\\":\\"6\\",\\"flip_effect\\":\\"flip-horizontal\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\",\\"visibility_desktop\\":\\"show\\",\\"visibility_desktop_show\\":\\"show\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet\\":\\"show\\",\\"visibility_tablet_show\\":\\"show\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile\\":\\"show\\",\\"visibility_mobile_show\\":\\"show\\",\\"visibility_mobile_hide\\":\\"hide\\"}},{\\"mod_name\\":\\"tile\\",\\"mod_settings\\":{\\"size\\":\\"landscape\\",\\"type_front\\":\\"button\\",\\"color_front\\":\\"default\\",\\"title_front\\":\\"Our Story\\",\\"button_link_front\\":\\"https://themify.me\\",\\"button_link_params_front\\":\\"newtab\\",\\"icon_type_front\\":\\"icon\\",\\"icon_color_front\\":\\"ffffff_1.00\\",\\"gallery_autoplay_front\\":\\"off\\",\\"gallery_hide_timer_front\\":\\"no\\",\\"type_map_front\\":\\"ROADMAP\\",\\"scrollwheel_map_front\\":\\"enable\\",\\"draggable_map_front\\":\\"enable\\",\\"action_param_front\\":\\"|\\",\\"text_color_front\\":\\"ffffff_1.00\\",\\"link_color_front\\":\\"ffffff_1.00\\",\\"background_image_front\\":\\"https://themify.me/demo/themes/stack/files/2014/12/172002317.jpg\\",\\"type_back\\":\\"text\\",\\"color_back\\":\\"default\\",\\"button_link_params_back\\":\\"|\\",\\"icon_type_back\\":\\"icon\\",\\"gallery_autoplay_back\\":\\"off\\",\\"gallery_hide_timer_back\\":\\"no\\",\\"type_map_back\\":\\"ROADMAP\\",\\"scrollwheel_map_back\\":\\"enable\\",\\"draggable_map_back\\":\\"enable\\",\\"action_param_back\\":\\"|\\",\\"tile_autoflip\\":\\"0\\",\\"flip_effect\\":\\"flip-horizontal\\",\\"font_family\\":\\"default\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\"}},{\\"mod_name\\":\\"tile\\",\\"mod_settings\\":{\\"size\\":\\"square-small\\",\\"type_front\\":\\"button\\",\\"color_front\\":\\"default\\",\\"title_front\\":\\"Like us\\",\\"button_link_front\\":\\"https://www.facebook.com/themify\\",\\"button_link_params_front\\":\\"newtab\\",\\"icon_type_front\\":\\"icon\\",\\"icon_front\\":\\"fa-facebook-square\\",\\"icon_color_front\\":\\"ffffff_1.00\\",\\"gallery_autoplay_front\\":\\"off\\",\\"gallery_hide_timer_front\\":\\"no\\",\\"type_map_front\\":\\"ROADMAP\\",\\"scrollwheel_map_front\\":\\"enable\\",\\"draggable_map_front\\":\\"enable\\",\\"action_param_front\\":\\"|\\",\\"background_color_front\\":\\"3D5B99\\",\\"text_color_front\\":\\"ffffff_1.00\\",\\"link_color_front\\":\\"ffffff_1.00\\",\\"type_back\\":\\"text\\",\\"color_back\\":\\"default\\",\\"button_link_params_back\\":\\"|\\",\\"icon_type_back\\":\\"icon\\",\\"gallery_autoplay_back\\":\\"off\\",\\"gallery_hide_timer_back\\":\\"no\\",\\"type_map_back\\":\\"ROADMAP\\",\\"scrollwheel_map_back\\":\\"enable\\",\\"draggable_map_back\\":\\"enable\\",\\"action_param_back\\":\\"|\\",\\"tile_autoflip\\":\\"0\\",\\"flip_effect\\":\\"flip-horizontal\\",\\"font_family\\":\\"default\\"}},{\\"mod_name\\":\\"tile\\",\\"mod_settings\\":{\\"size\\":\\"square-small\\",\\"type_front\\":\\"button\\",\\"color_front\\":\\"default\\",\\"title_front\\":\\"Email Us\\",\\"button_link_front\\":\\"https://themify.me/contact\\",\\"button_link_params_front\\":\\"newtab\\",\\"icon_type_front\\":\\"icon\\",\\"icon_front\\":\\"fa-envelope-o\\",\\"icon_color_front\\":\\"ffffff\\",\\"gallery_autoplay_front\\":\\"off\\",\\"gallery_hide_timer_front\\":\\"no\\",\\"type_map_front\\":\\"ROADMAP\\",\\"scrollwheel_map_front\\":\\"enable\\",\\"draggable_map_front\\":\\"enable\\",\\"action_param_front\\":\\"|\\",\\"background_color_front\\":\\"FEBD0F\\",\\"text_color_front\\":\\"ffffff_1.00\\",\\"link_color_front\\":\\"ffffff_1.00\\",\\"type_back\\":\\"text\\",\\"color_back\\":\\"default\\",\\"button_link_params_back\\":\\"|\\",\\"icon_type_back\\":\\"icon\\",\\"gallery_autoplay_back\\":\\"off\\",\\"gallery_hide_timer_back\\":\\"no\\",\\"type_map_back\\":\\"ROADMAP\\",\\"scrollwheel_map_back\\":\\"enable\\",\\"draggable_map_back\\":\\"enable\\",\\"action_param_back\\":\\"|\\",\\"tile_autoflip\\":\\"0\\",\\"flip_effect\\":\\"flip-horizontal\\",\\"font_family\\":\\"default\\"}},{\\"mod_name\\":\\"tile\\",\\"mod_settings\\":{\\"size\\":\\"square-small\\",\\"type_front\\":\\"button\\",\\"color_front\\":\\"default\\",\\"title_front\\":\\"Subscribe\\",\\"button_link_front\\":\\"https://www.youtube.com/user/themifyme\\",\\"button_link_params_front\\":\\"newtab\\",\\"icon_type_front\\":\\"icon\\",\\"icon_front\\":\\"fa-youtube-square\\",\\"icon_color_front\\":\\"ffffff_1.00\\",\\"gallery_autoplay_front\\":\\"off\\",\\"gallery_hide_timer_front\\":\\"no\\",\\"type_map_front\\":\\"ROADMAP\\",\\"scrollwheel_map_front\\":\\"enable\\",\\"draggable_map_front\\":\\"enable\\",\\"action_param_front\\":\\"|\\",\\"background_color_front\\":\\"E02927\\",\\"text_color_front\\":\\"ffffff_1.00\\",\\"link_color_front\\":\\"ffffff_1.00\\",\\"type_back\\":\\"text\\",\\"color_back\\":\\"default\\",\\"button_link_params_back\\":\\"|\\",\\"icon_type_back\\":\\"icon\\",\\"gallery_autoplay_back\\":\\"off\\",\\"gallery_hide_timer_back\\":\\"no\\",\\"type_map_back\\":\\"ROADMAP\\",\\"scrollwheel_map_back\\":\\"enable\\",\\"draggable_map_back\\":\\"enable\\",\\"action_param_back\\":\\"|\\",\\"tile_autoflip\\":\\"0\\",\\"flip_effect\\":\\"flip-horizontal\\",\\"font_family\\":\\"default\\"}},{\\"mod_name\\":\\"tile\\",\\"mod_settings\\":{\\"size\\":\\"square-small\\",\\"type_front\\":\\"button\\",\\"color_front\\":\\"default\\",\\"title_front\\":\\"Follow us\\",\\"button_link_front\\":\\"https://twitter.com/themify\\",\\"button_link_params_front\\":\\"newtab\\",\\"icon_type_front\\":\\"icon\\",\\"icon_front\\":\\"fa-twitter-square\\",\\"icon_color_front\\":\\"ffffff_1.00\\",\\"gallery_autoplay_front\\":\\"off\\",\\"gallery_hide_timer_front\\":\\"no\\",\\"type_map_front\\":\\"ROADMAP\\",\\"scrollwheel_map_front\\":\\"enable\\",\\"draggable_map_front\\":\\"enable\\",\\"action_param_front\\":\\"|\\",\\"background_color_front\\":\\"55ACEE\\",\\"text_color_front\\":\\"ffffff_1.00\\",\\"link_color_front\\":\\"ffffff_1.00\\",\\"type_back\\":\\"text\\",\\"color_back\\":\\"default\\",\\"button_link_params_back\\":\\"|\\",\\"icon_type_back\\":\\"icon\\",\\"gallery_autoplay_back\\":\\"off\\",\\"gallery_hide_timer_back\\":\\"no\\",\\"type_map_back\\":\\"ROADMAP\\",\\"scrollwheel_map_back\\":\\"enable\\",\\"draggable_map_back\\":\\"enable\\",\\"action_param_back\\":\\"|\\",\\"tile_autoflip\\":\\"0\\",\\"flip_effect\\":\\"flip-horizontal\\",\\"font_family\\":\\"default\\"}}],\\"styling\\":[]}],\\"styling\\":{\\"row_width\\":\\"fullwidth\\",\\"row_height\\":\\"\\",\\"animation_effect\\":\\"\\",\\"background_type\\":\\"image\\",\\"background_slider\\":\\"\\",\\"background_slider_mode\\":\\"\\",\\"background_video\\":\\"\\",\\"background_image\\":\\"\\",\\"background_repeat\\":\\"\\",\\"background_color\\":\\"\\",\\"font_family\\":\\"default\\",\\"font_color\\":\\"\\",\\"font_size\\":\\"\\",\\"font_size_unit\\":\\"\\",\\"line_height\\":\\"\\",\\"line_height_unit\\":\\"\\",\\"text_align\\":\\"\\",\\"link_color\\":\\"\\",\\"text_decoration\\":\\"\\",\\"padding_top\\":\\"\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right\\":\\"\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom\\":\\"\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left\\":\\"\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top\\":\\"\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right\\":\\"\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom\\":\\"\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left\\":\\"\\",\\"margin_left_unit\\":\\"px\\",\\"border_top_color\\":\\"\\",\\"border_top_width\\":\\"\\",\\"border_top_style\\":\\"\\",\\"border_right_color\\":\\"\\",\\"border_right_width\\":\\"\\",\\"border_right_style\\":\\"\\",\\"border_bottom_color\\":\\"\\",\\"border_bottom_width\\":\\"\\",\\"border_bottom_style\\":\\"\\",\\"border_left_color\\":\\"\\",\\"border_left_width\\":\\"\\",\\"border_left_style\\":\\"\\",\\"custom_css_row\\":\\"\\",\\"row_anchor\\":\\"\\"}},{\\"row_order\\":\\"2\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full first last\\",\\"modules\\":[],\\"styling\\":[]}],\\"styling\\":[]}]',
  ),
  'tax_input' => 
  array (
  ),
);
themify_process_post_import( $post );


$post = array (
  'ID' => 2663,
  'post_date' => '2014-12-29 17:32:43',
  'post_date_gmt' => '2014-12-29 17:32:43',
  'post_content' => '',
  'post_title' => 'Shop',
  'post_excerpt' => '',
  'post_name' => 'shop',
  'post_modified' => '2017-08-21 07:28:44',
  'post_modified_gmt' => '2017-08-21 07:28:44',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/stack/shop/',
  'menu_order' => 5,
  'post_type' => 'page',
  'meta_input' => 
  array (
    'page_layout' => 'default',
    'content_width' => 'default_width',
    'hide_page_title' => 'default',
    'order' => 'desc',
    'orderby' => 'date',
    'layout' => 'list-post',
    'enable_masonry' => 'default',
    'hide_title' => 'default',
    'unlink_title' => 'default',
    'hide_date' => 'default',
    'hide_image' => 'default',
    'unlink_image' => 'default',
    'hide_navigation' => 'default',
    'portfolio_order' => 'desc',
    'portfolio_orderby' => 'date',
    'portfolio_layout' => 'grid4',
    'portfolio_enable_masonry' => 'default',
    'portfolio_hide_title' => 'default',
    'portfolio_unlink_title' => 'default',
    'portfolio_hide_meta_all' => 'default',
    'portfolio_hide_image' => 'default',
    'portfolio_unlink_image' => 'default',
    'portfolio_hide_navigation' => 'default',
    'builder_tiles_fluid_tiles_base_size' => '16',
  ),
  'tax_input' => 
  array (
  ),
);
themify_process_post_import( $post );


$post = array (
  'ID' => 2814,
  'post_date' => '2014-12-30 23:46:16',
  'post_date_gmt' => '2014-12-30 23:46:16',
  'post_content' => '',
  'post_title' => 'Demo 4',
  'post_excerpt' => '',
  'post_name' => 'demo-4-2',
  'post_modified' => '2017-08-21 07:29:05',
  'post_modified_gmt' => '2017-08-21 07:29:05',
  'post_content_filtered' => '',
  'post_parent' => 2981,
  'guid' => 'https://themify.me/demo/themes/stack/?page_id=2814',
  'menu_order' => 5,
  'post_type' => 'page',
  'meta_input' => 
  array (
    'page_layout' => 'sidebar-none',
    'content_width' => 'full_width',
    'hide_page_title' => 'yes',
    'order' => 'desc',
    'orderby' => 'date',
    'layout' => 'list-post',
    'enable_masonry' => 'default',
    'display_content' => 'content',
    'hide_title' => 'default',
    'unlink_title' => 'default',
    'hide_date' => 'default',
    'hide_image' => 'default',
    'unlink_image' => 'default',
    'hide_navigation' => 'default',
    'portfolio_order' => 'desc',
    'portfolio_orderby' => 'date',
    'portfolio_layout' => 'grid4',
    'portfolio_enable_masonry' => 'default',
    'portfolio_display_content' => 'content',
    'portfolio_hide_title' => 'default',
    'portfolio_unlink_title' => 'default',
    'portfolio_hide_meta_all' => 'default',
    'portfolio_hide_image' => 'default',
    'portfolio_unlink_image' => 'default',
    'portfolio_hide_navigation' => 'default',
    'builder_tiles_fluid_tiles_base_size' => '16',
    'builder_switch_frontend' => '0',
    '_themify_builder_settings_json' => '[{\\"row_order\\":\\"0\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full first\\",\\"modules\\":[{\\"mod_name\\":\\"tile\\",\\"mod_settings\\":{\\"size\\":\\"square-small\\",\\"type_front\\":\\"button\\",\\"color_front\\":\\"default\\",\\"title_front\\":\\"Portfolio\\",\\"button_link_front\\":\\"https://themify.me/demo/themes/stack/portfolio/\\",\\"button_link_params_front\\":\\"newtab\\",\\"icon_type_front\\":\\"icon\\",\\"gallery_autoplay_front\\":\\"off\\",\\"gallery_hide_timer_front\\":\\"no\\",\\"type_map_front\\":\\"ROADMAP\\",\\"scrollwheel_map_front\\":\\"enable\\",\\"draggable_map_front\\":\\"enable\\",\\"action_param_front\\":\\"|\\",\\"text_color_front\\":\\"ffffff_1.00\\",\\"link_color_front\\":\\"ffffff_1.00\\",\\"background_image_front\\":\\"https://themify.me/demo/themes/stack/files/2014/12/91078382.jpg\\",\\"type_back\\":\\"text\\",\\"color_back\\":\\"default\\",\\"button_link_params_back\\":\\"|\\",\\"icon_type_back\\":\\"icon\\",\\"gallery_autoplay_back\\":\\"off\\",\\"gallery_hide_timer_back\\":\\"no\\",\\"type_map_back\\":\\"ROADMAP\\",\\"scrollwheel_map_back\\":\\"enable\\",\\"draggable_map_back\\":\\"enable\\",\\"action_param_back\\":\\"|\\",\\"tile_autoflip\\":\\"0\\",\\"flip_effect\\":\\"flip-horizontal\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"padding_top\\":\\"4\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right\\":\\"4\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom\\":\\"4\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left\\":\\"4\\",\\"padding_left_unit\\":\\"px\\"}},{\\"mod_name\\":\\"tile\\",\\"mod_settings\\":{\\"size\\":\\"square-large\\",\\"type_front\\":\\"map\\",\\"color_front\\":\\"default\\",\\"button_link_params_front\\":\\"|\\",\\"icon_type_front\\":\\"icon\\",\\"gallery_autoplay_front\\":\\"off\\",\\"gallery_hide_timer_front\\":\\"no\\",\\"address_map_front\\":\\"40 Holly St, Toronto, ON M4S 3C3, Canada\\",\\"type_map_front\\":\\"ROADMAP\\",\\"zoom_map_front\\":\\"16\\",\\"scrollwheel_map_front\\":\\"enable\\",\\"draggable_map_front\\":\\"enable\\",\\"action_param_front\\":\\"|\\",\\"text_color_front\\":\\"ffffff_1.00\\",\\"link_color_front\\":\\"ffffff_1.00\\",\\"type_back\\":\\"text\\",\\"color_back\\":\\"default\\",\\"button_link_params_back\\":\\"|\\",\\"icon_type_back\\":\\"icon\\",\\"gallery_autoplay_back\\":\\"off\\",\\"gallery_hide_timer_back\\":\\"no\\",\\"type_map_back\\":\\"ROADMAP\\",\\"zoom_map_back\\":\\"7\\",\\"scrollwheel_map_back\\":\\"enable\\",\\"draggable_map_back\\":\\"enable\\",\\"action_param_back\\":\\"|\\",\\"tile_autoflip\\":\\"0\\",\\"flip_effect\\":\\"flip-horizontal\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"padding_top\\":\\"4\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right\\":\\"4\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom\\":\\"4\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left\\":\\"4\\",\\"padding_left_unit\\":\\"px\\",\\"visibility_desktop\\":\\"show\\",\\"visibility_desktop_show\\":\\"show\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet\\":\\"show\\",\\"visibility_tablet_show\\":\\"show\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile\\":\\"show\\",\\"visibility_mobile_show\\":\\"show\\",\\"visibility_mobile_hide\\":\\"hide\\"}},{\\"mod_name\\":\\"tile\\",\\"mod_settings\\":{\\"size\\":\\"portrait\\",\\"type_front\\":\\"text\\",\\"color_front\\":\\"default\\",\\"title_front\\":\\"Masonry\\",\\"text_front\\":\\"<p>The Stack tile allows you to create masonry layouts with your portfolio and blog posts. </p>\\",\\"button_link_params_front\\":\\"|\\",\\"icon_type_front\\":\\"icon\\",\\"gallery_autoplay_front\\":\\"off\\",\\"gallery_hide_timer_front\\":\\"no\\",\\"type_map_front\\":\\"ROADMAP\\",\\"scrollwheel_map_front\\":\\"enable\\",\\"draggable_map_front\\":\\"enable\\",\\"action_text_front\\":\\"Buy Now\\",\\"action_link_front\\":\\"https://themify.me/themes/stack\\",\\"action_param_front\\":\\"newtab\\",\\"background_color_front\\":\\"407780_1.00\\",\\"text_color_front\\":\\"ffffff_1.00\\",\\"link_color_front\\":\\"ffffff_1.00\\",\\"type_back\\":\\"text\\",\\"color_back\\":\\"default\\",\\"button_link_params_back\\":\\"|\\",\\"icon_type_back\\":\\"icon\\",\\"gallery_autoplay_back\\":\\"off\\",\\"gallery_hide_timer_back\\":\\"no\\",\\"type_map_back\\":\\"ROADMAP\\",\\"scrollwheel_map_back\\":\\"enable\\",\\"draggable_map_back\\":\\"enable\\",\\"action_param_back\\":\\"|\\",\\"tile_autoflip\\":\\"0\\",\\"flip_effect\\":\\"flip-horizontal\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"padding_top\\":\\"4\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right\\":\\"4\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom\\":\\"4\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left\\":\\"4\\",\\"padding_left_unit\\":\\"px\\"}},{\\"mod_name\\":\\"tile\\",\\"mod_settings\\":{\\"size\\":\\"square-small\\",\\"type_front\\":\\"button\\",\\"color_front\\":\\"default\\",\\"title_front\\":\\"Shop\\",\\"button_link_front\\":\\"https://themify.me/demo/themes/stack/shop/\\",\\"button_link_params_front\\":\\"|\\",\\"icon_type_front\\":\\"icon\\",\\"icon_front\\":\\"fa-shopping-cart\\",\\"icon_color_front\\":\\"ffffff_1.00\\",\\"gallery_autoplay_front\\":\\"off\\",\\"gallery_hide_timer_front\\":\\"no\\",\\"type_map_front\\":\\"ROADMAP\\",\\"scrollwheel_map_front\\":\\"enable\\",\\"draggable_map_front\\":\\"enable\\",\\"action_param_front\\":\\"|\\",\\"background_color_front\\":\\"9e4fa8_1.00\\",\\"text_color_front\\":\\"ffffff_1.00\\",\\"link_color_front\\":\\"ffffff_1.00\\",\\"type_back\\":\\"text\\",\\"color_back\\":\\"default\\",\\"button_link_params_back\\":\\"|\\",\\"icon_type_back\\":\\"icon\\",\\"gallery_autoplay_back\\":\\"off\\",\\"gallery_hide_timer_back\\":\\"no\\",\\"type_map_back\\":\\"ROADMAP\\",\\"scrollwheel_map_back\\":\\"enable\\",\\"draggable_map_back\\":\\"enable\\",\\"action_param_back\\":\\"|\\",\\"tile_autoflip\\":\\"0\\",\\"flip_effect\\":\\"flip-horizontal\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"padding_top\\":\\"4\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right\\":\\"4\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom\\":\\"4\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left\\":\\"4\\",\\"padding_left_unit\\":\\"px\\"}},{\\"mod_name\\":\\"tile\\",\\"mod_settings\\":{\\"size\\":\\"square-large\\",\\"type_front\\":\\"text\\",\\"color_front\\":\\"default\\",\\"text_front\\":\\"<p>http://vimeo.com/channels/staffpicks/59137223</p><p>If you embed videos from YouTube, Vimeo, etc., you don\\\\\\\\\\\'t need to use the [Themify_video] shortcode. You can simple paste in the YouTube or Vimeo URL in the content editor.</p>\\",\\"button_link_params_front\\":\\"|\\",\\"icon_type_front\\":\\"icon\\",\\"gallery_autoplay_front\\":\\"off\\",\\"gallery_hide_timer_front\\":\\"no\\",\\"type_map_front\\":\\"ROADMAP\\",\\"scrollwheel_map_front\\":\\"enable\\",\\"draggable_map_front\\":\\"enable\\",\\"action_param_front\\":\\"|\\",\\"background_color_front\\":\\"992f2f_1.00\\",\\"text_color_front\\":\\"ffffff_1.00\\",\\"link_color_front\\":\\"ffffff_1.00\\",\\"type_back\\":\\"text\\",\\"color_back\\":\\"default\\",\\"button_link_params_back\\":\\"|\\",\\"icon_type_back\\":\\"icon\\",\\"gallery_autoplay_back\\":\\"off\\",\\"gallery_hide_timer_back\\":\\"no\\",\\"type_map_back\\":\\"ROADMAP\\",\\"scrollwheel_map_back\\":\\"enable\\",\\"draggable_map_back\\":\\"enable\\",\\"action_param_back\\":\\"|\\",\\"tile_autoflip\\":\\"0\\",\\"flip_effect\\":\\"flip-horizontal\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"padding_top\\":\\"4\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right\\":\\"4\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom\\":\\"4\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left\\":\\"4\\",\\"padding_left_unit\\":\\"px\\"}},{\\"mod_name\\":\\"tile\\",\\"mod_settings\\":{\\"size\\":\\"square-small\\",\\"type_front\\":\\"button\\",\\"color_front\\":\\"default\\",\\"button_link_params_front\\":\\"newtab\\",\\"icon_type_front\\":\\"icon\\",\\"gallery_autoplay_front\\":\\"off\\",\\"gallery_hide_timer_front\\":\\"no\\",\\"type_map_front\\":\\"ROADMAP\\",\\"scrollwheel_map_front\\":\\"enable\\",\\"draggable_map_front\\":\\"enable\\",\\"action_param_front\\":\\"|\\",\\"text_color_front\\":\\"ffffff_1.00\\",\\"link_color_front\\":\\"ffffff_1.00\\",\\"background_image_front\\":\\"https://themify.me/demo/themes/stack/files/2014/12/206166310.jpg\\",\\"type_back\\":\\"text\\",\\"color_back\\":\\"default\\",\\"title_back\\":\\"Fade In Left \\",\\"text_back\\":\\"<p>Add a background color and adjust opacity to add a text on your image</p>\\",\\"button_link_params_back\\":\\"|\\",\\"icon_type_back\\":\\"icon\\",\\"gallery_autoplay_back\\":\\"off\\",\\"gallery_hide_timer_back\\":\\"no\\",\\"type_map_back\\":\\"ROADMAP\\",\\"scrollwheel_map_back\\":\\"enable\\",\\"draggable_map_back\\":\\"enable\\",\\"action_text_back\\":\\"Go to Demo 2\\",\\"action_link_back\\":\\"https://themify.me/demo/themes/stack/demo-2\\",\\"action_param_back\\":\\"|\\",\\"tile_autoflip\\":\\"4\\",\\"flip_effect\\":\\"fadeInLeft\\",\\"background_color_back\\":\\"8f8f8f_0.79\\",\\"text_color_back\\":\\"ffffff_1.00\\",\\"link_color_back\\":\\"ffffff_1.00\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"padding_top\\":\\"4\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right\\":\\"4\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom\\":\\"4\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left\\":\\"4\\",\\"padding_left_unit\\":\\"px\\"}},{\\"mod_name\\":\\"tile\\",\\"mod_settings\\":{\\"size\\":\\"square-small\\",\\"type_front\\":\\"button\\",\\"color_front\\":\\"default\\",\\"title_front\\":\\"Horizontal Flip\\",\\"button_link_params_front\\":\\"newtab\\",\\"icon_type_front\\":\\"icon\\",\\"icon_front\\":\\"fa-bomb\\",\\"icon_color_front\\":\\"ffffff_1.00\\",\\"gallery_autoplay_front\\":\\"off\\",\\"gallery_hide_timer_front\\":\\"no\\",\\"type_map_front\\":\\"ROADMAP\\",\\"scrollwheel_map_front\\":\\"enable\\",\\"draggable_map_front\\":\\"enable\\",\\"action_param_front\\":\\"|\\",\\"background_color_front\\":\\"d45004_1.00\\",\\"text_color_front\\":\\"ffffff_1.00\\",\\"link_color_front\\":\\"ffffff_1.00\\",\\"type_back\\":\\"button\\",\\"color_back\\":\\"default\\",\\"title_back\\":\\"   \\",\\"button_link_params_back\\":\\"|\\",\\"icon_type_back\\":\\"icon\\",\\"gallery_autoplay_back\\":\\"off\\",\\"gallery_hide_timer_back\\":\\"no\\",\\"type_map_back\\":\\"ROADMAP\\",\\"scrollwheel_map_back\\":\\"enable\\",\\"draggable_map_back\\":\\"enable\\",\\"action_param_back\\":\\"|\\",\\"tile_autoflip\\":\\"4\\",\\"flip_effect\\":\\"flip-vertical\\",\\"background_image_back\\":\\"https://themify.me/demo/themes/stack/files/2014/12/boom-shots.jpg\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"padding_top\\":\\"4\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right\\":\\"4\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom\\":\\"4\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left\\":\\"4\\",\\"padding_left_unit\\":\\"px\\"}},{\\"mod_name\\":\\"tile\\",\\"mod_settings\\":{\\"size\\":\\"square-large\\",\\"type_front\\":\\"gallery\\",\\"color_front\\":\\"default\\",\\"button_link_params_front\\":\\"|\\",\\"icon_type_front\\":\\"icon\\",\\"gallery_front\\":\\"[gallery _orderByField=\\\\\\\\\\\\\\"menu_order ID\\\\\\\\\\\\\\" ids=\\\\\\\\\\\\\\"2763,2749,2619,2614\\\\\\\\\\\\\\"]\\",\\"gallery_autoplay_front\\":\\"off\\",\\"gallery_hide_timer_front\\":\\"no\\",\\"type_map_front\\":\\"ROADMAP\\",\\"scrollwheel_map_front\\":\\"enable\\",\\"draggable_map_front\\":\\"enable\\",\\"action_param_front\\":\\"|\\",\\"text_color_front\\":\\"ffffff_1.00\\",\\"link_color_front\\":\\"ffffff_1.00\\",\\"type_back\\":\\"text\\",\\"color_back\\":\\"default\\",\\"button_link_params_back\\":\\"|\\",\\"icon_type_back\\":\\"icon\\",\\"gallery_autoplay_back\\":\\"off\\",\\"gallery_hide_timer_back\\":\\"no\\",\\"type_map_back\\":\\"ROADMAP\\",\\"scrollwheel_map_back\\":\\"enable\\",\\"draggable_map_back\\":\\"enable\\",\\"action_param_back\\":\\"|\\",\\"tile_autoflip\\":\\"0\\",\\"flip_effect\\":\\"flip-horizontal\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"padding_top\\":\\"4\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right\\":\\"4\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom\\":\\"4\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left\\":\\"4\\",\\"padding_left_unit\\":\\"px\\"}},{\\"mod_name\\":\\"tile\\",\\"mod_settings\\":{\\"size\\":\\"landscape\\",\\"type_front\\":\\"button\\",\\"color_front\\":\\"default\\",\\"button_link_params_front\\":\\"|\\",\\"icon_type_front\\":\\"icon\\",\\"gallery_autoplay_front\\":\\"off\\",\\"gallery_hide_timer_front\\":\\"no\\",\\"type_map_front\\":\\"ROADMAP\\",\\"scrollwheel_map_front\\":\\"enable\\",\\"draggable_map_front\\":\\"enable\\",\\"action_param_front\\":\\"|\\",\\"text_color_front\\":\\"ffffff_1.00\\",\\"link_color_front\\":\\"ffffff_1.00\\",\\"background_image_front\\":\\"https://themify.me/demo/themes/stack/files/2014/12/94893043.jpg\\",\\"type_back\\":\\"text\\",\\"color_back\\":\\"default\\",\\"button_link_params_back\\":\\"|\\",\\"icon_type_back\\":\\"icon\\",\\"gallery_autoplay_back\\":\\"off\\",\\"gallery_hide_timer_back\\":\\"no\\",\\"type_map_back\\":\\"ROADMAP\\",\\"scrollwheel_map_back\\":\\"enable\\",\\"draggable_map_back\\":\\"enable\\",\\"action_param_back\\":\\"|\\",\\"tile_autoflip\\":\\"0\\",\\"flip_effect\\":\\"flip-horizontal\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"padding_top\\":\\"4\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right\\":\\"4\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom\\":\\"4\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left\\":\\"4\\",\\"padding_left_unit\\":\\"px\\"}},{\\"mod_name\\":\\"tile\\",\\"mod_settings\\":{\\"size\\":\\"square-large\\",\\"type_front\\":\\"text\\",\\"color_front\\":\\"blue\\",\\"title_front\\":\\"Stack\\",\\"text_front\\":\\"<p>The Stack theme is one of our most powerful theme yet. It\\\\\\\\\\\'s packed with multiple features and custom post types that\\\\\\\\\\\'ll give you to design your site anyway you like. Paired together with the built-in Tile module, you can create custom metro layout designs anywhere on your site. </p>\\",\\"button_link_params_front\\":\\"|\\",\\"icon_type_front\\":\\"icon\\",\\"gallery_autoplay_front\\":\\"off\\",\\"gallery_hide_timer_front\\":\\"no\\",\\"type_map_front\\":\\"ROADMAP\\",\\"scrollwheel_map_front\\":\\"enable\\",\\"draggable_map_front\\":\\"enable\\",\\"action_text_front\\":\\"Buy Now\\",\\"action_link_front\\":\\"https://themify.me/themes/stack\\",\\"action_param_front\\":\\"newtab\\",\\"background_color_front\\":\\"80406e_1.00\\",\\"text_color_front\\":\\"ffffff_1.00\\",\\"link_color_front\\":\\"ffffff_1.00\\",\\"type_back\\":\\"text\\",\\"color_back\\":\\"default\\",\\"button_link_params_back\\":\\"|\\",\\"icon_type_back\\":\\"icon\\",\\"gallery_autoplay_back\\":\\"off\\",\\"gallery_hide_timer_back\\":\\"no\\",\\"type_map_back\\":\\"ROADMAP\\",\\"scrollwheel_map_back\\":\\"enable\\",\\"draggable_map_back\\":\\"enable\\",\\"action_param_back\\":\\"|\\",\\"tile_autoflip\\":\\"0\\",\\"flip_effect\\":\\"flip-horizontal\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"padding_top\\":\\"4\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right\\":\\"4\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom\\":\\"4\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left\\":\\"4\\",\\"padding_left_unit\\":\\"px\\"}},{\\"mod_name\\":\\"tile\\",\\"mod_settings\\":{\\"size\\":\\"square-small\\",\\"type_front\\":\\"button\\",\\"color_front\\":\\"default\\",\\"title_front\\":\\"Email Us\\",\\"button_link_front\\":\\"https://themify.me/contact\\",\\"button_link_params_front\\":\\"newtab\\",\\"icon_type_front\\":\\"icon\\",\\"icon_front\\":\\"fa-envelope-o\\",\\"icon_color_front\\":\\"ffffff_1.00\\",\\"gallery_autoplay_front\\":\\"off\\",\\"gallery_hide_timer_front\\":\\"no\\",\\"type_map_front\\":\\"ROADMAP\\",\\"scrollwheel_map_front\\":\\"enable\\",\\"draggable_map_front\\":\\"enable\\",\\"action_param_front\\":\\"|\\",\\"background_color_front\\":\\"3342b0_1.00\\",\\"text_color_front\\":\\"ffffff_1.00\\",\\"link_color_front\\":\\"ffffff_1.00\\",\\"type_back\\":\\"text\\",\\"color_back\\":\\"default\\",\\"button_link_params_back\\":\\"|\\",\\"icon_type_back\\":\\"icon\\",\\"gallery_autoplay_back\\":\\"off\\",\\"gallery_hide_timer_back\\":\\"no\\",\\"type_map_back\\":\\"ROADMAP\\",\\"scrollwheel_map_back\\":\\"enable\\",\\"draggable_map_back\\":\\"enable\\",\\"action_param_back\\":\\"|\\",\\"tile_autoflip\\":\\"0\\",\\"flip_effect\\":\\"flip-horizontal\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"padding_top\\":\\"4\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right\\":\\"4\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom\\":\\"4\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left\\":\\"4\\",\\"padding_left_unit\\":\\"px\\"}},{\\"mod_name\\":\\"tile\\",\\"mod_settings\\":{\\"size\\":\\"square-small\\",\\"type_front\\":\\"button\\",\\"color_front\\":\\"default\\",\\"button_link_params_front\\":\\"newtab\\",\\"icon_type_front\\":\\"icon\\",\\"gallery_autoplay_front\\":\\"off\\",\\"gallery_hide_timer_front\\":\\"no\\",\\"type_map_front\\":\\"ROADMAP\\",\\"scrollwheel_map_front\\":\\"enable\\",\\"draggable_map_front\\":\\"enable\\",\\"action_param_front\\":\\"|\\",\\"text_color_front\\":\\"000000_1.00\\",\\"link_color_front\\":\\"000000_1.00\\",\\"background_image_front\\":\\"https://themify.me/demo/themes/stack/files/2014/12/133696103.jpg\\",\\"type_back\\":\\"button\\",\\"color_back\\":\\"default\\",\\"title_back\\":\\"Blog\\",\\"button_link_back\\":\\"https://themify.me/demo/themes/stack/blog\\",\\"button_link_params_back\\":\\"|\\",\\"icon_type_back\\":\\"icon\\",\\"icon_back\\":\\"fa-gear\\",\\"icon_color_back\\":\\"ffffff_1.00\\",\\"gallery_autoplay_back\\":\\"off\\",\\"gallery_hide_timer_back\\":\\"no\\",\\"type_map_back\\":\\"ROADMAP\\",\\"scrollwheel_map_back\\":\\"enable\\",\\"draggable_map_back\\":\\"enable\\",\\"action_param_back\\":\\"|\\",\\"tile_autoflip\\":\\"5\\",\\"flip_effect\\":\\"flip-vertical\\",\\"background_color_back\\":\\"4b4885_1.00\\",\\"text_color_back\\":\\"ffffff_1.00\\",\\"link_color_back\\":\\"ffffff_1.00\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"padding_top\\":\\"4\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right\\":\\"4\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom\\":\\"4\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left\\":\\"4\\",\\"padding_left_unit\\":\\"px\\"}},{\\"mod_name\\":\\"tile\\",\\"mod_settings\\":{\\"size\\":\\"square-small\\",\\"type_front\\":\\"button\\",\\"color_front\\":\\"default\\",\\"title_front\\":\\"Google+\\",\\"button_link_front\\":\\"https://plus.google.com/u/0/b/109280316400365629341/109280316400365629341/posts\\",\\"button_link_params_front\\":\\"newtab\\",\\"icon_type_front\\":\\"icon\\",\\"icon_front\\":\\"fa-google-plus\\",\\"icon_color_front\\":\\"ffffff_1.00\\",\\"gallery_autoplay_front\\":\\"off\\",\\"gallery_hide_timer_front\\":\\"no\\",\\"type_map_front\\":\\"ROADMAP\\",\\"scrollwheel_map_front\\":\\"enable\\",\\"draggable_map_front\\":\\"enable\\",\\"action_param_front\\":\\"|\\",\\"background_color_front\\":\\"DD4B39\\",\\"text_color_front\\":\\"ffffff_1.00\\",\\"link_color_front\\":\\"ffffff_1.00\\",\\"type_back\\":\\"text\\",\\"color_back\\":\\"default\\",\\"button_link_params_back\\":\\"|\\",\\"icon_type_back\\":\\"icon\\",\\"gallery_autoplay_back\\":\\"off\\",\\"gallery_hide_timer_back\\":\\"no\\",\\"type_map_back\\":\\"ROADMAP\\",\\"scrollwheel_map_back\\":\\"enable\\",\\"draggable_map_back\\":\\"enable\\",\\"action_param_back\\":\\"|\\",\\"tile_autoflip\\":\\"0\\",\\"flip_effect\\":\\"flip-horizontal\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"padding_top\\":\\"4\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right\\":\\"4\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom\\":\\"4\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left\\":\\"4\\",\\"padding_left_unit\\":\\"px\\"}},{\\"mod_name\\":\\"tile\\",\\"mod_settings\\":{\\"size\\":\\"square-small\\",\\"type_front\\":\\"button\\",\\"color_front\\":\\"default\\",\\"title_front\\":\\"Youtube\\",\\"button_link_front\\":\\"https://www.youtube.com/user/themifyme\\",\\"button_link_params_front\\":\\"newtab\\",\\"icon_type_front\\":\\"icon\\",\\"icon_front\\":\\"fa-youtube-play\\",\\"icon_color_front\\":\\"ffffff_1.00\\",\\"gallery_autoplay_front\\":\\"off\\",\\"gallery_hide_timer_front\\":\\"no\\",\\"type_map_front\\":\\"ROADMAP\\",\\"scrollwheel_map_front\\":\\"enable\\",\\"draggable_map_front\\":\\"enable\\",\\"action_param_front\\":\\"|\\",\\"background_color_front\\":\\"E02927\\",\\"text_color_front\\":\\"ffffff_1.00\\",\\"link_color_front\\":\\"ffffff_1.00\\",\\"type_back\\":\\"text\\",\\"color_back\\":\\"default\\",\\"button_link_params_back\\":\\"|\\",\\"icon_type_back\\":\\"icon\\",\\"gallery_autoplay_back\\":\\"off\\",\\"gallery_hide_timer_back\\":\\"no\\",\\"type_map_back\\":\\"ROADMAP\\",\\"scrollwheel_map_back\\":\\"enable\\",\\"draggable_map_back\\":\\"enable\\",\\"action_param_back\\":\\"|\\",\\"tile_autoflip\\":\\"0\\",\\"flip_effect\\":\\"flip-horizontal\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"padding_top\\":\\"4\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right\\":\\"4\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom\\":\\"4\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left\\":\\"4\\",\\"padding_left_unit\\":\\"px\\"}}],\\"styling\\":[]}],\\"styling\\":[]},{\\"row_order\\":\\"1\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full first last\\",\\"modules\\":[],\\"styling\\":[]}],\\"styling\\":[]}]',
  ),
  'tax_input' => 
  array (
  ),
);
themify_process_post_import( $post );


$post = array (
  'ID' => 2981,
  'post_date' => '2015-03-10 19:27:34',
  'post_date_gmt' => '2015-03-10 19:27:34',
  'post_content' => '<!--themify_builder_static--><h4>Welcome to Stack</h4> <p style="text-align: left;">Stack is a responsive and fluid WordPress theme that works on all resolutions, and on any device (desktop, tablet, and mobile). It comes with masonry &amp; infinite scroll features for WordPress Post Formats, Portfolio, and WooCommerce shop.</p> <p>Check out more demos here...</p> <p>[themify_button style="rect outline white" link="https://themify.me/demo/themes/stack/demo-1/" ]Demo 1[/themify_button] [themify_button style="rect outline white" link="https://themify.me/demo/themes/stack/demo-2/" ]Demo 2[/themify_button] [themify_button style="rect outline white" link="https://themify.me/demo/themes/stack/demo-3/" ]Demo 3[/themify_button] [themify_button style="rect outline white" link="https://themify.me/demo/themes/stack/demo-4/" ]Demo 4[/themify_button]</p> 
 
 
 
 <a href="https://themify.me/themes/stack/blog" > Blog </a>
 
 
 
 
 <a href="https://themify.me/demo/themes/stack/portfolio/" > <h4>Portfolio</h4> </a> 
 
 
 
 
 <a href="https://themify.me/demo/themes/stack/shop/" > <h4>Shop</h4> </a> 
 
 
 <h4>11 Flip Animtion</h4> <p style="text-align: left;">With timed controlled auto flip option. Click on the button below to the auto flip animation tiles in action.</p> <a href="https://themify.me/demo/themes/stack/home/demo-3/" > Demo 3 </a>
 
 <h4>Back Tile </h4> <p>Auto flip back and forth.</p> 
 
 
 <h4>300+ Icons</h4> 
 
 
 
 
 <p style="text-align: center;"> </p><p style="text-align: center;">Display a simple Image Tile that links to any page on your site</p> <a href="https://themify.me/themes/stack/" > More Info </a>
 
 
 
 
 
 
 <ul data-id="gallery-shortcode-slider-tile-0-" data-autoplay="3000" data-effect="scroll" data-speed="1000" data-visible="2" data-width="33" data-wrap="yes" data-slidernav="yes" data-pager="no"> <li> <a href="#" data-image="https://themify.me/demo/themes/stack/files/2014/12/142569277-1024x886.jpg" data-caption="" data-description=""> <img src="https://themify.me/demo/themes/stack/files/2014/12/142569277-40x33.jpg" width="40" height="33" alt="142569277" /> </a> </li> <li> <a href="#" data-image="https://themify.me/demo/themes/stack/files/2014/12/2086219601-1024x785.jpg" data-caption="" data-description=""> <img src="https://themify.me/demo/themes/stack/files/2014/12/2086219601-40x33.jpg" width="40" height="33" alt="208621960-2" /> </a> </li> <li> <a href="#" data-image="https://themify.me/demo/themes/stack/files/2014/12/1282562901-1024x682.jpg" data-caption="" data-description=""> <img src="https://themify.me/demo/themes/stack/files/2014/12/1282562901-40x33.jpg" width="40" height="33" alt="128256290-2" /> </a> </li> </ul> 
 
 
 
 
 <h2 style="text-align: center;">Hidden Tile</h2><p style="text-align: center;">Cool?</p> 
 
 
 <h4>Customizable</h4> <p>Both front and back tile can be customized</p> <a href="https://themify.me/themes/stack" > Learn More </a>
 
 
 
 
 <h3>Masonry <br />layouts <br />in shop, blog, <br />portfolio &amp; tiles</h3> 
 
 
 
 
 
 
 
 <a href="https://www.youtube.com/user/themifyme" > </a> 
 <p style="text-align: center;"> </p><p style="text-align: center;"><a href="https://www.youtube.com/user/themifyme"><strong>Subscribe</strong> </a>to our Youtube Channel and watch our latest tutorial videos!</p> 
 
 
 <a href="https://plus.google.com/u/0/b/109280316400365629341/109280316400365629341/videos" > </a> 
 <p style="text-align: center;"><a href="https://plus.google.com/u/0/b/109280316400365629341/109280316400365629341/videos"><strong>Follow us</strong> </a>on our Google+ Page to get the latest updates and promotions!</p> 
 
 
 <a href="https://www.facebook.com/themify" > </a> 
 <p style="text-align: center;"> <p style="text-align: center;"><a href="https://www.facebook.com/themify"><strong>Like us</strong> </a>on our Facebook Page to get the latest updates and promotions!</p> 
 
 
 <a href="https://twitter.com/themify" > </a> 
 <p style="text-align: center;"> </p><p style="text-align: center;"><a href="https://twitter.com/themify"><strong>Follow us</strong> </a>on Twitter to get the latest updates and promotions!</p><!--/themify_builder_static-->',
  'post_title' => 'Home',
  'post_excerpt' => '',
  'post_name' => 'home',
  'post_modified' => '2018-12-06 22:10:24',
  'post_modified_gmt' => '2018-12-06 22:10:24',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/stack/home-copy/',
  'menu_order' => 7,
  'post_type' => 'page',
  'meta_input' => 
  array (
    'page_layout' => 'sidebar-none',
    'content_width' => 'default_width',
    'hide_page_title' => 'yes',
    'order' => 'desc',
    'orderby' => 'date',
    'layout' => 'grid3',
    'enable_masonry' => 'yes',
    'posts_per_page' => '9',
    'hide_title' => 'default',
    'unlink_title' => 'default',
    'hide_date' => 'default',
    'hide_image' => 'default',
    'unlink_image' => 'default',
    'hide_navigation' => 'yes',
    'portfolio_order' => 'desc',
    'portfolio_orderby' => 'date',
    'portfolio_layout' => 'grid4',
    'portfolio_enable_masonry' => 'default',
    'portfolio_display_content' => 'content',
    'portfolio_hide_title' => 'default',
    'portfolio_unlink_title' => 'default',
    'portfolio_hide_meta_all' => 'default',
    'portfolio_hide_image' => 'default',
    'portfolio_unlink_image' => 'default',
    'portfolio_hide_navigation' => 'default',
    'builder_tiles_fluid_tiles' => 'yes',
    'builder_tiles_fluid_tiles_base_size' => '20',
    '_themify_builder_settings_json' => '[{\\"element_id\\":\\"7280a42\\",\\"row_order\\":\\"0\\",\\"cols\\":[{\\"element_id\\":\\"9c00362\\",\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"mod_name\\":\\"tile\\",\\"element_id\\":\\"b996e9b\\",\\"mod_settings\\":{\\"checkbox_padding_apply_all\\":\\"1\\",\\"title_front\\":\\"Welcome to Stack\\",\\"text_front\\":\\"<p style=\\\\\\\\\\\\\\"text-align: left;\\\\\\\\\\\\\\">Stack is a responsive and fluid WordPress theme that works on all resolutions, and on any device (desktop, tablet, and mobile). It comes with masonry &amp; infinite scroll features for WordPress Post Formats, Portfolio, and WooCommerce shop.<\\\\/p>\\\\n<p>Check out more demos here...<\\\\/p>\\\\n<p>[themify_button style=\\\\\\\\\\\\\\"rect outline white\\\\\\\\\\\\\\" link=\\\\\\\\\\\\\\"https://themify.me/demo/themes/stack\\\\/demo-1\\\\/\\\\\\\\\\\\\\" ]Demo 1[\\\\/themify_button] [themify_button style=\\\\\\\\\\\\\\"rect outline white\\\\\\\\\\\\\\" link=\\\\\\\\\\\\\\"https://themify.me/demo/themes/stack\\\\/demo-2\\\\/\\\\\\\\\\\\\\" ]Demo 2[\\\\/themify_button] [themify_button style=\\\\\\\\\\\\\\"rect outline white\\\\\\\\\\\\\\" link=\\\\\\\\\\\\\\"https://themify.me/demo/themes/stack\\\\/demo-3\\\\/\\\\\\\\\\\\\\" ]Demo 3[\\\\/themify_button] [themify_button style=\\\\\\\\\\\\\\"rect outline white\\\\\\\\\\\\\\" link=\\\\\\\\\\\\\\"https://themify.me/demo/themes/stack\\\\/demo-4\\\\/\\\\\\\\\\\\\\" ]Demo 4[\\\\/themify_button]<\\\\/p>\\",\\"icon_type_front\\":\\"icon\\",\\"gallery_autoplay_front\\":\\"off\\",\\"gallery_hide_timer_front\\":\\"no\\",\\"type_map_front\\":\\"ROADMAP\\",\\"zoom_map_front\\":\\"7\\",\\"scrollwheel_map_front\\":\\"enable\\",\\"draggable_map_front\\":\\"enable\\",\\"background_color_front\\":\\"d42689\\",\\"text_color_front\\":\\"ffffff\\",\\"link_color_front\\":\\"ffffff\\",\\"type_back\\":\\"text\\",\\"icon_type_back\\":\\"icon\\",\\"gallery_autoplay_back\\":\\"off\\",\\"gallery_hide_timer_back\\":\\"no\\",\\"type_map_back\\":\\"ROADMAP\\",\\"zoom_map_back\\":\\"7\\",\\"scrollwheel_map_back\\":\\"enable\\",\\"draggable_map_back\\":\\"enable\\",\\"tile_autoflip\\":\\"0\\",\\"flip_effect\\":\\"flip-horizontal\\",\\"background_color_back\\":\\"46317d\\",\\"text_color_back\\":\\"ffffff\\",\\"link_color_back\\":\\"ffffff\\"}},{\\"mod_name\\":\\"tile\\",\\"element_id\\":\\"377acfb\\",\\"mod_settings\\":{\\"size\\":\\"square-small\\",\\"type_front\\":\\"text\\",\\"color_front\\":\\"light-blue\\",\\"icon_type_front\\":\\"icon\\",\\"gallery_autoplay_front\\":\\"off\\",\\"gallery_hide_timer_front\\":\\"no\\",\\"type_map_front\\":\\"ROADMAP\\",\\"scrollwheel_map_front\\":\\"enable\\",\\"draggable_map_front\\":\\"enable\\",\\"action_text_front\\":\\"Blog\\",\\"action_link_front\\":\\"https:\\\\/\\\\/themify.me\\\\/themes\\\\/stack\\\\/blog\\",\\"background_color_front\\":\\"ffffff_1.00\\",\\"text_color_front\\":\\"000000_1.00\\",\\"link_color_front\\":\\"000000_1.00\\",\\"background_image_front\\":\\"https://themify.me/demo/themes/stack\\\\/files\\\\/2014\\\\/12\\\\/101397043.jpg\\",\\"type_back\\":\\"text\\",\\"icon_type_back\\":\\"icon\\",\\"gallery_autoplay_back\\":\\"off\\",\\"gallery_hide_timer_back\\":\\"no\\",\\"type_map_back\\":\\"ROADMAP\\",\\"scrollwheel_map_back\\":\\"enable\\",\\"draggable_map_back\\":\\"enable\\",\\"tile_autoflip\\":\\"0\\",\\"flip_effect\\":\\"flip-horizontal\\"}},{\\"mod_name\\":\\"tile\\",\\"element_id\\":\\"4e28a15\\",\\"mod_settings\\":{\\"size\\":\\"square-small\\",\\"type_front\\":\\"button\\",\\"color_front\\":\\"light-blue\\",\\"title_front\\":\\"Portfolio\\",\\"button_link_front\\":\\"https://themify.me/demo/themes/stack\\\\/portfolio\\\\/\\",\\"icon_type_front\\":\\"icon\\",\\"icon_front\\":\\"fa-suitcase\\",\\"icon_color_front\\":\\"ffffff_1.00\\",\\"gallery_autoplay_front\\":\\"off\\",\\"gallery_hide_timer_front\\":\\"no\\",\\"type_map_front\\":\\"ROADMAP\\",\\"zoom_map_front\\":\\"7\\",\\"scrollwheel_map_front\\":\\"enable\\",\\"draggable_map_front\\":\\"enable\\",\\"background_color_front\\":\\"EA3556\\",\\"text_color_front\\":\\"ffffff_1.00\\",\\"link_color_front\\":\\"ffffff_1.00\\",\\"type_back\\":\\"button\\",\\"icon_type_back\\":\\"icon\\",\\"gallery_autoplay_back\\":\\"off\\",\\"gallery_hide_timer_back\\":\\"no\\",\\"type_map_back\\":\\"ROADMAP\\",\\"zoom_map_back\\":\\"7\\",\\"scrollwheel_map_back\\":\\"enable\\",\\"draggable_map_back\\":\\"enable\\",\\"tile_autoflip\\":\\"0\\",\\"flip_effect\\":\\"flip-horizontal\\"}},{\\"mod_name\\":\\"tile\\",\\"element_id\\":\\"03fd61d\\",\\"mod_settings\\":{\\"size\\":\\"square-small\\",\\"type_front\\":\\"button\\",\\"color_front\\":\\"light-blue\\",\\"text_front\\":\\"<h1> <\\\\/h1>\\",\\"icon_type_front\\":\\"icon\\",\\"gallery_autoplay_front\\":\\"off\\",\\"gallery_hide_timer_front\\":\\"no\\",\\"type_map_front\\":\\"ROADMAP\\",\\"scrollwheel_map_front\\":\\"enable\\",\\"draggable_map_front\\":\\"enable\\",\\"action_param_front\\":\\"lightbox\\",\\"background_image_front\\":\\"https://themify.me/demo/themes/stack\\\\/files\\\\/2014\\\\/12\\\\/111233801.jpg\\",\\"type_back\\":\\"button\\",\\"title_back\\":\\"Shop\\",\\"button_link_back\\":\\"https://themify.me/demo/themes/stack\\\\/shop\\\\/\\",\\"icon_type_back\\":\\"icon\\",\\"icon_back\\":\\"fa-shopping-cart\\",\\"icon_color_back\\":\\"ffffff\\",\\"gallery_autoplay_back\\":\\"off\\",\\"gallery_hide_timer_back\\":\\"no\\",\\"type_map_back\\":\\"ROADMAP\\",\\"scrollwheel_map_back\\":\\"enable\\",\\"draggable_map_back\\":\\"enable\\",\\"action_param_back\\":\\"lightbox\\",\\"tile_autoflip\\":\\"3\\",\\"flip_effect\\":\\"flip-vertical\\",\\"background_color_back\\":\\"66c476\\",\\"text_color_back\\":\\"ffffff_1.00\\",\\"link_color_back\\":\\"ffffff_1.00\\"}},{\\"mod_name\\":\\"tile\\",\\"element_id\\":\\"07389d6\\",\\"mod_settings\\":{\\"size\\":\\"landscape\\",\\"type_front\\":\\"text\\",\\"color_front\\":\\"purple\\",\\"title_front\\":\\"11 Flip Animtion\\",\\"text_front\\":\\"<p style=\\\\\\\\\\\\\\"text-align: left;\\\\\\\\\\\\\\">With timed controlled auto flip option. Click on the button below to the auto flip animation tiles in action.<\\\\/p>\\\\n\\",\\"icon_type_front\\":\\"icon\\",\\"gallery_autoplay_front\\":\\"off\\",\\"gallery_hide_timer_front\\":\\"no\\",\\"type_map_front\\":\\"ROADMAP\\",\\"zoom_map_front\\":\\"7\\",\\"scrollwheel_map_front\\":\\"enable\\",\\"draggable_map_front\\":\\"enable\\",\\"action_text_front\\":\\"Demo 3\\",\\"action_link_front\\":\\"https://themify.me/demo/themes/stack\\\\/home\\\\/demo-3\\\\/\\",\\"background_color_front\\":\\"ffef0f_1.00\\",\\"text_color_front\\":\\"000000_1.00\\",\\"link_color_front\\":\\"000000_1.00\\",\\"type_back\\":\\"text\\",\\"color_back\\":\\"red\\",\\"title_back\\":\\"Back Tile \\",\\"text_back\\":\\"<p>Auto flip back and forth.<\\\\/p>\\",\\"icon_type_back\\":\\"icon\\",\\"gallery_autoplay_back\\":\\"off\\",\\"gallery_hide_timer_back\\":\\"no\\",\\"type_map_back\\":\\"ROADMAP\\",\\"zoom_map_back\\":\\"7\\",\\"scrollwheel_map_back\\":\\"enable\\",\\"draggable_map_back\\":\\"enable\\",\\"tile_autoflip\\":\\"4\\",\\"flip_effect\\":\\"flip-horizontal\\",\\"background_color_back\\":\\"834ae6_1.00\\",\\"text_color_back\\":\\"ffffff_1.00\\",\\"link_color_back\\":\\"ffffff_1.00\\"}},{\\"mod_name\\":\\"tile\\",\\"element_id\\":\\"e762e64\\",\\"mod_settings\\":{\\"size\\":\\"square-small\\",\\"type_front\\":\\"button\\",\\"color_front\\":\\"light-blue\\",\\"title_front\\":\\"300+ Icons\\",\\"text_front\\":\\"<p>Over 300+ icons available<\\\\/p>\\",\\"icon_type_front\\":\\"icon\\",\\"icon_front\\":\\"fa-angellist\\",\\"icon_color_front\\":\\"ffffff_1.00\\",\\"gallery_autoplay_front\\":\\"off\\",\\"gallery_hide_timer_front\\":\\"no\\",\\"type_map_front\\":\\"ROADMAP\\",\\"scrollwheel_map_front\\":\\"enable\\",\\"draggable_map_front\\":\\"enable\\",\\"action_text_front\\":\\"Learn More\\",\\"action_link_front\\":\\"https:\\\\/\\\\/themify.me\\\\/themes\\\\/stack\\",\\"background_color_front\\":\\"40c9f7_1.00\\",\\"text_color_front\\":\\"ffffff_1.00\\",\\"link_color_front\\":\\"ffffff_1.00\\",\\"type_back\\":\\"text\\",\\"icon_type_back\\":\\"icon\\",\\"gallery_autoplay_back\\":\\"off\\",\\"gallery_hide_timer_back\\":\\"no\\",\\"type_map_back\\":\\"ROADMAP\\",\\"scrollwheel_map_back\\":\\"enable\\",\\"draggable_map_back\\":\\"enable\\",\\"tile_autoflip\\":\\"0\\",\\"flip_effect\\":\\"flip-horizontal\\"}},{\\"mod_name\\":\\"tile\\",\\"element_id\\":\\"97834eb\\",\\"mod_settings\\":{\\"size\\":\\"portrait\\",\\"type_front\\":\\"button\\",\\"color_front\\":\\"light-blue\\",\\"text_front\\":\\"<p>Create Tumblr-like micro blogs<\\\\/p>\\",\\"icon_type_front\\":\\"icon\\",\\"gallery_autoplay_front\\":\\"off\\",\\"gallery_hide_timer_front\\":\\"no\\",\\"type_map_front\\":\\"ROADMAP\\",\\"scrollwheel_map_front\\":\\"enable\\",\\"draggable_map_front\\":\\"enable\\",\\"action_text_front\\":\\"Learn More\\",\\"action_link_front\\":\\"https:\\\\/\\\\/themify.me\\\\/themes\\\\/stack\\",\\"text_color_front\\":\\"ffffff_1.00\\",\\"link_color_front\\":\\"ffffff_1.00\\",\\"background_image_front\\":\\"https://themify.me/demo/themes/stack\\\\/files\\\\/2014\\\\/12\\\\/135815177.jpg\\",\\"type_back\\":\\"text\\",\\"color_back\\":\\"blue\\",\\"text_back\\":\\"<p style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\"> <\\\\/p><p style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">Display a simple Image Tile that links to any page on your site<\\\\/p>\\",\\"icon_type_back\\":\\"icon\\",\\"gallery_autoplay_back\\":\\"off\\",\\"gallery_hide_timer_back\\":\\"no\\",\\"type_map_back\\":\\"ROADMAP\\",\\"scrollwheel_map_back\\":\\"enable\\",\\"draggable_map_back\\":\\"enable\\",\\"action_text_back\\":\\"More Info\\",\\"action_link_back\\":\\"https:\\\\/\\\\/themify.me\\\\/themes\\\\/stack\\\\/\\",\\"tile_autoflip\\":\\"0\\",\\"flip_effect\\":\\"fadeIn\\",\\"background_color_back\\":\\"3c20c7_0.83\\",\\"text_color_back\\":\\"ffffff_1.00\\",\\"link_color_back\\":\\"ffffff_1.00\\"}},{\\"mod_name\\":\\"tile\\",\\"element_id\\":\\"0f3ceec\\",\\"mod_settings\\":{\\"size\\":\\"square-large\\",\\"type_front\\":\\"gallery\\",\\"color_front\\":\\"light-blue\\",\\"icon_type_front\\":\\"icon\\",\\"gallery_front\\":\\"[gallery _orderByField=\\\\\\\\\\\\\\"menu_order ID\\\\\\\\\\\\\\" ids=\\\\\\\\\\\\\\"2750,2629,2614\\\\\\\\\\\\\\"]\\",\\"gallery_autoplay_front\\":\\"3000\\",\\"gallery_hide_timer_front\\":\\"no\\",\\"type_map_front\\":\\"ROADMAP\\",\\"scrollwheel_map_front\\":\\"enable\\",\\"draggable_map_front\\":\\"enable\\",\\"type_back\\":\\"blank\\",\\"icon_type_back\\":\\"icon\\",\\"gallery_autoplay_back\\":\\"off\\",\\"gallery_hide_timer_back\\":\\"no\\",\\"type_map_back\\":\\"ROADMAP\\",\\"scrollwheel_map_back\\":\\"enable\\",\\"draggable_map_back\\":\\"enable\\",\\"tile_autoflip\\":\\"0\\",\\"flip_effect\\":\\"zoomInUp\\"}},{\\"mod_name\\":\\"tile\\",\\"element_id\\":\\"1795f54\\",\\"mod_settings\\":{\\"size\\":\\"square-small\\",\\"type_front\\":\\"blank\\",\\"color_front\\":\\"purple\\",\\"icon_type_front\\":\\"icon\\",\\"gallery_autoplay_front\\":\\"off\\",\\"gallery_hide_timer_front\\":\\"no\\",\\"type_map_front\\":\\"ROADMAP\\",\\"scrollwheel_map_front\\":\\"enable\\",\\"draggable_map_front\\":\\"enable\\",\\"type_back\\":\\"text\\",\\"color_back\\":\\"black\\",\\"text_back\\":\\"<h2 style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">Hidden Tile<\\\\/h2><p style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">Cool?<\\\\/p>\\",\\"icon_type_back\\":\\"icon\\",\\"gallery_autoplay_back\\":\\"off\\",\\"gallery_hide_timer_back\\":\\"no\\",\\"type_map_back\\":\\"ROADMAP\\",\\"scrollwheel_map_back\\":\\"enable\\",\\"draggable_map_back\\":\\"enable\\",\\"tile_autoflip\\":\\"4\\",\\"flip_effect\\":\\"flip-vertical\\",\\"background_color_back\\":\\"000000_1.00\\",\\"text_color_back\\":\\"ffffff_1.00\\",\\"link_color_back\\":\\"ffffff_1.00\\"}},{\\"mod_name\\":\\"tile\\",\\"element_id\\":\\"5fd6acf\\",\\"mod_settings\\":{\\"size\\":\\"square-small\\",\\"type_front\\":\\"text\\",\\"color_front\\":\\"light-blue\\",\\"title_front\\":\\"Customizable\\",\\"text_front\\":\\"<p>Both front and back tile can be customized<\\\\/p>\\",\\"icon_type_front\\":\\"icon\\",\\"gallery_autoplay_front\\":\\"off\\",\\"gallery_hide_timer_front\\":\\"no\\",\\"address_map_front\\":\\"Toronto, Ontario\\",\\"type_map_front\\":\\"ROADMAP\\",\\"scrollwheel_map_front\\":\\"disable\\",\\"draggable_map_front\\":\\"enable\\",\\"action_text_front\\":\\"Learn More\\",\\"action_link_front\\":\\"https:\\\\/\\\\/themify.me\\\\/themes\\\\/stack\\",\\"background_color_front\\":\\"52c4b7_1.00\\",\\"text_color_front\\":\\"ffffff_1.00\\",\\"link_color_front\\":\\"ffffff_1.00\\",\\"type_back\\":\\"text\\",\\"icon_type_back\\":\\"icon\\",\\"gallery_autoplay_back\\":\\"off\\",\\"gallery_hide_timer_back\\":\\"no\\",\\"type_map_back\\":\\"ROADMAP\\",\\"scrollwheel_map_back\\":\\"enable\\",\\"draggable_map_back\\":\\"enable\\",\\"tile_autoflip\\":\\"0\\",\\"flip_effect\\":\\"flip-horizontal\\"}},{\\"mod_name\\":\\"tile\\",\\"element_id\\":\\"46dd13f\\",\\"mod_settings\\":{\\"size\\":\\"square-large\\",\\"type_front\\":\\"text\\",\\"color_front\\":\\"light-blue\\",\\"text_front\\":\\"<h3>Masonry <br \\\\/>layouts <br \\\\/>in shop, blog, <br \\\\/>portfolio &amp; tiles<\\\\/h3>\\",\\"icon_type_front\\":\\"icon\\",\\"icon_front\\":\\"fa-comment-o\\",\\"icon_color_front\\":\\"ffffff_1.00\\",\\"gallery_autoplay_front\\":\\"off\\",\\"gallery_hide_timer_front\\":\\"no\\",\\"type_map_front\\":\\"ROADMAP\\",\\"scrollwheel_map_front\\":\\"enable\\",\\"draggable_map_front\\":\\"enable\\",\\"text_color_front\\":\\"ff4a4a\\",\\"link_color_front\\":\\"ff4a4a\\",\\"background_image_front\\":\\"https://themify.me/demo/themes/stack\\\\/files\\\\/2014\\\\/12\\\\/131900372.jpg\\",\\"type_back\\":\\"text\\",\\"icon_type_back\\":\\"icon\\",\\"gallery_autoplay_back\\":\\"off\\",\\"gallery_hide_timer_back\\":\\"no\\",\\"type_map_back\\":\\"ROADMAP\\",\\"scrollwheel_map_back\\":\\"enable\\",\\"draggable_map_back\\":\\"enable\\",\\"tile_autoflip\\":\\"0\\",\\"flip_effect\\":\\"flip-horizontal\\",\\"text_align\\":\\"right\\"}},{\\"mod_name\\":\\"tile\\",\\"element_id\\":\\"ad61694\\",\\"mod_settings\\":{\\"size\\":\\"square-small\\",\\"type_front\\":\\"map\\",\\"color_front\\":\\"light-blue\\",\\"icon_type_front\\":\\"icon\\",\\"gallery_autoplay_front\\":\\"off\\",\\"gallery_hide_timer_front\\":\\"no\\",\\"address_map_front\\":\\"30 Adelaide St E, Toronto, ON, Canada\\",\\"type_map_front\\":\\"ROADMAP\\",\\"zoom_map_front\\":\\"17\\",\\"scrollwheel_map_front\\":\\"disable\\",\\"draggable_map_front\\":\\"disable\\",\\"type_back\\":\\"text\\",\\"icon_type_back\\":\\"icon\\",\\"gallery_autoplay_back\\":\\"off\\",\\"gallery_hide_timer_back\\":\\"no\\",\\"type_map_back\\":\\"ROADMAP\\",\\"zoom_map_back\\":\\"7\\",\\"scrollwheel_map_back\\":\\"enable\\",\\"draggable_map_back\\":\\"enable\\",\\"tile_autoflip\\":\\"0\\",\\"flip_effect\\":\\"flip-horizontal\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}},{\\"mod_name\\":\\"tile\\",\\"element_id\\":\\"fa795c0\\",\\"mod_settings\\":{\\"size\\":\\"square-small\\",\\"type_front\\":\\"button\\",\\"color_front\\":\\"light-blue\\",\\"button_link_front\\":\\"https:\\\\/\\\\/www.youtube.com\\\\/user\\\\/themifyme\\",\\"icon_type_front\\":\\"icon\\",\\"icon_front\\":\\"fa-youtube\\",\\"icon_color_front\\":\\"ffffff\\",\\"gallery_autoplay_front\\":\\"off\\",\\"gallery_hide_timer_front\\":\\"no\\",\\"type_map_front\\":\\"ROADMAP\\",\\"scrollwheel_map_front\\":\\"enable\\",\\"draggable_map_front\\":\\"enable\\",\\"background_color_front\\":\\"c23836_1.00\\",\\"text_color_front\\":\\"ffffff_1.00\\",\\"link_color_front\\":\\"ffffff_1.00\\",\\"type_back\\":\\"text\\",\\"text_back\\":\\"<p style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\"> <\\\\/p><p style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\"><a href=\\\\\\\\\\\\\\"https:\\\\/\\\\/www.youtube.com\\\\/user\\\\/themifyme\\\\\\\\\\\\\\"><strong>Subscribe<\\\\/strong> <\\\\/a>to our Youtube Channel and watch our latest tutorial videos!<\\\\/p>\\",\\"icon_type_back\\":\\"icon\\",\\"gallery_autoplay_back\\":\\"off\\",\\"gallery_hide_timer_back\\":\\"no\\",\\"type_map_back\\":\\"ROADMAP\\",\\"scrollwheel_map_back\\":\\"enable\\",\\"draggable_map_back\\":\\"enable\\",\\"tile_autoflip\\":\\"0\\",\\"flip_effect\\":\\"flip-horizontal\\",\\"background_color_back\\":\\"DF2826\\",\\"text_color_back\\":\\"ffffff_1.00\\",\\"link_color_back\\":\\"ffffff_1.00\\"}},{\\"mod_name\\":\\"tile\\",\\"element_id\\":\\"311ca03\\",\\"mod_settings\\":{\\"size\\":\\"square-small\\",\\"type_front\\":\\"button\\",\\"color_front\\":\\"light-blue\\",\\"button_link_front\\":\\"https:\\\\/\\\\/plus.google.com\\\\/u\\\\/0\\\\/b\\\\/109280316400365629341\\\\/109280316400365629341\\\\/videos\\",\\"icon_type_front\\":\\"icon\\",\\"icon_front\\":\\"fa-google-plus\\",\\"icon_color_front\\":\\"ffffff\\",\\"gallery_autoplay_front\\":\\"off\\",\\"gallery_hide_timer_front\\":\\"no\\",\\"type_map_front\\":\\"ROADMAP\\",\\"scrollwheel_map_front\\":\\"enable\\",\\"draggable_map_front\\":\\"enable\\",\\"background_color_front\\":\\"DE5C4B\\",\\"text_color_front\\":\\"ffffff_1.00\\",\\"link_color_front\\":\\"ffffff_1.00\\",\\"type_back\\":\\"text\\",\\"text_back\\":\\"<p style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\"><a href=\\\\\\\\\\\\\\"https:\\\\/\\\\/plus.google.com\\\\/u\\\\/0\\\\/b\\\\/109280316400365629341\\\\/109280316400365629341\\\\/videos\\\\\\\\\\\\\\"><strong>Follow us<\\\\/strong> <\\\\/a>on our Google+ Page to get the latest updates and promotions!<\\\\/p>\\",\\"icon_type_back\\":\\"icon\\",\\"gallery_autoplay_back\\":\\"off\\",\\"gallery_hide_timer_back\\":\\"no\\",\\"type_map_back\\":\\"ROADMAP\\",\\"scrollwheel_map_back\\":\\"enable\\",\\"draggable_map_back\\":\\"enable\\",\\"tile_autoflip\\":\\"0\\",\\"flip_effect\\":\\"flip-vertical\\",\\"background_color_back\\":\\"DE5C4B\\",\\"text_color_back\\":\\"ffffff_1.00\\",\\"link_color_back\\":\\"ffffff_1.00\\"}},{\\"mod_name\\":\\"tile\\",\\"element_id\\":\\"43a8841\\",\\"mod_settings\\":{\\"size\\":\\"square-small\\",\\"type_front\\":\\"button\\",\\"color_front\\":\\"light-blue\\",\\"button_link_front\\":\\"https:\\\\/\\\\/www.facebook.com\\\\/themify\\",\\"icon_type_front\\":\\"icon\\",\\"icon_front\\":\\"fa-facebook\\",\\"icon_color_front\\":\\"ffffff\\",\\"gallery_autoplay_front\\":\\"off\\",\\"gallery_hide_timer_front\\":\\"no\\",\\"type_map_front\\":\\"ROADMAP\\",\\"scrollwheel_map_front\\":\\"enable\\",\\"draggable_map_front\\":\\"enable\\",\\"background_color_front\\":\\"47639E\\",\\"text_color_front\\":\\"ffffff_1.00\\",\\"link_color_front\\":\\"ffffff_1.00\\",\\"type_back\\":\\"text\\",\\"text_back\\":\\"<p style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">\\\\n<p style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\"><a href=\\\\\\\\\\\\\\"https:\\\\/\\\\/www.facebook.com\\\\/themify\\\\\\\\\\\\\\"><strong>Like us<\\\\/strong> <\\\\/a>on our Facebook Page to get the latest updates and promotions!<\\\\/p>\\\\n\\",\\"icon_type_back\\":\\"icon\\",\\"gallery_autoplay_back\\":\\"off\\",\\"gallery_hide_timer_back\\":\\"no\\",\\"type_map_back\\":\\"ROADMAP\\",\\"scrollwheel_map_back\\":\\"enable\\",\\"draggable_map_back\\":\\"enable\\",\\"tile_autoflip\\":\\"0\\",\\"flip_effect\\":\\"flip-horizontal\\",\\"background_color_back\\":\\"47639E\\",\\"text_color_back\\":\\"ffffff_1.00\\",\\"link_color_back\\":\\"ffffff_1.00\\"}},{\\"mod_name\\":\\"tile\\",\\"element_id\\":\\"8509d91\\",\\"mod_settings\\":{\\"size\\":\\"square-small\\",\\"type_front\\":\\"button\\",\\"color_front\\":\\"light-blue\\",\\"button_link_front\\":\\"https:\\\\/\\\\/twitter.com\\\\/themify\\",\\"icon_type_front\\":\\"icon\\",\\"icon_front\\":\\"fa-twitter\\",\\"icon_color_front\\":\\"ffffff\\",\\"gallery_autoplay_front\\":\\"off\\",\\"gallery_hide_timer_front\\":\\"no\\",\\"type_map_front\\":\\"ROADMAP\\",\\"scrollwheel_map_front\\":\\"enable\\",\\"draggable_map_front\\":\\"enable\\",\\"background_color_front\\":\\"329BC2\\",\\"text_color_front\\":\\"ffffff_1.00\\",\\"link_color_front\\":\\"ffffff_1.00\\",\\"type_back\\":\\"text\\",\\"text_back\\":\\"<p style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\"> <\\\\/p><p style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\"><a href=\\\\\\\\\\\\\\"https:\\\\/\\\\/twitter.com\\\\/themify\\\\\\\\\\\\\\"><strong>Follow us<\\\\/strong> <\\\\/a>on Twitter to get the latest updates and promotions!<\\\\/p>\\",\\"icon_type_back\\":\\"icon\\",\\"gallery_autoplay_back\\":\\"off\\",\\"gallery_hide_timer_back\\":\\"no\\",\\"type_map_back\\":\\"ROADMAP\\",\\"scrollwheel_map_back\\":\\"enable\\",\\"draggable_map_back\\":\\"enable\\",\\"tile_autoflip\\":\\"0\\",\\"flip_effect\\":\\"flip-vertical\\",\\"background_color_back\\":\\"329BC2\\",\\"text_color_back\\":\\"ffffff_1.00\\",\\"link_color_back\\":\\"ffffff_1.00\\"}}]}],\\"styling\\":{\\"row_width\\":\\"fullwidth\\",\\"background_type\\":\\"image\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom_unit\\":\\"%\\"}},{\\"element_id\\":\\"b5b6a02\\",\\"row_order\\":\\"1\\",\\"cols\\":[{\\"element_id\\":\\"b2dc952\\",\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\"}]}]',
  ),
  'tax_input' => 
  array (
  ),
);
themify_process_post_import( $post );


$post = array (
  'ID' => 2455,
  'post_date' => '2014-12-24 18:27:30',
  'post_date_gmt' => '2014-12-24 18:27:30',
  'post_content' => '',
  'post_title' => 'Portfolio',
  'post_excerpt' => '',
  'post_name' => 'portfolio',
  'post_modified' => '2017-08-21 07:29:05',
  'post_modified_gmt' => '2017-08-21 07:29:05',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/stack/?page_id=2455',
  'menu_order' => 9,
  'post_type' => 'page',
  'meta_input' => 
  array (
    'page_layout' => 'sidebar-none',
    'content_width' => 'full_width',
    'hide_page_title' => 'default',
    'order' => 'desc',
    'orderby' => 'date',
    'layout' => 'list-post',
    'enable_masonry' => 'default',
    'display_content' => 'content',
    'hide_title' => 'default',
    'unlink_title' => 'default',
    'hide_date' => 'default',
    'hide_image' => 'default',
    'unlink_image' => 'default',
    'hide_navigation' => 'default',
    'portfolio_query_category' => '0',
    'portfolio_order' => 'desc',
    'portfolio_orderby' => 'date',
    'portfolio_layout' => 'masonry',
    'portfolio_enable_masonry' => 'yes',
    'portfolio_posts_per_page' => '8',
    'portfolio_hide_title' => 'default',
    'portfolio_unlink_title' => 'default',
    'portfolio_hide_meta_all' => 'default',
    'portfolio_hide_image' => 'default',
    'portfolio_unlink_image' => 'default',
    'portfolio_hide_navigation' => 'default',
    'builder_tiles_fluid_tiles_base_size' => '16',
    'builder_switch_frontend' => '0',
  ),
  'tax_input' => 
  array (
  ),
);
themify_process_post_import( $post );


$post = array (
  'ID' => 2500,
  'post_date' => '2014-12-24 18:58:19',
  'post_date_gmt' => '2014-12-24 18:58:19',
  'post_content' => '',
  'post_title' => 'Blog',
  'post_excerpt' => '',
  'post_name' => 'blog',
  'post_modified' => '2017-08-21 07:29:20',
  'post_modified_gmt' => '2017-08-21 07:29:20',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/stack/?page_id=2500',
  'menu_order' => 10,
  'post_type' => 'page',
  'meta_input' => 
  array (
    'page_layout' => 'default',
    'content_width' => 'default_width',
    'hide_page_title' => 'default',
    'query_category' => '0',
    'order' => 'desc',
    'orderby' => 'date',
    'layout' => 'grid3',
    'enable_masonry' => 'yes',
    'posts_per_page' => '8',
    'display_content' => 'content',
    'hide_title' => 'default',
    'unlink_title' => 'default',
    'hide_date' => 'default',
    'hide_image' => 'default',
    'unlink_image' => 'default',
    'hide_navigation' => 'default',
    'portfolio_order' => 'desc',
    'portfolio_orderby' => 'date',
    'portfolio_layout' => 'grid4',
    'portfolio_enable_masonry' => 'default',
    'portfolio_display_content' => 'content',
    'portfolio_hide_title' => 'default',
    'portfolio_unlink_title' => 'default',
    'portfolio_hide_meta_all' => 'default',
    'portfolio_hide_image' => 'default',
    'portfolio_unlink_image' => 'default',
    'portfolio_hide_navigation' => 'default',
    'builder_tiles_fluid_tiles_base_size' => '16',
    'builder_switch_frontend' => '0',
  ),
  'tax_input' => 
  array (
  ),
);
themify_process_post_import( $post );


$post = array (
  'ID' => 22,
  'post_date' => '2012-02-23 19:22:45',
  'post_date_gmt' => '2012-02-23 19:22:45',
  'post_content' => 'Duis id tincidunt tortor. Curabitur placerat luctus lacinia. In hac habitasse platea dictumst. Suspendisse potenti. Nunc vestibulum, erat et pharetra aliquet, mi nunc iaculis erat, in pharetra libero felis sit amet ipsum.',
  'post_title' => 'Super Monkey Ball',
  'post_excerpt' => '',
  'post_name' => 'super-monkey-ball',
  'post_modified' => '2017-08-21 07:37:05',
  'post_modified_gmt' => '2017-08-21 07:37:05',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/shopdock/?post_type=product&#038;p=22',
  'menu_order' => 0,
  'post_type' => 'product',
  'meta_input' => 
  array (
    '_edit_last' => '172',
    '_regular_price' => '20',
    '_sale_price' => '18',
    '_tax_status' => 'taxable',
    '_stock_status' => 'instock',
    '_visibility' => 'visible',
    '_featured' => 'no',
    '_product_attributes' => 
    array (
    ),
    '_downloadable' => 'no',
    '_virtual' => 'no',
    '_price' => '18',
    '_stock' => NULL,
    '_manage_stock' => 'no',
    '_backorders' => 'no',
    '_thumbnail_id' => '2843',
    'post_image' => 'https://themify.me/demo/themes/stack/files/2012/02/monkey-ball.jpg',
    'total_sales' => '1',
    '_edit_lock' => '1503300913:172',
    '_wc_rating_count' => 
    array (
      4 => '1',
    ),
    '_wc_average_rating' => '4.00',
    '_wc_review_count' => '1',
    '_upsell_ids' => 
    array (
    ),
    '_crosssell_ids' => 
    array (
    ),
    '_default_attributes' => 
    array (
    ),
    '_download_limit' => '-1',
    '_download_expiry' => '-1',
    '_product_version' => '3.1.1',
    '_yoast_wpseo_content_score' => '30',
  ),
  'tax_input' => 
  array (
    'product_type' => 'simple',
    'product_cat' => 'games',
  ),
  'thumb' => 'https://themify.me/demo/themes/stack/files/2012/02/monkey-ball.jpg',
);
themify_process_post_import( $post );


$post = array (
  'ID' => 52,
  'post_date' => '2012-02-24 21:48:04',
  'post_date_gmt' => '2012-02-24 21:48:04',
  'post_content' => 'Vivamus in dolor eu lacus luctus auctor non ac turpis. Proin et rutrum dolor. Praesent venenatis purus convallis ipsum porttitor convallis consectetur orci condimentum. Curabitur ornare interdum pellentesque.',
  'post_title' => 'Casual Office Wear',
  'post_excerpt' => '',
  'post_name' => 'casual-office-wear',
  'post_modified' => '2017-08-21 07:36:56',
  'post_modified_gmt' => '2017-08-21 07:36:56',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/shopdock/?post_type=product&#038;p=52',
  'menu_order' => 0,
  'post_type' => 'product',
  'meta_input' => 
  array (
    '_stock_status' => 'instock',
    '_edit_last' => '172',
    '_regular_price' => '18',
    '_tax_status' => 'taxable',
    '_thumbnail_id' => '2837',
    'post_image' => 'https://themify.me/demo/themes/stack/files/2012/02/Bloody-Mary.jpg',
    '_visibility' => 'visible',
    '_featured' => 'no',
    '_product_attributes' => 
    array (
    ),
    '_downloadable' => 'no',
    '_virtual' => 'no',
    '_price' => '18',
    '_stock' => NULL,
    '_manage_stock' => 'no',
    '_backorders' => 'no',
    'total_sales' => '3',
    '_edit_lock' => '1503300911:172',
    '_wp_old_slug' => 'bloody-mary',
    '_wc_rating_count' => 
    array (
    ),
    '_wc_average_rating' => '0',
    '_wc_review_count' => '0',
    '_upsell_ids' => 
    array (
    ),
    '_crosssell_ids' => 
    array (
    ),
    '_default_attributes' => 
    array (
    ),
    '_download_limit' => '-1',
    '_download_expiry' => '-1',
    '_product_version' => '3.1.1',
    '_yoast_wpseo_content_score' => '30',
  ),
  'tax_input' => 
  array (
    'product_type' => 'simple',
    'product_cat' => 'tshirts',
  ),
  'thumb' => 'https://themify.me/demo/themes/stack/files/2012/02/Bloody-Mary.jpg',
);
themify_process_post_import( $post );


$post = array (
  'ID' => 54,
  'post_date' => '2012-02-24 21:50:23',
  'post_date_gmt' => '2012-02-24 21:50:23',
  'post_content' => 'Praesent eu ligula ut ligula tempus porttitor. In at sem ipsum, sed commodo felis. Nullam nec elit sapien. Donec at congue sapien. Mauris a diam nec felis auctor ultrices. Sed tempus mollis orci in viverra.',
  'post_title' => 'Andreas',
  'post_excerpt' => '',
  'post_name' => 'andreas',
  'post_modified' => '2017-08-21 07:36:51',
  'post_modified_gmt' => '2017-08-21 07:36:51',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/shopdock/?post_type=product&#038;p=54',
  'menu_order' => 0,
  'post_type' => 'product',
  'meta_input' => 
  array (
    '_edit_last' => '172',
    '_regular_price' => '18',
    '_sale_price' => '15',
    '_tax_status' => 'taxable',
    '_stock_status' => 'instock',
    '_visibility' => 'visible',
    '_featured' => 'no',
    '_product_attributes' => 
    array (
    ),
    '_downloadable' => 'no',
    '_virtual' => 'no',
    '_price' => '15',
    '_stock' => NULL,
    '_manage_stock' => 'no',
    '_backorders' => 'no',
    '_thumbnail_id' => '2838',
    'post_image' => 'https://themify.me/demo/themes/stack/files/2012/02/Donkey-Kong.jpg',
    'total_sales' => '2',
    '_edit_lock' => '1503301053:172',
    '_wp_old_slug' => 'donkey-kong',
    '_wc_rating_count' => 
    array (
    ),
    '_wc_average_rating' => '0',
    '_wc_review_count' => '0',
    '_upsell_ids' => 
    array (
    ),
    '_crosssell_ids' => 
    array (
    ),
    '_default_attributes' => 
    array (
    ),
    '_download_limit' => '-1',
    '_download_expiry' => '-1',
    '_product_version' => '3.1.1',
    '_yoast_wpseo_content_score' => '30',
  ),
  'tax_input' => 
  array (
    'product_type' => 'simple',
    'product_cat' => 'tshirts',
  ),
  'thumb' => 'https://themify.me/demo/themes/stack/files/2012/02/Donkey-Kong.jpg',
);
themify_process_post_import( $post );


$post = array (
  'ID' => 2671,
  'post_date' => '2012-02-24 22:06:11',
  'post_date_gmt' => '2012-02-24 22:06:11',
  'post_content' => 'Vivamus in dolor eu lacus luctus auctor non ac turpis. Proin et rutrum dolor. Praesent venenatis purus convallis ipsum porttitor convallis consectetur orci condimentum. Curabitur ornare interdum pellentesque.',
  'post_title' => 'Puzzle Bobble',
  'post_excerpt' => '',
  'post_name' => 'puzzle-bobble',
  'post_modified' => '2017-08-21 07:36:50',
  'post_modified_gmt' => '2017-08-21 07:36:50',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/shopdock/?post_type=product&#038;p=62',
  'menu_order' => 0,
  'post_type' => 'product',
  'meta_input' => 
  array (
    '_edit_last' => '172',
    '_regular_price' => '29',
    '_tax_status' => 'taxable',
    '_stock_status' => 'instock',
    '_visibility' => 'visible',
    '_featured' => 'no',
    '_product_attributes' => 
    array (
    ),
    '_downloadable' => 'no',
    '_virtual' => 'no',
    '_price' => '29',
    '_stock' => NULL,
    '_manage_stock' => 'no',
    '_backorders' => 'no',
    'total_sales' => '2',
    '_thumbnail_id' => '2850',
    'post_image' => 'https://themify.me/demo/themes/stack/files/2012/02/puzzle-bobble.jpg',
    '_wp_old_slug' => 'barbie',
    '_edit_lock' => '1503301052:172',
    '_wc_rating_count' => 
    array (
    ),
    '_wc_average_rating' => '0',
    '_wc_review_count' => '0',
    '_upsell_ids' => 
    array (
    ),
    '_crosssell_ids' => 
    array (
    ),
    '_default_attributes' => 
    array (
    ),
    '_download_limit' => '-1',
    '_download_expiry' => '-1',
    '_product_version' => '3.1.1',
    '_yoast_wpseo_content_score' => '30',
  ),
  'tax_input' => 
  array (
    'product_type' => 'simple',
    'product_cat' => 'games',
  ),
  'thumb' => 'https://themify.me/demo/themes/stack/files/2012/02/puzzle-bobble.jpg',
);
themify_process_post_import( $post );


$post = array (
  'ID' => 65,
  'post_date' => '2012-02-24 22:08:10',
  'post_date_gmt' => '2012-02-24 22:08:10',
  'post_content' => 'Maecenas rhoncus malesuada aliquet. Morbi vulputate vulputate mauris quis condimentum. Ut ut ligula et mauris accumsan tristique ut nec lacus. Cras tempus pretium sagittis. Praesent porta libero nec magna vulputate porta.',
  'post_title' => 'PKM',
  'post_excerpt' => '',
  'post_name' => 'pkm',
  'post_modified' => '2017-08-21 07:36:49',
  'post_modified_gmt' => '2017-08-21 07:36:49',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/shopdock/?post_type=product&#038;p=65',
  'menu_order' => 0,
  'post_type' => 'product',
  'meta_input' => 
  array (
    '_edit_last' => '172',
    '_regular_price' => '26',
    '_tax_status' => 'taxable',
    '_stock_status' => 'instock',
    '_visibility' => 'visible',
    '_featured' => 'yes',
    '_product_attributes' => 
    array (
    ),
    '_downloadable' => 'no',
    '_virtual' => 'no',
    '_price' => '26',
    '_stock' => NULL,
    '_manage_stock' => 'no',
    '_backorders' => 'no',
    '_wp_old_slug' => 'peppa-pig',
    'total_sales' => '4',
    '_thumbnail_id' => '2849',
    'post_image' => 'https://themify.me/demo/themes/stack/files/2012/02/pkmnb-550x506.jpg',
    '_edit_lock' => '1503301052:172',
    '_wc_rating_count' => 
    array (
    ),
    '_wc_average_rating' => '0',
    '_wc_review_count' => '0',
    '_upsell_ids' => 
    array (
    ),
    '_crosssell_ids' => 
    array (
    ),
    '_default_attributes' => 
    array (
    ),
    '_download_limit' => '-1',
    '_download_expiry' => '-1',
    '_product_version' => '3.1.1',
    '_yoast_wpseo_content_score' => '30',
  ),
  'tax_input' => 
  array (
    'product_type' => 'simple',
    'product_cat' => 'games',
  ),
  'thumb' => 'https://themify.me/demo/themes/stack/files/2012/02/pkmnb-550x506.jpg',
);
themify_process_post_import( $post );


$post = array (
  'ID' => 67,
  'post_date' => '2012-02-24 22:10:07',
  'post_date_gmt' => '2012-02-24 22:10:07',
  'post_content' => 'Ut ut ligula et mauris accumsan tristique ut nec lacus. Cras tempus pretium sagittis. Praesent porta libero nec magna vulputate porta. Maecenas rhoncus malesuada aliquet. Morbi vulputate vulputate mauris quis condimentum.',
  'post_title' => 'Ridge Racers 3D',
  'post_excerpt' => '',
  'post_name' => 'ridge-racers-3d',
  'post_modified' => '2017-08-21 07:36:45',
  'post_modified_gmt' => '2017-08-21 07:36:45',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/shopdock/?post_type=product&#038;p=67',
  'menu_order' => 0,
  'post_type' => 'product',
  'meta_input' => 
  array (
    '_thumbnail_id' => '2846',
    'post_image' => 'https://themify.me/demo/themes/stack/files/2012/02/ridge-racers.jpg',
    '_edit_last' => '172',
    '_regular_price' => '29',
    '_tax_status' => 'taxable',
    '_stock_status' => 'instock',
    '_visibility' => 'visible',
    '_featured' => 'yes',
    '_product_attributes' => 
    array (
    ),
    '_downloadable' => 'no',
    '_virtual' => 'no',
    '_price' => '29',
    '_stock' => NULL,
    '_manage_stock' => 'no',
    '_backorders' => 'no',
    '_edit_lock' => '1503300906:172',
    'total_sales' => '0',
    '_wc_rating_count' => 
    array (
    ),
    '_wc_average_rating' => '0',
    '_wc_review_count' => '0',
    '_upsell_ids' => 
    array (
    ),
    '_crosssell_ids' => 
    array (
    ),
    '_default_attributes' => 
    array (
    ),
    '_download_limit' => '-1',
    '_download_expiry' => '-1',
    '_product_version' => '3.1.1',
    '_yoast_wpseo_content_score' => '30',
  ),
  'tax_input' => 
  array (
    'product_type' => 'simple',
    'product_cat' => 'games',
  ),
  'thumb' => 'https://themify.me/demo/themes/stack/files/2012/02/ridge-racers.jpg',
);
themify_process_post_import( $post );


$post = array (
  'ID' => 70,
  'post_date' => '2012-02-24 22:11:52',
  'post_date_gmt' => '2012-02-24 22:11:52',
  'post_content' => '',
  'post_title' => 'Joystick',
  'post_excerpt' => '',
  'post_name' => 'joystick',
  'post_modified' => '2017-08-21 07:36:42',
  'post_modified_gmt' => '2017-08-21 07:36:42',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/shopdock/?post_type=product&#038;p=70',
  'menu_order' => 0,
  'post_type' => 'product',
  'meta_input' => 
  array (
    '_thumbnail_id' => '2842',
    'post_image' => 'https://themify.me/demo/themes/stack/files/2012/02/Joystick.jpg',
    '_edit_last' => '172',
    '_regular_price' => '23',
    '_sale_price' => '15',
    '_tax_status' => 'taxable',
    '_stock_status' => 'instock',
    '_visibility' => 'visible',
    '_featured' => 'no',
    '_product_attributes' => 
    array (
    ),
    '_downloadable' => 'no',
    '_virtual' => 'no',
    '_price' => '15',
    '_stock' => NULL,
    '_manage_stock' => 'no',
    '_backorders' => 'no',
    'total_sales' => '2',
    '_edit_lock' => '1503301049:172',
    '_wp_old_slug' => 'pilotwings-resort',
    '_wc_rating_count' => 
    array (
    ),
    '_wc_average_rating' => '0',
    '_wc_review_count' => '0',
    '_upsell_ids' => 
    array (
    ),
    '_crosssell_ids' => 
    array (
    ),
    '_default_attributes' => 
    array (
    ),
    '_download_limit' => '-1',
    '_download_expiry' => '-1',
    '_product_version' => '3.1.1',
    '_yoast_wpseo_content_score' => '30',
  ),
  'tax_input' => 
  array (
    'product_type' => 'simple',
    'product_cat' => 'games',
  ),
  'thumb' => 'https://themify.me/demo/themes/stack/files/2012/02/Joystick.jpg',
);
themify_process_post_import( $post );


$post = array (
  'ID' => 72,
  'post_date' => '2012-02-24 22:12:51',
  'post_date_gmt' => '2012-02-24 22:12:51',
  'post_content' => 'Maecenas rhoncus malesuada aliquet. Morbi vulputate vulputate mauris quis condimentum. Ut ut ligula et mauris accumsan tristique ut nec lacus. Cras tempus pretium sagittis. Praesent porta libero nec magna vulputate porta.',
  'post_title' => 'Australia',
  'post_excerpt' => '',
  'post_name' => 'australia',
  'post_modified' => '2017-08-21 07:36:41',
  'post_modified_gmt' => '2017-08-21 07:36:41',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/shopdock/?post_type=product&#038;p=72',
  'menu_order' => 0,
  'post_type' => 'product',
  'meta_input' => 
  array (
    '_thumbnail_id' => '2833',
    'post_image' => 'https://themify.me/demo/themes/stack/files/2012/02/Australia.jpg',
    '_edit_last' => '172',
    '_regular_price' => '28',
    '_tax_status' => 'taxable',
    '_stock_status' => 'instock',
    '_visibility' => 'visible',
    '_featured' => 'yes',
    '_product_attributes' => 
    array (
    ),
    '_downloadable' => 'no',
    '_virtual' => 'no',
    '_price' => '28',
    '_stock' => NULL,
    '_manage_stock' => 'no',
    '_backorders' => 'no',
    'total_sales' => '16',
    '_edit_lock' => '1503300904:172',
    '_wc_rating_count' => 
    array (
    ),
    '_wc_average_rating' => '0',
    '_wc_review_count' => '0',
    '_upsell_ids' => 
    array (
    ),
    '_crosssell_ids' => 
    array (
    ),
    '_default_attributes' => 
    array (
    ),
    '_download_limit' => '-1',
    '_download_expiry' => '-1',
    '_product_version' => '3.1.1',
    '_yoast_wpseo_content_score' => '30',
  ),
  'tax_input' => 
  array (
    'product_type' => 'simple',
    'product_cat' => 'tshirts',
  ),
  'thumb' => 'https://themify.me/demo/themes/stack/files/2012/02/Australia.jpg',
);
themify_process_post_import( $post );


$post = array (
  'ID' => 74,
  'post_date' => '2012-02-24 22:13:48',
  'post_date_gmt' => '2012-02-24 22:13:48',
  'post_content' => 'In at sem ipsum, sed commodo felis. Nullam nec elit sapien. Donec at congue sapien. Mauris a diam nec felis auctor ultrices. Sed tempus mollis orci in viverra. Vivamus libero eros, dictum id aliquam in, tristique id sapien.',
  'post_title' => 'Plaid Shirts',
  'post_excerpt' => '',
  'post_name' => 'plaid-shirts',
  'post_modified' => '2017-08-21 07:36:38',
  'post_modified_gmt' => '2017-08-21 07:36:38',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/shopdock/?post_type=product&#038;p=74',
  'menu_order' => 0,
  'post_type' => 'product',
  'meta_input' => 
  array (
    '_thumbnail_id' => '2839',
    'post_image' => 'https://themify.me/demo/themes/stack/files/2012/02/Elephant.jpg',
    '_edit_last' => '172',
    '_regular_price' => '25',
    '_tax_status' => 'taxable',
    '_stock_status' => 'instock',
    '_visibility' => 'visible',
    '_featured' => 'no',
    '_product_attributes' => 
    array (
    ),
    '_downloadable' => 'no',
    '_virtual' => 'no',
    '_price' => '25',
    '_stock' => NULL,
    '_manage_stock' => 'no',
    '_backorders' => 'no',
    'total_sales' => '1',
    '_edit_lock' => '1503300903:172',
    '_wp_old_slug' => 'elephant',
    '_wc_rating_count' => 
    array (
    ),
    '_wc_average_rating' => '0',
    '_wc_review_count' => '0',
    '_upsell_ids' => 
    array (
    ),
    '_crosssell_ids' => 
    array (
    ),
    '_default_attributes' => 
    array (
    ),
    '_download_limit' => '-1',
    '_download_expiry' => '-1',
    '_product_version' => '3.1.1',
    '_yoast_wpseo_content_score' => '30',
  ),
  'tax_input' => 
  array (
    'product_type' => 'simple',
    'product_cat' => 'tshirts',
  ),
  'thumb' => 'https://themify.me/demo/themes/stack/files/2012/02/Elephant.jpg',
);
themify_process_post_import( $post );


$post = array (
  'ID' => 77,
  'post_date' => '2012-02-24 22:15:42',
  'post_date_gmt' => '2012-02-24 22:15:42',
  'post_content' => 'Donec quis augue nibh, eu facilisis metus. Donec cursus condimentum erat quis sollicitudin. Mauris enim tortor, hendrerit ut pharetra non, eleifend non elit. Ut dapibus eleifend ipsum a rhoncus. Aenean eu ante felis, nec vulputate enim.',
  'post_title' => 'Bardenas',
  'post_excerpt' => '',
  'post_name' => 'bardenas',
  'post_modified' => '2017-08-21 07:36:36',
  'post_modified_gmt' => '2017-08-21 07:36:36',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/shopdock/?post_type=product&#038;p=77',
  'menu_order' => 0,
  'post_type' => 'product',
  'meta_input' => 
  array (
    '_edit_last' => '172',
    '_regular_price' => '69',
    '_tax_status' => 'taxable',
    '_stock_status' => 'instock',
    '_visibility' => 'visible',
    '_featured' => 'yes',
    '_product_attributes' => 
    array (
    ),
    '_downloadable' => 'no',
    '_virtual' => 'no',
    '_price' => '69',
    '_stock' => NULL,
    '_manage_stock' => 'no',
    '_backorders' => 'no',
    '_thumbnail_id' => '2835',
    'post_image' => 'https://themify.me/demo/themes/stack/files/2012/02/Bardenas.jpg',
    'total_sales' => '13',
    '_edit_lock' => '1503300903:172',
    '_wc_rating_count' => 
    array (
    ),
    '_wc_average_rating' => '0',
    '_wc_review_count' => '0',
    '_upsell_ids' => 
    array (
    ),
    '_crosssell_ids' => 
    array (
    ),
    '_default_attributes' => 
    array (
    ),
    '_download_limit' => '-1',
    '_download_expiry' => '-1',
    '_product_version' => '3.1.1',
    '_yoast_wpseo_content_score' => '30',
  ),
  'tax_input' => 
  array (
    'product_type' => 'simple',
    'product_cat' => 'shoes',
  ),
  'thumb' => 'https://themify.me/demo/themes/stack/files/2012/02/Bardenas.jpg',
);
themify_process_post_import( $post );


$post = array (
  'ID' => 80,
  'post_date' => '2012-02-24 22:18:10',
  'post_date_gmt' => '2012-02-24 22:18:10',
  'post_content' => 'Nullam dapibus semper risus eu accumsan. Nulla facilisis eros ac ligula sodales suscipit. Fusce pellentesque iaculis dignissim. Phasellus tristique neque vitae justo laoreet tempus.',
  'post_title' => 'Vansera',
  'post_excerpt' => '',
  'post_name' => 'vansera',
  'post_modified' => '2017-08-21 07:36:33',
  'post_modified_gmt' => '2017-08-21 07:36:33',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/shopdock/?post_type=product&#038;p=80',
  'menu_order' => 0,
  'post_type' => 'product',
  'meta_input' => 
  array (
    '_thumbnail_id' => '2848',
    'post_image' => 'https://themify.me/demo/themes/stack/files/2012/02/Vansera.jpg',
    '_edit_last' => '172',
    '_regular_price' => '79',
    '_tax_status' => 'taxable',
    '_stock_status' => 'instock',
    '_visibility' => 'visible',
    '_featured' => 'yes',
    '_product_attributes' => 
    array (
    ),
    '_downloadable' => 'no',
    '_virtual' => 'no',
    '_price' => '79',
    '_stock' => NULL,
    '_manage_stock' => 'no',
    '_backorders' => 'no',
    'total_sales' => '14',
    '_edit_lock' => '1503300933:172',
    '_wc_rating_count' => 
    array (
      5 => '1',
    ),
    '_wc_average_rating' => '5.00',
    '_wc_review_count' => '1',
    '_upsell_ids' => 
    array (
    ),
    '_crosssell_ids' => 
    array (
    ),
    '_default_attributes' => 
    array (
    ),
    '_download_limit' => '-1',
    '_download_expiry' => '-1',
    '_product_version' => '3.1.1',
    '_yoast_wpseo_content_score' => '30',
  ),
  'tax_input' => 
  array (
    'product_type' => 'simple',
    'product_cat' => 'shoes',
  ),
  'thumb' => 'https://themify.me/demo/themes/stack/files/2012/02/Vansera.jpg',
);
themify_process_post_import( $post );


$post = array (
  'ID' => 83,
  'post_date' => '2012-02-24 22:32:25',
  'post_date_gmt' => '2012-02-24 22:32:25',
  'post_content' => 'Proin non velit arcu, sit amet laoreet massa. Aliquam gravida eros sit amet leo scelerisque molestie. Morbi et cursus felis. Pellentesque at dui nunc. Integer euismod tincidunt nisl, in iaculis tellus feugiat sed.',
  'post_title' => 'Era',
  'post_excerpt' => '',
  'post_name' => 'era',
  'post_modified' => '2017-08-21 07:36:32',
  'post_modified_gmt' => '2017-08-21 07:36:32',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/shopdock/?post_type=product&#038;p=83',
  'menu_order' => 0,
  'post_type' => 'product',
  'meta_input' => 
  array (
    '_thumbnail_id' => '2840',
    'post_image' => 'https://themify.me/demo/themes/stack/files/2012/02/Era.jpg',
    '_edit_last' => '172',
    '_regular_price' => '69',
    '_tax_status' => 'taxable',
    '_stock_status' => 'instock',
    '_visibility' => 'visible',
    '_featured' => 'yes',
    '_product_attributes' => 
    array (
    ),
    '_downloadable' => 'no',
    '_virtual' => 'no',
    '_price' => '69',
    '_stock' => NULL,
    '_manage_stock' => 'no',
    '_backorders' => 'no',
    'total_sales' => '14',
    '_edit_lock' => '1503300887:172',
    '_wc_rating_count' => 
    array (
    ),
    '_wc_average_rating' => '0',
    '_wc_review_count' => '0',
    '_upsell_ids' => 
    array (
    ),
    '_crosssell_ids' => 
    array (
    ),
    '_default_attributes' => 
    array (
    ),
    '_download_limit' => '-1',
    '_download_expiry' => '-1',
    '_product_version' => '3.1.1',
    '_yoast_wpseo_content_score' => '30',
  ),
  'tax_input' => 
  array (
    'product_type' => 'simple',
    'product_cat' => 'shoes',
  ),
  'thumb' => 'https://themify.me/demo/themes/stack/files/2012/02/Era.jpg',
);
themify_process_post_import( $post );


$post = array (
  'ID' => 85,
  'post_date' => '2012-02-24 22:34:11',
  'post_date_gmt' => '2012-02-24 22:34:11',
  'post_content' => 'Aliquam gravida eros sit amet leo scelerisque molestie. Morbi et cursus felis. Pellentesque at dui nunc. Integer euismod tincidunt nisl, in iaculis tellus feugiat sed. Proin non velit arcu, sit amet laoreet massa.',
  'post_title' => 'SK8',
  'post_excerpt' => '',
  'post_name' => 'sk8',
  'post_modified' => '2017-08-21 07:36:26',
  'post_modified_gmt' => '2017-08-21 07:36:26',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/shopdock/?post_type=product&#038;p=85',
  'menu_order' => 0,
  'post_type' => 'product',
  'meta_input' => 
  array (
    '_thumbnail_id' => '2847',
    'post_image' => 'https://themify.me/demo/themes/stack/files/2012/02/SK8.jpg',
    '_edit_last' => '172',
    '_regular_price' => '79',
    '_sale_price' => '49',
    '_tax_status' => 'taxable',
    '_stock_status' => 'instock',
    '_visibility' => 'visible',
    '_featured' => 'yes',
    '_product_attributes' => 
    array (
    ),
    '_downloadable' => 'no',
    '_virtual' => 'no',
    '_price' => '49',
    '_stock' => NULL,
    '_manage_stock' => 'no',
    '_backorders' => 'no',
    'total_sales' => '21',
    '_edit_lock' => '1503301029:172',
    '_wc_rating_count' => 
    array (
      5 => '1',
    ),
    '_wc_average_rating' => '5.00',
    '_wc_review_count' => '1',
    '_upsell_ids' => 
    array (
    ),
    '_crosssell_ids' => 
    array (
    ),
    '_default_attributes' => 
    array (
    ),
    '_download_limit' => '-1',
    '_download_expiry' => '-1',
    '_product_version' => '3.1.1',
    '_yoast_wpseo_content_score' => '30',
  ),
  'tax_input' => 
  array (
    'product_type' => 'simple',
    'product_cat' => 'shoes',
  ),
  'thumb' => 'https://themify.me/demo/themes/stack/files/2012/02/SK8.jpg',
);
themify_process_post_import( $post );


$post = array (
  'ID' => 87,
  'post_date' => '2012-02-23 22:35:36',
  'post_date_gmt' => '2012-02-23 22:35:36',
  'post_content' => 'Proin non velit arcu, sit amet laoreet massa. Aliquam gravida eros sit amet leo scelerisque molestie. Morbi et cursus felis. Pellentesque at dui nunc. Integer euismod tincidunt nisl, in iaculis tellus feugiat sed.',
  'post_title' => 'Purple Sweater',
  'post_excerpt' => '',
  'post_name' => 'purple-sweater',
  'post_modified' => '2017-08-21 07:37:02',
  'post_modified_gmt' => '2017-08-21 07:37:02',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/shopdock/?post_type=product&#038;p=87',
  'menu_order' => 0,
  'post_type' => 'product',
  'meta_input' => 
  array (
    '_thumbnail_id' => '2836',
    'post_image' => 'https://themify.me/demo/themes/stack/files/2012/02/Black-Jacket.jpg',
    '_edit_last' => '172',
    '_regular_price' => '120',
    '_sale_price' => '80',
    '_tax_status' => 'taxable',
    '_stock_status' => 'instock',
    '_visibility' => 'visible',
    '_featured' => 'no',
    '_product_attributes' => 
    array (
      'size' => 
      array (
        'name' => 'Size',
        'value' => 'Large | Xlarge',
        'position' => 2,
        'is_visible' => 1,
        'is_variation' => 1,
        'is_taxonomy' => 0,
      ),
      'color' => 
      array (
        'name' => 'Color',
        'value' => 'Black | Gray | Green',
        'position' => 3,
        'is_visible' => 1,
        'is_variation' => 1,
        'is_taxonomy' => 0,
      ),
    ),
    '_downloadable' => 'no',
    '_virtual' => 'no',
    '_price' => '80',
    '_stock' => NULL,
    '_manage_stock' => 'no',
    '_backorders' => 'no',
    '_default_attributes' => 
    array (
    ),
    'total_sales' => '7',
    '_edit_lock' => '1503300912:172',
    '_wp_old_slug' => 'black-jacket',
    '_wc_rating_count' => 
    array (
    ),
    '_wc_average_rating' => '0',
    '_wc_review_count' => '0',
    '_upsell_ids' => 
    array (
    ),
    '_crosssell_ids' => 
    array (
    ),
    '_download_limit' => '-1',
    '_download_expiry' => '-1',
    '_product_version' => '3.1.1',
    '_yoast_wpseo_content_score' => '30',
  ),
  'tax_input' => 
  array (
    'product_type' => 'simple',
    'product_cat' => 'jacket',
  ),
  'thumb' => 'https://themify.me/demo/themes/stack/files/2012/02/Black-Jacket.jpg',
);
themify_process_post_import( $post );


$post = array (
  'ID' => 94,
  'post_date' => '2012-02-23 22:39:44',
  'post_date_gmt' => '2012-02-23 22:39:44',
  'post_content' => 'Ut eleifend rhoncus augue sit amet dignissim. In mattis lobortis imperdiet. Aliquam molestie nisi et purus mattis volutpat. Cras dignissim, arcu vel pretium interdum, turpis sapien rutrum felis, non condimentum nulla orci ornare tellus.',
  'post_title' => 'Green Rain Coat',
  'post_excerpt' => '',
  'post_name' => 'green-rain-coat',
  'post_modified' => '2017-08-21 07:36:58',
  'post_modified_gmt' => '2017-08-21 07:36:58',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/shopdock/?post_type=product&#038;p=94',
  'menu_order' => 0,
  'post_type' => 'product',
  'meta_input' => 
  array (
    '_thumbnail_id' => '2844',
    'post_image' => 'https://themify.me/demo/themes/stack/files/2012/02/Parka.jpg',
    '_edit_last' => '172',
    '_regular_price' => '169',
    '_tax_status' => 'taxable',
    '_stock_status' => 'instock',
    '_visibility' => 'visible',
    '_featured' => 'no',
    '_product_attributes' => 
    array (
    ),
    '_downloadable' => 'no',
    '_virtual' => 'no',
    '_price' => '169',
    '_stock' => NULL,
    '_manage_stock' => 'no',
    '_backorders' => 'no',
    'total_sales' => '1',
    '_edit_lock' => '1503300911:172',
    '_wp_old_slug' => 'parka',
    '_wc_rating_count' => 
    array (
    ),
    '_wc_average_rating' => '0',
    '_wc_review_count' => '0',
    '_upsell_ids' => 
    array (
    ),
    '_crosssell_ids' => 
    array (
    ),
    '_default_attributes' => 
    array (
    ),
    '_download_limit' => '-1',
    '_download_expiry' => '-1',
    '_product_version' => '3.1.1',
    '_yoast_wpseo_content_score' => '30',
  ),
  'tax_input' => 
  array (
    'product_type' => 'simple',
    'product_cat' => 'jacket',
  ),
  'thumb' => 'https://themify.me/demo/themes/stack/files/2012/02/Parka.jpg',
);
themify_process_post_import( $post );


$post = array (
  'ID' => 2874,
  'post_date' => '2015-01-05 02:07:50',
  'post_date_gmt' => '2015-01-05 02:07:50',
  'post_content' => 'Praesent eu ligula ut ligula tempus porttitor. In at sem ipsum, sed commodo felis. Nullam nec elit sapien. Donec at congue sapien. Mauris a diam nec felis auctor ultrices. Sed tempus mollis orci in viverra.',
  'post_title' => 'MIB Set',
  'post_excerpt' => '',
  'post_name' => 'mib-set',
  'post_modified' => '2017-08-21 07:36:25',
  'post_modified_gmt' => '2017-08-21 07:36:25',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/stack/?post_type=product&#038;p=2874',
  'menu_order' => 0,
  'post_type' => 'product',
  'meta_input' => 
  array (
    '_edit_last' => '172',
    '_regular_price' => '109',
    '_tax_status' => 'taxable',
    '_stock_status' => 'instock',
    '_visibility' => 'visible',
    '_featured' => 'no',
    '_product_attributes' => 
    array (
    ),
    '_downloadable' => 'no',
    '_virtual' => 'no',
    '_price' => '109',
    '_stock' => NULL,
    '_manage_stock' => 'no',
    '_backorders' => 'no',
    'total_sales' => '2',
    '_edit_lock' => '1503300886:172',
    '_wp_old_slug' => 'donkey-kong',
    '_dp_original' => '54',
    '_thumbnail_id' => '2875',
    'post_image' => 'https://themify.me/demo/themes/stack/files/2015/01/shutterstock_73533424.jpg',
    '_wc_rating_count' => 
    array (
    ),
    '_wc_average_rating' => '0',
    '_wc_review_count' => '0',
    '_upsell_ids' => 
    array (
    ),
    '_crosssell_ids' => 
    array (
    ),
    '_default_attributes' => 
    array (
    ),
    '_download_limit' => '-1',
    '_download_expiry' => '-1',
    '_product_version' => '3.1.1',
    '_yoast_wpseo_content_score' => '30',
  ),
  'tax_input' => 
  array (
    'product_type' => 'simple',
    'product_cat' => 'jacket, shoes, tshirts',
  ),
  'thumb' => 'https://themify.me/demo/themes/stack/files/2015/01/shutterstock_73533424.jpg',
);
themify_process_post_import( $post );


$post = array (
  'ID' => 2877,
  'post_date' => '2015-01-05 02:09:21',
  'post_date_gmt' => '2015-01-05 02:09:21',
  'post_content' => 'In at sem ipsum, sed commodo felis. Nullam nec elit sapien. Donec at congue sapien. Mauris a diam nec felis auctor ultrices. Sed tempus mollis orci in viverra. Vivamus libero eros, dictum id aliquam in, tristique id sapien.',
  'post_title' => 'Girl Dress',
  'post_excerpt' => '',
  'post_name' => 'girl-dress',
  'post_modified' => '2017-08-21 07:36:24',
  'post_modified_gmt' => '2017-08-21 07:36:24',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/stack/?post_type=product&#038;p=2877',
  'menu_order' => 0,
  'post_type' => 'product',
  'meta_input' => 
  array (
    '_edit_last' => '172',
    '_regular_price' => '39',
    '_tax_status' => 'taxable',
    '_stock_status' => 'instock',
    '_visibility' => 'visible',
    '_featured' => 'no',
    '_product_attributes' => 
    array (
    ),
    '_downloadable' => 'no',
    '_virtual' => 'no',
    '_price' => '39',
    '_stock' => NULL,
    '_manage_stock' => 'no',
    '_backorders' => 'no',
    'total_sales' => '2',
    '_edit_lock' => '1503300886:172',
    '_wp_old_slug' => 'elephant',
    '_dp_original' => '74',
    '_thumbnail_id' => '2878',
    'post_image' => 'https://themify.me/demo/themes/stack/files/2015/01/8897806.jpg',
    '_wc_rating_count' => 
    array (
    ),
    '_wc_average_rating' => '0',
    '_wc_review_count' => '0',
    '_upsell_ids' => 
    array (
    ),
    '_crosssell_ids' => 
    array (
    ),
    '_default_attributes' => 
    array (
    ),
    '_download_limit' => '-1',
    '_download_expiry' => '-1',
    '_product_version' => '3.1.1',
    '_yoast_wpseo_content_score' => '30',
  ),
  'tax_input' => 
  array (
    'product_type' => 'simple',
    'product_cat' => 'tshirts',
  ),
  'thumb' => 'https://themify.me/demo/themes/stack/files/2015/01/8897806.jpg',
);
themify_process_post_import( $post );


$post = array (
  'ID' => 2880,
  'post_date' => '2015-01-05 02:10:19',
  'post_date_gmt' => '2015-01-05 02:10:19',
  'post_content' => 'In at sem ipsum, sed commodo felis. Nullam nec elit sapien. Donec at congue sapien. Mauris a diam nec felis auctor ultrices. Sed tempus mollis orci in viverra. Vivamus libero eros, dictum id aliquam in, tristique id sapien.',
  'post_title' => 'Dress Pants',
  'post_excerpt' => '',
  'post_name' => 'dress-pants',
  'post_modified' => '2017-08-21 07:36:18',
  'post_modified_gmt' => '2017-08-21 07:36:18',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/stack/?post_type=product&#038;p=2880',
  'menu_order' => 0,
  'post_type' => 'product',
  'meta_input' => 
  array (
    '_edit_last' => '172',
    '_regular_price' => '49',
    '_tax_status' => 'taxable',
    '_stock_status' => 'instock',
    '_visibility' => 'visible',
    '_featured' => 'no',
    '_product_attributes' => 
    array (
    ),
    '_downloadable' => 'no',
    '_virtual' => 'no',
    '_price' => '49',
    '_stock' => NULL,
    '_manage_stock' => 'no',
    '_backorders' => 'no',
    'total_sales' => '1',
    '_edit_lock' => '1503300886:172',
    '_wp_old_slug' => 'elephant',
    '_dp_original' => '74',
    '_thumbnail_id' => '2881',
    'post_image' => 'https://themify.me/demo/themes/stack/files/2015/01/31570588.jpg',
    '_wc_rating_count' => 
    array (
    ),
    '_wc_average_rating' => '0',
    '_wc_review_count' => '0',
    '_upsell_ids' => 
    array (
    ),
    '_crosssell_ids' => 
    array (
    ),
    '_default_attributes' => 
    array (
    ),
    '_download_limit' => '-1',
    '_download_expiry' => '-1',
    '_product_version' => '3.1.1',
    '_yoast_wpseo_content_score' => '30',
  ),
  'tax_input' => 
  array (
    'product_type' => 'simple',
    'product_cat' => 'men',
  ),
  'thumb' => 'https://themify.me/demo/themes/stack/files/2015/01/31570588.jpg',
);
themify_process_post_import( $post );


$post = array (
  'ID' => 2882,
  'post_date' => '2015-01-05 02:11:00',
  'post_date_gmt' => '2015-01-05 02:11:00',
  'post_content' => 'In at sem ipsum, sed commodo felis. Nullam nec elit sapien. Donec at congue sapien. Mauris a diam nec felis auctor ultrices. Sed tempus mollis orci in viverra. Vivamus libero eros, dictum id aliquam in, tristique id sapien.',
  'post_title' => 'Leather Shoe',
  'post_excerpt' => '',
  'post_name' => 'leather-shoe',
  'post_modified' => '2017-08-21 07:36:17',
  'post_modified_gmt' => '2017-08-21 07:36:17',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/stack/?post_type=product&#038;p=2882',
  'menu_order' => 0,
  'post_type' => 'product',
  'meta_input' => 
  array (
    '_edit_last' => '172',
    '_regular_price' => '99',
    '_tax_status' => 'taxable',
    '_stock_status' => 'instock',
    '_visibility' => 'visible',
    '_featured' => 'no',
    '_product_attributes' => 
    array (
    ),
    '_downloadable' => 'no',
    '_virtual' => 'no',
    '_price' => '99',
    '_stock' => NULL,
    '_manage_stock' => 'no',
    '_backorders' => 'no',
    'total_sales' => '2',
    '_edit_lock' => '1503300886:172',
    '_wp_old_slug' => 'elephant',
    '_dp_original' => '74',
    '_thumbnail_id' => '2883',
    'post_image' => 'https://themify.me/demo/themes/stack/files/2015/01/19193362.jpg',
    '_wc_rating_count' => 
    array (
    ),
    '_wc_average_rating' => '0',
    '_wc_review_count' => '0',
    '_upsell_ids' => 
    array (
    ),
    '_crosssell_ids' => 
    array (
    ),
    '_default_attributes' => 
    array (
    ),
    '_download_limit' => '-1',
    '_download_expiry' => '-1',
    '_product_version' => '3.1.1',
    '_yoast_wpseo_content_score' => '30',
  ),
  'tax_input' => 
  array (
    'product_type' => 'simple',
    'product_cat' => 'men',
  ),
  'thumb' => 'https://themify.me/demo/themes/stack/files/2015/01/19193362.jpg',
);
themify_process_post_import( $post );


$post = array (
  'ID' => 2884,
  'post_date' => '2015-01-05 02:11:38',
  'post_date_gmt' => '2015-01-05 02:11:38',
  'post_content' => 'In at sem ipsum, sed commodo felis. Nullam nec elit sapien. Donec at congue sapien. Mauris a diam nec felis auctor ultrices. Sed tempus mollis orci in viverra. Vivamus libero eros, dictum id aliquam in, tristique id sapien.',
  'post_title' => 'Dress Hat',
  'post_excerpt' => '',
  'post_name' => 'dress-hat',
  'post_modified' => '2017-08-21 07:36:15',
  'post_modified_gmt' => '2017-08-21 07:36:15',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/stack/?post_type=product&#038;p=2884',
  'menu_order' => 0,
  'post_type' => 'product',
  'meta_input' => 
  array (
    '_edit_last' => '172',
    '_regular_price' => '19',
    '_sale_price' => '17',
    '_tax_status' => 'taxable',
    '_stock_status' => 'instock',
    '_visibility' => 'visible',
    '_featured' => 'no',
    '_product_attributes' => 
    array (
    ),
    '_downloadable' => 'no',
    '_virtual' => 'no',
    '_price' => '17',
    '_stock' => NULL,
    '_manage_stock' => 'no',
    '_backorders' => 'no',
    'total_sales' => '1',
    '_edit_lock' => '1503300886:172',
    '_wp_old_slug' => 'elephant',
    '_dp_original' => '74',
    '_thumbnail_id' => '2885',
    'post_image' => 'https://themify.me/demo/themes/stack/files/2015/01/61925014.jpg',
    '_wc_rating_count' => 
    array (
    ),
    '_wc_average_rating' => '0',
    '_wc_review_count' => '0',
    '_upsell_ids' => 
    array (
    ),
    '_crosssell_ids' => 
    array (
    ),
    '_default_attributes' => 
    array (
    ),
    '_download_limit' => '-1',
    '_download_expiry' => '-1',
    '_product_version' => '3.1.1',
    '_yoast_wpseo_content_score' => '30',
  ),
  'tax_input' => 
  array (
    'product_type' => 'simple',
    'product_cat' => 'men',
  ),
  'thumb' => 'https://themify.me/demo/themes/stack/files/2015/01/61925014.jpg',
);
themify_process_post_import( $post );


$post = array (
  'ID' => 2886,
  'post_date' => '2015-01-05 02:12:17',
  'post_date_gmt' => '2015-01-05 02:12:17',
  'post_content' => 'In at sem ipsum, sed commodo felis. Nullam nec elit sapien. Donec at congue sapien. Mauris a diam nec felis auctor ultrices. Sed tempus mollis orci in viverra. Vivamus libero eros, dictum id aliquam in, tristique id sapien.',
  'post_title' => 'Black Tie',
  'post_excerpt' => '',
  'post_name' => 'black-tie',
  'post_modified' => '2017-08-21 07:36:11',
  'post_modified_gmt' => '2017-08-21 07:36:11',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/stack/?post_type=product&#038;p=2886',
  'menu_order' => 0,
  'post_type' => 'product',
  'meta_input' => 
  array (
    '_edit_last' => '172',
    '_regular_price' => '25',
    '_tax_status' => 'taxable',
    '_stock_status' => 'instock',
    '_visibility' => 'visible',
    '_featured' => 'no',
    '_product_attributes' => 
    array (
    ),
    '_downloadable' => 'no',
    '_virtual' => 'no',
    '_price' => '25',
    '_stock' => NULL,
    '_manage_stock' => 'no',
    '_backorders' => 'no',
    'total_sales' => '1',
    '_edit_lock' => '1503300886:172',
    '_wp_old_slug' => 'elephant',
    '_dp_original' => '74',
    '_thumbnail_id' => '2887',
    'post_image' => 'https://themify.me/demo/themes/stack/files/2015/01/30958780.jpg',
    '_wc_rating_count' => 
    array (
    ),
    '_wc_average_rating' => '0',
    '_wc_review_count' => '0',
    '_upsell_ids' => 
    array (
    ),
    '_crosssell_ids' => 
    array (
    ),
    '_default_attributes' => 
    array (
    ),
    '_download_limit' => '-1',
    '_download_expiry' => '-1',
    '_product_version' => '3.1.1',
    '_yoast_wpseo_content_score' => '30',
  ),
  'tax_input' => 
  array (
    'product_type' => 'simple',
    'product_cat' => 'men',
  ),
  'thumb' => 'https://themify.me/demo/themes/stack/files/2015/01/30958780.jpg',
);
themify_process_post_import( $post );


$post = array (
  'ID' => 2888,
  'post_date' => '2015-01-05 02:13:36',
  'post_date_gmt' => '2015-01-05 02:13:36',
  'post_content' => 'Proin non velit arcu, sit amet laoreet massa. Aliquam gravida eros sit amet leo scelerisque molestie. Morbi et cursus felis. Pellentesque at dui nunc. Integer euismod tincidunt nisl, in iaculis tellus feugiat sed.',
  'post_title' => 'Woman Shoe',
  'post_excerpt' => '',
  'post_name' => 'woman-shoe',
  'post_modified' => '2017-08-21 07:36:08',
  'post_modified_gmt' => '2017-08-21 07:36:08',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/stack/?post_type=product&#038;p=2888',
  'menu_order' => 0,
  'post_type' => 'product',
  'meta_input' => 
  array (
    '_edit_last' => '172',
    '_regular_price' => '89',
    '_sale_price' => '80',
    '_tax_status' => 'taxable',
    '_stock_status' => 'instock',
    '_visibility' => 'visible',
    '_featured' => 'no',
    '_product_attributes' => 
    array (
      'size' => 
      array (
        'name' => 'Size',
        'value' => 'Large | Xlarge',
        'position' => 2,
        'is_visible' => 1,
        'is_variation' => 1,
        'is_taxonomy' => 0,
      ),
      'color' => 
      array (
        'name' => 'Color',
        'value' => 'Black | Gray | Green',
        'position' => 3,
        'is_visible' => 1,
        'is_variation' => 1,
        'is_taxonomy' => 0,
      ),
    ),
    '_downloadable' => 'no',
    '_virtual' => 'no',
    '_price' => '80',
    '_stock' => NULL,
    '_manage_stock' => 'no',
    '_backorders' => 'no',
    '_default_attributes' => 
    array (
    ),
    'total_sales' => '7',
    '_edit_lock' => '1503300886:172',
    '_wp_old_slug' => 'black-jacket',
    '_dp_original' => '87',
    '_thumbnail_id' => '2889',
    'post_image' => 'https://themify.me/demo/themes/stack/files/2015/01/46735969.jpg',
    '_wc_rating_count' => 
    array (
    ),
    '_wc_average_rating' => '0',
    '_wc_review_count' => '0',
    '_upsell_ids' => 
    array (
    ),
    '_crosssell_ids' => 
    array (
    ),
    '_download_limit' => '-1',
    '_download_expiry' => '-1',
    '_product_version' => '3.1.1',
    '_yoast_wpseo_content_score' => '30',
  ),
  'tax_input' => 
  array (
    'product_type' => 'simple',
    'product_cat' => 'women',
  ),
  'thumb' => 'https://themify.me/demo/themes/stack/files/2015/01/46735969.jpg',
);
themify_process_post_import( $post );


$post = array (
  'ID' => 2891,
  'post_date' => '2015-01-05 02:14:31',
  'post_date_gmt' => '2015-01-05 02:14:31',
  'post_content' => 'Proin non velit arcu, sit amet laoreet massa. Aliquam gravida eros sit amet leo scelerisque molestie. Morbi et cursus felis. Pellentesque at dui nunc. Integer euismod tincidunt nisl, in iaculis tellus feugiat sed.',
  'post_title' => 'Winter Boots',
  'post_excerpt' => '',
  'post_name' => 'winter-boots',
  'post_modified' => '2017-08-21 07:36:06',
  'post_modified_gmt' => '2017-08-21 07:36:06',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/stack/?post_type=product&#038;p=2891',
  'menu_order' => 0,
  'post_type' => 'product',
  'meta_input' => 
  array (
    '_edit_last' => '172',
    '_regular_price' => '120',
    '_sale_price' => '99',
    '_tax_status' => 'taxable',
    '_stock_status' => 'instock',
    '_visibility' => 'visible',
    '_featured' => 'no',
    '_product_attributes' => 
    array (
      'size' => 
      array (
        'name' => 'Size',
        'value' => 'Large | Xlarge',
        'position' => 2,
        'is_visible' => 1,
        'is_variation' => 1,
        'is_taxonomy' => 0,
      ),
      'color' => 
      array (
        'name' => 'Color',
        'value' => 'Black | Gray | Green',
        'position' => 3,
        'is_visible' => 1,
        'is_variation' => 1,
        'is_taxonomy' => 0,
      ),
    ),
    '_downloadable' => 'no',
    '_virtual' => 'no',
    '_price' => '99',
    '_stock' => NULL,
    '_manage_stock' => 'no',
    '_backorders' => 'no',
    '_default_attributes' => 
    array (
    ),
    'total_sales' => '7',
    '_edit_lock' => '1503300886:172',
    '_wp_old_slug' => 'black-jacket',
    '_dp_original' => '87',
    '_thumbnail_id' => '2892',
    'post_image' => 'https://themify.me/demo/themes/stack/files/2015/01/87173518.jpg',
    '_wc_rating_count' => 
    array (
    ),
    '_wc_average_rating' => '0',
    '_wc_review_count' => '0',
    '_upsell_ids' => 
    array (
    ),
    '_crosssell_ids' => 
    array (
    ),
    '_download_limit' => '-1',
    '_download_expiry' => '-1',
    '_product_version' => '3.1.1',
    '_yoast_wpseo_content_score' => '30',
  ),
  'tax_input' => 
  array (
    'product_type' => 'simple',
    'product_cat' => 'women',
  ),
  'thumb' => 'https://themify.me/demo/themes/stack/files/2015/01/87173518.jpg',
);
themify_process_post_import( $post );


$post = array (
  'ID' => 2893,
  'post_date' => '2015-01-05 02:15:26',
  'post_date_gmt' => '2015-01-05 02:15:26',
  'post_content' => 'Proin non velit arcu, sit amet laoreet massa. Aliquam gravida eros sit amet leo scelerisque molestie. Morbi et cursus felis. Pellentesque at dui nunc. Integer euismod tincidunt nisl, in iaculis tellus feugiat sed.',
  'post_title' => 'Red Heels',
  'post_excerpt' => '',
  'post_name' => 'red-heels',
  'post_modified' => '2017-08-21 07:36:03',
  'post_modified_gmt' => '2017-08-21 07:36:03',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/stack/?post_type=product&#038;p=2893',
  'menu_order' => 0,
  'post_type' => 'product',
  'meta_input' => 
  array (
    '_edit_last' => '172',
    '_regular_price' => '160',
    '_tax_status' => 'taxable',
    '_stock_status' => 'instock',
    '_visibility' => 'visible',
    '_featured' => 'no',
    '_product_attributes' => 
    array (
      'size' => 
      array (
        'name' => 'Size',
        'value' => 'Large | Xlarge',
        'position' => 2,
        'is_visible' => 1,
        'is_variation' => 1,
        'is_taxonomy' => 0,
      ),
      'color' => 
      array (
        'name' => 'Color',
        'value' => 'Black | Gray | Green',
        'position' => 3,
        'is_visible' => 1,
        'is_variation' => 1,
        'is_taxonomy' => 0,
      ),
    ),
    '_downloadable' => 'no',
    '_virtual' => 'no',
    '_price' => '160',
    '_stock' => NULL,
    '_manage_stock' => 'no',
    '_backorders' => 'no',
    '_default_attributes' => 
    array (
    ),
    'total_sales' => '7',
    '_edit_lock' => '1503300885:172',
    '_wp_old_slug' => 'black-jacket',
    '_dp_original' => '87',
    '_thumbnail_id' => '2895',
    'post_image' => 'https://themify.me/demo/themes/stack/files/2015/01/shutterstock_101154979.jpg',
    '_wc_rating_count' => 
    array (
    ),
    '_wc_average_rating' => '0',
    '_wc_review_count' => '0',
    '_upsell_ids' => 
    array (
    ),
    '_crosssell_ids' => 
    array (
    ),
    '_download_limit' => '-1',
    '_download_expiry' => '-1',
    '_product_version' => '3.1.1',
    '_yoast_wpseo_content_score' => '30',
  ),
  'tax_input' => 
  array (
    'product_type' => 'simple',
    'product_cat' => 'women',
  ),
  'thumb' => 'https://themify.me/demo/themes/stack/files/2015/01/shutterstock_101154979.jpg',
);
themify_process_post_import( $post );


$post = array (
  'ID' => 2896,
  'post_date' => '2015-01-05 02:17:23',
  'post_date_gmt' => '2015-01-05 02:17:23',
  'post_content' => 'Aliquam gravida eros sit amet leo scelerisque molestie. Morbi et cursus felis. Pellentesque at dui nunc. Integer euismod tincidunt nisl, in iaculis tellus feugiat sed. Proin non velit arcu, sit amet laoreet massa.',
  'post_title' => 'Beauty Products',
  'post_excerpt' => '',
  'post_name' => 'beauty-products',
  'post_modified' => '2017-08-21 07:36:01',
  'post_modified_gmt' => '2017-08-21 07:36:01',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/stack/?post_type=product&#038;p=2896',
  'menu_order' => 0,
  'post_type' => 'product',
  'meta_input' => 
  array (
    '_edit_last' => '172',
    '_regular_price' => '200',
    '_sale_price' => '120',
    '_tax_status' => 'taxable',
    '_stock_status' => 'instock',
    '_visibility' => 'visible',
    '_featured' => 'yes',
    '_product_attributes' => 
    array (
    ),
    '_downloadable' => 'no',
    '_virtual' => 'no',
    '_price' => '120',
    '_stock' => NULL,
    '_manage_stock' => 'no',
    '_backorders' => 'no',
    'total_sales' => '21',
    '_edit_lock' => '1503300885:172',
    '_dp_original' => '2869',
    '_thumbnail_id' => '2897',
    'post_image' => 'https://themify.me/demo/themes/stack/files/2015/01/100262221.jpg',
    '_wc_rating_count' => 
    array (
    ),
    '_wc_average_rating' => '0',
    '_wc_review_count' => '0',
    '_upsell_ids' => 
    array (
    ),
    '_crosssell_ids' => 
    array (
    ),
    '_default_attributes' => 
    array (
    ),
    '_download_limit' => '-1',
    '_download_expiry' => '-1',
    '_product_version' => '3.1.1',
    '_yoast_wpseo_content_score' => '30',
  ),
  'tax_input' => 
  array (
    'product_type' => 'simple',
    'product_cat' => 'women',
  ),
  'thumb' => 'https://themify.me/demo/themes/stack/files/2015/01/100262221.jpg',
);
themify_process_post_import( $post );


$post = array (
  'ID' => 2898,
  'post_date' => '2015-01-05 02:18:51',
  'post_date_gmt' => '2015-01-05 02:18:51',
  'post_content' => 'Aliquam gravida eros sit amet leo scelerisque molestie. Morbi et cursus felis. Pellentesque at dui nunc. Integer euismod tincidunt nisl, in iaculis tellus feugiat sed. Proin non velit arcu, sit amet laoreet massa.',
  'post_title' => 'Leather Purse',
  'post_excerpt' => '',
  'post_name' => 'leather-purse',
  'post_modified' => '2017-08-21 07:35:59',
  'post_modified_gmt' => '2017-08-21 07:35:59',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/stack/?post_type=product&#038;p=2898',
  'menu_order' => 0,
  'post_type' => 'product',
  'meta_input' => 
  array (
    '_edit_last' => '172',
    '_regular_price' => '80',
    '_tax_status' => 'taxable',
    '_stock_status' => 'instock',
    '_visibility' => 'visible',
    '_featured' => 'yes',
    '_product_attributes' => 
    array (
    ),
    '_downloadable' => 'no',
    '_virtual' => 'no',
    '_price' => '80',
    '_stock' => NULL,
    '_manage_stock' => 'no',
    '_backorders' => 'no',
    'total_sales' => '21',
    '_edit_lock' => '1503300885:172',
    '_dp_original' => '2896',
    '_thumbnail_id' => '2899',
    'post_image' => 'https://themify.me/demo/themes/stack/files/2015/01/144212706.jpg',
    '_wc_rating_count' => 
    array (
    ),
    '_wc_average_rating' => '0',
    '_wc_review_count' => '0',
    '_upsell_ids' => 
    array (
    ),
    '_crosssell_ids' => 
    array (
    ),
    '_default_attributes' => 
    array (
    ),
    '_download_limit' => '-1',
    '_download_expiry' => '-1',
    '_product_version' => '3.1.1',
    '_yoast_wpseo_content_score' => '30',
  ),
  'tax_input' => 
  array (
    'product_type' => 'simple',
    'product_cat' => 'women',
  ),
  'thumb' => 'https://themify.me/demo/themes/stack/files/2015/01/144212706.jpg',
);
themify_process_post_import( $post );


$post = array (
  'ID' => 2900,
  'post_date' => '2015-01-05 02:22:14',
  'post_date_gmt' => '2015-01-05 02:22:14',
  'post_content' => 'Aliquam gravida eros sit amet leo scelerisque molestie. Morbi et cursus felis. Pellentesque at dui nunc. Integer euismod tincidunt nisl, in iaculis tellus feugiat sed. Proin non velit arcu, sit amet laoreet massa.',
  'post_title' => 'Gravida',
  'post_excerpt' => '',
  'post_name' => 'gravida',
  'post_modified' => '2017-08-21 07:35:57',
  'post_modified_gmt' => '2017-08-21 07:35:57',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/stack/?post_type=product&#038;p=2900',
  'menu_order' => 0,
  'post_type' => 'product',
  'meta_input' => 
  array (
    '_edit_last' => '172',
    '_regular_price' => '600',
    '_tax_status' => 'taxable',
    '_stock_status' => 'instock',
    '_visibility' => 'visible',
    '_featured' => 'yes',
    '_product_attributes' => 
    array (
    ),
    '_downloadable' => 'no',
    '_virtual' => 'no',
    '_price' => '600',
    '_stock' => NULL,
    '_manage_stock' => 'no',
    '_backorders' => 'no',
    'total_sales' => '21',
    '_edit_lock' => '1503300885:172',
    '_dp_original' => '2898',
    '_thumbnail_id' => '2903',
    'post_image' => 'https://themify.me/demo/themes/stack/files/2015/01/96121718.jpg',
    '_wc_rating_count' => 
    array (
    ),
    '_wc_average_rating' => '0',
    '_wc_review_count' => '0',
    '_upsell_ids' => 
    array (
    ),
    '_crosssell_ids' => 
    array (
    ),
    '_default_attributes' => 
    array (
    ),
    '_download_limit' => '-1',
    '_download_expiry' => '-1',
    '_product_version' => '3.1.1',
    '_yoast_wpseo_content_score' => '30',
  ),
  'tax_input' => 
  array (
    'product_type' => 'simple',
    'product_cat' => 'men, shoes',
  ),
  'thumb' => 'https://themify.me/demo/themes/stack/files/2015/01/96121718.jpg',
);
themify_process_post_import( $post );


$post = array (
  'ID' => 2447,
  'post_date' => '2014-09-01 18:25:39',
  'post_date_gmt' => '2014-09-01 18:25:39',
  'post_content' => 'Maecenas faucibus, est sed pretium convallis, urna turpis malesuada leo, eu venenatis neque magna eget urna. Pellentesque habitant morbi tristique senectus et netus et malesuada fames ac turpis egestas. Aenean ornare euismod purus ac rhoncus. Phasellus malesuada consequat metus, a accumsan libero dapibus ut. Nunc venenatis ut libero vitae porta. Sed est turpis, pharetra nec lorem non, porttitor ullamcorper nisi.',
  'post_title' => 'Nature at a Glance',
  'post_excerpt' => 'Add any excerpt ',
  'post_name' => 'nature-glance',
  'post_modified' => '2017-08-21 07:32:53',
  'post_modified_gmt' => '2017-08-21 07:32:53',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/stack/?post_type=portfolio&#038;p=2447',
  'menu_order' => 0,
  'post_type' => 'portfolio',
  'meta_input' => 
  array (
    'content_width' => 'default_width',
    'layout' => 'sidebar-none',
    'tile_layout' => 'size-small image-right',
    'gallery_shortcode' => '[gallery size="large" ids="2448,2449,2450,2451,2452,2453,2454,2457,2458"]',
    'hide_post_title' => 'default',
    'unlink_post_title' => 'default',
    'hide_post_date' => 'default',
    'hide_post_meta' => 'default',
    'hide_post_image' => 'default',
    'unlink_post_image' => 'default',
    'project_date' => 'December 12, 2013',
    'project_client' => 'Photography Studios',
    'project_services' => 'Photo edits, still shots',
    'background_color' => '#2a86d1',
    'text_color' => '#ffffff',
    'link_color' => '#ffffff',
    'builder_switch_frontend' => '0',
  ),
  'tax_input' => 
  array (
    'portfolio-category' => 'photography',
  ),
  'thumb' => 'https://themify.me/demo/themes/stack/files/2014/02/180684791.jpg',
  'gallery_shortcode' => 
  array (
    'gallery_shortcode' => 
    array (
      0 => 'https://themify.me/demo/themes/stack/files/2014/12/135443573.jpg',
      1 => 'https://themify.me/demo/themes/stack/files/2014/12/139416557.jpg',
      2 => 'https://themify.me/demo/themes/stack/files/2014/12/144189244.jpg',
      3 => 'https://themify.me/demo/themes/stack/files/2014/12/151305473.jpg',
      4 => 'https://themify.me/demo/themes/stack/files/2014/12/153446054.jpg',
      5 => 'https://themify.me/demo/themes/stack/files/2014/12/159967142.jpg',
      6 => 'https://themify.me/demo/themes/stack/files/2014/12/162447488.jpg',
      7 => 'https://themify.me/demo/themes/stack/files/2014/01/175819034.jpg',
      8 => 'https://themify.me/demo/themes/stack/files/2014/01/183052871.jpg',
    ),
  ),
);
themify_process_post_import( $post );


$post = array (
  'ID' => 2459,
  'post_date' => '2014-11-05 18:31:14',
  'post_date_gmt' => '2014-11-05 18:31:14',
  'post_content' => 'Maecenas faucibus, est sed pretium convallis, urna turpis malesuada leo, eu venenatis neque magna eget urna. Pellentesque habitant morbi tristique senectus et netus et malesuada fames ac turpis egestas. Aenean ornare euismod purus ac rhoncus. Phasellus malesuada consequat metus, a accumsan libero dapibus ut. Nunc venenatis ut libero vitae porta. Sed est turpis, pharetra nec lorem non, porttitor ullamcorper nisi.',
  'post_title' => 'Image Design',
  'post_excerpt' => 'Small Tile To The Right',
  'post_name' => 'image-design',
  'post_modified' => '2017-08-21 07:33:28',
  'post_modified_gmt' => '2017-08-21 07:33:28',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/stack/?post_type=portfolio&#038;p=2459',
  'menu_order' => 0,
  'post_type' => 'portfolio',
  'meta_input' => 
  array (
    'content_width' => 'default_width',
    'layout' => 'sidebar-none',
    'tile_layout' => 'size-small image-right',
    'gallery_shortcode' => '[gallery columns="4" size="full" ids="2473,2474,2475,2476,2477,2478,2479,2480,2481,2482,2483,2484"]',
    'hide_post_title' => 'default',
    'unlink_post_title' => 'default',
    'hide_post_date' => 'default',
    'hide_post_meta' => 'default',
    'hide_post_image' => 'default',
    'unlink_post_image' => 'default',
    'project_date' => 'January 13, 2014',
    'project_client' => 'ABC Media',
    'project_services' => 'Creative Designs',
    'background_color' => '#fd67c0',
    'background_repeat' => 'fullcover',
    'text_color' => '#ffffff',
    'link_color' => '#ffffff',
    'builder_switch_frontend' => '0',
  ),
  'tax_input' => 
  array (
    'portfolio-category' => 'design',
  ),
  'thumb' => 'https://themify.me/demo/themes/stack/files/2014/02/86506050.jpg',
  'gallery_shortcode' => 
  array (
    'gallery_shortcode' => 
    array (
      0 => 'https://themify.me/demo/themes/stack/files/2014/02/163927736.jpg',
      1 => 'https://themify.me/demo/themes/stack/files/2014/02/165050489.jpg',
      2 => 'https://themify.me/demo/themes/stack/files/2014/02/166987241.jpg',
      3 => 'https://themify.me/demo/themes/stack/files/2014/02/170611466.jpg',
      4 => 'https://themify.me/demo/themes/stack/files/2014/02/179212070.jpg',
      5 => 'https://themify.me/demo/themes/stack/files/2014/02/180684791.jpg',
      6 => 'https://themify.me/demo/themes/stack/files/2014/02/187174172.jpg',
      7 => 'https://themify.me/demo/themes/stack/files/2014/02/192510125.jpg',
      8 => 'https://themify.me/demo/themes/stack/files/2014/02/193785158.jpg',
      9 => 'https://themify.me/demo/themes/stack/files/2014/02/196909301.jpg',
      10 => 'https://themify.me/demo/themes/stack/files/2014/02/201242249.jpg',
      11 => 'https://themify.me/demo/themes/stack/files/2014/02/202489726.jpg',
    ),
  ),
);
themify_process_post_import( $post );


$post = array (
  'ID' => 2550,
  'post_date' => '2014-11-01 20:11:23',
  'post_date_gmt' => '2014-11-01 20:11:23',
  'post_content' => 'Maecenas faucibus, est sed pretium convallis, urna turpis malesuada leo, eu venenatis neque magna eget urna. Pellentesque habitant morbi tristique senectus et netus et malesuada fames ac turpis egestas. Aenean ornare euismod purus ac rhoncus. Phasellus malesuada consequat metus, a accumsan libero dapibus ut. Nunc venenatis ut libero vitae porta. Sed est turpis, pharetra nec lorem non, porttitor ullamcorper nisi.',
  'post_title' => 'Wedding Photos',
  'post_excerpt' => 'Add any excerpt',
  'post_name' => 'wedding-photos',
  'post_modified' => '2017-08-21 07:32:38',
  'post_modified_gmt' => '2017-08-21 07:32:38',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/stack/?post_type=portfolio&#038;p=2550',
  'menu_order' => 0,
  'post_type' => 'portfolio',
  'meta_input' => 
  array (
    'content_width' => 'default_width',
    'layout' => 'sidebar-none',
    'tile_layout' => 'size-small image-right',
    'gallery_shortcode' => '[gallery columns="4" size="full" ids="2552,2553,2554,2555,2556,2557,2559,2560,2561,2562,2563,2564,2565,2566"]',
    'hide_post_title' => 'default',
    'unlink_post_title' => 'default',
    'hide_post_date' => 'default',
    'hide_post_meta' => 'default',
    'hide_post_image' => 'default',
    'unlink_post_image' => 'default',
    'project_date' => 'January 13, 2014',
    'project_client' => 'Various Weddings',
    'project_services' => 'Photography',
    'background_color' => '#09beef',
    'background_repeat' => 'fullcover',
    'text_color' => '#ffffff',
    'link_color' => '#ffffff',
    'builder_switch_frontend' => '0',
  ),
  'tax_input' => 
  array (
    'portfolio-category' => 'photography',
  ),
  'thumb' => 'https://themify.me/demo/themes/stack/files/2014/02/179212070.jpg',
  'gallery_shortcode' => 
  array (
    'gallery_shortcode' => 
    array (
      0 => 'https://themify.me/demo/themes/stack/files/2014/12/114041497.jpg',
      1 => 'https://themify.me/demo/themes/stack/files/2014/12/114785206.jpg',
      2 => 'https://themify.me/demo/themes/stack/files/2014/12/115990051.jpg',
      3 => 'https://themify.me/demo/themes/stack/files/2014/12/192147314.jpg',
      4 => 'https://themify.me/demo/themes/stack/files/2014/12/190754081.jpg',
      5 => 'https://themify.me/demo/themes/stack/files/2014/12/192449156.jpg',
      6 => 'https://themify.me/demo/themes/stack/files/2014/07/148404666.jpg',
      7 => 'https://themify.me/demo/themes/stack/files/2014/07/148328327.jpg',
      8 => 'https://themify.me/demo/themes/stack/files/2014/07/148245891.jpg',
      9 => 'https://themify.me/demo/themes/stack/files/2014/07/146901099.jpg',
      10 => 'https://themify.me/demo/themes/stack/files/2014/07/178514300.jpg',
      11 => 'https://themify.me/demo/themes/stack/files/2014/07/182685461.jpg',
      12 => 'https://themify.me/demo/themes/stack/files/2014/07/134996096.jpg',
      13 => 'https://themify.me/demo/themes/stack/files/2014/07/147796814.jpg',
    ),
  ),
);
themify_process_post_import( $post );


$post = array (
  'ID' => 2485,
  'post_date' => '2014-07-05 18:45:49',
  'post_date_gmt' => '2014-07-05 18:45:49',
  'post_content' => 'Maecenas faucibus, est sed pretium convallis, urna turpis malesuada leo, eu venenatis neque magna eget urna. Pellentesque habitant morbi tristique senectus et netus et malesuada fames ac turpis egestas. Aenean ornare euismod purus ac rhoncus. Phasellus malesuada consequat metus, a accumsan libero dapibus ut. Nunc venenatis ut libero vitae porta. Sed est turpis, pharetra nec lorem non, porttitor ullamcorper nisi.',
  'post_title' => 'Photo Art',
  'post_excerpt' => '  ',
  'post_name' => 'photo-art',
  'post_modified' => '2017-08-21 07:33:11',
  'post_modified_gmt' => '2017-08-21 07:33:11',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/stack/?post_type=portfolio&#038;p=2485',
  'menu_order' => 0,
  'post_type' => 'portfolio',
  'meta_input' => 
  array (
    'content_width' => 'default_width',
    'layout' => 'sidebar-none',
    'tile_layout' => 'size-small image-left',
    'gallery_shortcode' => '[gallery columns="4" size="large" ids="2486,2487,2488,2489,2490,2491,2492,2493,2494,2495,2496,2497"]',
    'hide_post_title' => 'default',
    'unlink_post_title' => 'default',
    'hide_post_date' => 'default',
    'hide_post_meta' => 'default',
    'hide_post_image' => 'default',
    'unlink_post_image' => 'default',
    'project_date' => 'January 13, 2014',
    'project_client' => 'ABC Media',
    'project_services' => 'Creative Designs',
    'background_color' => '#45bfa5',
    'background_repeat' => 'fullcover',
    'text_color' => '#000000',
    'link_color' => '#000000',
    'builder_switch_frontend' => '0',
  ),
  'tax_input' => 
  array (
    'portfolio-category' => 'photography',
  ),
  'thumb' => 'https://themify.me/demo/themes/stack/files/2014/12/136757601.jpg',
  'gallery_shortcode' => 
  array (
    'gallery_shortcode' => 
    array (
      0 => 'https://themify.me/demo/themes/stack/files/2014/12/122890795.jpg',
      1 => 'https://themify.me/demo/themes/stack/files/2014/12/126886069.jpg',
      2 => 'https://themify.me/demo/themes/stack/files/2014/12/136757601.jpg',
      3 => 'https://themify.me/demo/themes/stack/files/2014/12/141952035.jpg',
      4 => 'https://themify.me/demo/themes/stack/files/2014/12/147258761.jpg',
      5 => 'https://themify.me/demo/themes/stack/files/2014/12/147418065.jpg',
      6 => 'https://themify.me/demo/themes/stack/files/2014/12/147917882.jpg',
      7 => 'https://themify.me/demo/themes/stack/files/2014/12/151332473.jpg',
      8 => 'https://themify.me/demo/themes/stack/files/2014/12/153711719.jpg',
      9 => 'https://themify.me/demo/themes/stack/files/2014/12/154232705.jpg',
      10 => 'https://themify.me/demo/themes/stack/files/2014/12/154342192.jpg',
      11 => 'https://themify.me/demo/themes/stack/files/2014/12/154403378.jpg',
    ),
  ),
);
themify_process_post_import( $post );


$post = array (
  'ID' => 2528,
  'post_date' => '2014-12-24 19:53:31',
  'post_date_gmt' => '2014-12-24 19:53:31',
  'post_content' => '<!--themify_builder_static--><h1>Builder Project</h1><h3>Porfolio Page Completely Customized and Constructed Using the Builder</h3> 
 <h1 style="text-align: right;">01</h1><h4 style="text-align: right;">Background</h4> 
 <p>Nulla pellentesque lectus ac augue malesuada condimentum. Cras pellentesque risus a condimentum sodales. Quisque nunc ipsum, posuere sagittis ex mollis, ultricies lacinia tellus. Etiam dictum enim ac ipsum tristique dapibus. Aenean venenatis justo non enim scelerisque, sed pellentesque nisl facilisis. Quisque eget venenatis justo. In vestibulum orci maximus, feugiat arcu nec, volutpat dolor. Curabitur interdum convallis lectus at aliquam. Cras quis varius lorem. Nulla mattis maximus sapien aliquam eleifend.</p><p>[themify_button style="rect outline white" link="https://themify.me"]Launch Site[/themify_button]</p> 
 <h1 style="text-align: center;">02</h1><h4 style="text-align: center;">This is Where It All Begins</h4> 
 <p style="text-align: center;">Faelis facilisis non. Pellentesque eleifend luctus massa at vestibulum. Aliquam nisl odio, congue non sagittis a, viverra et sapien. Quisque ut magna facilisis, consequat mauris non, finibus felis. Aenean leo arcu, tincidunt at nisl tempus, aliquet tristique enim. Donec ullamcorper justo non turpis feugiat fringilla. Integer lacinia diam odio, non finibus lorem convallis sit amet. Proin vestibulum ultrices gravida.</p> 
 <ul data-id="slider-0-" data-visible="4" data-mob-visible="" data-scroll="1" data-auto-scroll="4" data-speed="1" data-wrap="yes" data-arrow="yes" data-pagination="yes" data-effect="continuously" data-height="variable" data-pause-on-hover="resume" > 
 <li> <img src="https://themify.me/demo/themes/elegant/files/2014/10/2024380661.jpg" width="400" height="400" alt="" /> </li> <li> <img src="https://themify.me/demo/themes/elegant/files/2014/10/1988883051.jpg" width="400" height="400" alt="" /> </li> <li> <img src="https://themify.me/demo/themes/elegant/files/2014/10/2002890712.jpg" width="400" height="400" alt="" /> </li> <li> <img src="https://themify.me/demo/themes/elegant/files/2014/10/195028886.jpg" width="400" height="400" alt="" /> </li> <li> <img src="https://themify.me/demo/themes/elegant/files/2014/10/194739149.jpg" width="400" height="400" alt="" /> </li> <li> <img src="https://themify.me/demo/themes/elegant/files/2014/10/180333233.jpg" width="400" height="400" alt="" /> </li> </ul> 
 <p style="text-align: center;">Faelis facilisis non. Pellentesque eleifend luctus massa at vestibulum. Aliquam nisl odio, congue non sagittis a, viverra et sapien. Quisque ut magna facilisis, consequat mauris non, finibus felis. Aenean leo arcu, tincidunt at nisl tempus, aliquet tristique enim. Donec ullamcorper justo non turpis feugiat fringilla. Integer lacinia diam odio, non finibus lorem convallis sit amet. Proin vestibulum ultrices gravida.</p> 
 <h4 style="text-align: center;">Moving forward...</h4> 
[gallery _orderbyfield="menu_order ID" _orderByField="menu_order ID" ids="3138,3089,3079,3072,3016,3019,2988,2943"]
 <h2>03 <em>Strategy</em></h2><p>Donec convallis luctus convallis. Proin gravida porttitor sem eget interdum. Donec fermentum orci nisi. Nunc id imperdiet metus. Nulla quis facilisis mauris, non consequat quam. Quisque ut dictum magna. Suspendisse aliquam at arcu sit amet hendrerit. Nam vel risus ut felis rutrum interdum. Nam sapien arcu, mattis eu diam eleifend, dictum tincidunt ante. Proin venenatis quis purus non tempor. Ut nibh nunc, mollis commodo pulvinar in, auctor sit amet orci. Suspendisse ligula metus, viverra ac rhoncus eu, consectetur quis odio.</p><p>Interdum et malesuada fames ac ante ipsum primis in faucibus. Aliquam eget placerat odio, vitae imperdiet urna. Mauris eu ligula eros. Curabitur semper non velit vitae consequat. Aliquam ut ipsum dui. Suspendisse scelerisque nulla non vehicula ullamcorper. Morbi cursus erat sed quam malesuada blandit.</p><p> </p> 
 <h4 style="text-align: center;">Finally...</h4> 
 <h1 style="text-align: center;"><em>Final</em></h1><p style="text-align: center;">[themify_button style="large rect outline white" link="https://themify.me/addons/counter"]Buy Counter Addon[/themify_button] </p><p style="text-align: center;">Show off your numbers in an elegant and unique way by purchasing our Counter Addon. Whether it\'s statistics about your company, followers, profit, or concerts performed the counting animation will make your numbers stand out. Check it below:</p> 
 
 Traffic Increase
 
 
 Followers
 
 
 Performances
 
 
 Bill Income<!--/themify_builder_static-->',
  'post_title' => 'Themify Builder Project',
  'post_excerpt' => 'Portfolio Post that\'s designed entirely using the Builder',
  'post_name' => 'themify-builder-project',
  'post_modified' => '2018-07-19 18:34:45',
  'post_modified_gmt' => '2018-07-19 18:34:45',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/stack/?post_type=portfolio&#038;p=2528',
  'menu_order' => 0,
  'post_type' => 'portfolio',
  'meta_input' => 
  array (
    'content_width' => 'full_width',
    'layout' => 'sidebar-none',
    'tile_layout' => 'size-large image-left',
    'gallery_shortcode' => '[gallery columns="4" size="full" ids="2537,2538,2539,2540,2541,2542,2543,2544,2545,2546,2547" orderby="rand"]',
    'hide_post_title' => 'yes',
    'unlink_post_title' => 'default',
    'hide_post_date' => 'yes',
    'hide_post_meta' => 'yes',
    'hide_post_image' => 'default',
    'unlink_post_image' => 'default',
    'background_color' => '#71318f',
    'text_color' => '#ffffff',
    'link_color' => '#ffffff',
    'builder_switch_frontend' => '0',
    '_themify_builder_settings_json' => '[{\\"row_order\\":\\"0\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h1>Builder Project<\\\\/h1><h3>Porfolio Page Completely Customized and Constructed Using the Builder<\\\\/h3>\\"}}]}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"padding_top\\":\\"7\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"2\\",\\"padding_bottom_unit\\":\\"%\\"}},{\\"row_order\\":\\"1\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col4-1\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h1 style=\\\\\\\\\\\\\\"text-align: right;\\\\\\\\\\\\\\">01<\\\\/h1><h4 style=\\\\\\\\\\\\\\"text-align: right;\\\\\\\\\\\\\\">Background<\\\\/h4>\\",\\"padding_right\\":\\"5\\",\\"padding_right_unit\\":\\"%\\"}}]},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col4-3\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<p>Nulla pellentesque lectus ac augue malesuada condimentum. Cras pellentesque risus a condimentum sodales. Quisque nunc ipsum, posuere sagittis ex mollis, ultricies lacinia tellus. Etiam dictum enim ac ipsum tristique dapibus. Aenean venenatis justo non enim scelerisque, sed pellentesque nisl facilisis. Quisque eget venenatis justo. In vestibulum orci maximus, feugiat arcu nec, volutpat dolor. Curabitur interdum convallis lectus at aliquam. Cras quis varius lorem. Nulla mattis maximus sapien aliquam eleifend.<\\\\/p><p>[themify_button style=\\\\\\\\\\\\\\"rect outline white\\\\\\\\\\\\\\" link=\\\\\\\\\\\\\\"https:\\\\/\\\\/themify.me\\\\\\\\\\\\\\"]Launch Site[\\\\/themify_button]<\\\\/p>\\"}}]}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"10\\",\\"padding_bottom_unit\\":\\"%\\"}},{\\"row_order\\":\\"2\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\"}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"background_image\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/elegant\\\\/files\\\\/2014\\\\/10\\\\/161176295.jpg\\",\\"background_repeat\\":\\"builder-parallax-scrolling\\",\\"padding_top\\":\\"20\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"20\\",\\"padding_bottom_unit\\":\\"%\\"}},{\\"row_order\\":\\"3\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h1 style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">02<\\\\/h1><h4 style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">This is Where It All Begins<\\\\/h4>\\"}}]}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"padding_top\\":\\"4\\",\\"padding_top_unit\\":\\"%\\"}},{\\"row_order\\":\\"4\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<p style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">Faelis facilisis non. Pellentesque eleifend luctus massa at vestibulum. Aliquam nisl odio, congue non sagittis a, viverra et sapien. Quisque ut magna facilisis, consequat mauris non, finibus felis. Aenean leo arcu, tincidunt at nisl tempus, aliquet tristique enim. Donec ullamcorper justo non turpis feugiat fringilla. Integer lacinia diam odio, non finibus lorem convallis sit amet. Proin vestibulum ultrices gravida.<\\\\/p>\\"}}]}]},{\\"row_order\\":\\"5\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"mod_name\\":\\"slider\\",\\"mod_settings\\":{\\"layout_display_slider\\":\\"image\\",\\"blog_category_slider\\":\\"|single\\",\\"slider_category_slider\\":\\"|single\\",\\"portfolio_category_slider\\":\\"|single\\",\\"testimonial_category_slider\\":\\"|single\\",\\"order_slider\\":\\"desc\\",\\"orderby_slider\\":\\"date\\",\\"display_slider\\":\\"content\\",\\"img_content_slider\\":[{\\"img_url_slider\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/elegant\\\\/files\\\\/2014\\\\/10\\\\/2024380661.jpg\\"},{\\"img_url_slider\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/elegant\\\\/files\\\\/2014\\\\/10\\\\/1988883051.jpg\\"},{\\"img_url_slider\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/elegant\\\\/files\\\\/2014\\\\/10\\\\/2002890712.jpg\\"},{\\"img_url_slider\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/elegant\\\\/files\\\\/2014\\\\/10\\\\/195028886.jpg\\"},{\\"img_url_slider\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/elegant\\\\/files\\\\/2014\\\\/10\\\\/194739149.jpg\\"},{\\"img_url_slider\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/elegant\\\\/files\\\\/2014\\\\/10\\\\/180333233.jpg\\"}],\\"layout_slider\\":\\"slider-default\\",\\"img_w_slider\\":\\"400\\",\\"img_h_slider\\":\\"400\\",\\"visible_opt_slider\\":\\"4\\",\\"auto_scroll_opt_slider\\":\\"4\\",\\"scroll_opt_slider\\":\\"1\\",\\"speed_opt_slider\\":\\"normal\\",\\"effect_slider\\":\\"continuously\\",\\"pause_on_hover_slider\\":\\"resume\\",\\"wrap_slider\\":\\"yes\\",\\"show_nav_slider\\":\\"yes\\",\\"show_arrow_slider\\":\\"yes\\",\\"left_margin_slider\\":\\"5\\",\\"right_margin_slider\\":\\"5\\"}},{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<p style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">Faelis facilisis non. Pellentesque eleifend luctus massa at vestibulum. Aliquam nisl odio, congue non sagittis a, viverra et sapien. Quisque ut magna facilisis, consequat mauris non, finibus felis. Aenean leo arcu, tincidunt at nisl tempus, aliquet tristique enim. Donec ullamcorper justo non turpis feugiat fringilla. Integer lacinia diam odio, non finibus lorem convallis sit amet. Proin vestibulum ultrices gravida.<\\\\/p>\\"}}]}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"padding_top\\":\\"3\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"8\\",\\"padding_bottom_unit\\":\\"%\\"}},{\\"row_order\\":\\"6\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h4 style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">Moving forward...<\\\\/h4>\\"}}]}],\\"styling\\":{\\"row_height\\":\\"fullheight\\",\\"background_type\\":\\"image\\",\\"background_image\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/elegant\\\\/files\\\\/2014\\\\/10\\\\/214781395.jpg\\",\\"background_repeat\\":\\"builder-parallax-scrolling\\",\\"background_color\\":\\"afcacc_1.00\\",\\"font_color\\":\\"ffffff_1.00\\",\\"padding_top_unit\\":\\"%\\",\\"margin_top_unit\\":\\"%\\",\\"margin_bottom_unit\\":\\"%\\"}},{\\"row_order\\":\\"7\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col3-1\\",\\"modules\\":[{\\"mod_name\\":\\"gallery\\",\\"mod_settings\\":{\\"layout_gallery\\":\\"showcase\\",\\"shortcode_gallery\\":\\"[gallery _orderbyfield=\\\\\\\\\\\\\\"menu_order ID\\\\\\\\\\\\\\" _orderByField=\\\\\\\\\\\\\\"menu_order ID\\\\\\\\\\\\\\" ids=\\\\\\\\\\\\\\"3138,3089,3079,3072,3016,3019,2988,2943\\\\\\\\\\\\\\"]\\",\\"thumb_w_gallery\\":\\"100\\",\\"thumb_h_gallery\\":\\"100\\",\\"padding_top\\":\\"5\\",\\"padding_top_unit\\":\\"%\\"}}],\\"grid_width\\":\\"23.8\\"},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col3-2\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h2>03 <em>Strategy<\\\\/em><\\\\/h2><p>Donec convallis luctus convallis. Proin gravida porttitor sem eget interdum. Donec fermentum orci nisi. Nunc id imperdiet metus. Nulla quis facilisis mauris, non consequat quam. Quisque ut dictum magna. Suspendisse aliquam at arcu sit amet hendrerit. Nam vel risus ut felis rutrum interdum. Nam sapien arcu, mattis eu diam eleifend, dictum tincidunt ante. Proin venenatis quis purus non tempor. Ut nibh nunc, mollis commodo pulvinar in, auctor sit amet orci. Suspendisse ligula metus, viverra ac rhoncus eu, consectetur quis odio.<\\\\/p><p>Interdum et malesuada fames ac ante ipsum primis in faucibus. Aliquam eget placerat odio, vitae imperdiet urna. Mauris eu ligula eros. Curabitur semper non velit vitae consequat. Aliquam ut ipsum dui. Suspendisse scelerisque nulla non vehicula ullamcorper. Morbi cursus erat sed quam malesuada blandit.<\\\\/p><p> <\\\\/p>\\"}}],\\"grid_width\\":\\"73\\"}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"padding_top\\":\\"8\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"8\\",\\"padding_bottom_unit\\":\\"%\\"}},{\\"row_order\\":\\"8\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h4 style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">Finally...<\\\\/h4>\\"}}]}],\\"styling\\":{\\"row_height\\":\\"fullheight\\",\\"background_type\\":\\"image\\",\\"background_image\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/elegant\\\\/files\\\\/2014\\\\/10\\\\/183068741.jpg\\",\\"background_repeat\\":\\"builder-parallax-scrolling\\",\\"background_color\\":\\"b8e0d2_1.00\\",\\"font_color\\":\\"ffffff_1.00\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom_unit\\":\\"%\\"}},{\\"row_order\\":\\"9\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h1 style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\"><em>Final<\\\\/em><\\\\/h1><p style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">[themify_button style=\\\\\\\\\\\\\\"large rect outline white\\\\\\\\\\\\\\" link=\\\\\\\\\\\\\\"https:\\\\/\\\\/themify.me\\\\/addons\\\\/counter\\\\\\\\\\\\\\"]Buy Counter Addon[\\\\/themify_button] <\\\\/p><p style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">Show off your numbers in an elegant and unique way by purchasing our Counter Addon. Whether it\\\\\\\\\\\'s statistics about your company, followers, profit, or concerts performed the counting animation will make your numbers stand out. Check it below:<\\\\/p>\\"}}]}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"padding_top\\":\\"8\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom_unit\\":\\"%\\"}},{\\"row_order\\":\\"10\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col4-1\\",\\"modules\\":[{\\"mod_name\\":\\"counter\\",\\"mod_settings\\":{\\"number_counter\\":\\"500%\\",\\"label_counter\\":\\"Traffic Increase\\",\\"size_counter\\":\\"large\\",\\"font_family\\":\\"Marvel\\",\\"font_size\\":\\"30\\"}}]},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col4-1\\",\\"modules\\":[{\\"mod_name\\":\\"counter\\",\\"mod_settings\\":{\\"number_counter\\":\\"60K\\",\\"label_counter\\":\\"Followers\\",\\"size_counter\\":\\"large\\",\\"font_family\\":\\"Ubuntu\\",\\"font_size\\":\\"30\\"}}]},{\\"column_order\\":\\"2\\",\\"grid_class\\":\\"col4-1\\",\\"modules\\":[{\\"mod_name\\":\\"counter\\",\\"mod_settings\\":{\\"number_counter\\":\\"37\\",\\"label_counter\\":\\"Performances\\",\\"size_counter\\":\\"large\\",\\"font_family\\":\\"Rationale\\",\\"font_size\\":\\"30\\"}}]},{\\"column_order\\":\\"3\\",\\"grid_class\\":\\"col4-1\\",\\"modules\\":[{\\"mod_name\\":\\"counter\\",\\"mod_settings\\":{\\"number_counter\\":\\"$4\\",\\"label_counter\\":\\"Bill Income\\",\\"size_counter\\":\\"large\\",\\"font_family\\":\\"Sniglet\\",\\"font_size\\":\\"30\\"}}]}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"background_slider_size\\":\\"large\\",\\"background_slider_mode\\":\\"fullcover\\",\\"background_repeat\\":\\"repeat\\",\\"background_attachment\\":\\"scroll\\",\\"background_position\\":\\"center-center\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"background_repeat_inner\\":\\"repeat\\",\\"background_attachment_inner\\":\\"scroll\\",\\"background_position_inner\\":\\"center-center\\",\\"checkbox_padding_inner_apply_all\\":\\"1\\",\\"checkbox_border_inner_apply_all\\":\\"1\\",\\"top-frame_type\\":\\"top-presets\\",\\"top-frame_width_unit\\":\\"%\\",\\"top-frame_height_unit\\":\\"%\\",\\"bottom-frame_type\\":\\"bottom-presets\\",\\"bottom-frame_width_unit\\":\\"%\\",\\"bottom-frame_height_unit\\":\\"%\\",\\"left-frame_type\\":\\"left-presets\\",\\"left-frame_width_unit\\":\\"%\\",\\"left-frame_height_unit\\":\\"%\\",\\"right-frame_type\\":\\"right-presets\\",\\"right-frame_width_unit\\":\\"%\\",\\"right-frame_height_unit\\":\\"%\\",\\"padding_top\\":\\"5\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"5\\",\\"padding_bottom_unit\\":\\"%\\",\\"checkbox_border_apply_all\\":\\"1\\"}},{\\"row_order\\":\\"11\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\"}]}]',
  ),
  'tax_input' => 
  array (
    'portfolio-category' => 'design',
  ),
  'thumb' => 'https://themify.me/demo/themes/stack/files/2014/12/94513792.jpg',
  'gallery_shortcode' => 
  array (
    'gallery_shortcode' => 
    array (
      0 => 'https://themify.me/demo/themes/stack/files/2014/12/90053719.jpg',
      1 => 'https://themify.me/demo/themes/stack/files/2014/12/93009460.jpg',
      2 => 'https://themify.me/demo/themes/stack/files/2014/12/94893043.jpg',
      3 => 'https://themify.me/demo/themes/stack/files/2014/12/94513792.jpg',
      4 => 'https://themify.me/demo/themes/stack/files/2014/12/93501982.jpg',
      5 => 'https://themify.me/demo/themes/stack/files/2014/12/90038560.jpg',
      6 => 'https://themify.me/demo/themes/stack/files/2014/12/92168305.jpg',
      7 => 'https://themify.me/demo/themes/stack/files/2014/12/92694433.jpg',
      8 => 'https://themify.me/demo/themes/stack/files/2014/12/93701056.jpg',
      9 => 'https://themify.me/demo/themes/stack/files/2014/12/90849914.jpg',
      10 => 'https://themify.me/demo/themes/stack/files/2014/12/89457784.jpg',
    ),
  ),
);
themify_process_post_import( $post );


$post = array (
  'ID' => 2529,
  'post_date' => '2014-11-24 19:57:58',
  'post_date_gmt' => '2014-11-24 19:57:58',
  'post_content' => 'Sed convallis risus massa, vel pellentesque mauris convallis a. Quisque libero tellus, ullamcorper in nunc id, pretium rutrum ex. Integer sollicitudin hendrerit accumsan. Pellentesque imperdiet purus varius nulla semper, at dapibus leo maximus. Sed consectetur lorem nunc, quis ultrices est dignissim eget. Duis dictum, urna vitae vehicula fringilla, leo leo ullamcorper nunc, eget fermentum libero augue sed dui. Nam pharetra eros dictum, bibendum libero eget, vehicula sem. Vivamus interdum, ex at fermentum varius, dolor nulla vulputate nisl, et hendrerit ipsum ex eu lacus. Nulla facilisi.',
  'post_title' => 'A Pop of Color',
  'post_excerpt' => 'Color popping images',
  'post_name' => 'site-interface',
  'post_modified' => '2017-08-21 07:32:34',
  'post_modified_gmt' => '2017-08-21 07:32:34',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/stack/?post_type=portfolio&#038;p=2529',
  'menu_order' => 0,
  'post_type' => 'portfolio',
  'meta_input' => 
  array (
    'content_width' => 'default_width',
    'layout' => 'sidebar-none',
    'tile_layout' => 'size-large image-right',
    'gallery_shortcode' => '[gallery size="full" ids="2482,2530,2532,2533,2534,2536,2481,2567,2568,2569,2570,2571,2572,2573,2574"]',
    'hide_post_title' => 'default',
    'unlink_post_title' => 'default',
    'hide_post_date' => 'default',
    'hide_post_meta' => 'default',
    'hide_post_image' => 'default',
    'unlink_post_image' => 'default',
    'project_date' => 'February 6, 2014',
    'project_client' => 'Virgin Mobile',
    'background_color' => '#e34236',
    'text_color' => '#ffffff',
    'link_color' => '#ffffff',
    'builder_switch_frontend' => '0',
  ),
  'tax_input' => 
  array (
    'portfolio-category' => 'fashion',
  ),
  'thumb' => 'https://themify.me/demo/themes/stack/files/2014/12/111233801.jpg',
  'gallery_shortcode' => 
  array (
    'gallery_shortcode' => 
    array (
      0 => 'https://themify.me/demo/themes/stack/files/2014/02/196909301.jpg',
      1 => 'https://themify.me/demo/themes/stack/files/2014/12/185751812.jpg',
      2 => 'https://themify.me/demo/themes/stack/files/2014/12/91078382.jpg',
      3 => 'https://themify.me/demo/themes/stack/files/2014/12/141272308.jpg',
      4 => 'https://themify.me/demo/themes/stack/files/2014/12/637381451.jpg',
      5 => 'https://themify.me/demo/themes/stack/files/2014/12/111233801.jpg',
      6 => 'https://themify.me/demo/themes/stack/files/2014/02/193785158.jpg',
      7 => 'https://themify.me/demo/themes/stack/files/2014/09/197247329.jpg',
      8 => 'https://themify.me/demo/themes/stack/files/2014/09/195584003.jpg',
      9 => 'https://themify.me/demo/themes/stack/files/2014/09/194510450.jpg',
      10 => 'https://themify.me/demo/themes/stack/files/2014/09/190029455.jpg',
      11 => 'https://themify.me/demo/themes/stack/files/2014/09/185809034.jpg',
      12 => 'https://themify.me/demo/themes/stack/files/2014/09/185056664.jpg',
      13 => 'https://themify.me/demo/themes/stack/files/2014/09/183178742.jpg',
      14 => 'https://themify.me/demo/themes/stack/files/2014/09/178954478.jpg',
    ),
  ),
);
themify_process_post_import( $post );


$post = array (
  'ID' => 2576,
  'post_date' => '2014-10-24 21:07:05',
  'post_date_gmt' => '2014-10-24 21:07:05',
  'post_content' => 'Maecenas faucibus, est sed pretium convallis, urna turpis malesuada leo, eu venenatis neque magna eget urna. Pellentesque habitant morbi tristique senectus et netus et malesuada fames ac turpis egestas. Aenean ornare euismod purus ac rhoncus. Phasellus malesuada consequat metus, a accumsan libero dapibus ut. Nunc venenatis ut libero vitae porta. Sed est turpis, pharetra nec lorem non, porttitor ullamcorper nisi.',
  'post_title' => 'Creative Images',
  'post_excerpt' => 'Large Tile to the Left',
  'post_name' => 'creative-images',
  'post_modified' => '2017-08-21 07:32:40',
  'post_modified_gmt' => '2017-08-21 07:32:40',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/stack/?post_type=portfolio&#038;p=2576',
  'menu_order' => 0,
  'post_type' => 'portfolio',
  'meta_input' => 
  array (
    'content_width' => 'default_width',
    'layout' => 'sidebar-none',
    'tile_layout' => 'size-large image-left',
    'gallery_shortcode' => '[gallery columns="4" size="large" ids="2579,2580,2581,2582,2583,2584,2585,2578"]',
    'hide_post_title' => 'default',
    'unlink_post_title' => 'default',
    'hide_post_date' => 'default',
    'hide_post_meta' => 'default',
    'hide_post_image' => 'default',
    'unlink_post_image' => 'default',
    'project_date' => 'March 14, 2014',
    'project_client' => 'Inspi.com.ink',
    'background_color' => '#000000',
    'background_repeat' => 'fullcover',
    'text_color' => '#ffffff',
    'link_color' => '#ffffff',
    'builder_switch_frontend' => '0',
  ),
  'tax_input' => 
  array (
    'portfolio-category' => 'design',
  ),
  'thumb' => 'https://themify.me/demo/themes/stack/files/2014/12/74685121.jpg',
  'gallery_shortcode' => 
  array (
    'gallery_shortcode' => 
    array (
      0 => 'https://themify.me/demo/themes/stack/files/2014/12/79073116.jpg',
      1 => 'https://themify.me/demo/themes/stack/files/2014/12/83454803.jpg',
      2 => 'https://themify.me/demo/themes/stack/files/2014/12/86531137.jpg',
      3 => 'https://themify.me/demo/themes/stack/files/2014/12/99387508.jpg',
      4 => 'https://themify.me/demo/themes/stack/files/2014/12/136295491.jpg',
      5 => 'https://themify.me/demo/themes/stack/files/2014/12/137155350.jpg',
      6 => 'https://themify.me/demo/themes/stack/files/2014/12/200471810-001.jpg',
      7 => 'https://themify.me/demo/themes/stack/files/2014/12/61277827.jpg',
    ),
  ),
);
themify_process_post_import( $post );


$post = array (
  'ID' => 2587,
  'post_date' => '2014-12-02 21:29:57',
  'post_date_gmt' => '2014-12-02 21:29:57',
  'post_content' => 'Maecenas faucibus, est sed pretium convallis, urna turpis malesuada leo, eu venenatis neque magna eget urna. Pellentesque habitant morbi tristique senectus et netus et malesuada fames ac turpis egestas. Aenean ornare euismod purus ac rhoncus. Phasellus malesuada consequat metus, a accumsan libero dapibus ut. Nunc venenatis ut libero vitae porta. Sed est turpis, pharetra nec lorem non, porttitor ullamcorper nisi.',
  'post_title' => 'Cool!',
  'post_excerpt' => 'Photography for Magazine',
  'post_name' => 'cool',
  'post_modified' => '2017-08-21 07:32:29',
  'post_modified_gmt' => '2017-08-21 07:32:29',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/stack/?post_type=portfolio&#038;p=2587',
  'menu_order' => 0,
  'post_type' => 'portfolio',
  'meta_input' => 
  array (
    'content_width' => 'default_width',
    'layout' => 'sidebar-none',
    'tile_layout' => 'size-small image-right',
    'hide_post_title' => 'default',
    'unlink_post_title' => 'default',
    'hide_post_date' => 'default',
    'hide_post_meta' => 'default',
    'hide_post_image' => 'default',
    'unlink_post_image' => 'default',
    'project_date' => 'Jan 2010',
    'project_client' => 'Magazine',
    'project_services' => 'Photo shooting, planning, and make-up',
    'project_launch' => 'https://themify.me',
    'background_color' => '#ffe51f',
    'text_color' => '#000000',
    'link_color' => '#000000',
    'builder_switch_frontend' => '0',
  ),
  'tax_input' => 
  array (
    'portfolio-category' => 'photography',
  ),
  'thumb' => 'https://themify.me/demo/themes/stack/files/2014/09/183178742.jpg',
);
themify_process_post_import( $post );


$post = array (
  'ID' => 2588,
  'post_date' => '2014-08-24 21:36:13',
  'post_date_gmt' => '2014-08-24 21:36:13',
  'post_content' => 'Maecenas faucibus, est sed pretium convallis, urna turpis malesuada leo, eu venenatis neque magna eget urna. Pellentesque habitant morbi tristique senectus et netus et malesuada fames ac turpis egestas. Aenean ornare euismod purus ac rhoncus. Phasellus malesuada consequat metus, a accumsan libero dapibus ut. Nunc venenatis ut libero vitae porta. Sed est turpis, pharetra nec lorem non, porttitor ullamcorper nisi.',
  'post_title' => 'Hello Orange',
  'post_excerpt' => 'Photography for Magazine',
  'post_name' => 'hello-orange',
  'post_modified' => '2017-08-21 07:32:54',
  'post_modified_gmt' => '2017-08-21 07:32:54',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/stack/?post_type=portfolio&#038;p=2588',
  'menu_order' => 0,
  'post_type' => 'portfolio',
  'meta_input' => 
  array (
    'content_width' => 'default_width',
    'layout' => 'sidebar-none',
    'tile_layout' => 'size-large image-right',
    'hide_post_title' => 'default',
    'unlink_post_title' => 'default',
    'hide_post_date' => 'default',
    'hide_post_meta' => 'default',
    'hide_post_image' => 'default',
    'unlink_post_image' => 'default',
    'project_date' => 'Feb 2011',
    'project_client' => 'Orange',
    'project_services' => 'Web design and branding',
    'project_launch' => 'https://themify.me',
    'background_color' => '#6f3cfa',
    'text_color' => '#ffffff',
    'link_color' => '#ffffff',
    'builder_switch_frontend' => '0',
  ),
  'tax_input' => 
  array (
    'portfolio-category' => 'design',
  ),
  'thumb' => 'https://themify.me/demo/themes/stack/files/2014/09/185809034.jpg',
);
themify_process_post_import( $post );


$post = array (
  'ID' => 2593,
  'post_date' => '2014-06-29 20:50:30',
  'post_date_gmt' => '2014-06-29 20:50:30',
  'post_content' => 'Pellentesque imperdiet purus varius nulla semper, at dapibus leo maximus. Sed consectetur lorem nunc, quis ultrices est dignissim eget. Duis dictum, urna vitae vehicula fringilla, leo leo ullamcorper nunc, eget fermentum libero augue sed dui. Nam pharetra eros dictum, bibendum libero eget, vehicula sem. Vivamus interdum, ex at fermentum varius, dolor nulla vulputate nisl, et hendrerit ipsum ex eu lacus. Nulla facilisi. Sed convallis risus massa, vel pellentesque mauris convallis a. Quisque libero tellus, ullamcorper in nunc id, pretium rutrum ex. Integer sollicitudin hendrerit accumsan.',
  'post_title' => 'A Splash of Fashion',
  'post_excerpt' => 'Model Fashion',
  'post_name' => 'splash-fashion',
  'post_modified' => '2017-08-21 07:33:16',
  'post_modified_gmt' => '2017-08-21 07:33:16',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/stack/?post_type=portfolio&#038;p=2593',
  'menu_order' => 0,
  'post_type' => 'portfolio',
  'meta_input' => 
  array (
    'content_width' => 'default_width',
    'layout' => 'sidebar-none',
    'tile_layout' => 'size-large image-right',
    'gallery_shortcode' => '[gallery columns="4" size="full" ids="2547,2496,2494,2537,2539,2545,2544,2489,2359,2538,2542"]',
    'hide_post_title' => 'default',
    'unlink_post_title' => 'default',
    'hide_post_date' => 'default',
    'hide_post_meta' => 'default',
    'hide_post_image' => 'default',
    'unlink_post_image' => 'default',
    'project_date' => 'November 2011',
    'project_client' => 'Splash Media',
    'project_services' => 'Model Casting, Photoshoot, Make-up artists',
    'background_color' => '#ab9344',
    'text_color' => '#ffffff',
    'link_color' => '#ffffff',
    'builder_switch_frontend' => '0',
  ),
  'tax_input' => 
  array (
    'portfolio-category' => 'fashion',
  ),
  'thumb' => 'https://themify.me/demo/themes/stack/files/2014/12/94893043.jpg',
  'gallery_shortcode' => 
  array (
    'gallery_shortcode' => 
    array (
      0 => 'https://themify.me/demo/themes/stack/files/2014/12/94893043.jpg',
      1 => 'https://themify.me/demo/themes/stack/files/2014/12/154342192.jpg',
      2 => 'https://themify.me/demo/themes/stack/files/2014/12/153711719.jpg',
      3 => 'https://themify.me/demo/themes/stack/files/2014/12/89457784.jpg',
      4 => 'https://themify.me/demo/themes/stack/files/2014/12/90053719.jpg',
      5 => 'https://themify.me/demo/themes/stack/files/2014/12/93701056.jpg',
      6 => 'https://themify.me/demo/themes/stack/files/2014/12/93501982.jpg',
      7 => 'https://themify.me/demo/themes/stack/files/2014/12/141952035.jpg',
      8 => 'https://themify.me/demo/themes/stack/files/2014/12/208621960.jpg',
      9 => 'https://themify.me/demo/themes/stack/files/2014/12/90038560.jpg',
      10 => 'https://themify.me/demo/themes/stack/files/2014/12/92694433.jpg',
    ),
  ),
);
themify_process_post_import( $post );


$post = array (
  'ID' => 2599,
  'post_date' => '2014-09-27 06:05:35',
  'post_date_gmt' => '2014-09-27 06:05:35',
  'post_content' => 'Maecenas faucibus, est sed pretium convallis, urna turpis malesuada leo, eu venenatis neque magna eget urna. Pellentesque habitant morbi tristique senectus et netus et malesuada fames ac turpis egestas. Aenean ornare euismod purus ac rhoncus. Phasellus malesuada consequat metus, a accumsan libero dapibus ut. Nunc venenatis ut libero vitae porta. Sed est turpis, pharetra nec lorem non, porttitor ullamcorper nisi.',
  'post_title' => 'Beauty In My Eyes',
  'post_excerpt' => 'Small Tile where images appear on the left',
  'post_name' => 'beauty-eyes',
  'post_modified' => '2017-08-21 07:32:46',
  'post_modified_gmt' => '2017-08-21 07:32:46',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/stack/?post_type=portfolio&#038;p=2599',
  'menu_order' => 0,
  'post_type' => 'portfolio',
  'meta_input' => 
  array (
    'content_width' => 'default_width',
    'layout' => 'sidebar-none',
    'tile_layout' => 'size-large image-left',
    'gallery_shortcode' => '[gallery columns="6" size="large" ids="2601,2602,2603,2604,2605,2606,2607,2608,2609,2610,2611,2612,2613,2614,2616,2600"]',
    'hide_post_title' => 'default',
    'unlink_post_title' => 'default',
    'hide_post_date' => 'default',
    'hide_post_meta' => 'default',
    'hide_post_image' => 'default',
    'unlink_post_image' => 'default',
    'project_date' => 'May 12, 2014',
    'project_client' => 'Beauty Scenic',
    'project_services' => 'Photo edits, still shots',
    'background_color' => '#3939b0',
    'text_color' => '#ffffff',
    'link_color' => '#ffffff',
    'builder_switch_frontend' => '0',
  ),
  'tax_input' => 
  array (
    'portfolio-category' => 'photography',
  ),
  'thumb' => 'https://themify.me/demo/themes/stack/files/2014/12/987611571.jpg',
  'gallery_shortcode' => 
  array (
    'gallery_shortcode' => 
    array (
      0 => 'https://themify.me/demo/themes/stack/files/2014/12/74242195.jpg',
      1 => 'https://themify.me/demo/themes/stack/files/2014/12/74316751.jpg',
      2 => 'https://themify.me/demo/themes/stack/files/2014/12/74420149.jpg',
      3 => 'https://themify.me/demo/themes/stack/files/2014/12/790731161.jpg',
      4 => 'https://themify.me/demo/themes/stack/files/2014/12/89127241.jpg',
      5 => 'https://themify.me/demo/themes/stack/files/2014/12/93280132.jpg',
      6 => 'https://themify.me/demo/themes/stack/files/2014/12/987611571.jpg',
      7 => 'https://themify.me/demo/themes/stack/files/2014/12/99811742.jpg',
      8 => 'https://themify.me/demo/themes/stack/files/2014/12/101397043.jpg',
      9 => 'https://themify.me/demo/themes/stack/files/2014/12/103279379.jpg',
      10 => 'https://themify.me/demo/themes/stack/files/2014/12/110481773.jpg',
      11 => 'https://themify.me/demo/themes/stack/files/2014/12/1140414971.jpg',
      12 => 'https://themify.me/demo/themes/stack/files/2014/12/120947872.jpg',
      13 => 'https://themify.me/demo/themes/stack/files/2014/12/1282562901.jpg',
      14 => 'https://themify.me/demo/themes/stack/files/2014/12/189340448.jpg',
      15 => 'https://themify.me/demo/themes/stack/files/2014/12/54153043.jpg',
    ),
  ),
);
themify_process_post_import( $post );


$post = array (
  'ID' => 2617,
  'post_date' => '2014-10-05 06:14:53',
  'post_date_gmt' => '2014-10-05 06:14:53',
  'post_content' => 'Sed est turpis, pharetra nec lorem non, porttitor ullamcorper nisi. Maecenas faucibus, est sed pretium convallis, urna turpis malesuada leo, eu venenatis neque magna eget urna. Pellentesque habitant morbi tristique senectus et netus et malesuada fames ac turpis egestas. Aenean ornare euismod purus.',
  'post_title' => 'Daily Fashion Wear',
  'post_excerpt' => 'Daily Glowing Attire',
  'post_name' => 'daily-fashion-wear',
  'post_modified' => '2017-08-21 07:32:44',
  'post_modified_gmt' => '2017-08-21 07:32:44',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/stack/?post_type=portfolio&#038;p=2617',
  'menu_order' => 0,
  'post_type' => 'portfolio',
  'meta_input' => 
  array (
    'content_width' => 'default_width',
    'layout' => 'sidebar-none',
    'tile_layout' => 'size-small image-left',
    'gallery_shortcode' => '[gallery columns="4" size="full" ids="2618,2619,2620,2621,2622,2623,2624,2625,2626,2627,2628,2629,2630"]',
    'hide_post_title' => 'default',
    'unlink_post_title' => 'default',
    'hide_post_date' => 'default',
    'hide_post_meta' => 'default',
    'hide_post_image' => 'default',
    'unlink_post_image' => 'default',
    'project_date' => 'June 30, 2014',
    'project_client' => 'Outwear & Co.',
    'project_services' => 'Outwear street shots',
    'background_color' => '#f0b513',
    'text_color' => '#ffffff',
    'link_color' => '#ffffff',
    'builder_switch_frontend' => '0',
  ),
  'tax_input' => 
  array (
    'portfolio-category' => 'fashion',
  ),
  'thumb' => 'https://themify.me/demo/themes/stack/files/2014/12/2086219601.jpg',
  'gallery_shortcode' => 
  array (
    'gallery_shortcode' => 
    array (
      0 => 'https://themify.me/demo/themes/stack/files/2014/12/118537408.jpg',
      1 => 'https://themify.me/demo/themes/stack/files/2014/12/120140851.jpg',
      2 => 'https://themify.me/demo/themes/stack/files/2014/12/129225449.jpg',
      3 => 'https://themify.me/demo/themes/stack/files/2014/12/131900372.jpg',
      4 => 'https://themify.me/demo/themes/stack/files/2014/12/136803617.jpg',
      5 => 'https://themify.me/demo/themes/stack/files/2014/12/159833045.jpg',
      6 => 'https://themify.me/demo/themes/stack/files/2014/12/164236085.jpg',
      7 => 'https://themify.me/demo/themes/stack/files/2014/12/182474618.jpg',
      8 => 'https://themify.me/demo/themes/stack/files/2014/12/185198609.jpg',
      9 => 'https://themify.me/demo/themes/stack/files/2014/12/192995783.jpg',
      10 => 'https://themify.me/demo/themes/stack/files/2014/12/199308632.jpg',
      11 => 'https://themify.me/demo/themes/stack/files/2014/12/2086219601.jpg',
      12 => 'https://themify.me/demo/themes/stack/files/2014/12/211462315.jpg',
    ),
  ),
);
themify_process_post_import( $post );


$post = array (
  'ID' => 2631,
  'post_date' => '2014-09-05 06:23:23',
  'post_date_gmt' => '2014-09-05 06:23:23',
  'post_content' => 'Aenean ornare euismod purus.Sed est turpis, pharetra nec lorem non, porttitor ullamcorper nisi.Pellentesque habitant morbi tristique senectus et netus et malesuada fames ac turpis egestas. Maecenas faucibus, est sed pretium convallis, urna turpis malesuada leo, eu venenatis neque magna eget urna. Pellentesque habitant morbi tristique senectus et netus et malesuada fames ac turpis egestas.',
  'post_title' => 'Inspirations',
  'post_excerpt' => 'Images for Creative Inspirations',
  'post_name' => 'inspirations',
  'post_modified' => '2017-08-21 07:32:52',
  'post_modified_gmt' => '2017-08-21 07:32:52',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/stack/?post_type=portfolio&#038;p=2631',
  'menu_order' => 0,
  'post_type' => 'portfolio',
  'meta_input' => 
  array (
    'content_width' => 'default_width',
    'layout' => 'sidebar-none',
    'tile_layout' => 'size-small image-right',
    'gallery_shortcode' => '[gallery columns="4" size="large" ids="2632,2633,2634,2635,2636,2637,2638,2639,2640,2641,2642,2643"]',
    'hide_post_title' => 'default',
    'unlink_post_title' => 'default',
    'hide_post_date' => 'default',
    'hide_post_meta' => 'default',
    'hide_post_image' => 'default',
    'unlink_post_image' => 'default',
    'project_date' => 'November 18, 2013',
    'project_client' => 'Media Group Agency',
    'project_services' => 'Daily Inspirations',
    'background_color' => '#ababab',
    'text_color' => '#000000',
    'link_color' => '#000000',
    'builder_switch_frontend' => '0',
  ),
  'tax_input' => 
  array (
    'portfolio-category' => 'design',
  ),
  'thumb' => 'https://themify.me/demo/themes/stack/files/2014/12/168015233.jpg',
  'gallery_shortcode' => 
  array (
    'gallery_shortcode' => 
    array (
      0 => 'https://themify.me/demo/themes/stack/files/2014/12/151934489.jpg',
      1 => 'https://themify.me/demo/themes/stack/files/2014/12/154160375.jpg',
      2 => 'https://themify.me/demo/themes/stack/files/2014/12/156294731.jpg',
      3 => 'https://themify.me/demo/themes/stack/files/2014/12/164990474.jpg',
      4 => 'https://themify.me/demo/themes/stack/files/2014/12/165819980.jpg',
      5 => 'https://themify.me/demo/themes/stack/files/2014/12/168015233.jpg',
      6 => 'https://themify.me/demo/themes/stack/files/2014/12/172002317.jpg',
      7 => 'https://themify.me/demo/themes/stack/files/2014/12/174280970.jpg',
      8 => 'https://themify.me/demo/themes/stack/files/2014/12/178349915.jpg',
      9 => 'https://themify.me/demo/themes/stack/files/2014/12/183592982.jpg',
      10 => 'https://themify.me/demo/themes/stack/files/2014/12/192302303.jpg',
      11 => 'https://themify.me/demo/themes/stack/files/2014/12/194761766.jpg',
    ),
  ),
);
themify_process_post_import( $post );


$post = array (
  'ID' => 2675,
  'post_date' => '2014-10-01 19:52:04',
  'post_date_gmt' => '2014-10-01 19:52:04',
  'post_content' => 'Nunc venenatis ut libero vitae porta. Sed est turpis, pharetra nec lorem non, porttitor ullamcorper nisi. Pellentesque habitant morbi tristique senectus et netus et malesuada fames ac turpis egestas. Aenean ornare euismod purus ac rhoncus. Phasellus malesuada consequat metus, a accumsan libero dapibus ut.',
  'post_title' => 'Living Art',
  'post_excerpt' => 'Small Tile where images appear on the left',
  'post_name' => 'living-art',
  'post_modified' => '2017-08-21 07:32:45',
  'post_modified_gmt' => '2017-08-21 07:32:45',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/stack/?post_type=portfolio&#038;p=2675',
  'menu_order' => 0,
  'post_type' => 'portfolio',
  'meta_input' => 
  array (
    'content_width' => 'default_width',
    'layout' => 'sidebar-none',
    'tile_layout' => 'size-small image-right',
    'gallery_shortcode' => '[gallery columns="5" size="large" ids="2692,2693,2694,2695,2696,2697,2698,2700,2701,2702,2703,2704,2705,2706,2707"]',
    'hide_post_title' => 'default',
    'unlink_post_title' => 'default',
    'hide_post_date' => 'default',
    'hide_post_meta' => 'default',
    'hide_post_image' => 'default',
    'unlink_post_image' => 'default',
    'project_date' => 'October 26, 2014',
    'project_client' => 'Desgin Inc. ',
    'project_services' => 'Photo edits, still shots, editing',
    'background_color' => '#383838',
    'text_color' => '#ffffff',
    'link_color' => '#ffffff',
    'builder_switch_frontend' => '0',
  ),
  'tax_input' => 
  array (
    'portfolio-category' => 'design',
  ),
  'thumb' => 'https://themify.me/demo/themes/stack/files/2014/05/96437909.jpg',
  'gallery_shortcode' => 
  array (
    'gallery_shortcode' => 
    array (
      0 => 'https://themify.me/demo/themes/stack/files/2014/05/78516814.jpg',
      1 => 'https://themify.me/demo/themes/stack/files/2014/05/92168350.jpg',
      2 => 'https://themify.me/demo/themes/stack/files/2014/05/93009460.jpg',
      3 => 'https://themify.me/demo/themes/stack/files/2014/05/95135980.jpg',
      4 => 'https://themify.me/demo/themes/stack/files/2014/05/95259592.jpg',
      5 => 'https://themify.me/demo/themes/stack/files/2014/05/96437909.jpg',
      6 => 'https://themify.me/demo/themes/stack/files/2014/05/98211974.jpg',
      7 => 'https://themify.me/demo/themes/stack/files/2014/05/120337861.jpg',
      8 => 'https://themify.me/demo/themes/stack/files/2014/05/123982801.jpg',
      9 => 'https://themify.me/demo/themes/stack/files/2014/05/134119568.jpg',
      10 => 'https://themify.me/demo/themes/stack/files/2014/05/147318717.jpg',
      11 => 'https://themify.me/demo/themes/stack/files/2014/05/147954449.jpg',
      12 => 'https://themify.me/demo/themes/stack/files/2014/05/156781577.jpg',
      13 => 'https://themify.me/demo/themes/stack/files/2014/05/163983824.jpg',
      14 => 'https://themify.me/demo/themes/stack/files/2014/05/172632767.jpg',
    ),
  ),
);
themify_process_post_import( $post );


$post = array (
  'ID' => 2710,
  'post_date' => '2014-08-05 20:18:20',
  'post_date_gmt' => '2014-08-05 20:18:20',
  'post_content' => 'Maecenas faucibus, est sed pretium convallis, urna turpis malesuada leo, eu venenatis neque magna eget urna.Nunc venenatis ut libero vitae porta. Sed est turpis, pharetra nec lorem non, porttitor ullamcorper nisi. Pellentesque habitant morbi tristique senectus et netus et malesuada fames ac turpis egestas. Aenean ornare euismod purus ac rhoncus. Phasellus malesuada consequat metus, a accumsan libero dapibus ut.',
  'post_title' => 'People Landscape',
  'post_excerpt' => 'Landscape Portfolio',
  'post_name' => 'people-landscape',
  'post_modified' => '2017-08-21 07:33:06',
  'post_modified_gmt' => '2017-08-21 07:33:06',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/stack/?post_type=portfolio&#038;p=2710',
  'menu_order' => 0,
  'post_type' => 'portfolio',
  'meta_input' => 
  array (
    'content_width' => 'default_width',
    'layout' => 'sidebar-none',
    'tile_layout' => 'size-small image-right',
    'gallery_shortcode' => '[gallery columns="4" size="full" ids="2722,2711,2712,2713,2714,2716,2717,2718,2720,2719,2721,2715"]',
    'hide_post_title' => 'default',
    'unlink_post_title' => 'default',
    'hide_post_date' => 'default',
    'hide_post_meta' => 'default',
    'hide_post_image' => 'default',
    'unlink_post_image' => 'default',
    'project_date' => 'April 23, 2013',
    'project_client' => 'Geography and Co. ',
    'project_services' => 'Lanscape Shots',
    'project_launch' => 'https://themify.me',
    'background_color' => '#1fd2ff',
    'text_color' => '#000000',
    'link_color' => '#000000',
    'builder_switch_frontend' => '0',
  ),
  'tax_input' => 
  array (
    'portfolio-category' => 'photography',
  ),
  'thumb' => 'https://themify.me/demo/themes/stack/files/2014/12/198880088.jpg',
  'gallery_shortcode' => 
  array (
    'gallery_shortcode' => 
    array (
      0 => 'https://themify.me/demo/themes/stack/files/2014/12/198880088.jpg',
      1 => 'https://themify.me/demo/themes/stack/files/2014/12/73170592.jpg',
      2 => 'https://themify.me/demo/themes/stack/files/2014/12/90343744.jpg',
      3 => 'https://themify.me/demo/themes/stack/files/2014/12/95408806.jpg',
      4 => 'https://themify.me/demo/themes/stack/files/2014/12/109177334.jpg',
      5 => 'https://themify.me/demo/themes/stack/files/2014/12/116947477.jpg',
      6 => 'https://themify.me/demo/themes/stack/files/2014/12/131869148.jpg',
      7 => 'https://themify.me/demo/themes/stack/files/2014/12/144290307.jpg',
      8 => 'https://themify.me/demo/themes/stack/files/2014/12/192230474.jpg',
      9 => 'https://themify.me/demo/themes/stack/files/2014/12/161216648.jpg',
      10 => 'https://themify.me/demo/themes/stack/files/2014/12/193609070.jpg',
      11 => 'https://themify.me/demo/themes/stack/files/2014/12/116403520.jpg',
    ),
  ),
);
themify_process_post_import( $post );


$post = array (
  'ID' => 2723,
  'post_date' => '2014-08-01 20:25:13',
  'post_date_gmt' => '2014-08-01 20:25:13',
  'post_content' => 'Pellentesque habitant morbi tristique senectus et netus et malesuada fames ac turpis egestas. Aenean ornare euismod purus ac rhoncus. Phasellus malesuada consequat metus, a accumsan libero dapibus ut. Nunc Maecenas faucibus, est sed pretium convallis, urna turpis malesuada leo, eu venenatis neque magna eget urna. Pellentesque habitant morbi tristique senectus et netus et malesuada fames ac turpis egestas. Aenean ornare euismod purus ac rhoncus. Phasellus malesuada consequat metus, a accumsan libero dapibus ut. Nunc venenatis ut libero vitae porta. Sed est turpis, pharetra nec lorem non, porttitor ullamcorper nisi. Est sed pretium convallis, urna turpis malesuada leo, eu venenatis neque magna eget urna. Pellentesque habitant morbi tristique senectus et netus et malesuada fames ac turpis egestas.',
  'post_title' => 'Popping Fashion',
  'post_excerpt' => 'Amazing eye-catching images',
  'post_name' => 'popping-fashion',
  'post_modified' => '2017-08-21 07:33:08',
  'post_modified_gmt' => '2017-08-21 07:33:08',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/stack/?post_type=portfolio&#038;p=2723',
  'menu_order' => 0,
  'post_type' => 'portfolio',
  'meta_input' => 
  array (
    'content_width' => 'default_width',
    'layout' => 'sidebar-none',
    'tile_layout' => 'size-small image-left',
    'gallery_shortcode' => '[gallery columns="5" size="medium" ids="2724,2725,2726,2727,2728,2729,2730,2732,2733,2734,2735,2737,2738"]',
    'hide_post_title' => 'default',
    'unlink_post_title' => 'default',
    'hide_post_date' => 'default',
    'hide_post_meta' => 'default',
    'hide_post_image' => 'default',
    'unlink_post_image' => 'default',
    'project_date' => 'June 2011',
    'project_client' => 'Pop Magazine',
    'project_services' => 'Photo shooting, styling, photoshop',
    'project_launch' => 'https://themify.me',
    'background_color' => '#ff3d0d',
    'text_color' => '#ffffff',
    'link_color' => '#ffffff',
    'builder_switch_frontend' => '0',
  ),
  'tax_input' => 
  array (
    'portfolio-category' => 'fashion',
  ),
  'thumb' => 'https://themify.me/demo/themes/stack/files/2014/12/117155164.jpg',
  'gallery_shortcode' => 
  array (
    'gallery_shortcode' => 
    array (
      0 => 'https://themify.me/demo/themes/stack/files/2014/12/110690840.jpg',
      1 => 'https://themify.me/demo/themes/stack/files/2014/12/116242903.jpg',
      2 => 'https://themify.me/demo/themes/stack/files/2014/12/117155164.jpg',
      3 => 'https://themify.me/demo/themes/stack/files/2014/12/122701141.jpg',
      4 => 'https://themify.me/demo/themes/stack/files/2014/12/124412803.jpg',
      5 => 'https://themify.me/demo/themes/stack/files/2014/12/134521469.jpg',
      6 => 'https://themify.me/demo/themes/stack/files/2014/12/135815177.jpg',
      7 => 'https://themify.me/demo/themes/stack/files/2014/12/156682313.jpg',
      8 => 'https://themify.me/demo/themes/stack/files/2014/12/171688262.jpg',
      9 => 'https://themify.me/demo/themes/stack/files/2014/12/175582337.jpg',
      10 => 'https://themify.me/demo/themes/stack/files/2014/12/177600644.jpg',
      11 => 'https://themify.me/demo/themes/stack/files/2014/12/205008820.jpg',
      12 => 'https://themify.me/demo/themes/stack/files/2014/12/214781395.jpg',
    ),
  ),
);
themify_process_post_import( $post );


$post = array (
  'ID' => 2739,
  'post_date' => '2014-07-29 20:31:20',
  'post_date_gmt' => '2014-07-29 20:31:20',
  'post_content' => 'Pellentesque habitant morbi tristique senectus et netus et malesuada fames ac turpis egestas. Aenean ornare euismod purus ac rhoncus. Phasellus malesuada consequat metus, a accumsan libero dapibus ut. Nunc venenatis ut libero vitae porta. Sed est turpis, pharetra nec lorem non, porttitor ullamcorper nisi.',
  'post_title' => 'Profile Photography',
  'post_excerpt' => 'Various Profile Images',
  'post_name' => 'profile-photography',
  'post_modified' => '2017-08-21 07:33:09',
  'post_modified_gmt' => '2017-08-21 07:33:09',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/stack/?post_type=portfolio&#038;p=2739',
  'menu_order' => 0,
  'post_type' => 'portfolio',
  'meta_input' => 
  array (
    'content_width' => 'default_width',
    'layout' => 'sidebar-none',
    'tile_layout' => 'size-large image-left',
    'gallery_shortcode' => '[gallery columns="6" size="medium" ids="2740,2741,2742,2743,2744,2745,2746,2747,2748,2749,2750,2751,2752"]',
    'hide_post_title' => 'default',
    'unlink_post_title' => 'default',
    'hide_post_date' => 'default',
    'hide_post_meta' => 'default',
    'hide_post_image' => 'default',
    'unlink_post_image' => 'default',
    'project_date' => 'Jan 2010',
    'project_client' => 'Magazine',
    'project_services' => 'Photo shooting, planning, and make-up',
    'project_launch' => 'https://themify.me',
    'background_color' => '#d9c06c',
    'text_color' => '#000000',
    'link_color' => '#000000',
    'builder_switch_frontend' => '0',
  ),
  'tax_input' => 
  array (
    'portfolio-category' => 'photography',
  ),
  'thumb' => 'https://themify.me/demo/themes/stack/files/2014/12/128238248.jpg',
  'gallery_shortcode' => 
  array (
    'gallery_shortcode' => 
    array (
      0 => 'https://themify.me/demo/themes/stack/files/2014/12/111005441.jpg',
      1 => 'https://themify.me/demo/themes/stack/files/2014/12/111904952.jpg',
      2 => 'https://themify.me/demo/themes/stack/files/2014/12/112231973.jpg',
      3 => 'https://themify.me/demo/themes/stack/files/2014/12/113580784.jpg',
      4 => 'https://themify.me/demo/themes/stack/files/2014/12/115719700.jpg',
      5 => 'https://themify.me/demo/themes/stack/files/2014/12/122670844.jpg',
      6 => 'https://themify.me/demo/themes/stack/files/2014/12/123528982.jpg',
      7 => 'https://themify.me/demo/themes/stack/files/2014/12/128238248.jpg',
      8 => 'https://themify.me/demo/themes/stack/files/2014/12/128912897.jpg',
      9 => 'https://themify.me/demo/themes/stack/files/2014/12/140641234.jpg',
      10 => 'https://themify.me/demo/themes/stack/files/2014/12/142569277.jpg',
      11 => 'https://themify.me/demo/themes/stack/files/2014/12/144709642.jpg',
      12 => 'https://themify.me/demo/themes/stack/files/2014/12/164096684.jpg',
    ),
  ),
);
themify_process_post_import( $post );


$post = array (
  'ID' => 2753,
  'post_date' => '2014-12-01 20:38:03',
  'post_date_gmt' => '2014-12-01 20:38:03',
  'post_content' => 'Pretium convallis, urna turpis malesuada leo, eu venenatis neque magna eget urna. Habitant morbi tristique senectus et netus et malesuada fames ac turpis egestas. Aenean ornare euismod purus ac rhoncus. Phasellus malesuada consequat metus, a accumsan libero dapibus ut. Nunc venenatis ut libero vitae porta. Sed est turpis, pharetra nec lorem non, porttitor ullamcorper nisi. Maecenas faucibus, est sed pretium convallis, urna turpis malesuada leo, eu venenatis neque magna eget urna. Pellentesque habitant morbi tristique senectus et netus et malesuada fames ac turpis egestas. Aenean ornare euismod purus ac rhoncus. Phasellus malesuada consequat metus, a accumsan libero dapibus ut. Nunc venenatis ut libero vitae porta. Sed est turpis, pharetra nec lorem non, porttitor ullamcorper nisi.',
  'post_title' => 'Retro',
  'post_excerpt' => 'Old School Styles',
  'post_name' => 'retro',
  'post_modified' => '2017-08-21 07:33:24',
  'post_modified_gmt' => '2017-08-21 07:33:24',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/stack/?post_type=portfolio&#038;p=2753',
  'menu_order' => 0,
  'post_type' => 'portfolio',
  'meta_input' => 
  array (
    'content_width' => 'default_width',
    'layout' => 'sidebar-none',
    'tile_layout' => 'size-small image-left',
    'gallery_shortcode' => '[gallery columns="4" size="full" ids="2754,2755,2756,2757,2758,2759,2760,2761,2762,2763"]',
    'hide_post_title' => 'default',
    'unlink_post_title' => 'default',
    'hide_post_date' => 'default',
    'hide_post_meta' => 'default',
    'hide_post_image' => 'default',
    'unlink_post_image' => 'default',
    'project_date' => 'Jan 2010',
    'project_client' => 'Magazine',
    'project_services' => 'Photo shooting, planning, and make-up',
    'project_launch' => 'https://themify.me',
    'background_color' => '#807952',
    'text_color' => '#ffffff',
    'link_color' => '#ffffff',
    'builder_switch_frontend' => '0',
  ),
  'tax_input' => 
  array (
    'portfolio-category' => 'fashion',
  ),
  'thumb' => 'https://themify.me/demo/themes/stack/files/2014/12/122608266.jpg',
  'gallery_shortcode' => 
  array (
    'gallery_shortcode' => 
    array (
      0 => 'https://themify.me/demo/themes/stack/files/2014/12/87451673.jpg',
      1 => 'https://themify.me/demo/themes/stack/files/2014/12/89306323.jpg',
      2 => 'https://themify.me/demo/themes/stack/files/2014/12/106387560.jpg',
      3 => 'https://themify.me/demo/themes/stack/files/2014/12/106393937.jpg',
      4 => 'https://themify.me/demo/themes/stack/files/2014/12/122608266.jpg',
      5 => 'https://themify.me/demo/themes/stack/files/2014/12/137845756.jpg',
      6 => 'https://themify.me/demo/themes/stack/files/2014/12/146025176.jpg',
      7 => 'https://themify.me/demo/themes/stack/files/2014/12/146724730.jpg',
      8 => 'https://themify.me/demo/themes/stack/files/2014/12/146742842.jpg',
      9 => 'https://themify.me/demo/themes/stack/files/2014/12/147293620.jpg',
    ),
  ),
);
themify_process_post_import( $post );


$post = array (
  'ID' => 2764,
  'post_date' => '2014-07-01 20:43:28',
  'post_date_gmt' => '2014-07-01 20:43:28',
  'post_content' => 'Morbi tristique senectus et netus et malesuada fames ac turpis egestas. Aenean ornare euismod purus ac rhoncus. Phasellus malesuada consequat metus, a accumsan libero dapibus ut.',
  'post_title' => 'Animal Love',
  'post_excerpt' => 'Animal photos',
  'post_name' => 'animal-love',
  'post_modified' => '2017-08-21 07:33:14',
  'post_modified_gmt' => '2017-08-21 07:33:14',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/stack/?post_type=portfolio&#038;p=2764',
  'menu_order' => 0,
  'post_type' => 'portfolio',
  'meta_input' => 
  array (
    'content_width' => 'default_width',
    'layout' => 'sidebar-none',
    'tile_layout' => 'size-small image-right',
    'gallery_shortcode' => '[gallery columns="4" size="full" ids="2765,2766,2767,2768,2769,2770,2771,2772,2773,2774,2775,2776"]',
    'hide_post_title' => 'default',
    'unlink_post_title' => 'default',
    'hide_post_date' => 'default',
    'hide_post_meta' => 'default',
    'hide_post_image' => 'default',
    'unlink_post_image' => 'default',
    'project_date' => 'December 2012',
    'project_client' => 'Animal Mag',
    'project_services' => 'Photo shoot, creative directing',
    'project_launch' => 'https://themify.me',
    'background_color' => '#2dad46',
    'text_color' => '#ffffff',
    'link_color' => '#ffffff',
    'builder_switch_frontend' => '0',
  ),
  'tax_input' => 
  array (
    'portfolio-category' => 'photography',
  ),
  'thumb' => 'https://themify.me/demo/themes/stack/files/2014/12/115532547.jpg',
  'gallery_shortcode' => 
  array (
    'gallery_shortcode' => 
    array (
      0 => 'https://themify.me/demo/themes/stack/files/2014/12/86523757.jpg',
      1 => 'https://themify.me/demo/themes/stack/files/2014/12/86525557.jpg',
      2 => 'https://themify.me/demo/themes/stack/files/2014/12/86536350.jpg',
      3 => 'https://themify.me/demo/themes/stack/files/2014/12/86542749.jpg',
      4 => 'https://themify.me/demo/themes/stack/files/2014/12/115532547.jpg',
      5 => 'https://themify.me/demo/themes/stack/files/2014/12/126524306.jpg',
      6 => 'https://themify.me/demo/themes/stack/files/2014/12/126808831.jpg',
      7 => 'https://themify.me/demo/themes/stack/files/2014/12/134180419.jpg',
      8 => 'https://themify.me/demo/themes/stack/files/2014/12/149091904.jpg',
      9 => 'https://themify.me/demo/themes/stack/files/2014/12/200459997-001.jpg',
      10 => 'https://themify.me/demo/themes/stack/files/2014/12/moi.jpg',
      11 => 'https://themify.me/demo/themes/stack/files/2014/12/rocky.jpg',
    ),
  ),
);
themify_process_post_import( $post );


$post = array (
  'ID' => 2854,
  'post_date' => '2015-01-04 21:10:59',
  'post_date_gmt' => '2015-01-04 21:10:59',
  'post_content' => ' ',
  'post_title' => '',
  'post_excerpt' => '',
  'post_name' => '2854',
  'post_modified' => '2015-01-04 21:14:07',
  'post_modified_gmt' => '2015-01-04 21:14:07',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/stack/?p=2854',
  'menu_order' => 1,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '0',
    '_menu_item_object_id' => '2380',
    '_menu_item_object' => 'page',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'main-navigation',
  ),
);
themify_process_post_import( $post );


$post = array (
  'ID' => 3005,
  'post_date' => '2015-03-13 21:45:31',
  'post_date_gmt' => '2015-03-13 21:45:31',
  'post_content' => ' ',
  'post_title' => '',
  'post_excerpt' => '',
  'post_name' => '3005',
  'post_modified' => '2016-02-29 18:35:33',
  'post_modified_gmt' => '2016-02-29 18:35:33',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/stack/?p=3005',
  'menu_order' => 1,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '0',
    '_menu_item_object_id' => '2981',
    '_menu_item_object' => 'page',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
    '_menu_item_icon' => 'fa-home',
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'main-nav',
  ),
);
themify_process_post_import( $post );


$post = array (
  'ID' => 2655,
  'post_date' => '2014-12-28 10:11:43',
  'post_date_gmt' => '2014-12-28 10:11:43',
  'post_content' => ' ',
  'post_title' => '',
  'post_excerpt' => '',
  'post_name' => '2655',
  'post_modified' => '2016-02-29 18:35:33',
  'post_modified_gmt' => '2016-02-29 18:35:33',
  'post_content_filtered' => '',
  'post_parent' => 2981,
  'guid' => 'https://themify.me/demo/themes/stack/?p=2655',
  'menu_order' => 2,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '3005',
    '_menu_item_object_id' => '2380',
    '_menu_item_object' => 'page',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'main-nav',
  ),
);
themify_process_post_import( $post );


$post = array (
  'ID' => 2855,
  'post_date' => '2015-01-04 21:10:59',
  'post_date_gmt' => '2015-01-04 21:10:59',
  'post_content' => ' ',
  'post_title' => '',
  'post_excerpt' => '',
  'post_name' => '2855',
  'post_modified' => '2015-01-04 21:14:07',
  'post_modified_gmt' => '2015-01-04 21:14:07',
  'post_content_filtered' => '',
  'post_parent' => 2380,
  'guid' => 'https://themify.me/demo/themes/stack/?p=2855',
  'menu_order' => 2,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '2854',
    '_menu_item_object_id' => '2779',
    '_menu_item_object' => 'page',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'main-navigation',
  ),
);
themify_process_post_import( $post );


$post = array (
  'ID' => 2856,
  'post_date' => '2015-01-04 21:10:59',
  'post_date_gmt' => '2015-01-04 21:10:59',
  'post_content' => ' ',
  'post_title' => '',
  'post_excerpt' => '',
  'post_name' => '2856',
  'post_modified' => '2015-01-04 21:14:07',
  'post_modified_gmt' => '2015-01-04 21:14:07',
  'post_content_filtered' => '',
  'post_parent' => 2380,
  'guid' => 'https://themify.me/demo/themes/stack/?p=2856',
  'menu_order' => 3,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '2854',
    '_menu_item_object_id' => '2808',
    '_menu_item_object' => 'page',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'main-navigation',
  ),
);
themify_process_post_import( $post );


$post = array (
  'ID' => 2873,
  'post_date' => '2015-01-04 21:32:04',
  'post_date_gmt' => '2015-01-04 21:32:04',
  'post_content' => ' ',
  'post_title' => '',
  'post_excerpt' => '',
  'post_name' => '2873',
  'post_modified' => '2016-02-29 18:35:33',
  'post_modified_gmt' => '2016-02-29 18:35:33',
  'post_content_filtered' => '',
  'post_parent' => 2981,
  'guid' => 'https://themify.me/demo/themes/stack/?p=2873',
  'menu_order' => 3,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '3005',
    '_menu_item_object_id' => '2779',
    '_menu_item_object' => 'page',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'main-nav',
  ),
);
themify_process_post_import( $post );


$post = array (
  'ID' => 2857,
  'post_date' => '2015-01-04 21:10:59',
  'post_date_gmt' => '2015-01-04 21:10:59',
  'post_content' => ' ',
  'post_title' => '',
  'post_excerpt' => '',
  'post_name' => '2857',
  'post_modified' => '2015-01-04 21:14:07',
  'post_modified_gmt' => '2015-01-04 21:14:07',
  'post_content_filtered' => '',
  'post_parent' => 2380,
  'guid' => 'https://themify.me/demo/themes/stack/?p=2857',
  'menu_order' => 4,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '2854',
    '_menu_item_object_id' => '2810',
    '_menu_item_object' => 'page',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'main-navigation',
  ),
);
themify_process_post_import( $post );


$post = array (
  'ID' => 2872,
  'post_date' => '2015-01-04 21:32:04',
  'post_date_gmt' => '2015-01-04 21:32:04',
  'post_content' => ' ',
  'post_title' => '',
  'post_excerpt' => '',
  'post_name' => '2872',
  'post_modified' => '2016-02-29 18:35:33',
  'post_modified_gmt' => '2016-02-29 18:35:33',
  'post_content_filtered' => '',
  'post_parent' => 2981,
  'guid' => 'https://themify.me/demo/themes/stack/?p=2872',
  'menu_order' => 4,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '3005',
    '_menu_item_object_id' => '2808',
    '_menu_item_object' => 'page',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'main-nav',
  ),
);
themify_process_post_import( $post );


$post = array (
  'ID' => 2858,
  'post_date' => '2015-01-04 21:10:59',
  'post_date_gmt' => '2015-01-04 21:10:59',
  'post_content' => ' ',
  'post_title' => '',
  'post_excerpt' => '',
  'post_name' => '2858',
  'post_modified' => '2015-01-04 21:14:07',
  'post_modified_gmt' => '2015-01-04 21:14:07',
  'post_content_filtered' => '',
  'post_parent' => 2380,
  'guid' => 'https://themify.me/demo/themes/stack/?p=2858',
  'menu_order' => 5,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '2854',
    '_menu_item_object_id' => '2814',
    '_menu_item_object' => 'page',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'main-navigation',
  ),
);
themify_process_post_import( $post );


$post = array (
  'ID' => 2871,
  'post_date' => '2015-01-04 21:32:04',
  'post_date_gmt' => '2015-01-04 21:32:04',
  'post_content' => ' ',
  'post_title' => '',
  'post_excerpt' => '',
  'post_name' => '2871',
  'post_modified' => '2016-02-29 18:35:33',
  'post_modified_gmt' => '2016-02-29 18:35:33',
  'post_content_filtered' => '',
  'post_parent' => 2981,
  'guid' => 'https://themify.me/demo/themes/stack/?p=2871',
  'menu_order' => 5,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '3005',
    '_menu_item_object_id' => '2810',
    '_menu_item_object' => 'page',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'main-nav',
  ),
);
themify_process_post_import( $post );


$post = array (
  'ID' => 2861,
  'post_date' => '2015-01-04 21:10:59',
  'post_date_gmt' => '2015-01-04 21:10:59',
  'post_content' => ' ',
  'post_title' => '',
  'post_excerpt' => '',
  'post_name' => '2861',
  'post_modified' => '2015-01-04 21:14:07',
  'post_modified_gmt' => '2015-01-04 21:14:07',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/stack/?p=2861',
  'menu_order' => 6,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '0',
    '_menu_item_object_id' => '2455',
    '_menu_item_object' => 'page',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'main-navigation',
  ),
);
themify_process_post_import( $post );


$post = array (
  'ID' => 2870,
  'post_date' => '2015-01-04 21:32:04',
  'post_date_gmt' => '2015-01-04 21:32:04',
  'post_content' => ' ',
  'post_title' => '',
  'post_excerpt' => '',
  'post_name' => '2870',
  'post_modified' => '2016-02-29 18:35:33',
  'post_modified_gmt' => '2016-02-29 18:35:33',
  'post_content_filtered' => '',
  'post_parent' => 2981,
  'guid' => 'https://themify.me/demo/themes/stack/?p=2870',
  'menu_order' => 6,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '3005',
    '_menu_item_object_id' => '2814',
    '_menu_item_object' => 'page',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'main-nav',
  ),
);
themify_process_post_import( $post );


$post = array (
  'ID' => 2657,
  'post_date' => '2014-12-28 10:11:43',
  'post_date_gmt' => '2014-12-28 10:11:43',
  'post_content' => ' ',
  'post_title' => '',
  'post_excerpt' => '',
  'post_name' => '2657',
  'post_modified' => '2016-02-29 18:35:33',
  'post_modified_gmt' => '2016-02-29 18:35:33',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/stack/?p=2657',
  'menu_order' => 7,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '0',
    '_menu_item_object_id' => '2455',
    '_menu_item_object' => 'page',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
    '_menu_item_icon' => 'fa-suitcase',
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'main-nav',
  ),
);
themify_process_post_import( $post );


$post = array (
  'ID' => 2862,
  'post_date' => '2015-01-04 21:10:59',
  'post_date_gmt' => '2015-01-04 21:10:59',
  'post_content' => ' ',
  'post_title' => '',
  'post_excerpt' => '',
  'post_name' => '2862',
  'post_modified' => '2015-01-04 21:14:07',
  'post_modified_gmt' => '2015-01-04 21:14:07',
  'post_content_filtered' => '',
  'post_parent' => 2455,
  'guid' => 'https://themify.me/demo/themes/stack/?p=2862',
  'menu_order' => 7,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '2861',
    '_menu_item_object_id' => '2787',
    '_menu_item_object' => 'page',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'main-navigation',
  ),
);
themify_process_post_import( $post );


$post = array (
  'ID' => 2792,
  'post_date' => '2014-12-30 02:49:30',
  'post_date_gmt' => '2014-12-30 02:49:30',
  'post_content' => ' ',
  'post_title' => '',
  'post_excerpt' => '',
  'post_name' => '2792',
  'post_modified' => '2016-02-29 18:35:33',
  'post_modified_gmt' => '2016-02-29 18:35:33',
  'post_content_filtered' => '',
  'post_parent' => 2455,
  'guid' => 'https://themify.me/demo/themes/stack/?p=2792',
  'menu_order' => 8,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '2657',
    '_menu_item_object_id' => '2787',
    '_menu_item_object' => 'page',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'main-nav',
  ),
);
themify_process_post_import( $post );


$post = array (
  'ID' => 2863,
  'post_date' => '2015-01-04 21:10:59',
  'post_date_gmt' => '2015-01-04 21:10:59',
  'post_content' => ' ',
  'post_title' => '',
  'post_excerpt' => '',
  'post_name' => '2863',
  'post_modified' => '2015-01-04 21:14:07',
  'post_modified_gmt' => '2015-01-04 21:14:07',
  'post_content_filtered' => '',
  'post_parent' => 2455,
  'guid' => 'https://themify.me/demo/themes/stack/?p=2863',
  'menu_order' => 8,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '2861',
    '_menu_item_object_id' => '2782',
    '_menu_item_object' => 'page',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'main-navigation',
  ),
);
themify_process_post_import( $post );


$post = array (
  'ID' => 2793,
  'post_date' => '2014-12-30 02:49:30',
  'post_date_gmt' => '2014-12-30 02:49:30',
  'post_content' => ' ',
  'post_title' => '',
  'post_excerpt' => '',
  'post_name' => '2793',
  'post_modified' => '2016-02-29 18:35:33',
  'post_modified_gmt' => '2016-02-29 18:35:33',
  'post_content_filtered' => '',
  'post_parent' => 2455,
  'guid' => 'https://themify.me/demo/themes/stack/?p=2793',
  'menu_order' => 9,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '2657',
    '_menu_item_object_id' => '2782',
    '_menu_item_object' => 'page',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'main-nav',
  ),
);
themify_process_post_import( $post );


$post = array (
  'ID' => 2864,
  'post_date' => '2015-01-04 21:10:59',
  'post_date_gmt' => '2015-01-04 21:10:59',
  'post_content' => ' ',
  'post_title' => '',
  'post_excerpt' => '',
  'post_name' => '2864',
  'post_modified' => '2015-01-04 21:14:07',
  'post_modified_gmt' => '2015-01-04 21:14:07',
  'post_content_filtered' => '',
  'post_parent' => 2455,
  'guid' => 'https://themify.me/demo/themes/stack/?p=2864',
  'menu_order' => 9,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '2861',
    '_menu_item_object_id' => '2785',
    '_menu_item_object' => 'page',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'main-navigation',
  ),
);
themify_process_post_import( $post );


$post = array (
  'ID' => 2794,
  'post_date' => '2014-12-30 02:49:30',
  'post_date_gmt' => '2014-12-30 02:49:30',
  'post_content' => ' ',
  'post_title' => '',
  'post_excerpt' => '',
  'post_name' => '2794',
  'post_modified' => '2016-02-29 18:35:33',
  'post_modified_gmt' => '2016-02-29 18:35:33',
  'post_content_filtered' => '',
  'post_parent' => 2455,
  'guid' => 'https://themify.me/demo/themes/stack/?p=2794',
  'menu_order' => 10,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '2657',
    '_menu_item_object_id' => '2785',
    '_menu_item_object' => 'page',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'main-nav',
  ),
);
themify_process_post_import( $post );


$post = array (
  'ID' => 2866,
  'post_date' => '2015-01-04 21:10:59',
  'post_date_gmt' => '2015-01-04 21:10:59',
  'post_content' => ' ',
  'post_title' => '',
  'post_excerpt' => '',
  'post_name' => '2866',
  'post_modified' => '2015-01-04 21:14:07',
  'post_modified_gmt' => '2015-01-04 21:14:07',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/stack/?p=2866',
  'menu_order' => 10,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '0',
    '_menu_item_object_id' => '2500',
    '_menu_item_object' => 'page',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'main-navigation',
  ),
);
themify_process_post_import( $post );


$post = array (
  'ID' => 2658,
  'post_date' => '2014-12-28 10:11:43',
  'post_date_gmt' => '2014-12-28 10:11:43',
  'post_content' => ' ',
  'post_title' => '',
  'post_excerpt' => '',
  'post_name' => '2658',
  'post_modified' => '2016-02-29 18:35:33',
  'post_modified_gmt' => '2016-02-29 18:35:33',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/stack/?p=2658',
  'menu_order' => 11,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '0',
    '_menu_item_object_id' => '2500',
    '_menu_item_object' => 'page',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
    '_menu_item_icon' => 'fa-comment',
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'main-nav',
  ),
);
themify_process_post_import( $post );


$post = array (
  'ID' => 2867,
  'post_date' => '2015-01-04 21:10:59',
  'post_date_gmt' => '2015-01-04 21:10:59',
  'post_content' => ' ',
  'post_title' => '',
  'post_excerpt' => '',
  'post_name' => '2867',
  'post_modified' => '2015-01-04 21:14:07',
  'post_modified_gmt' => '2015-01-04 21:14:07',
  'post_content_filtered' => '',
  'post_parent' => 2500,
  'guid' => 'https://themify.me/demo/themes/stack/?p=2867',
  'menu_order' => 11,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '2866',
    '_menu_item_object_id' => '2648',
    '_menu_item_object' => 'page',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'main-navigation',
  ),
);
themify_process_post_import( $post );


$post = array (
  'ID' => 2659,
  'post_date' => '2014-12-28 10:11:43',
  'post_date_gmt' => '2014-12-28 10:11:43',
  'post_content' => ' ',
  'post_title' => '',
  'post_excerpt' => '',
  'post_name' => '2659',
  'post_modified' => '2016-02-29 18:35:33',
  'post_modified_gmt' => '2016-02-29 18:35:33',
  'post_content_filtered' => '',
  'post_parent' => 2500,
  'guid' => 'https://themify.me/demo/themes/stack/?p=2659',
  'menu_order' => 12,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '2658',
    '_menu_item_object_id' => '2648',
    '_menu_item_object' => 'page',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'main-nav',
  ),
);
themify_process_post_import( $post );


$post = array (
  'ID' => 2868,
  'post_date' => '2015-01-04 21:10:59',
  'post_date_gmt' => '2015-01-04 21:10:59',
  'post_content' => ' ',
  'post_title' => '',
  'post_excerpt' => '',
  'post_name' => '2868',
  'post_modified' => '2015-01-04 21:14:07',
  'post_modified_gmt' => '2015-01-04 21:14:07',
  'post_content_filtered' => '',
  'post_parent' => 2500,
  'guid' => 'https://themify.me/demo/themes/stack/?p=2868',
  'menu_order' => 12,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '2866',
    '_menu_item_object_id' => '2646',
    '_menu_item_object' => 'page',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'main-navigation',
  ),
);
themify_process_post_import( $post );


$post = array (
  'ID' => 2660,
  'post_date' => '2014-12-28 10:11:43',
  'post_date_gmt' => '2014-12-28 10:11:43',
  'post_content' => ' ',
  'post_title' => '',
  'post_excerpt' => '',
  'post_name' => '2660',
  'post_modified' => '2016-02-29 18:35:33',
  'post_modified_gmt' => '2016-02-29 18:35:33',
  'post_content_filtered' => '',
  'post_parent' => 2500,
  'guid' => 'https://themify.me/demo/themes/stack/?p=2660',
  'menu_order' => 13,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '2658',
    '_menu_item_object_id' => '2646',
    '_menu_item_object' => 'page',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'main-nav',
  ),
);
themify_process_post_import( $post );


$post = array (
  'ID' => 2859,
  'post_date' => '2015-01-04 21:11:00',
  'post_date_gmt' => '2015-01-04 21:11:00',
  'post_content' => ' ',
  'post_title' => '',
  'post_excerpt' => '',
  'post_name' => '2859',
  'post_modified' => '2015-01-04 21:14:07',
  'post_modified_gmt' => '2015-01-04 21:14:07',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/stack/?p=2859',
  'menu_order' => 13,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '0',
    '_menu_item_object_id' => '2653',
    '_menu_item_object' => 'page',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'main-navigation',
  ),
);
themify_process_post_import( $post );


$post = array (
  'ID' => 2790,
  'post_date' => '2014-12-30 02:49:30',
  'post_date_gmt' => '2014-12-30 02:49:30',
  'post_content' => ' ',
  'post_title' => '',
  'post_excerpt' => '',
  'post_name' => '2790',
  'post_modified' => '2016-02-29 18:35:33',
  'post_modified_gmt' => '2016-02-29 18:35:33',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/stack/?p=2790',
  'menu_order' => 14,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '0',
    '_menu_item_object_id' => '2663',
    '_menu_item_object' => 'page',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
    '_menu_item_icon' => 'fa-shopping-cart',
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'main-nav',
  ),
);
themify_process_post_import( $post );


$post = array (
  'ID' => 2860,
  'post_date' => '2015-01-04 21:11:00',
  'post_date_gmt' => '2015-01-04 21:11:00',
  'post_content' => ' ',
  'post_title' => '',
  'post_excerpt' => '',
  'post_name' => '2860',
  'post_modified' => '2015-01-04 21:14:07',
  'post_modified_gmt' => '2015-01-04 21:14:07',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/stack/?p=2860',
  'menu_order' => 14,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '0',
    '_menu_item_object_id' => '2663',
    '_menu_item_object' => 'page',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'main-navigation',
  ),
);
themify_process_post_import( $post );


$post = array (
  'ID' => 2656,
  'post_date' => '2014-12-28 10:11:43',
  'post_date_gmt' => '2014-12-28 10:11:43',
  'post_content' => ' ',
  'post_title' => '',
  'post_excerpt' => '',
  'post_name' => '2656',
  'post_modified' => '2016-02-29 18:35:33',
  'post_modified_gmt' => '2016-02-29 18:35:33',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/stack/?p=2656',
  'menu_order' => 15,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '0',
    '_menu_item_object_id' => '2653',
    '_menu_item_object' => 'page',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
    '_menu_item_icon' => 'fa-envelope',
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'main-nav',
  ),
);
themify_process_post_import( $post );



function themify_import_get_term_id_from_slug( $slug ) {
	$menu = get_term_by( "slug", $slug, "nav_menu" );
	return is_wp_error( $menu ) ? 0 : (int) $menu->term_id;
}

	$widgets = get_option( "widget_themify-feature-posts" );
$widgets[1002] = array (
  'title' => 'Recent Posts',
  'category' => '5',
  'show_count' => '3',
  'show_date' => NULL,
  'show_thumb' => 'on',
  'display' => 'excerpt',
  'hide_title' => NULL,
  'thumb_width' => '100',
  'thumb_height' => '100',
  'excerpt_length' => '55',
  'orderby' => 'date',
  'order' => 'DESC',
);
update_option( "widget_themify-feature-posts", $widgets );

$widgets = get_option( "widget_themify-twitter" );
$widgets[1003] = array (
  'title' => 'Latest Tweets',
  'username' => 'themify',
  'show_count' => '3',
  'hide_timestamp' => NULL,
  'show_follow' => NULL,
  'follow_text' => '→ Follow me',
  'include_retweets' => 'on',
  'exclude_replies' => 'on',
);
update_option( "widget_themify-twitter", $widgets );

$widgets = get_option( "widget_themify-social-links" );
$widgets[1004] = array (
  'title' => '',
  'show_link_name' => NULL,
  'open_new_window' => NULL,
  'icon_size' => 'icon-medium',
  'orientation' => 'horizontal',
);
update_option( "widget_themify-social-links", $widgets );

$widgets = get_option( "widget_themify-twitter" );
$widgets[1005] = array (
  'title' => 'Latest Tweets',
  'username' => 'themify',
  'show_count' => '3',
  'hide_timestamp' => NULL,
  'show_follow' => NULL,
  'follow_text' => '→ Follow me',
  'include_retweets' => NULL,
  'exclude_replies' => NULL,
);
update_option( "widget_themify-twitter", $widgets );



$sidebars_widgets = array (
  'sidebar-main' => 
  array (
    0 => 'themify-feature-posts-1002',
    1 => 'themify-twitter-1003',
  ),
  'social-widget' => 
  array (
    0 => 'themify-social-links-1004',
  ),
  'header-widget' => 
  array (
    0 => 'themify-twitter-1005',
  ),
); 
update_option( "sidebars_widgets", $sidebars_widgets );

$menu_locations = array();
$menu = get_terms( "nav_menu", array( "slug" => "main-nav" ) );
if( is_array( $menu ) && ! empty( $menu ) ) $menu_locations["main-nav"] = $menu[0]->term_id;
set_theme_mod( "nav_menu_locations", $menu_locations );


$homepage = get_posts( array( 'name' => 'home', 'post_type' => 'page' ) );
			if( is_array( $homepage ) && ! empty( $homepage ) ) {
				update_option( 'show_on_front', 'page' );
				update_option( 'page_on_front', $homepage[0]->ID );
			}
			
	ob_start(); ?>a:78:{s:21:"setting-webfonts_list";s:11:"recommended";s:22:"setting-default_layout";s:12:"sidebar-none";s:27:"setting-default_post_layout";s:5:"grid3";s:23:"setting-disable_masonry";s:3:"yes";s:30:"setting-default_layout_display";s:7:"excerpt";s:25:"setting-default_more_text";s:4:"More";s:21:"setting-index_orderby";s:4:"date";s:19:"setting-index_order";s:4:"DESC";s:31:"setting-image_post_feature_size";s:5:"blank";s:32:"setting-default_page_post_layout";s:8:"sidebar1";s:38:"setting-image_post_single_feature_size";s:5:"blank";s:27:"setting-default_page_layout";s:12:"sidebar-none";s:38:"setting-default_portfolio_index_layout";s:12:"sidebar-none";s:43:"setting-default_portfolio_index_post_layout";s:5:"grid4";s:33:"setting-portfolio_disable_masonry";s:3:"yes";s:39:"setting-default_portfolio_index_display";s:4:"none";s:42:"setting-default_portfolio_index_post_image";s:3:"yes";s:49:"setting-default_portfolio_index_unlink_post_image";s:3:"yes";s:39:"setting-default_portfolio_single_layout";s:12:"sidebar-none";s:43:"setting-default_portfolio_single_post_image";s:3:"yes";s:50:"setting-default_portfolio_single_unlink_post_image";s:3:"yes";s:22:"themify_portfolio_slug";s:7:"project";s:31:"setting-product_disable_masonry";s:3:"yes";s:34:"setting-product_archive_hide_image";s:3:"yes";s:34:"setting-product_archive_hide_title";s:3:"yes";s:34:"setting-product_archive_hide_price";s:3:"yes";s:35:"setting-product_archive_hide_rating";s:3:"yes";s:40:"setting-product_archive_hide_add_to_cart";s:3:"yes";s:53:"setting-customizer_responsive_design_tablet_landscape";s:4:"1024";s:43:"setting-customizer_responsive_design_tablet";s:3:"768";s:43:"setting-customizer_responsive_design_mobile";s:3:"480";s:33:"setting-mobile_menu_trigger_point";s:4:"1200";s:24:"setting-gallery_lightbox";s:8:"lightbox";s:27:"setting-page_builder_expiry";s:1:"2";s:19:"setting-entries_nav";s:8:"numbered";s:18:"setting-more_posts";s:8:"infinite";s:22:"setting-footer_widgets";s:17:"footerwidget-3col";s:25:"setting-img_php_base_size";s:5:"large";s:27:"setting-global_feature_size";s:5:"blank";s:22:"setting-link_icon_type";s:9:"font-icon";s:32:"setting-link_type_themify-link-0";s:10:"image-icon";s:33:"setting-link_title_themify-link-0";s:7:"Twitter";s:31:"setting-link_img_themify-link-0";s:87:"https://themify.me/demo/themes/stack/wp-content/themes/themify-stack/images/twitter.png";s:32:"setting-link_type_themify-link-1";s:10:"image-icon";s:33:"setting-link_title_themify-link-1";s:8:"Facebook";s:31:"setting-link_img_themify-link-1";s:88:"https://themify.me/demo/themes/stack/wp-content/themes/themify-stack/images/facebook.png";s:32:"setting-link_type_themify-link-2";s:10:"image-icon";s:33:"setting-link_title_themify-link-2";s:6:"Google";s:31:"setting-link_img_themify-link-2";s:91:"https://themify.me/demo/themes/stack/wp-content/themes/themify-stack/images/google-plus.png";s:32:"setting-link_type_themify-link-3";s:10:"image-icon";s:33:"setting-link_title_themify-link-3";s:7:"YouTube";s:31:"setting-link_img_themify-link-3";s:87:"https://themify.me/demo/themes/stack/wp-content/themes/themify-stack/images/youtube.png";s:32:"setting-link_type_themify-link-4";s:10:"image-icon";s:33:"setting-link_title_themify-link-4";s:9:"Pinterest";s:31:"setting-link_img_themify-link-4";s:89:"https://themify.me/demo/themes/stack/wp-content/themes/themify-stack/images/pinterest.png";s:32:"setting-link_type_themify-link-5";s:9:"font-icon";s:33:"setting-link_title_themify-link-5";s:7:"Twitter";s:32:"setting-link_link_themify-link-5";s:26:"http://twitter.com/themify";s:33:"setting-link_ficon_themify-link-5";s:10:"fa-twitter";s:32:"setting-link_type_themify-link-6";s:9:"font-icon";s:33:"setting-link_title_themify-link-6";s:8:"Facebook";s:32:"setting-link_link_themify-link-6";s:27:"http://facebook.com/themify";s:33:"setting-link_ficon_themify-link-6";s:11:"fa-facebook";s:32:"setting-link_type_themify-link-7";s:9:"font-icon";s:33:"setting-link_title_themify-link-7";s:6:"Google";s:33:"setting-link_ficon_themify-link-7";s:14:"fa-google-plus";s:32:"setting-link_type_themify-link-8";s:9:"font-icon";s:33:"setting-link_title_themify-link-8";s:7:"YouTube";s:32:"setting-link_link_themify-link-8";s:38:"https://www.youtube.com/user/themifyme";s:33:"setting-link_ficon_themify-link-8";s:10:"fa-youtube";s:32:"setting-link_type_themify-link-9";s:9:"font-icon";s:33:"setting-link_title_themify-link-9";s:9:"Pinterest";s:33:"setting-link_ficon_themify-link-9";s:12:"fa-pinterest";s:22:"setting-link_field_ids";s:341:"{"themify-link-0":"themify-link-0","themify-link-1":"themify-link-1","themify-link-2":"themify-link-2","themify-link-3":"themify-link-3","themify-link-4":"themify-link-4","themify-link-5":"themify-link-5","themify-link-6":"themify-link-6","themify-link-7":"themify-link-7","themify-link-8":"themify-link-8","themify-link-9":"themify-link-9"}";s:23:"setting-link_field_hash";s:2:"11";s:30:"setting-page_builder_is_active";s:6:"enable";s:46:"setting-page_builder_animation_parallax_scroll";s:6:"mobile";s:4:"skin";s:86:"https://themify.me/demo/themes/stack/wp-content/themes/themify-stack/skins/0/style.css";}<?php $themify_data = unserialize( ob_get_clean() );

	// fix the weird way "skin" is saved
	if( isset( $themify_data['skin'] ) ) {
		$parsed_skin = parse_url( $themify_data['skin'], PHP_URL_PATH );
		$basedir_skin = basename( dirname( $parsed_skin ) );
		$themify_data['skin'] = trailingslashit( get_template_directory_uri() ) . 'skins/' . $basedir_skin . '/style.css';
	}

	themify_set_data( $themify_data );
	
}
themify_do_demo_import();